/*!
*  filename: ej.widget.all.dark.js
*  version : 12.2.0.42
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/

window.ej = window.Syncfusion = window.Syncfusion || {};

(function ($, ej, undefined) {
    'use strict';

    ej.consts = {
        NamespaceJoin: '-'
    };
    ej.TextAlign = {
        Center: 'center',
        Justify: 'justify',
        Left: 'left',
        Right: 'right'
    };
    ej.Orientation = { Horizontal: "horizontal", Vertical: "vertical" };

    if (!Object.prototype.hasOwnProperty) {
        Object.prototype.hasOwnProperty = function (obj, prop) {
            return obj[prop] !== undefined;
        };
    }

    String.format = function () {
        var source = arguments[0];
        for (var i = 0; i < arguments.length - 1; i++)
            source = source.replace(new RegExp("\\{" + i + "\\}", "gm"), arguments[i + 1]);

        source = source.replace(/\{[0-9]\}/g, "");
        return source;
    };

    // Function to create new class
    ej.defineClass = function (className, constructor, proto, replace) {
        /// <summary>Creates the javascript class with given namespace & class name & constructor etc</summary>
        /// <param name="className" type="String">class name prefixed with namespace</param>
        /// <param name="constructor" type="Function">constructor function</param>
        /// <param name="proto" type="Object">prototype for the class</param>
        /// <param name="replace" type="Boolean">[Optional]Replace existing class if exists</param>
        /// <returns type="Function">returns the class function</returns>
        if (!className || !proto) return undefined;

        var parts = className.split(".");

        // Object creation
        var obj = window, i = 0;
        for (; i < parts.length - 1; i++) {

            if (ej.isNullOrUndefined(obj[parts[i]]))
                obj[parts[i]] = {};

            obj = obj[parts[i]];
        }

        if (replace || ej.isNullOrUndefined(obj[parts[i]])) {

            //constructor
            constructor = typeof constructor === "function" ? constructor : function () {
            };

            obj[parts[i]] = constructor;

            // prototype
            obj[parts[i]].prototype = proto;
        }

        return obj[parts[i]];
    };

    ej.util = {
        getNameSpace: function (className) {
            /// <summary>Internal function, this will create namespace for plugins using class name</summary>
            /// <param name="className" type="String"></param>
            /// <returns type="String"></returns>
            var splits = className.toLowerCase().split(".");
            splits[0] === "ej" && (splits[0] = "e");

            return splits.join(ej.consts.NamespaceJoin);
        },

        getObject: function (nameSpace, from) {
            if (!from) return undefined;

            var value = from, splits = nameSpace.split('.');

            for (var i = 0; i < splits.length; i++) {

                if (ej.util.isNullOrUndefined(value)) break;

                value = value[splits[i]];
            }

            return value;
        },

        createObject: function (nameSpace, value, initIn) {
            var splits = nameSpace.split('.'), start = initIn || window, from = start, i;

            for (i = 0; i < splits.length; i++) {

                if (i + 1 == splits.length)
                    from[splits[i]] = ej.isNullOrUndefined(value) ? {} : value;
                else if (ej.isNullOrUndefined(from[splits[i]]))
                    from[splits[i]] = {};

                from = from[splits[i]];
            }

            return start;
        },

        isNullOrUndefined: function (value) {
            /// <summary>Util to check null or undefined</summary>
            /// <param name="value" type="Object"></param>
            /// <returns type="Boolean"></returns>
            return value === undefined || value === null;
        },

        buildTag: function (tag, innerHtml, styles, attrs) {
            /// <summary>Helper to build jQuery element</summary>
            /// <param name="tag" type="String">tagName#id.cssClass</param>
            /// <param name="innerHtml" type="String"></param>
            /// <param name="styles" type="Object">A set of key/value pairs that configure styles</param>
            /// <param name="attrs" type="Object">A set of key/value pairs that configure attributes</param>
            /// <returns type="jQuery"></returns>
            var tagName = /^[a-z]*[0-9a-z]+/ig.exec(tag)[0];

            var id = /#([a-z]+[-_0-9a-z]+)/ig.exec(tag);
            id = id ? id[id.length - 1] : undefined;

            var className = /\.([a-z]+[-_0-9a-z ]+)/ig.exec(tag);
            className = className ? className[className.length - 1] : undefined;

            return $(document.createElement(tagName))
                .attr(id ? { "id": id } : {})
                .addClass(className || "")
                .css(styles || {})
                .attr(attrs || {})
                .html(innerHtml || "");
        }
    };

    $.extend(ej, ej.util);

    // base class for all ej widgets. It will automatically inhertied
    ej.widgetBase = {
        droppables: { 'default': [] },
        resizables: { 'default': [] },

        destroy: function () {

            if (this._trigger("destroy"))
                return;

            if (this.model.enablePersistence)
                this.persistState();

            try {
                this._destroy();
            } catch (e) { }

            var arr = this.element.data("ejWidgets") || [];
            for (var i = 0; i < arr.length; i++) {
                if (arr[i] == this.pluginName) {
                    arr.splice(i, 1);
                }
            }
            if (!arr.length)
                this.element.removeData("ejWidgets");

            while (this._events) {
                var item = this._events.pop(), args = [];

                if (!item)
                    break;

                for (var i = 0; i < item[1].length; i++)
                    if (!$.isPlainObject(item[1][i]))
                        args.push(item[1][i]);

                $.fn.off.apply(item[0], args);
            }

            this._events = null;

            this.element
                .removeClass(ej.util.getNameSpace(this.sfType))
                .removeClass("e-js")
                .removeData(this.pluginName);

            this.element = null;
            this.model = null;
        },

        _on: function (element) {
            if (!this._events)
                this._events = [];
            var args = [].splice.call(arguments, 1, arguments.length - 1);

            var handler = {}, i = args.length;
            while (handler && typeof handler !== "function") {
                handler = args[--i];
            }

            args[i] = ej.proxy(args[i], this);

            this._events.push([element, args, handler, args[i]]);

            $.fn.on.apply(element, args);

            return this;
        },

        _off: function (element, eventName, selector, handlerObject) {
            var e = this._events, temp;
            if (!e || !e.length)
                return this;
            if (typeof selector == "function") {
                temp = handlerObject;
                handlerObject = selector;
                selector = temp;
            }
            for (var i = 0; i < e.length; i++) {
                var arg = e[i],
                r = arg[0].length && (!handlerObject || arg[2] === handlerObject) && arg[1][0] === eventName && (!selector || arg[1][1] === selector) && $.inArray(element[0], arg[0]) > -1;
                if (r) {
                    $.fn.off.apply(element, handlerObject ? [eventName, selector, arg[3]] : [eventName, selector]);
                    e.splice(i, 1);
                    break;
                }
            }

            return this;
        },

        // Client side events wire-up / trigger helper.
        _trigger: function (eventName, eventProp) {
            var fn = this.model[eventName], returnValue, args, clientProp = {};
            $.extend(clientProp, eventProp)

            if (fn) {
                if (typeof fn === "string") {
                    fn = ej.util.getObject(fn, window);
                }

                if ($.isFunction(fn)) {

                    args = ej.event(eventName, this.model, eventProp);

                    returnValue = fn.call(this, args);

                    // sending changes back - deep copy option should not be enabled for this $.extend 
                    if (eventProp) $.extend(eventProp, args);

                    if (args.cancel || !ej.isNullOrUndefined(returnValue))
                        return returnValue === false || args.cancel;
                }
            }

            var isPropDefined = Boolean(eventProp);
            eventProp = eventProp || {};
            eventProp.originalEventType = eventName;
            eventProp.type = this.pluginName + eventName;

            args = $.Event(eventProp.type, ej.event(eventProp.type, this.model, eventProp));

            this.element.trigger(args);

            // sending changes back - deep copy option should not be enabled for this $.extend 
            if (isPropDefined) $.extend(eventProp, args);

            if (ej.isOnWebForms && args.cancel == false && this.model.serverEvents && this.model.serverEvents.length)
                ej.raiseWebFormsServerEvents(eventName, eventProp, clientProp);

            return args.cancel;
        },

        setModel: function (options, forceSet) {
            // check for whether to apply values are not. if _setModel function is defined in child,
            //  this will call that function and validate it using return value

            if (this._trigger("modelChange", { "changes": options }))
                return;


            for (var prop in options) {
                if (!forceSet) {
                    if (this.model[prop] === options[prop]) {
                        delete options[prop];
                        continue;
                    }
                    if ($.isPlainObject(options[prop])) {
                        iterateAndRemoveProps(this.model[prop], options[prop]);
                        if ($.isEmptyObject(options[prop]))
                            continue;
                    }
                }

                if (this.dataTypes) {
                    var returnValue = this._isValidModelValue(prop, this.dataTypes, options);
                    if (returnValue !== true)
                        throw "setModel - Invalid input for property :" + prop + " - " + returnValue;
                }
                if (this.model.notifyOnEachPropertyChanges && this.model[prop] !== options[prop]) {
                    var arg = {
                        oldValue: this.model[prop],
                        newValue: options[prop]
                    };

                    options[prop] = this._trigger(prop + "Change", arg) ? this.model[prop] : arg.newValue;
                }
            }
            if ($.isEmptyObject(options))
                return;

            if (this._setFirst) {
                var ds = options.dataSource;
                if (ds) delete options.dataSource

                $.extend(true, this.model, options);
                if (ds) {
                    this.model.dataSource = (ds instanceof Array) ? ds.slice() : ds;
                    options["dataSource"] = this.model.dataSource;
                }
                !this._setModel || this._setModel(options);

            } else if (!this._setModel || this._setModel(options) !== false) {
                $.extend(true, this.model, options);
            }
            if ("enablePersistence" in options) {
                if (options.enablePersistence === true) {
                    this._persistHandler = ej.proxy(this.persistState, this);
                    $(window).on("unload", this._persistHandler);
                } else {
                    $(window).off("unload", this._persistHandler);
                }
            }
        },

        option: function (prop, value, forceSet) {
            if (!prop)
                return this.model;

            if ($.isPlainObject(prop))
                return this.setModel(prop);

            if (typeof prop === "string") {
                prop = prop.replace(/^model\./, "");
                var oldValue = ej.getObject(prop, this.model);

                if (value === undefined)
                    return oldValue;

                if (forceSet && value === ej.extensions.modelGUID) {
                    return this._setModel(ej.createObject(prop, ej.getObject(prop, this.model), {}));
                }

                if (forceSet || ej.getObject(prop, this.model) !== value)
                    return this.setModel(ej.createObject(prop, value, {}), forceSet);
            }
            return undefined;
        },

        _isValidModelValue: function (prop, types, options) {
            var value = types[prop], option = options[prop], returnValue;

            if (!value)
                return true;

            if (typeof value === "string") {
                if (value == "enum") {
                    options[prop] = option ? option.toString().toLowerCase() : option;
                    value = "string";
                }

                if (value === "array") {
                    if (option instanceof Array)
                        return true;
                }
                else if (value === "data") {
                    return true;
                }
                else if (typeof option === value)
                    return true;

                return "Expected type - " + value;
            }

            if (option instanceof Array) {
                for (var i = 0; i < option.length; i++) {
                    returnValue = this._isValidModelValue(prop, types, option[i]);
                    if (returnValue !== true) {
                        return " [" + i + "] - " + returnValue;
                    }
                }
                return true;
            }

            for (var innerProp in option) {
                returnValue = this._isValidModelValue(innerProp, value, option);
                if (returnValue !== true)
                    return innerProp + " : " + returnValue;
            }

            return true;
        },

        persistState: function () {
            var model = copyObject({}, this.model);

            if (this._ignoreOnPersist) {
                for (var i = 0; i < this._ignoreOnPersist; i++) {
                    delete model[this._ignoreOnPersist[i]];
                }
            }

            if (this._persistState) {
                model.customPersists = {};
                this._persistState(model.customPersists);
            }

            if (window.localStorage)
                window.localStorage.setItem(this.pluginName + this._id, JSON.stringify(model));
            else if (document.cookie)
                ej.cookie.set(this.pluginName + this._id, model);
        },

        restoreState: function (silent) {
            var value = null;
            if (window.localStorage)
                value = window.localStorage.getItem(this.pluginName + this._id);
            else if (document.cookie)
                value = ej.cookie.get(this.pluginName + this._id);

            if (value) {
                var model = JSON.parse(value);

                if (this._restoreState) {
                    this._restoreState(model.customPersists);
                    delete model.customPersists;
                }

                this.model = $.extend(true, this.model, model);
            }

            if (!silent && value && this._setModel)
                this._setModel(this.model);
        }
    };

    var iterateAndRemoveProps = function (source, target) {
        for (var prop in source) {
            if (source[prop] === target[prop])
                delete target[prop];
            if ($.isPlainObject(target[prop]) && $.isPlainObject(source[prop]))
                iterateAndRemoveProps(source[prop], target[prop]);
        }
    }

    ej.widget = function (pluginName, className, proto) {
        /// <summary>Widget helper for developers, this set have predefined function to jQuery plug-ins</summary>
        /// <param name="pluginName" type="String">the plugin name that will be added in jquery.fn</param>
        /// <param name="className" type="String">the class name for your plugin, this will help create default cssClas</param>
        /// <param name="proto" type="Object">prototype for of the plug-in</param>

        if (typeof pluginName === "object") {
            proto = className;
            for (var prop in pluginName) {
                var name = pluginName[prop];

                if (name instanceof Array) {
                    proto._rootCSS = name[1];
                    name = name[0];
                }

                ej.widget(prop, name, proto);

                if (pluginName[prop] instanceof Array)
                    proto._rootCSS = "";
            }

            return;
        }

        var nameSpace = proto._rootCSS || ej.getNameSpace(className);

        proto = ej.defineClass(className, function (element, options) {

            this.sfType = className;
            this.pluginName = pluginName;
            this.instance = pInstance;

            if (ej.isNullOrUndefined(this._setFirst))
                this._setFirst = true;

            this["ob.values"] = {};

            $.extend(this, ej.widgetBase);

            if (this.dataTypes) {
                for (var property in options) {
                    var returnValue = this._isValidModelValue(property, this.dataTypes, options);
                    if (returnValue !== true)
                        throw "setModel - Invalid input for property :" + property + " - " + returnValue;
                }
            }

            var arr = (element.data("ejWidgets") || []);
            arr.push(pluginName);
            element.data("ejWidgets", arr);

            for (var i = 0; ej.widget.observables && this.observables && i < this.observables.length; i++) {
                var t = ej.getObject(this.observables[i], options);
                if (t) ej.createObject(this.observables[i], ej.widget.observables.register(t, this.observables[i], this, element), options);
            }

            this.element = element.jquery ? element : $(element);
            this.model = copyObject(true, {}, proto.prototype.defaults, options);
            this.model.keyConfigs = copyObject(this.keyConfigs);
			
			this.element.addClass(nameSpace + " e-js").data(pluginName, this);

            this._id = element[0].id;

            if (!this.element.attr("tabIndex"))
                this.element.attr("tabIndex", "");

            if (this.model.enablePersistence) {
                this._persistHandler = ej.proxy(this.persistState, this);
                $(window).on("unload", this._persistHandler);
                this.restoreState(true);
            }

            this._init();

            if (typeof this.model.keyConfigs === "object" && !(this.model.keyConfigs instanceof Array)) {
                var requiresEvt = false;
                if (this.model.keyConfigs.focus)
                    this.element.attr("accesskey", this.model.keyConfigs.focus);

                for (var keyProps in this.model.keyConfigs) {
                    if (keyProps !== "focus") {
                        requiresEvt = true;
                        break;
                    }
                }

                if (requiresEvt && this._keyPressed) {
                    var el = element, evt = "keydown";

                    if (this.keySettings) {
                        el = this.keySettings.getElement ? this.keySettings.getElement() || el : el;
                        evt = this.keySettings.event || evt;
                    }

                    this._on(el, evt, function (e) {
                        if (!this.model.keyConfigs) return;

                        var action = keyFn.getActionFromCode(this.model.keyConfigs, e.which, e.ctrlKey, e.shiftKey, e.altKey);
                        var arg = {
                            code: e.which,
                            ctrl: e.ctrlKey,
                            alt: e.altKey,
                            shift: e.shiftKey
                        };
                        if (!action) return;

                        if (this._keyPressed(action, e.target, arg, e) === false)
                            e.preventDefault();
                    });
                }
            }

            this._trigger("create");
        }, proto);

        $.fn[pluginName] = function (options) {

            for (var i = 0; i < this.length; i++) {

                var $this = $(this[i]),
                    pluginObj = $this.data(pluginName),
                    isAlreadyExists = pluginObj && $this.hasClass(nameSpace),
                    obj = null;

                // ----- plug-in creation/init
                if (!isAlreadyExists) {
                    if (!options || typeof options === "object") {
                        new proto($this, options);
                    }
                    else {
                        throwError(pluginName + ": methods/properties can be accessed only after plugin creation");
                    }
                    continue;
                }

                if (!options) continue;

                // --- Function/property set/access
                if ($.isPlainObject(options)) {
                    // setModel using JSON object
                    pluginObj.setModel(options);
                }

                    // function/property name starts with "_" is private so ignore it.
                else if (options.indexOf('_') !== 0
                    && !ej.isNullOrUndefined(obj = ej.getObject(options, pluginObj))
                    || options.indexOf("model.") === 0) {

                    if (!obj || !$.isFunction(obj)) {

                        // if property is accessed, then break the jquery chain
                        if (arguments.length == 1)
                            return obj;

                        //setModel using string input
                        pluginObj.option(options, arguments[1]);

                        continue;
                    }

                    var value = obj.apply(pluginObj, [].splice.call(arguments, 1, arguments.length - 1));

                    // If function call returns any value, then break the jquery chain
                    if (value !== undefined)
                        return value;

                } else {
                    throwError(className + ": function/property - " + options + " does not exist");
                }
            }

            // maintaining jquery chain
            return this;
        };

        ej.widget.register(pluginName, className, proto.prototype);
    };

    $.extend(ej.widget, (function () {
        var _widgets = {},

        register = function (pluginName, className, prototype) {
            if (!ej.isNullOrUndefined(_widgets[pluginName]))
                throwError("ej.widget : The widget named " + pluginName + " is trying to register twice.");

            _widgets[pluginName] = { name: pluginName, className: className, proto: prototype };
        }

        return {
            register: register,
            registeredWidgets: _widgets
        };

    })());

    ej.widget.destroyAll = function (elements) {
        if (!elements || !elements.length) return;

        for (var i = 0; i < elements.length; i++) {
            var data = elements.eq(i).data(), wds = data["ejWidgets"];
            if (wds && wds.length) {
                for (var j = 0; j < wds.length; j++) {
                    if (data[wds[j]] && data[wds[j]].destroy)
                        data[wds[j]].destroy();
                }
            }
        }
    };

    ej.cookie = {
        get: function (name) {
            var value = RegExp(name + "=([^;]+)").exec(document.cookie);

            if (value && value.length > 1)
                return value[1];

            return undefined;
        },
        set: function (name, value, expiryDate) {
            if (typeof value === "object")
                value = JSON.stringify(value);

            value = escape(value) + ((expiryDate == null) ? "" : "; expires=" + expiryDate.toUTCString());
            document.cookie = name + "=" + value;
        }
    };

    var keyFn = {
        getActionFromCode: function (keyConfigs, keyCode, isCtrl, isShift, isAlt) {
            isCtrl = isCtrl || false;
            isShift = isShift || false;
            isAlt = isAlt || false;

            for (var keys in keyConfigs) {
                if (keys === "focus") continue;

                var key = keyFn.getKeyObject(keyConfigs[keys]);
                if (keyCode === key.code && isCtrl == key.isCtrl && isShift == key.isShift && isAlt == key.isAlt)
                    return keys;
            }
            return null;
        },
        getKeyObject: function (key) {
            var res = {
                isCtrl: false,
                isShift: false,
                isAlt: false
            };
            key = key.split("+");
            for (var i = 0; i < key.length; i++) {
                if (key[i] === "ctrl")
                    res.isCtrl = true;
                else if (key[i] === "shift")
                    res.isShift = true;
                else if (key[i] === "alt")
                    res.isAlt = true;
                else res.code = parseInt(key[i], 10);
            }
            return res;
        }
    };

    ej.browserInfo = function () {
        var browser = {}, clientInfo = [],
        browserClients = {
            webkit: /(chrome)[ \/]([\w.]+)/i, safari: /(webkit)[ \/]([\w.]+)/i, msie: /(msie) ([\w.]+)/i,
            opera: /(opera)(?:.*version|)[ \/]([\w.]+)/i, mozilla: /(mozilla)(?:.*? rv:([\w.]+)|)/i
        };
        for (var client in browserClients) {
            if (browserClients.hasOwnProperty(client)) {
                clientInfo = navigator.userAgent.match(browserClients[client]);
                if (clientInfo) {
                    browser.name = clientInfo[1].toLowerCase();
                    browser.version = clientInfo[2];
                    if (!!navigator.userAgent.match(/Trident\/7\./)) {
                        browser.name = "msie";
                    }
                    break;
                }
            }
        }
        browser.isMSPointerEnabled = (browser.name == 'msie') && browser.version > 9 && window.navigator.msPointerEnabled;
        return browser;
    };

    ej.eventType = {
        mouseDown: "mousedown touchstart",
        mouseMove: "mousemove touchmove",
        mouseUp: "mouseup touchend",
        mouseLeave: "mouseleave touchcancel",
        click: "click touchend"
    };

    ej.event = function (type, data, eventProp) {

        var e = $.extend(eventProp || {},
            {
                "type": type,
                "model": data,
                "cancel": false
            });

        return e;
    };

    ej.proxy = function (fn, context, arg) {
        if (!fn || typeof fn !== "function")
            return null;

        if ('bind' in fn)
            return arg ? fn.bind(context, arg) : fn.bind(context);

        return function () {
            var args = arg ? [arg] : []; args.push.apply(args, arguments);
            fn.apply(context, args);
        };
    };

    ej.hasStyle = function (prop) {
        var style = document.documentElement.style;

        if (prop in style) return true;

        var prefixs = ['ms', 'Moz', 'Webkit', 'O', 'Khtml'];

        prop = prop[0].toUpperCase() + prop.slice(1);

        for (var i = 0; i < prefixs.length; i++) {
            if (prefixs[i] + prop in style)
                return true;
        }

        return false;
    };

    Array.prototype.indexOf = Array.prototype.indexOf || function (searchElement) {
        var len = this.length;

        if (len === 0) return -1;

        for (var i = 0; i < len; i++) {
            if (i in this && this[i] === searchElement)
                return i;
        }
        return -1;
    };

    String.prototype.startsWith = String.prototype.startsWith || function (key) {
        return this.slice(0, key.length) === key;
    };
    var copyObject = ej.copyObject = function (isFirstDefault, target) {
        var start = 2, current, source;
        if (typeof isFirstDefault !== "boolean") {
            start = 1;
        }
        var objects = [].slice.call(arguments, start);
        if (start === 1) {
            target = isFirstDefault;
            isFirstDefault = undefined;
        }

        for (var i = 0; i < objects.length; i++) {
            for (var prop in objects[i]) {
                current = target[prop], source = objects[i][prop];

                if (source === undefined || current === source || objects[i] === source || target === source)
                    continue;
                if (source instanceof Array) {
                    if (i === 0 && isFirstDefault)
                        target[prop] = source.slice();
                    else
                        target[prop] = source.slice();
                } else if (ej.isPlainObject(source)) {
                    target[prop] = current || {};
                    if (isFirstDefault)
                        copyObject(isFirstDefault, target[prop], source);
                    else
                        copyObject(target[prop], source);
                } else
                    target[prop] = source;
            }
        }
        return target;
    };
    var pInstance = function () {
        return this;
    }
    ej.isPlainObject = function (obj) {
        if (!obj) return false;

        if (typeof obj !== "object" || obj.nodeType || jQuery.isWindow(obj)) {
            return false;
        }

        try {
            if (obj.constructor &&
                !obj.constructor.prototype.hasOwnProperty("isPrototypeOf")) {
                return false;
            }
        } catch (e) {
            return false;
        }

        var key, ownLast = ej.support.isOwnLast;
        for (key in obj) {
            if (ownLast) break;
        }

        return key === undefined || obj.hasOwnProperty(key);
    };
    ej.util.valueFunction = function (prop) {
        return function (value) {
            var val = ej.getObject(prop, this.model);

            if (value === undefined)
                return typeof val === "function" ? val() : val;

            if (typeof val === "function") {
                this["ob.values"][prop] = value;
                val.call(this, value);
            }
            else
                ej.createObject(prop, value, this.model);
        }
    };
    ej.util.getVal = function (val) {
        if (typeof val === "function")
            return val();
        return val;
    };
    ej.support = {
        isOwnLast: function () {
            var fn = function () { this.a = 1; };
            fn.prototype.b = 1;

            for (var p in new fn()) {
                return p === "b";
            }
        }(),
        outerHTML: function () {
            return document.createElement("div").outerHTML !== undefined;
        }()
    };

    var throwError = ej.throwError = function (er) {
        try {
            throw new Error(er);
        } catch (e) {
            throw e.message + "\n" + e.stack;
        }
    };

    ej.extensions = {};
    ej.extensions.modelGUID = "{0B1051BA-1CCB-42C2-A3B5-635389B92A50}";
})(window.jQuery, window.Syncfusion);;
window.ej = window.Syncfusion = window.Syncfusion || {};

(function ($, ej, doc, undefined) {
    'use strict';

    ej.DataManager = function (dataSource, query, adaptor) {
        if (!(this instanceof ej.DataManager))
            return new ej.DataManager(dataSource, query, adaptor);

        if (!dataSource)
            throwError("DataManger : a dataSource is required to create Manager");
			
		adaptor = adaptor || dataSource.adaptor

        if (typeof (adaptor) === "string")
            adaptor = new ej[adaptor]();
			
        var data = [], self = this;

        if (dataSource instanceof Array) {
            // JSON array
            data = {
                json: dataSource,
                offline: true
            };

        } else if (typeof dataSource === "object") {
            if ($.isPlainObject(dataSource)) {

                if (dataSource.table)
                    dataSource.json = this._getJsonFromElement(dataSource.table, dataSource.headerOption);

                data = {
                    url: dataSource.url,
                    insertUrl: dataSource.insertUrl,
                    removeUrl: dataSource.removeUrl,
                    updateUrl: dataSource.updateUrl,
                    crudUrl: dataSource.crudUrl,
                    batchUrl: dataSource.batchUrl,
                    json: dataSource.json,
                    headers: dataSource.headers,
                    accept: dataSource.accept,
                    data: dataSource.data,
                    requestType: dataSource.requestType,
                    key: dataSource.key,
                    crossDomain: dataSource.crossDomain,
                    jsonp: dataSource.jsonp,
                    dataType: dataSource.dataType,
                    offline: dataSource.offline !== undefined ? dataSource.offline : dataSource.adaptor == "remoteSaveAdaptor" ? false : dataSource.url ? false : true,
                    requiresFormat: dataSource.requiresFormat
                };
            } else if (dataSource.jquery || isHtmlElement(dataSource)) {
                data = {
                    json: this._getJsonFromElement(dataSource),
                    offline: true,
                    table: dataSource
                };
            }
        } else if (typeof dataSource === "string") {
            data = {
                url: dataSource,
                offline: false,
                dataType: "json"
            };
        }

        if (data.requiresFormat === undefined && !ej.support.cors)
            data.requiresFormat = isNull(data.crossDomain) ? true : data.crossDomain;
        if (data.dataType === undefined)
            data.dataType = "json";

        this.dataSource = data;
        this.defaultQuery = query;

        if (data.url && data.offline && !data.json) {
            this.isDataAvailable = false;
            this.adaptor = adaptor || new ej.ODataAdaptor();
            this.dataSource.offline = false;
            this.ready = this.executeQuery(query || ej.Query()).done(function (e) {
                self.dataSource.offline = true;
                self.isDataAvailable = true;
                data.json = e.result;
                self.adaptor = new ej.JsonAdaptor();
            });
        } else
            this.adaptor = data.offline ? new ej.JsonAdaptor() : new ej.ODataAdaptor();
        if (!data.jsonp && this.adaptor instanceof ej.ODataAdaptor)
            data.jsonp = "callback";
        this.adaptor = adaptor || this.adaptor;
        return this;
    };

    ej.DataManager.prototype = {
        setDefaultQuery: function (query) {
            this.defaultQuery = query;
        },

        executeQuery: function (query, done, fail, always) {
            if (typeof query === "function") {
                always = fail;
                fail = done;
                done = query;
                query = null;
            }

            if (!query)
                query = this.defaultQuery;

            if (!(query instanceof ej.Query))
                throwError("DataManager - executeQuery() : A query is required to execute");

            var deffered = $.Deferred();

            deffered.then(done, fail, always);
            var args = { query: query };

            if (!this.dataSource.offline && this.dataSource.url != undefined) {
                this._makeRequest(this.adaptor.processQuery(this, query), deffered, args, query);
            } else {
                nextTick(function () {
                    var res = this.executeLocal(query);
                    if (query._requiresCount) {
                        args.result = res.result;
                        args.count = res.count;
                    } else
                        args.result = res;
                    args.getTableModel = getTableModel(query._fromTable, args.result, this);
                    args.getKnockoutModel = getKnockoutModel(args.result);

                    deffered.resolveWith(this, [args]);
                }, this);
            }

            return deffered.promise();
        },

        executeLocal: function (query) {
            if (!this.defaultQuery && !(query instanceof ej.Query))
                throwError("DataManager - executeLocal() : A query is required to execute");

            if (!this.dataSource.json)
                throwError("DataManager - executeLocal() : Json data is required to execute");

            var ret, key;
            query = query || this.defaultQuery;

            var result = this.adaptor.processQuery(this, query);

            if (query._subQuery) {
                var from = query._subQuery._fromTable, lookup = query._subQuery._lookup,
                    res = query._requiresCount ? result.result : result;

                if (lookup && lookup instanceof Array) {
                    buildHierarchy(query._subQuery._fKey, from, res, lookup);
                }

                for (var j = 0; j < res.length; j++) {
                    if (res[j][from] instanceof Array) {
                        res[j] = $.extend({}, res[j]);
                        res[j][from] = this.adaptor.processResponse(query._subQuery.using(ej.DataManager(res[j][from].slice(0))).executeLocal(), this, query);
                    }
                }
            }

            return this.adaptor.processResponse(result, this, query);
        },

        _makeRequest: function (url, deffered, args, query) {
            var isSelector = !!query._subQuerySelector;

            var fnFail = $proxy(function (e) {
                args.error = e;
                deffered.rejectWith(this, [args]);
            }, this);

            var process = $proxy(function (data, count, xhr, request, actual) {
                if (isSelector) return;

                args.xhr = xhr;
                args.count = parseInt(count, 10);
                args.result = data;
                args.request = request;
                args.getTableModel = getTableModel(query._fromTable, data, this);
                args.getKnockoutModel = getKnockoutModel(data);
                args.actual = actual;
                deffered.resolveWith(this, [args]);

            }, this);

            var fnQueryChild = $proxy(function (data, selector) {
                var subDeffer = $.Deferred(),
                    childArgs = { parent: args };

                query._subQuery._isChild = true;

                var subUrl = this.adaptor.processQuery(this, query._subQuery, data ? this.adaptor.processResponse(data) : selector);

                var childReq = this._makeRequest(subUrl, subDeffer, childArgs, query._subQuery);

                subDeffer.then(function (subData) {
                    if (data) {
                        buildHierarchy(query._subQuery._fKey, query._subQuery._fromTable, data, subData);
                        process(data);
                    }
                }, fnFail);

                return childReq;
            }, this);

            var fnSuccess = proxy(function (data, status, xhr, request) {
                data = p.parseJson(data);
                var result = this.adaptor.processResponse(data, this, query, xhr, request), count = 0;
                if (query._requiresCount) {
                    count = result.count;
                    result = result.result;
                }

                if (!query._subQuery) {
                    process(result, count, xhr, request, data);
                    return;
                }

                if (!isSelector)
                    fnQueryChild(result);

            }, this);

            var req = $.extend({
                type: "GET",
                dataType: this.dataSource.dataType,
                crossDomain: this.dataSource.crossDomain,
                jsonp: this.dataSource.jsonp,
                cache: true,
                beforeSend: $proxy(this._beforeSend, this),
                processData: false,
                success: fnSuccess,
                error: fnFail
            }, url);

            req = $.ajax(req);

            if (isSelector) {
                var res = query._subQuerySelector.call(this, { query: query._subQuery, parent: query });

                if (res && res.length) {
                    req = $.when(req, fnQueryChild(null, res));

                    req.then(proxy(function (pData, cData, requests) {
                        var pResult = this.adaptor.processResponse(pData[0], this, query, pData[2], requests[0]), count = 0;
                        if (query._requiresCount) {
                            count = pResult.count;
                            pResult = pResult.result;
                        }
                        var cResult = this.adaptor.processResponse(cData[0], this, query._subQuery, cData[2], requests[1]), count = 0;
                        if (query._subQuery._requiresCount) {
                            count = cResult.count;
                            cResult = cResult.result;
                        }

                        buildHierarchy(query._subQuery._fKey, query._subQuery._fromTable, pResult, cResult);
                        isSelector = false;
                        process(pResult, count, pData[2]);

                    }, this), fnFail);
                } else {
                    isSelector = false;
                }
            }

            return req;
        },

        _beforeSend: function (request, settings) {
            this.adaptor.beforeSend(this, request, settings);

            var headers = this.dataSource.headers, props;
            for (var i = 0; headers && i < headers.length; i++) {
                props = [];
                for (var prop in headers[i]) props.push(prop);
                request.setRequestHeader(headers[props[0]], headers[props[1]]);
            }
        },

        saveChanges: function (changes, key, tableName) {
            var args = {
                url: tableName,
                key: key || this.dataSource.key
            };

            var req = this.adaptor.batchRequest(this, changes, args);

            if (this.dataSource.offline) {
                return req;
            }

            var deff = $.Deferred();
            $.ajax($.extend({
                beforeSend: $proxy(this._beforeSend, this),
                success: proxy(function (data, status, xhr, request) {
                    deff.resolveWith(this, this.adaptor.processResponse(data, this, null, xhr, request, changes));
                }, this),
                fail: function (e) {
                    deff.rejectWith(this, e);
                }
            }, req));

            return deff;
        },

        insert: function (data, tableName) {
            var res = this.adaptor.insert(this, data, tableName);
            if (this.dataSource.offline) {
                return res;
            }

            var deffer = $.Deferred();

            $.ajax($.extend({
                type: "POST",
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                processData: false,
                beforeSend: $proxy(this._beforeSend, this),
                success: proxy(function (record, status, xhr, request) {
                    record = this.adaptor.processResponse(p.parseJson(record), this, null, xhr, request);
                    deffer.resolveWith(this, [{ record: record, dataManager: this }]);
                }, this),
                error: function (e) {
                    deffer.rejectWith(this, [{ error: e, dataManager: this }]);
                }
            }, res));

            return deffer.promise();
        },

        remove: function (keyField, value, tableName) {
            if (typeof value === "object")
                value = value[keyField];

            var res = this.adaptor.remove(this, keyField, value, tableName);

            if (this.dataSource.offline)
                return res;

            return $.ajax($.extend({
                type: "POST",
                contentType: "application/json; charset=utf-8",
                beforeSend: $proxy(this._beforeSend, this),
                dataType: "json"
            }, res));
        },

        update: function (keyField, value, tableName) {
            var res = this.adaptor.update(this, keyField, value, tableName);

            if (this.dataSource.offline) {
                return res;
            }

            return $.ajax($.extend({
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                beforeSend: $proxy(this._beforeSend, this)
            }, res));
        },

        _getJsonFromElement: function (ds) {
            if (typeof (ds) == "string")
                ds = $($(ds).html());

            ds = ds.jquery ? ds[0] : ds;

            var tagName = ds.tagName.toLowerCase();

            if (tagName !== "table")
                throwError("ej.DataManager : Unsupported htmlElement : " + tagName);

            return ej.parseTable(ds);
        }
    };

    var buildHierarchy = function (fKey, from, source, lookup) {
        var i, grp = {}, t;
        if (lookup.result) lookup = lookup.result;

        if (lookup.GROUPGUID)
            throwError("ej.DataManager: Do not have support Grouping in hierarchy");

        for (i = 0; i < lookup.length; i++) {
            t = grp[lookup[i][fKey]] || (grp[lookup[i][fKey]] = []);

            t.push(lookup[i]);
        }

        for (i = 0; i < source.length; i++) {
            source[i][from] = grp[source[i][fKey]];
        }
    };

    var oData = {
        accept: "application/json;odata=light;q=1,application/json;odata=verbose;q=0.5",
        multipartAccept: "multipart/mixed",
        batch: "$batch",
        changeSet: "--changeset_",
        batchPre: "batch_",
        contentId: "Content-Id: ",
        batchContent: "Content-Type: multipart/mixed; boundary=",
        changeSetContent: "Content-Type: application/http\nContent-Transfer-Encoding: binary ",
        batchChangeSetContentType: "Content-Type: application/json; charset=utf-8 "
    };
    var p = {
        parseJson: function (jsonText) {
            var type = typeof jsonText;
            if (type === "string") {
                jsonText = JSON.parse(jsonText, p.jsonReviver);
            } else if (jsonText instanceof Array) {
                p.iterateAndReviveArray(jsonText);
            } else if (type === "object")
                p.iterateAndReviveJson(jsonText);
            return jsonText;
        },
        iterateAndReviveArray: function (array) {
            for (var i = 0; i < array.length; i++) {
                if (typeof array[i] === "object")
                    p.iterateAndReviveJson(array[i]);
                else
                    array[i] = p.parseJson(array[i]);
            }
        },
        iterateAndReviveJson: function (json) {
            var value;

            for (var prop in json) {
                if (prop.startsWith("__"))
                    continue;

                value = json[prop];
                if (typeof value === "object") {
                    if (value instanceof Array)
                        p.iterateAndReviveArray(value);
                    else
                        p.iterateAndReviveJson(value);
                } else
                    json[prop] = p.jsonReviver(prop, value);
            }
        },
        jsonReviver: function (field, value) {
            var s = value;
            if (typeof value === "string") {
                var ms = /^\/Date\(([+-]?[0-9]+)([+-][0-9]{4})?\)\/$/.exec(value);
                if (ms)
                    return new Date(parseInt(ms[1]));
                else if (/^(\d{4}\-\d\d\-\d\d([tT][\d:\.]*)?)([zZ]|([+\-])(\d\d):?(\d\d))?$/.test(value)) {
                    value = new Date(value);
                    if (value == "Invalid Date") {
                        var a = s.split(/[^0-9]/);
                        value = new Date(a[0], a[1] - 1, a[2], a[3], a[4], a[5]);
                    }
                }
            }

            return value;
        },
        isJson: function (jsonData) {
            if(typeof jsonData[0]== "string")
                return jsonData;
            return ej.parseJSON(jsonData);
        }
    };

    ej.isJSON = p.isJson;
    ej.parseJSON = p.parseJson;

    ej.Query = function (from) {
        if (!(this instanceof ej.Query))
            return new ej.Query(from);

        this.queries = [];
        this._key = "";
        this._fKey = "";

        if (typeof from === "string")
            this._fromTable = from || "";
        else if (from && from instanceof Array)
            this._lookup = from;

        this._expands = [];
        this._sortedColumns = [];
        this._groupedColumns = [];
        this._subQuery = null;
        this._isChild = false;
        this._params = [];
        return this;
    };

    ej.Query.prototype = {
        key: function (field) {
            if (typeof field === "string")
                this._key = field;

            return this;
        },

        using: function (dataManager) {
            if (dataManager instanceof ej.DataManager) {
                this.dataManagar = dataManager;
                return this;
            }

            return throwError("Query - using() : 'using' function should be called with parameter of instance ej.DataManager");
        },

        execute: function (dataManager, done, fail, always) {
            dataManager = dataManager || this.dataManagar;

            if (dataManager && dataManager instanceof ej.DataManager)
                return dataManager.executeQuery(this, done, fail, always);

            return throwError("Query - execute() : dataManager needs to be is set using 'using' function or should be passed as argument");
        },

        executeLocal: function (dataManager) {
            // this does not support for URL binding

            dataManager = dataManager || this.dataManagar;

            if (dataManager && dataManager instanceof ej.DataManager)
                return dataManager.executeLocal(this);

            return throwError("Query - executeLocal() : dataManager needs to be is set using 'using' function or should be passed as argument");
        },

        clone: function () {
            var cl = new ej.Query();
            cl.queries = this.queries.slice(0);
            cl._key = this._key;
            cl._isChild = this._isChild;
            cl.dataManagar = this.dataManager;
            cl._fromTable = this._fromTable;
            cl._params = this._params.slice(0);
            cl._expands = this._expands.slice(0);
            cl._sortedColumns = this._sortedColumns.slice(0);
            cl._groupedColumns = this._groupedColumns.slice(0);
            cl._subQuerySelector = this._subQuerySelector;
            cl._subQuery = this._subQuery;
            cl._fKey = this._fKey;
            cl._requiresCount = this._requiresCount;
            return cl;
        },

        from: function (tableName) {
            if (typeof tableName === "string")
                this._fromTable = tableName;

            return this;
        },

        addParams: function (key, value) {
            if (typeof value !== "function" && !ej.isPlainObject(value))
                this._params.push({ key: key, value: value });
            else if (typeof value === "function")
                this._params.push({ key: key, fn: value });

            return this;
        },

        expand: function (tables) {
            if (typeof tables === "string")
                this._expands = [].slice.call(arguments, 0);
            else
                this._expands = tables.slice(0);

            return this;
        },

        where: function (fieldName, operator, value, ignoreCase) {
            operator = (operator || ej.FilterOperators.equal).toLowerCase();
            var predicate = null;

            if (typeof fieldName === "string")
                predicate = new ej.Predicate(fieldName, operator, value, ignoreCase);
            else if (fieldName instanceof ej.Predicate)
                predicate = fieldName;
            else
                throwError("Query - where : Invalid arguments");

            this.queries.push({
                fn: "onWhere",
                e: predicate
            });
            return this;
        },

        search: function (searchKey, fieldNames, operator, ignoreCase) {
            if (!fieldNames || typeof fieldNames === "boolean") {
                fieldNames = [];
                ignoreCase = fieldNames;
            } else if (typeof fieldNames === "string")
                fieldNames = [fieldNames];

            if (typeof operator === "boolean") {
                ignoreCase = operator;
                operator = null;
            }
            operator = operator || ej.FilterOperators.contains;
            if (operator.length < 3)
                operator = ej.data.operatorSymbols[operator];

            var comparer = ej.data.fnOperators[operator] || ej.data.fnOperators.processSymbols(operator);

            this.queries.push({
                fn: "onSearch",
                e: {
                    fieldNames: fieldNames,
                    operator: operator,
                    searchKey: searchKey,
                    ignoreCase: ignoreCase,
                    comparer: comparer
                }
            });
            return this;
        },

        sortBy: function (fieldName, comparer, isFromGroup) {
            var order = ej.sortOrder.Ascending, sorts, t;

            if (typeof fieldName === "string" && fieldName.toLowerCase().endsWith(" desc")) {
                fieldName = fieldName.replace(/ desc$/i, '');
                comparer = ej.sortOrder.Descending;
            }

            if (typeof comparer === "boolean")
                comparer = !comparer ? ej.sortOrder.Ascending : ej.sortOrder.Descending;
            else if (typeof comparer === "function")
                order = "custom";

            if (!comparer || typeof comparer === "string") {
                order = comparer ? comparer.toLowerCase() : ej.sortOrder.Ascending;
                comparer = ej.pvt.fnSort(comparer);
            }
            if (isFromGroup) {
                sorts = filterQueries(this.queries, "onSortBy");

                for (var i = 0; i < sorts.length; i++) {
                    t = sorts[i].e.fieldName;
                    if (typeof t === "string") {
                        if (t === fieldName) return;
                    } else if (t instanceof Array) {
                        for (var j = 0; j < t.length; j++)
                            if (t[j] === fieldName || fieldName.toLowerCase() === t[j] + " desc")
                                return;
                    }
                }
            }

            this.queries.push({
                fn: "onSortBy",
                e: {
                    fieldName: fieldName,
                    comparer: comparer,
                    direction: order
                }
            });

            return this;
        },

        sortByDesc: function (fieldName) {
            return this.sortBy(fieldName, ej.sortOrder.Descending);
        },

        group: function (fieldName) {
            this.sortBy(fieldName, null, true);

            this.queries.push({
                fn: "onGroup",
                e: {
                    fieldName: fieldName
                }
            });
            return this;
        },

        page: function (pageIndex, pageSize) {
            this.queries.push({
                fn: "onPage",
                e: {
                    pageIndex: pageIndex,
                    pageSize: pageSize
                }
            });
            return this;
        },

        range: function (start, end) {
            if (typeof start !== "number" || typeof end !== "number")
                throwError("Query() - range : Arguments type should be a number");

            this.queries.push({
                fn: "onRange",
                e: {
                    start: start,
                    end: end
                }
            });
            return this;
        },

        take: function (nos) {
            if (typeof nos !== "number")
                throwError("Query() - Take : Argument type should be a number");

            this.queries.push({
                fn: "onTake",
                e: {
                    nos: nos
                }
            });
            return this;
        },

        skip: function (nos) {
            if (typeof nos !== "number")
                throwError("Query() - Skip : Argument type should be a number");

            this.queries.push({
                fn: "onSkip",
                e: { nos: nos }
            });
            return this;
        },

        select: function (fieldNames) {
            if (typeof fieldNames === "string")
                fieldNames = [].slice.call(arguments, 0);

            if (!(fieldNames instanceof Array)) {
                throwError("Query() - Select : Argument type should be String or Array");
            }

            this.queries.push({
                fn: "onSelect",
                e: { fieldNames: fieldNames }
            });
            return this;
        },

        hierarchy: function (query, selectorFn) {
            if (!query || !(query instanceof ej.Query))
                throwError("Query() - hierarchy : query must be instance of ej.Query");

            if (typeof selectorFn === "function")
                this._subQuerySelector = selectorFn;

            this._subQuery = query;
            return this;
        },

        foreignKey: function (key) {
            if (typeof key === "string")
                this._fKey = key;

            return this;
        },

        requiresCount: function () {
            this._requiresCount = true;

            return this;
        }
    };

    ej.Adaptor = function (ds) {
        this.dataSource = ds;
        this.pvt = {};
    };

    ej.Adaptor.prototype = {
        options: {
            from: "table",
            requestType: "json",
            sortBy: "sorted",
            select: "select",
            skip: "skip",
            group: "group",
            take: "take",
            search: "search",
            count: "requiresCounts",
            where: "where"
        },
        extend: function (overrides) {
            var fn = function (ds) {
                this.dataSource = ds;

                if (this.options)
                    this.options = $.extend({}, this.options);

                this.pvt = {};
            };
            fn.prototype = new this.type();
            fn.prototype.type = fn;

            var base = fn.prototype.base = {};
            for (var p in overrides) {
                if (fn.prototype[p])
                    base[p] = fn.prototype[p];
            }
            $.extend(true, fn.prototype, overrides);
            return fn;
        },
        processQuery: function (dm, query) {
            // this needs to be overridden
        },
        processResponse: function (data, ds, query, xhr) {
            return data;
        },
        convertToQueryString: function (req, query, dm) {
            return $.param(req);
        },
        type: ej.Adaptor
    };

    ej.UrlAdaptor = new ej.Adaptor().extend({
        processQuery: function (dm, query, hierarchyFilters) {
            var sorted = filterQueries(query.queries, "onSortBy"),
                grouped = filterQueries(query.queries, "onGroup"),
                filters = filterQueries(query.queries, "onWhere"),
                searchs = filterQueries(query.queries, "onSearch"),
                singles = filterQueryLists(query.queries, ["onSelect", "onPage", "onSkip", "onTake", "onRange"]),
                params = query._params,
                url = dm.dataSource.url, tmp, skip, take = null,
                op = this.options;

            var r = {
                sorted: [],
                grouped: [],
                filters: [],
                searches: []
            };

            // calc Paging & Range
            if (singles["onPage"]) {
                tmp = singles["onPage"];
                skip = getValue(tmp.pageIndex, query);
                take = getValue(tmp.pageSize, query);

                skip = (skip - 1) * take;
            } else if (singles["onRange"]) {
                tmp = singles["onRange"];
                skip = tmp.start;
                take = tmp.end - tmp.start;
            }

            // Sorting
            for (var i = 0; i < sorted.length; i++) {
                tmp = getValue(sorted[i].e.fieldName, query);

                r.sorted.push(callAdaptorFunc(this, "onEachSort", { name: tmp, direction: sorted[i].e.direction }, query));
            }

            // hierarchy
            if (hierarchyFilters) {
                tmp = this.getFiltersFrom(hierarchyFilters, query);
                if (tmp)
                    r.filters.push(callAdaptorFunc(this, "onEachWhere", tmp.toJSON(), query));
            }

            // Filters
            for (var i = 0; i < filters.length; i++) {
                r.filters.push(callAdaptorFunc(this, "onEachWhere", filters[i].e.toJSON(), query));

                for (var prop in r.filters[i]) {
                    if (isNull(r[prop]))
                        delete r[prop];
                }
            }

            // Searches
            for (var i = 0; i < searchs.length; i++) {
                tmp = searchs[i].e;
                r.searches.push(callAdaptorFunc(this, "onEachSearch", {
                    fields: tmp.fieldNames,
                    operator: tmp.operator,
                    key: tmp.searchKey,
                    ignoreCase: tmp.ignoreCase
                }, query));
            }

            // Grouping
            for (var i = 0; i < grouped.length; i++) {
                r.grouped.push(getValue(grouped[i].e.fieldName, query));
            }

            var req = {};
            req[op.from] = query._fromTable;
            if (op.expand) req[op.expand] = query._expands;
            req[op.select] = singles["onSelect"] ? callAdaptorFunc(this, "onSelect", getValue(singles["onSelect"].fieldNames, query), query) : "";
            req[op.count] = query._requiresCount ? callAdaptorFunc(this, "onCount", query._requiresCount, query) : "";
            req[op.search] = r.searches.length ? callAdaptorFunc(this, "onSearch", r.searches, query) : "";
            req[op.skip] = singles["onSkip"] ? callAdaptorFunc(this, "onSkip", getValue(singles["onSkip"].nos, query), query) : "";
            req[op.take] = singles["onTake"] ? callAdaptorFunc(this, "onTake", getValue(singles["onTake"].nos, query), query) : "";
            req[op.where] = r.filters.length || r.searches.length ? callAdaptorFunc(this, "onWhere", r.filters, query) : "";
            req[op.sortBy] = r.sorted.length ? callAdaptorFunc(this, "onSortBy", r.sorted, query) : "";
            req[op.group] = r.grouped.length ? callAdaptorFunc(this, "onGroup", r.grouped, query) : "";

            // Params
            for (var i = 0; tmp = params[i]; i++) {
                if (req[tmp.key]) throwError("ej.Query: Custom Param is conflicting other request arguments");

                req[tmp.key] = tmp.value;
                if (tmp.fn)
                    req[tmp.key] = tmp.fn.call(query, tmp.key, query, dm);
            }

            // cleanup
            for (var prop in req) {
                if (isNull(req[prop]) || req[prop] === "" || req[prop].length === 0)
                    delete req[prop];
            }

            if (!(op.skip in req && op.take in req) && take !== null) {
                req[op.skip] = callAdaptorFunc(this, "onSkip", skip, query);
                req[op.take] = callAdaptorFunc(this, "onTake", take, query);
            }
            var p = this.pvt;
            this.pvt = {};

            if (this.options.requestType === "json") {
                return {
                    data: JSON.stringify(req),
                    url: url,
                    ejPvtData: p,
                    type: "POST",
                    contentType: "application/json; charset=utf-8"
                }
            }
            tmp = this.convertToQueryString(req, query, dm);
            return {
                type: "GET",
                url: tmp.length ? url.replace(/\/*$/, "/" + tmp) : url,
                ejPvtData: p
            };
        },
        convertToQueryString: function (req, query, dm) {
            if (dm.dataSource.url && dm.dataSource.url.indexOf("?") !== -1)
                return $.param(req);
            return "?" + $.param(req);
        },
        processResponse: function (data, ds, query, xhr, request, changes) {
            var pvt = request.ejPvtData || {};
            var d = JSON.parse(request.data)
            if (d && d.action === "batch" && data.added) {
                changes.added = data.added;
                return changes;
            }

            if (pvt.groups && pvt.groups.length) {
                var groups = pvt.groups, args = {};
                if (data["count"]) args.count = data.count;
                if (data["result"]) data = data.result;
                for (var i = 0; i < groups.length; i++)
                    data = ej.group(data, groups[i]);
                if (args.count)
                    args.result = data;
                else
                    args = data;
                return args;
            }
            return data;
        },
        onGroup: function (e) {
            this.pvt.groups = e;
        },
        batchRequest: function (dm, changes, e) {
            return {
                type: "POST",
                url: dm.dataSource.batchUrl || dm.dataSource.crudUrl || dm.dataSource.url,
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                data: JSON.stringify({
                    changed: changes.changed,
                    added: changes.added,
                    deleted: changes.deleted,
                    action: "batch",
                    table: e.url,
                    key: e.key
                })
            };
        },
        beforeSend: function (dm, request) {
        },
        insert: function (dm, data, tableName) {
            return {
                url: dm.dataSource.insertUrl || dm.dataSource.crudUrl || dm.dataSource.url,
                data: JSON.stringify({
                    value: data,
                    table: tableName,
                    action: "insert"
                })
            };
        },
        remove: function (dm, keyField, value, tableName) {
            return {
                type: "POST",
                url: dm.dataSource.removeUrl || dm.dataSource.crudUrl || dm.dataSource.url,
                data: JSON.stringify({
                    key: value,
                    keyColumn: keyField,
                    table: tableName,
                    action: "remove"
                })
            };
        },
        update: function (dm, keyField, value, tableName) {
            return {
                type: "POST",
                url: dm.dataSource.updateUrl || dm.dataSource.crudUrl || dm.dataSource.url,
                data: JSON.stringify({
                    value: value,
                    action: "update",
                    keyColumn: keyField,
                    key: value[keyField],
                    table: tableName
                })
            };
        },
        getFiltersFrom: function (data, query) {
            if (!(data instanceof Array) || !data.length)
                throwError("ej.SubQuery: Array of key values required");
            var key = query._fKey, value, prop = key, predicats = [],
                isValues = typeof data[0] !== "object";

            if (typeof data[0] !== "object") prop = null;

            for (var i = 0; i < data.length; i++) {
                value = !isValues ? ej.pvt.getObject(prop, data[i]) : data[i];
                predicats.push(new ej.Predicate(key, "==", value));
            }

            return ej.Predicate.or(predicats);
        }
    });

    var filterQueries = function (queries, name) {
        return queries.filter(function (q) {
            return q.fn === name;
        }) || [];
    };
    var filterQueryLists = function (queries, singles) {
        var filtered = queries.filter(function (q) {
            return singles.indexOf(q.fn) !== -1;
        }), res = {};
        for (var i = 0; i < filtered.length; i++) {
            if (!res[filtered[i].fn])
                res[filtered[i].fn] = filtered[i].e;
        }
        return res;
    };
    var callAdaptorFunc = function (obj, fnName, param, param1) {
        if (obj[fnName]) {
            var res = obj[fnName](param, param1);
            if (!isNull(res)) param = res;
        }
        return param;
    };

    ej.ODataAdaptor = new ej.UrlAdaptor().extend({
        options: {
            requestType: "get",
            accept: "application/json;odata=light;q=1,application/json;odata=verbose;q=0.5",
            multipartAccept: "multipart/mixed",
            sortBy: "$orderby",
            select: "$select",
            skip: "$skip",
            take: "$top",
            count: "$inlinecount",
            where: "$filter",
            expand: "$expand",
            batch: "$batch",
            changeSet: "--changeset_",
            batchPre: "batch_",
            contentId: "Content-Id: ",
            batchContent: "Content-Type: multipart/mixed; boundary=",
            changeSetContent: "Content-Type: application/http\nContent-Transfer-Encoding: binary ",
            batchChangeSetContentType: "Content-Type: application/json; charset=utf-8 "
        },
        onEachWhere: function (filter, requiresCast) {
            return filter.isComplex ? this.onComplexPredicate(filter, requiresCast) : this.onPredicate(filter, requiresCast);
        },
        onPredicate: function (pred, query, requiresCast) {
            var returnValue = "",
                operator = pred.operator,
                val = pred.value,
                type = typeof val,
                field = this._p(pred.field);

            if (val instanceof Date)
                val = "datetime'" + dateSerialize(val) + "'";

            if (type === "string") {
                val = "'" + val + "'";

                if (requiresCast) {
                    field = "cast(" + field + ", 'Edm.String')";
                }

                if (pred.ignoreCase) {
                    field = "tolower(" + field + ")";
                    val = val.toLowerCase();
                }
            }

            operator = ej.data.odBiOperator[pred.operator];
            if (operator) {
                returnValue += field;
                returnValue += operator;

                return returnValue + val;
            }

            operator = ej.data.odUniOperator[pred.operator];
            if (!operator || type !== "string") return "";

            if (operator === "substringof") {
                var t = val;
                val = field;
                field = t;
            }

            returnValue += operator + "(";
            returnValue += field + ",";
            returnValue += val + ")";

            return returnValue;
        },
        onComplexPredicate: function (pred, requiresCast) {
            var res = [];
            for (var i = 0; i < pred.predicates.length; i++) {
                res.push("(" + this.onEachWhere(pred.predicates[i], requiresCast) + ")");
            }
            return res.join(" " + pred.condition + " ");
        },
        onWhere: function (filters) {
            if (this.pvt.searches)
                filters.push(this.onEachWhere(this.pvt.searches, null, true));

            return filters.join(" and ");
        },
        onEachSearch: function (e) {
            if (e.fields.length === 0)
                throwError("Query() - Search : oData search requires list of field names to search");

            var filter = this.pvt.searches || [];
            for (var i = 0; i < e.fields.length; i++) {
                filter.push(new ej.Predicate(e.fields[i], e.operator, e.key, e.ignoreCase));
            }
            this.pvt.searches = filter;
        },
        onSearch: function (e) {
            this.pvt.searches = ej.Predicate.or(this.pvt.searches);
            return "";
        },
        onEachSort: function (e) {
            var res = [];
            if (e.name instanceof Array) {
                for (var i = 0; i < e.name.length; i++)
                    res.push(this._p(e.name[i]));
            } else
                res.push(this._p(e.name) + (e.direction === "descending" ? " desc" : ""));

            return res.join(",");
        },
        onSortBy: function (e) {
            return e.reverse().join(",");
        },
        onGroup: function (e) {
            this.pvt.groups = e;
            return "";
        },
        onSelect: function (e) {
            for (var i = 0; i < e.length; i++)
                e[i] = this._p(e[i]);

            return e.join(',');
        },
        onCount: function (e) {
            return e === true ? "allpages" : "";
        },
        beforeSend: function (dm, request, settings) {
            if (settings.url.endsWith(this.options.batch) && settings.type.toLowerCase() === "post") {
                request.setRequestHeader("Accept", oData.multipartAccept);
                request.setRequestHeader("DataServiceVersion", "2.0");
                request.overrideMimeType("text/plain; charset=x-user-defined");
            }

            if (!dm.dataSource.crossDomain) {
                request.setRequestHeader("DataServiceVersion", "2.0");
                request.setRequestHeader("MaxDataServiceVersion", "2.0");
            }
        },
        processResponse: function (data, ds, query, xhr, request, changes) {
            var pvt = request && request.ejPvtData;
            if (request && request.url.endsWith(this.options.batch) && request.type.toLowerCase() === "post") {
                var guid = xhr.getResponseHeader("Content-Type"), cIdx, jsonObj;
                guid = guid.substring(guid.indexOf("=batchresponse") + 1);
                data = data.split(guid);
                if (data.length < 2) return;

                data = data[1];
                var exVal = /(?:\bContent-Type.+boundary=)(changesetresponse.+)/i.exec(data);
                data.replace(exVal[0], "");

                var changeGuid = exVal[1];
                data = data.split(changeGuid);

                for (var i = data.length; i > -1; i--) {
                    if (!/\bContent-ID:/i.test(data[i]) || !/\bHTTP.+201/.test(data[i]))
                        continue;

                    cIdx = parseInt(/\bContent-ID: (\d+)/i.exec(data[i])[1]);

                    if (changes.added[cIdx]) {
                        jsonObj = p.parseJson(/^\{.+\}/m.exec(data[i])[0]);
                        $.extend(changes.added[cIdx], this.processResponse(jsonObj));
                    }
                }
                return changes;
            }
            var version = xhr && xhr.getResponseHeader("DataServiceVersion"), count = null;
            version = (version && parseInt(version, 10)) || 2;

            if (query && query._requiresCount) {
                if (data.__count || data['odata.count']) count = data.__count || data['odata.count'];
                if (data.d) data = data.d;
                if (data.__count || data['odata.count']) count = data.__count || data['odata.count'];
            }

            if (version === 3 && data.value) data = data.value;
            if (data.d) data = data.d;
            if (version < 3 && data.results) data = data.results;

            if (pvt && pvt.groups && pvt.groups.length) {
                var groups = pvt.groups;
                for (var i = 0; i < groups.length; i++)
                    data = ej.group(data, groups[i]);
            }
            return isNull(count) ? data : { result: data, count: count };
        },
        convertToQueryString: function (req, query, dm) {
            var res = [], tableName = req.table || "";
            delete req.table;

            if (dm.dataSource.requiresFormat)
                req["$format"] = "json";

            for (var prop in req)
                res.push(prop + "=" + req[prop]);

            res = res.join("&");

            if (dm.dataSource.url && dm.dataSource.url.indexOf("?") !== -1 && !tableName)
                return res;

            return res.length ? tableName + "?" + res : tableName || "";
        },
        insert: function (dm, data, tableName) {
            return {
                url: dm.dataSource.url.replace(/\/*$/, tableName ? '/' + tableName : ''),
                data: JSON.stringify(data)
            }
        },
        remove: function (dm, keyField, value, tableName) {
            return {
                type: "DELETE",
                url: dm.dataSource.url.replace(/\/*$/, tableName ? '/' + tableName : '') + '(' + value + ')'
            };
        },
        update: function (dm, keyField, value, tableName) {
            return {
                type: "PUT",
                url: dm.dataSource.url.replace(/\/*$/, tableName ? '/' + tableName : '') + '(' + value[keyField] + ')',
                data: JSON.stringify(value),
                accept: this.options.accept
            };
        },
        batchRequest: function (dm, changes, e) {
            var initialGuid = e.guid = ej.getGuid(oData.batchPre);
            var url = dm.dataSource.url.replace(/\/*$/, '/' + this.options.batch);
            var args = {
                url: e.url,
                key: e.key,
                cid: 1,
                cSet: ej.getGuid(oData.changeSet)
            };
            var req = "--" + initialGuid + "\n";

            req += "Content-Type: multipart/mixed; boundary=" + args.cSet.replace("--", "") + "\n";

            req += this.generateInsertRequest(changes.added, args);
            req += this.generateUpdateRequest(changes.changed, args);
            req += this.generateDeleteRequest(changes.deleted, args);

            req += args.cSet + "--\n";
            req += "--" + initialGuid + "--";

            return {
                type: "POST",
                url: url,
                contentType: "multipart/mixed; charset=UTF-8;boundary=" + initialGuid,
                data: req
            };
        },
        generateDeleteRequest: function (arr, e) {
            if (!arr) return "";
            var req = "";

            for (var i = 0; i < arr.length; i++) {
                req += "\n" + e.cSet + "\n";
                req += oData.changeSetContent + "\n\n";
                req += "DELETE ";
                req += e.url + "(" + arr[i][e.key] + ") HTTP/1.1\n";
                req += "Accept: " + oData.accept + "\n";
                req += oData.batchChangeSetContentType + "\n";
            }

            return req + "\n";
        },
        generateInsertRequest: function (arr, e) {
            if (!arr) return "";
            var req = "";

            for (var i = 0; i < arr.length; i++) {
                req += "\n" + e.cSet + "\n";
                req += oData.changeSetContent + "\n\n";
                req += "POST ";
                req += e.url + " HTTP/1.1\n";
                req += "Accept: " + oData.accept + "\n";
                req += "Content-Id: " + i + "\n";
                req += oData.batchChangeSetContentType + "\n\n";

                req += JSON.stringify(arr[i]) + "\n";
            }

            return req;
        },
        generateUpdateRequest: function (arr, e) {
            if (!arr) return "";
            var req = "";

            for (var i = 0; i < arr.length; i++) {
                req += "\n" + e.cSet + "\n";
                req += oData.changeSetContent + "\n\n";
                req += "PUT ";
                req += e.url + "(" + arr[i][e.key] + ")" + " HTTP/1.1\n";
                req += "Accept: " + oData.accept + "\n";
                req += oData.batchChangeSetContentType + "\n\n";

                req += JSON.stringify(arr[i]) + "\n\n";
            }

            return req;
        },
        _p: function (prop) {
            return prop.replace(/\./g, "/");
        }
    });

    ej.JsonAdaptor = new ej.Adaptor().extend({
        processQuery: function (ds, query) {
            var result = ds.dataSource.json.slice(0), count = result.length, cntFlg = true, ret, key;

            for (var i = 0; i < query.queries.length; i++) {
                key = query.queries[i];
                ret = this[key.fn].call(this, result, key.e, query);
                result = ret !== undefined ? ret : result;

                if (key.fn === "onPage" || key.fn === "onSkip" || key.fn === "onTake" || key.fn === "onRange") cntFlg = false;

                if (cntFlg) count = result.length;
            }

            if (query._requiresCount) {
                result = {
                    result: result,
                    count: count
                };
            }

            return result;
        },
        batchRequest: function (dm, changes, e) {
            for (var i = 0; i < changes.added.length; i++)
                this.insert(dm, changes.added[i]);
            for (var i = 0; i < changes.changed.length; i++)
                this.update(dm, e.key, changes.changed[i]);
            for (var i = 0; i < changes.deleted.length; i++)
                this.remove(dm, e.key, changes.deleted[i]);
            return changes;
        },
        onWhere: function (ds, e) {
            if (!ds) return ds;

            return ds.filter(function (obj) {
                return e.validate(obj);
            });
        },
        onSearch: function (ds, e) {
            if (!ds || !ds.length) return ds;

            if (e.fieldNames.length === 0) {
                ej.pvt.getFieldList(ds[0], e.fieldNames);
            }

            return ds.filter(function (obj) {
                for (var j = 0; j < e.fieldNames.length; j++) {
                    if (e.comparer.call(obj, ej.pvt.getObject(e.fieldNames[j], obj), e.searchKey, e.ignoreCase))
                        return true;
                }
                return false;
            });
        },
        onSortBy: function (ds, e, query) {
            if (!ds) return ds;
            var fnCompare, field = getValue(e.fieldName, query);
            if (!field)
                return ds.sort(e.comparer);

            if (field instanceof Array) {
                field = field.slice(0);

                for (var i = field.length - 1; i >= 0; i--) {
                    if (!field[i]) continue;

                    fnCompare = e.comparer;

                    if (field[i].endsWith(" desc")) {
                        fnCompare = ej.pvt.fnSort(ej.sortOrder.Descending);
                        field[i] = field[i].replace(" desc", "");
                    }

                    ds = stableSort(ds, field[i], fnCompare);
                }
                return ds;
            }
            return stableSort(ds, field, e.comparer);
        },
        onGroup: function (ds, e, query) {
            if (!ds) return ds;

            return ej.group(ds, getValue(e.fieldName, query));
        },
        onPage: function (ds, e, query) {
            var size = getValue(e.pageSize, query),
                start = (getValue(e.pageIndex, query) - 1) * size, end = start + size;

            if (!ds) return ds;

            return ds.slice(start, end);
        },
        onRange: function (ds, e) {
            if (!ds) return ds;
            return ds.slice(getValue(e.start), getValue(e.end));
        },
        onTake: function (ds, e) {
            if (!ds) return ds;

            return ds.slice(0, getValue(e.nos));
        },
        onSkip: function (ds, e) {
            if (!ds) return ds;
            return ds.slice(getValue(e.nos));
        },
        onSelect: function (ds, e) {
            if (!ds) return ds;
            return ej.select(ds, getValue(e.fieldNames));
        },
        insert: function (dm, data) {
            return dm.dataSource.json.push(data);
        },
        remove: function (dm, keyField, value, tableName) {
            var ds = dm.dataSource.json, i;
            if (typeof value === "object")
                value = value[keyField];
            for (i = 0; i < ds.length; i++) {
                if (ds[i][keyField] === value) break;
            }

            return i !== ds.length ? ds.splice(i, 1) : null;
        },
        update: function (dm, keyField, value, tableName) {
            var ds = dm.dataSource.json, i, key = value[keyField];

            for (i = 0; i < ds.length; i++) {
                if (ds[i][keyField] === key) break;
            }

            return i < ds.length ? $.extend(ds[i], value) : null;
        }
    });
    ej.remoteSaveAdaptor = new ej.JsonAdaptor().extend({
        beforeSend: ej.UrlAdaptor.prototype.beforeSend,
        insert: ej.UrlAdaptor.prototype.insert,
        update: ej.UrlAdaptor.prototype.update,
        remove: ej.UrlAdaptor.prototype.remove
    });
    var getValue = function (value, inst) {
        if (typeof value === "function")
            return value.call(inst || {});
        return value;
    }

    ej.TableModel = function (name, jsonArray, dataManager, modelComputed) {
        if (!instance(this, ej.TableModel))
            return new ej.TableModel(jsonArray);

        if (!instance(jsonArray, Array))
            throwError("ej.TableModel - Json Array is required");

        var rows = [], model, dirtyFn = $proxy(setDirty, this);

        for (var i = 0; i < jsonArray.length; i++) {
            model = new ej.Model(jsonArray[i], this);
            model.state = "unchanged";
            model.on("stateChange", dirtyFn);
            if (modelComputed)
                model.computes(modelComputed);
            rows.push(model);
        }

        this.name = name || "table1";

        this.rows = ej.NotifierArray(rows);
        this._deleted = [];

        this._events = $({});

        this.dataManager = dataManager;

        this._isDirty = false;

        return this;
    };

    ej.TableModel.prototype = {
        on: function (eventName, handler) {
            this._events.on(eventName, handler);
        },

        off: function (eventName, handler) {
            this._events.off(eventName, handler);
        },

        setDataManager: function (dataManager) {
            this.dataManagar = dataManager;
        },

        saveChanges: function () {
            if (!this.dataManager || !instance(this.dataManager, ej.DataManager))
                throwError("ej.TableModel - saveChanges : Set the dataManager using setDataManager function");

            if (!this.isDirty())
                return;

            var promise = this.dataManager.saveChanges(this.getChanges(), this.key, this.name);

            promise.done($proxy(function (changes) {
                var rows = this.toArray();
                for (var i = 0; i < rows.length; i++) {
                    if (rows.state === "added") {
                        rows.set(this.key, changes.added.filter(function (e) {
                            return e[this.key] === rows.get(this.key);
                        })[0][this.key]);
                    }
                    rows[i].markCommit();
                }

                this._events.triggerHandler({ type: "save", table: this });

            }, this));

            promise.fail($proxy(function (e) {
                this.rejectChanges();
                this._events.triggerHandler({ type: "reject", table: this, error: e });
            }, this));

            this._isDirty = false;
        },

        rejectChanges: function () {
            var rows = this.toArray();
            for (var i = 0; i < rows.length; i++)
                rows[i].revert(true);

            this._isDirty = false;
            this._events.triggerHandler({ type: "reject", table: this });
        },

        insert: function (json) {
            var model = new ej.Model(json);
            model._isDirty = this._isDirty = true;

            this.rows.push(model);

            this._events.triggerHandler({ type: "insert", model: model, table: this });
        },

        update: function (value) {
            if (!this.key)
                throwError("TableModel - update : Primary key should be assigned to TableModel.key");

            var row = value, model, key = this.key, keyValue = row[key];

            model = this.rows.array.filter(function (obj) {
                return obj.get(key) === keyValue;
            });

            model = model[0];

            for (var col in row) {
                model.set(col, row[col]);
            }

            this._isDirty = true;

            this._events.triggerHandler({ type: "update", model: model, table: this });
        },

        remove: function (key) {
            if (!this.key)
                throwError("TableModel - update : Primary key should be assigned to TableModel.key");

            var field = this.key;

            var index = -1, model;

            if (key && typeof key === "object") {
                key = key[field] !== undefined ? key[field] : key.get(field);
            }

            for (var i = 0; i < this.rows.length() ; i++) {
                if (this.rows.array[i].get(field) === key) {
                    index = i;
                    break;
                }
            }

            if (index > -1) {
                model = this.rows.removeAt(index);
                model.markDelete();

                this._deleted.push({ model: model, position: index });

                this._isDirty = true;
                this._events.triggerHandler({ type: "remove", model: model, table: this });
            }
        },

        isDirty: function () {
            return this._isDirty;
        },

        getChanges: function () {

            var changes = {
                added: [],
                changed: []
            };
            var rows = this.toArray();
            for (var i = 0; i < rows.length; i++) {
                if (changes[rows[i].state])
                    changes[rows[i].state].push(rows[i].json);
            }

            changes.deleted = ej.select(this._deleted, ["model"]);

            return changes;
        },

        toArray: function () {
            return this.rows.toArray();
        },

        setDirty: function (dirty, model) {
            if (this._isDirty === !!dirty) return;

            this._isDirty = !!dirty;

            this._events.triggerHandler({ type: "dirty", table: this, model: model });
        },
        get: function (index) {
            return this.rows.array[index];
        },
        length: function () {
            return this.rows.array.length;
        },

        bindTo: function (element) {
            var marker = tDiv, template = $(element.html()), rows = this.toArray(), cur;
            if ($.inArray(element.prop("tagName").toLowerCase(), ["table", "tbody"]))
                marker = tTR;

            marker.insertBefore(element);
            element.detach().empty();

            for (var i = 0; i < rows.length; i++) {
                cur = template.clone();
                rows[i].bindTo(cur);
                element.append(cur);
            }

            element.insertAfter(marker);
            marker.remove();
        }
    };

    var tDiv = doc ? $(document.createElement("div")) : {},
        tTR = doc ? $(document.createElement("tr")) : {};

    ej.Model = function (json, table, name) {
        if (typeof table === "string") {
            name = table;
            table = null;
        }
        this.$id = getUid("m");

        this.json = json;
        this.table = table instanceof ej.TableModel ? table : null;
        this.name = name || (this.table && this.table.name);
        this.dataManager = (table instanceof ej.DataManager) ? table : table.dataManagar;
        this.actual = {};
        this._events = $({});
        this.isDirty = false;
        this.state = "added";
        this._props = [];
        this._computeEls = {};
        this._fields = {};
        this._attrEls = {};
        this._updates = {};
        this.computed = {};
    };

    ej.Model.prototype = {
        computes: function (value) {
            $.extend(this.computed, value);
        },
        on: function (eventName, handler) {
            this._events.on(eventName, handler);
        },
        off: function (eventName, handler) {
            this._events.off(eventName, handler);
        },
        set: function (field, value) {
            var obj = this.json, actual = field, prev;
            field = field.split('.');

            for (var i = 0; i < field.length - 1; i++) {
                field = field[0];
                obj = obj[field[0]];
            }

            this.isDirty = true;
            this.changeState("changed", { from: "set" });

            prev = obj[field];

            if (this.actual[field] === undefined && !(field in this.actual))
                this.actual[field] = value; // Complex property ?

            obj[field] = value;

            this._updateValues(field, value);
            this._events.triggerHandler({ type: actual, current: value, previous: prev, model: this });
        },
        get: function (field) {
            return ej.pvt.getObject(field, this.json);
        },
        revert: function (suspendEvent) {
            for (var prop in this.actual) {
                this.json[prop] = this.actual[prop];
            }

            this.isDirty = false;

            if (suspendEvent)
                this.state = "unchanged";
            else
                this.changeState("unchanged", { from: "revert" });
        },
        save: function (dm, key) {
            dm = dm || this.dataManagar;
            key = key || dm.dataSource.key;
            if (!dm) throwError("ej.Model - DataManager is required to commit the changes");
            if (this.state === "added") {
                return dm.insert(this.json, this.name).done(ej.proxy(function (e) {
                    $.extend(this.json, e.record);
                }, this));
            }
            else if (this.state === "changed") {
                return dm.update(key, this.json, this.name);
            }
            else if (this.state === "deleted") {
                return dm.remove(key, this.json, this.name);
            }
        },
        markCommit: function () {
            this.isDirty = false;
            this.changeState("unchanged", { from: "commit" });
        },
        markDelete: function () {
            this.changeState("deleted", { from: "delete" });
        },
        changeState: function (state, args) {
            if (this.state === state) return;

            if (this.state === "added") {
                if (state === "deleted")
                    state = "unchanged";
                else return;
            }

            var prev = state;
            args = args || {};

            this.state = state;
            this._events.triggerHandler($.extend({ type: "stateChange", current: state, previous: prev, model: this }, args));
        },
        properties: function () {
            if (this._props.length)
                return this._props;

            for (var pr in this.json) {
                this._props.push(pr);
                this._updates[pr] = { read: [], input: [] };
            }

            return this._props;
        },
        bindTo: function (element) {
            var props = this.properties(), el = $(element), ctl, field,
                elements = el.find("[ej-observe], [ej-computed], [ej-prop]"), len = elements.length;

            el.data("ejModel", this);
            var unbindData = { fields: [], props: [], computes: [] };
            for (var i = 0; i < len; i++) {
                ctl = elements.eq(i);

                field = ctl.attr("ej-prop")
                if (field) {
                    this._processAttrib(field, ctl, unbindData);
                }
                field = ctl.attr("ej-observe");
                if (field && this._props.indexOf(field) !== -1) {
                    this._processField(ctl, field, unbindData);
                    continue;
                }

                field = ctl.attr("ej-computed");
                if (field) {
                    this._processComputed(field, ctl, unbindData);
                    continue;
                }
            }
            el.data("ejModelBinding" + this.$id, unbindData);
        },
        unbind: function (element) {
            var props = this.properties(), tmp, data = {
                props: this._attrEls,
                computes: this._computeEls
            }, isCustom = false;

            if (element) {
                data = $(element).removeData("ejModel").data("ejModelBinding" + this.$id) || data;
                isCustom = true;
            }

            for (var p in this.computed) {
                tmp = data.computes[p], p = this.computed[p];
                if (tmp && p.deps) {
                    this.off(p.deps.join(' '), tmp.handle);
                    if (isCustom)
                        delete this._computeEls[p];
                }
            }
            if (!isCustom)
                this._computeEls = {};

            for (var p in data.props) {
                tmp = data.props[p];
                if (tmp) {
                    this.off(tmp.deps.join(' '), tmp.handle);
                    delete data.props[p];
                    if (isCustom)
                        delete this._attrEls[p];
                }
            }
            if (!isCustom)
                this._attrEls = {};

            if (data.fields && data.fields.length) {
                var len = data.fields.length, ctl, idx, ty;
                for (var i = 0; i < len; i++) {
                    ctl = data.fields[i];
                    $(ctl).off("change", null, this._changeHandler);

                    ty = this.formElements.indexOf(ctl.tagName.toLowerCase()) !== -1 ? "input" : "read";
                    idx = this._updates[ty].indexOf(ctl);
                    if (idx !== -1)
                        this._updates[ty].splice(idx, 1);
                }
            }
        },
        _processComputed: function (value, element, data) {
            if (!value) return;

            var val, deps = [], safeVal = safeStr(value),
            type = this.formElements.indexOf(element[0].tagName.toLowerCase()) !== -1 ? "val" : "html";

            if (!this.computed[value] || !this.computed[safeVal]) {
                this.computed[safeVal] = {
                    value: new Function("var e = this; return " + value),
                    deps: this._generateDeps(value)
                }
                value = safeVal;
            }

            val = this.computed[value];
            if (!val.get) {
                val.get = function () {
                    val.value.call(this.json);
                }
            }

            deps = val.deps;
            val = val.value;

            this._updateDeps(deps);
            this._updateElement(element, type, val);

            val = { el: element, handle: $proxy(this._computeHandle, this, { value: value, type: type }) };
            this._computeEls[value] = val;
            data.computes[value] = val;

            this.on(deps.join(' '), val.handle);
        },
        _computeHandle: function (e) {
            var el = this._computeEls[e.value];
            if (el && this.computed[e.value])
                this._updateElement(el.el, e.type, this.computed[e.value].value);
        },
        _updateElement: function (el, type, val) {
            el[type](val.call($.extend({}, this.json, this.computed)));
        },
        _updateDeps: function (deps) {
            for (var i = 0; i < deps.length; i++) {
                if (!(deps[i] in this.json) && deps[i] in this.computed)
                    ej.merge(deps, this.computed[deps[i]].deps);
            }
        },
        _generateDeps: function (value) {
            var splits = value.replace(/(^e\.)|( e\.)/g, '#%^*##ej.#').split("#%^*#"),
                field, deps = [];

            for (var i = 0; i < splits.length; i++) {
                if (splits[i].startsWith("#ej.#")) {
                    field = splits[i].replace("#ej.#", "").split(' ')[0];
                    if (field && this._props.indexOf(field) !== -1)
                        deps.push(field);
                }
            }

            return deps;
        },
        _processAttrib: function (value, el, data) {
            var prop, val, res = {};
            value = value.replace(/^ +| +$/g, "").split(";");
            for (var i = 0; i < value.length; i++) {
                value[i] = value[i].split(":");
                if (value[i].length < 2) continue;

                prop = value[i][0].replace(/^ +| +$/g, "").replace(/^'|^"|'$|"$/g, "");
                res[prop] = value[i][1].replace(/^ +| +$/g, "").replace(/^'|^"|'$|"$/g, "");
            }
            value = res;
            var deps = [];
            for (var prop in value)
                deps.push(value[prop]);

            this._updateDeps(deps);
            this._updateProps(el, value);

            res = getUid("emak");
            val = { el: el, handle: $proxy(this._attrHandle, this, res), value: value, deps: deps };
            el.prop("ejmodelattrkey", res);

            data.props[res] = val;
            this._attrEls[res] = val;

            this.on(deps.join(' '), val.handle);
        },
        _attrHandle: function (res) {
            var el = this._attrEls[res];
            if (el)
                this._updateProps(el.el, el.value);
        },
        _updateProps: function (element, value) {
            var json = this.json, t, c = this.computed;
            for (var prop in value) {
                t = value[prop];
                if (t in json)
                    t = json[t];
                else if (t in this.computed) {
                    t = this.computed[t];
                    if (t) {
                        t = t.value.call($.extend({}, this.json, this.computed));
                    }
                }

                if (!isNull(t)) {
                    element.prop(prop, t);
                }
            }
        },
        _updateValues: function (prop, value) {
            var arr = this._updates[prop];

            if (!arr || (!arr.read && !arr.input)) return;

            this._ensureItems(arr.read, "html", value);
            this._ensureItems(arr.input, "val", value);
        },
        _ensureItems: function (a, type, value) {
            if (!a) return;

            for (var i = a.length - 1; i > -1; i--) {
                if (!a[i].offsetParent) {
                    a.splice(i, 1);
                    continue;
                }
                $(a[i])[type](value);
            }
        },
        _changeHandler: function (e) {
            e.data.self.set(e.data.prop, $(this).val());
        },
        _processField: function (ctl, field, data) {
            var e = { self: this, prop: field }, val = this.get(field);

            data.fields.push(ctl[0]);

            if (this.formElements.indexOf(ctl[0].tagName.toLowerCase()) === -1) {
                ctl.html(val);
                return this._updates[field].read.push(ctl[0]);
            }

            ctl.val(val)
                    .off("change", null, this._changeHandler)
                    .on("change", null, e, this._changeHandler);

            return this._updates[field].input.push(ctl[0]);
        },
        formElements: ["input", "select", "textarea"]
    };

    var safeReg = /[^\w]+/g;
    var safeStr = function (value) {
        return value.replace(safeReg, "_");
    };
    var setDirty = function (e) {
        this.setDirty(true, e.model);
    };

    ej.Predicate = function (field, operator, value, ignoreCase) {
        if (!(this instanceof ej.Predicate))
            return new ej.Predicate(field, operator, value, ignoreCase);

        if (typeof field === "string") {
            this.field = field;
            this.operator = operator;
            this.value = value;
            this.ignoreCase = ignoreCase;
            this.isComplex = false;

            this._comparer = ej.data.fnOperators.processOperator(this.operator);

        } else if (field instanceof ej.Predicate && value instanceof ej.Predicate || value instanceof Array) {
            this.isComplex = true;
            this.condition = operator.toLowerCase();
            this.predicates = [field];
            if (value instanceof Array)
                [].push.apply(this.predicates, value);
            else
                this.predicates.push(value);
        }
        return this;
    };

    ej.Predicate.and = function () {
        return pvtPredicate._combinePredicates([].slice.call(arguments, 0), "and");
    };

    ej.Predicate.or = function () {
        return pvtPredicate._combinePredicates([].slice.call(arguments, 0), "or");
    };

    // Private fn
    var pvtPredicate = {
        _combinePredicates: function (predicates, operator) {
            if (!predicates.length) return undefined;
            if (predicates.length === 1) {
                if (!instance(predicates[0], Array))
                    return predicates[0];
                predicates = predicates[0];
            }
            return new ej.Predicate(predicates[0], operator, predicates.slice(1));;
        },

        _combine: function (pred, field, operator, value, condition, ignoreCase) {
            if (field instanceof ej.Predicate)
                return ej.Predicate[condition](pred, field);

            if (typeof field === "string")
                return ej.Predicate[condition](pred, new ej.Predicate(field, operator, value, ignoreCase));

            return throwError("Predicate - " + condition + " : invalid arguments");
        }
    };

    ej.Predicate.prototype = {
        and: function (field, operator, value, ignoreCase) {
            return pvtPredicate._combine(this, field, operator, value, "and", ignoreCase);
        },
        or: function (field, operator, value, ignoreCase) {
            return pvtPredicate._combine(this, field, operator, value, "or", ignoreCase);
        },
        validate: function (record) {
            var value, p = this.predicates, isAnd, ret;

            if (!this.isComplex) {
                return this._comparer.call(this, ej.pvt.getObject(this.field, record), this.value, this.ignoreCase);
            }

            isAnd = this.condition === "and";

            for (var i = 0; i < p.length; i++) {
                ret = p[i].validate(record);
                if (isAnd) {
                    if (!ret) return false;
                } else {
                    if (ret) return true;
                }
            }

            return isAnd;
        },
        toJSON: function () {
            var predicates, p;
            if (this.isComplex) {
                predicates = [], p = this.predicates;
                for (var i = 0; i < p.length; i++)
                    predicates.push(p[i].toJSON());
            }
            return {
                isComplex: this.isComplex,
                field: this.field,
                operator: this.operator,
                value: this.value,
                ignoreCase: this.ignoreCase,
                condition: this.condition,
                predicates: predicates
            }
        }
    };

    ej.dataUtil = {
        swap: function (array, x, y) {
            if (x == y) return;

            var tmp = array[x];
            array[x] = array[y];
            array[y] = tmp;
        },

        mergeSort: function (jsonArray, fieldName, comparer) {
            if (!comparer || typeof comparer === "string")
                comparer = ej.pvt.fnSort(comparer, true);

            if (typeof fieldName === "function") {
                comparer = fieldName;
                fieldName = null;
            }

            return ej.pvt.mergeSort(jsonArray, fieldName, comparer);
        },

        max: function (jsonArray, fieldName, comparer) {
            if (typeof fieldName === "function") {
                comparer = fieldName;
                fieldName = null;
            }

            return ej.pvt.getItemFromComparer(jsonArray, fieldName, comparer || ej.pvt.fnDescending);
        },

        min: function (jsonArray, fieldName, comparer) {
            if (typeof fieldName === "function") {
                comparer = fieldName;
                fieldName = null;
            }

            return ej.pvt.getItemFromComparer(jsonArray, fieldName, comparer || ej.pvt.fnAscending);
        },

        distinct: function (json, fieldName, requiresCompleteRecord) {
            var result = [], val, tmp = {};
            for (var i = 0; i < json.length; i++) {
                val = getVal(json, fieldName, i);
                if (!(val in tmp)) {
                    result.push(!requiresCompleteRecord ? val : json[i]);
                    tmp[val] = 1;
                }
            }
            return result;
        },

        sum: function (json, fieldName) {
            var result = 0, val, castRequired = typeof getVal(json, fieldName, 0) !== "number";

            for (var i = 0; i < json.length; i++) {
                val = getVal(json, fieldName, i);
                if (val !== undefined){
                   if(castRequired && +val)
                       val = +val;
                   result += val;
                }
            }
            return result;
        },

        avg: function (json, fieldName) {
            return ej.sum(json, fieldName) / json.length;
        },

        select: function (jsonArray, fields) {
            var newData = [];

            for (var i = 0; i < jsonArray.length; i++) {
                newData.push(ej.pvt.extractFields(jsonArray[i], fields));
            }

            return newData;
        },

        group: function (jsonArray, field, /* internal */ level) {
            level = level || 1;

            if (jsonArray.GROUPGUID == ej.pvt.consts.GROUPGUID) {
                for (var j = 0; j < jsonArray.length; j++) {
                    jsonArray[j].items = ej.group(jsonArray[j].items, field, jsonArray.level + 1);
                    jsonArray[j].count = jsonArray[j].items.length;
                }

                jsonArray.childLevels += 1;
                return jsonArray;
            }

            var grouped = {}, groupedArray = [];

            groupedArray.GROUPGUID = ej.pvt.consts.GROUPGUID;
            groupedArray.level = level;
            groupedArray.childLevels = 0;
            groupedArray.records = jsonArray;

            for (var i = 0; i < jsonArray.length; i++) {
                var val = getVal(jsonArray, field, i);

                if (!grouped[val]) {
                    grouped[val] = {
                        key: val,
                        count: 0,
                        items: [],
                        field: field
                    };
                    groupedArray.push(grouped[val]);
                }

                grouped[val].count += 1;
                grouped[val].items.push(jsonArray[i]);
            }

            return groupedArray;
        },

        parseTable: function (table, headerOption, headerRowIndex) {
            var tr = table.rows, headerRow, headerTds = [], data = [], i;

            if (!tr.length) return [];

            headerRowIndex = headerRowIndex || 0;

            switch ((headerOption || "").toLowerCase()) {
                case ej.headerOption.tHead:
                    headerRow = table.tHead.rows[headerRowIndex];
                    break;
                case ej.headerOption.row:
                default:
                    headerRow = table.rows[headerRowIndex];
                    break;
            }

            var hTd = headerRow.cells;

            for (i = 0; i < hTd.length; i++)
                headerTds.push($.trim(hTd[i].innerHTML));

            for (i = headerRowIndex + 1; i < tr.length; i++) {
                var json = {}, td = tr[i].cells;
                for (var j = 0; j < td.length; j++) {
                    json[headerTds[j]] = td[j].innerHTML;
                }
                data.push(json);
            }
            return data;
        }
    };

    ej.headerOption = {
        tHead: "thead",
        row: "row"
    };

    ej.pvt = {
        filterQueries: filterQueries,
        mergeSort: function (jsonArray, fieldName, comparer) {
            if (jsonArray.length <= 1)
                return jsonArray;

            // else list size is > 1, so split the list into two sublists
            var middle = parseInt(jsonArray.length / 2, 10);

            var left = jsonArray.slice(0, middle),
                right = jsonArray.slice(middle);

            left = ej.pvt.mergeSort(left, fieldName, comparer);
            right = ej.pvt.mergeSort(right, fieldName, comparer);

            return ej.pvt.merge(left, right, fieldName, comparer);
        },

        getItemFromComparer: function (array, field, comparer) {
            var keyVal = getVal(array, field, 0), current, key = array[0];
            for (var i = 1; i < array.length; i++) {
                current = getVal(array, field, i);
                if (comparer(keyVal, current) > 0) {
                    keyVal = current;
                    key = array[i];
                }
            }
            return key;
        },

        quickSelect: function (array, fieldName, left, right, k, comparer) {
            if (left == right)
                return array[left];

            var pivotNewIndex = ej.pvt.partition(array, fieldName, left, right, comparer);

            var pivotDist = pivotNewIndex - left + 1;

            if (pivotDist == k)
                return array[pivotNewIndex];

            else if (k < pivotDist)
                return ej.pvt.quickSelect(array, fieldName, left, pivotNewIndex - 1, k, comparer);
            else
                return ej.pvt.quickSelect(array, fieldName, pivotNewIndex + 1, right, k - pivotDist, comparer);
        },

        extractFields: function (obj, fields) {
            var newObj = {};

            if (fields.length == 1)
                return ej.pvt.getObject(fields[0], obj);

            for (var i = 0; i < fields.length; i++) {
                newObj[fields[i].replace('.', ej.pvt.consts.complexPropertyMerge)] = ej.pvt.getObject(fields[i], obj);
            }

            return newObj;
        },

        partition: function (array, field, left, right, comparer) {

            var pivotIndex = parseInt((left + right) / 2, 10),
                pivot = getVal(array, field, pivotIndex);

            ej.swap(array, pivotIndex, right);

            pivotIndex = left;

            for (var i = left; i < right; i++) {
                if (comparer(getVal(array, field, i), pivot)) {
                    ej.swap(array, i, pivotIndex);
                    pivotIndex++;
                }
            }

            ej.swap(array, pivotIndex, right);

            return pivotIndex;
        },

        fnSort: function (order) {
            order = order ? order.toLowerCase() : ej.sortOrder.Ascending;

            if (order == ej.sortOrder.Ascending)
                return ej.pvt.fnAscending;

            return ej.pvt.fnDescending;
        },

        fnGetComparer: function (field, fn) {
            return function (x, y) {
                return fn(ej.pvt.getObject(field, x), ej.pvt.getObject(field, y));
            }
        },

        fnAscending: function (x, y) {
            if (x && x.localeCompare)
                return x.localeCompare(y);
            if (x === undefined) {
                if (y === undefined)
                    return 0;
                return 1;
            }
            if (y === undefined)
                return -1;
            return x - y;
        },

        fnDescending: function (x, y) {
            if (x && x.localeCompare)
                return x.localeCompare(y) * -1;
            if (x === undefined) {
                if (y === undefined)
                    return 0;
                return -1;
            }
            if (y === undefined)
                return 1;
            return y - x;
        },

        merge: function (left, right, fieldName, comparer) {
            var result = [], current;

            while (left.length > 0 || right.length > 0) {
                if (left.length > 0 && right.length > 0) {
                    if (comparer)
                        current = comparer(getVal(left, fieldName, 0), getVal(right, fieldName, 0)) < 1 ? left : right;
                    else
                        current = left[0][fieldName] < left[0][fieldName] ? left : right;
                } else {
                    current = left.length > 0 ? left : right;
                }

                result.push(current.shift());
            }

            return result;
        },

        getObject: function (nameSpace, from) {
            if (!from) return undefined;
            if (!nameSpace) return from;

            if (nameSpace.indexOf('.') === -1) return from[nameSpace];

            var value = from, splits = nameSpace.split('.');

            for (var i = 0; i < splits.length; i++) {

                if (value == null) break;

                value = value[splits[i]];
            }

            return value;
        },

        createObject: function (nameSpace, value, initIn) {
            var splits = nameSpace.split('.'), start = initIn || window, from = start, i;

            for (i = 0; i < splits.length; i++) {

                if (i + 1 == splits.length)
                    from[splits[i]] = value === undefined ? {} : value;
                else if (from[splits[i]] == null)
                    from[splits[i]] = {};

                from = from[splits[i]];
            }

            return start;
        },

        getFieldList: function (obj, fields, prefix) {
            if (prefix === undefined)
                prefix = "";

            if (fields === undefined || fields === null)
                return ej.pvt.getFieldList(obj, [], prefix);

            for (var prop in obj) {
                if (typeof obj[prop] === "object" && !(obj[prop] instanceof Array))
                    ej.pvt.getFieldList(obj[prop], fields, prefix + prop + ".");
                else
                    fields.push(prefix + prop);
            }

            return fields;
        }
    };

    ej.FilterOperators = {
        lessThan: "lessthan",
        greaterThan: "greaterthan",
        lessThanOrEqual: "lessthanorequal",
        greaterThanOrEqual: "greaterthanorequal",
        equal: "equal",
        contains: "contains",
        startsWith: "startswith",
        endsWith: "endswith",
        notEqual: "notequal"
    };

    ej.data = {};

    ej.data.operatorSymbols = {
        "<": "lessthan",
        ">": "greaterthan",
        "<=": "lessthanorequal",
        ">=": "greaterthanorequal",
        "==": "equal",
        "!=": "notequal",
        "*=": "contains",
        "$=": "endswith",
        "^=": "startswith"
    };

    ej.data.odBiOperator = {
        "<": " lt ",
        ">": " gt ",
        "<=": " le ",
        ">=": " ge ",
        "==": " eq ",
        "!=": " ne ",
        "lessthan": " lt ",
        "lessthanorequal": " le ",
        "greaterthan": " gt ",
        "greaterthanorequal": " ge ",
        "equal": " eq ",
        "notequal": " ne "
    };

    ej.data.odUniOperator = {
        "$=": "endswith",
        "^=": "startswith",
        "*=": "substringof",
        "endswith": "endswith",
        "startswith": "startswith",
        "contains": "substringof"
    };

    ej.data.fnOperators = {
        equal: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return toLowerCase(actual) == toLowerCase(expected);

            return actual == expected;
        },
        notequal: function (actual, expected, ignoreCase) {
            return !ej.data.fnOperators.equal(actual, expected, ignoreCase);
        },
        lessthan: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return toLowerCase(actual) < toLowerCase(expected);

            return actual < expected;
        },
        greaterthan: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return toLowerCase(actual) > toLowerCase(expected);

            return actual > expected;
        },
        lessthanorequal: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return toLowerCase(actual) <= toLowerCase(expected);

            return actual <= expected;
        },
        greaterthanorequal: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return toLowerCase(actual) >= toLowerCase(expected);

            return actual >= expected;
        },
        contains: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return !isNull(actual) && !isNull(expected) && toLowerCase(actual).indexOf(toLowerCase(expected)) != -1;

            return !isNull(actual) && !isNull(expected) && actual.toString().indexOf(expected) != -1;
        },
        notnull: function (actual) {
            return actual !== null;
        },
        isnull: function (actual) {
            return actual === null;
        },
        startswith: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return actual && expected && toLowerCase(actual).startsWith(toLowerCase(expected));

            return actual && expected && actual.startsWith(expected);
        },
        endswith: function (actual, expected, ignoreCase) {
            if (ignoreCase)
                return actual && expected && toLowerCase(actual).endsWith(toLowerCase(expected));

            return actual && expected && actual.endsWith(expected);
        },

        processSymbols: function (operator) {
            var fnName = ej.data.operatorSymbols[operator];
            if (fnName) {
                var fn = ej.data.fnOperators[fnName];
                if (fn) return fn;
            }

            return throwError("Query - Process Operator : Invalid operator");
        },

        processOperator: function (operator) {
            var fn = ej.data.fnOperators[operator];
            if (fn) return fn;
            return ej.data.fnOperators.processSymbols(operator);
        }
    };

    ej.NotifierArray = function (array) {
        if (!instance(this, ej.NotifierArray))
            return new ej.NotifierArray(array);

        this.array = array;

        this._events = $({});
        this._isDirty = false;

        return this;
    };

    ej.NotifierArray.prototype = {
        on: function (eventName, handler) {
            this._events.on(eventName, handler);
        },
        off: function (eventName, handler) {
            this._events.off(eventName, handler);
        },
        push: function (item) {
            var ret;

            if (instance(item, Array))
                ret = [].push.apply(this.array, item);
            else
                ret = this.array.push(item);

            this._raise("add", { item: item, index: this.length() - 1 });

            return ret;
        },
        pop: function () {
            var ret = this.array.pop();

            this._raise("remove", { item: ret, index: this.length() - 1 });

            return ret;
        },
        addAt: function (index, item) {
            this.array.splice(index, 0, item);

            this._raise("add", { item: item, index: index });

            return item;
        },
        removeAt: function (index) {
            var ret = this.array.splice(index, 1)[0];

            this._raise("remove", { item: ret, index: index });

            return ret;
        },
        remove: function (item) {
            var index = this.array.indexOf(item);

            if (index > -1) {
                this.array.splice(index, 1);
                this._raise("remove", { item: item, index: index });
            }

            return index;
        },
        length: function () {
            return this.array.length;
        },
        _raise: function (e, args) {
            this._events.triggerHandler($.extend({ type: e }, args));
            this._events.triggerHandler({ type: "all", name: e, args: args });
        },
        toArray: function () {
            return this.array;
        }
    };

    $.extend(ej, ej.dataUtil);

    // For IE8
    Array.prototype.forEach = Array.prototype.forEach || function (fn, scope) {
        for (var i = 0, len = this.length; i < len; ++i) {
            fn.call(scope, this[i], i, this);
        }
    };

    Array.prototype.indexOf = Array.prototype.indexOf || function (searchElement) {
        var len = this.length;

        if (len === 0) return -1;

        for (var i = 0; i < len; i++) {
            if (i in this && this[i] === searchElement)
                return i;
        }
        return -1;
    };

    Array.prototype.filter = Array.prototype.filter || function (fn) {
        if (typeof fn != "function")
            throw new TypeError();

        var res = [];
        var thisp = arguments[1] || this;
        for (var i = 0; i < this.length; i++) {
            var val = this[i]; // in case fun mutates this
            if (fn.call(thisp, val, i, this))
                res.push(val);
        }

        return res;
    };

    String.prototype.endsWith = String.prototype.endsWith || function (key) {
        return this.slice(-key.length) === key;
    };

    String.prototype.startsWith = String.prototype.startsWith || function (key) {
        return this.slice(0, key.length) === key;
    };

    if (!ej.support) ej.support = {};
    ej.support.stableSort = function () {
        var res = [0, 1, 2, 3, 4].sort(function () { return 0; });
        return res[0] === 0 && res[1] === 1 && res[2] === 2 && res[3] === 3 && res[4] === 4;
    }();
    ej.support.cors = $.support.cors;

    if (!$.support.cors && window.XDomainRequest) {
        var httpRegEx = /^https?:\/\//i;
        var getOrPostRegEx = /^get|post$/i;
        var sameSchemeRegEx = new RegExp('^' + location.protocol, 'i');
        var xmlRegEx = /\/xml/i;

        // ajaxTransport exists in jQuery 1.5+
        $.ajaxTransport('text html xml json', function (options, userOptions, jqXHR) {
            // XDomainRequests must be: asynchronous, GET or POST methods, HTTP or HTTPS protocol, and same scheme as calling page
            if (options.crossDomain && options.async && getOrPostRegEx.test(options.type) && httpRegEx.test(userOptions.url) && sameSchemeRegEx.test(userOptions.url)) {
                var xdr = null;
                var userType = (userOptions.dataType || '').toLowerCase();
                return {
                    send: function (headers, complete) {
                        xdr = new XDomainRequest();
                        if (/^\d+$/.test(userOptions.timeout)) {
                            xdr.timeout = userOptions.timeout;
                        }
                        xdr.ontimeout = function () {
                            complete(500, 'timeout');
                        };
                        xdr.onload = function () {
                            var allResponseHeaders = 'Content-Length: ' + xdr.responseText.length + '\r\nContent-Type: ' + xdr.contentType;
                            var status = {
                                code: 200,
                                message: 'success'
                            };
                            var responses = {
                                text: xdr.responseText
                            };

                            try {
                                if (userType === 'json') {
                                    try {
                                        responses.json = JSON.parse(xdr.responseText);
                                    } catch (e) {
                                        status.code = 500;
                                        status.message = 'parseerror';
                                        //throw 'Invalid JSON: ' + xdr.responseText;
                                    }
                                } else if ((userType === 'xml') || ((userType !== 'text') && xmlRegEx.test(xdr.contentType))) {
                                    var doc = new ActiveXObject('Microsoft.XMLDOM');
                                    doc.async = false;
                                    try {
                                        doc.loadXML(xdr.responseText);
                                    } catch (e) {
                                        doc = undefined;
                                    }
                                    if (!doc || !doc.documentElement || doc.getElementsByTagName('parsererror').length) {
                                        status.code = 500;
                                        status.message = 'parseerror';
                                        throw 'Invalid XML: ' + xdr.responseText;
                                    }
                                    responses.xml = doc;
                                }
                            } catch (parseMessage) {
                                throw parseMessage;
                            } finally {
                                complete(status.code, status.message, responses, allResponseHeaders);
                            }
                        };
                        xdr.onerror = function () {
                            complete(500, 'error', {
                                text: xdr.responseText
                            });
                        };
                        xdr.open(options.type, options.url);
                        //xdr.send(userOptions.data);
                        xdr.send();
                    },
                    abort: function () {
                        if (xdr) {
                            xdr.abort();
                        }
                    }
                };
            }
        });
    }

    $.support.cors = true;

    ej.sortOrder = {
        Ascending: "ascending",
        Descending: "descending"
    };

    // privates
    ej.pvt.consts = {
        GROUPGUID: "{271bbba0-1ee7}",
        complexPropertyMerge: "_"
    };

    // private utils
    var nextTick = function (fn, context) {
        if (context) fn = $proxy(fn, context);
        (window.setImmediate || window.setTimeout)(fn, 0);
    };

    ej.support.enableLocalizedSort = false;

    var stableSort = function (ds, field, comparer) {
        if (ej.support.stableSort) {
            if(!ej.support.enableLocalizedSort && typeof ej.getObject(field, ds[0] || {}) == "string" 
                && (comparer === ej.pvt.fnAscending || comparer === ej.pvt.fnDescending))
                return fastSort(ds, field, comparer === ej.pvt.fnDescending);
            return ds.sort(ej.pvt.fnGetComparer(field, comparer));
        }
        return ej.mergeSort(ds, field, comparer);
    };

    var fastSort = function(ds, field, isDesc){
        var old = Object.prototype.toString;
        Object.prototype.toString = (field.indexOf('.') === -1) ? function(){
            return this[field];
        }:function(){
            return ej.getObject(field, this);
        };
        ds = ds.sort();
        Object.prototype.toString = old;
        if(isDesc)
            ds.reverse();
    }

    var toLowerCase = function (val) {
        return val ? val.toLowerCase ? val.toLowerCase() : val.toString() : (val === 0 || val === false) ? val.toString() : "";
    };

    var getVal = function (array, field, index) {
        return field ? ej.pvt.getObject(field, array[index]) : array[index];
    };

    var isHtmlElement = function (e) {
        return typeof HTMLElement === "object" ? e instanceof HTMLElement :
            e && e.nodeType === 1 && typeof e === "object" && typeof e.nodeName === "string";
    };

    var instance = function (obj, element) {
        return obj instanceof element;
    };

    var getTableModel = function (name, result, dm, computed) {
        return function (tName) {
            if (typeof tName === "object") {
                computed = tName;
                tName = null;
            }
            return new ej.TableModel(tName || name, result, dm, computed);
        };
    };

    var getKnockoutModel = function (result) {
        return function (computedObservables, ko) {
            ko = ko || window.ko;

            if (!ko) throwError("Knockout is undefined");

            var model, koModels = [], prop, ob;
            for (var i = 0; i < result.length; i++) {
                model = {};
                for (prop in result[i]) {
                    if (!prop.startsWith("_"))
                        model[prop] = ko.observable(result[i][prop]);
                }
                for (prop in computedObservables) {
                    ob = computedObservables[prop];

                    if ($.isPlainObject(ob)) {
                        if (!ob.owner) ob.owner = model;
                        ob = ko.computed(ob);
                    } else
                        ob = ko.computed(ob, model);

                    model[prop] = ob;
                }
                koModels.push(model);
            }

            return ko.observableArray(koModels);
        };
    };

    var uidIndex = 0;
    var getUid = function (prefix) {
        uidIndex += 1;
        return prefix + uidIndex;
    };

    ej.getGuid = function (prefix) {
        var hexs = '0123456789abcdef', rand;
        return (prefix || "") + '00000000-0000-4000-0000-000000000000'.replace(/0/g, function (val, i) {
            rand = Math.random() * 16 | 0;
            return hexs[i === 19 ? rand & 0x3 | 0x8 : rand];
        });
    };

    var proxy = function (fn, context) {
        return function () {
            var args = [].slice.call(arguments, 0);
            args.push(this);

            return fn.apply(context || this, args);
        };
    };

    var $proxy = function (fn, context, arg) {
        if ('bind' in fn)
            return arg ? fn.bind(context, arg) : fn.bind(context);

        return function () {
            var args = arg ? [arg] : []; args.push.apply(args, arguments);
            fn.apply(context || this, args);
        };
    };

    var dateSerialize = function (date) {
        date = JSON.parse(JSON.stringify({ val: date })).val;
        return date.slice(0);
    };

    ej.merge = function (first, second) {
        if (!first || !second) return;

        Array.prototype.push.apply(first, second);
    };

    var isNull = function (val) {
        return val === undefined || val === null;
    };

    var throwError = function (er) {
        try {
            throw new Error(er);
        } catch (e) {
            throw e.message + "\n" + e.stack;
        }
    };

})(window.jQuery, window.Syncfusion, window.document);;

(function ($, ej, undefined) {

    var $document = $(document);
    // add new event shortcuts
    $.each(("touchstart touchmove touchend " +
		"tap doubletap taphold " +
		"swipe swipeleft swiperight " + "pinch pinchin pinchout pinchstop " +
		"scrollstart scrollstop").split(" "), function (i, name) {

		    $.fn[name] = function (fn) {
		        return fn ? this.bind(name, fn) : this.trigger(name);
		    };

		    // jQuery < 1.8
		    if ($.attrFn) {
		        $.attrFn[name] = true;
		    }
		});

    var isPointer = browserInfo().isMSPointerEnabled,
    isIE11Pointer = browserInfo().pointerEnabled,
    supportTouch = 'ontouchstart' in window,
	scrollEvent = "scroll",
	touchStartEvent = isPointer ? (isIE11Pointer ? "pointerdown" : "MSPointerDown") : (supportTouch ? "touchstart" : "mousedown"),
	touchStopEvent = isPointer ? (isIE11Pointer ? "pointerup" : "MSPointerUp") : (supportTouch ? "touchend" : "mouseup"),
	touchMoveEvent = isPointer ? (isIE11Pointer ? "pointermove" : "MSPointerMove") : (supportTouch ? "touchmove" : "mousemove"),
    touchCancelEvent = isPointer ? (isIE11Pointer ? "pointercancel" : "MSPointerCancel") : (supportTouch ? "touchcancel" : "mouseleave"),
    mouseStartEvent = isPointer ? touchStartEvent : "touchstart mousedown",
    mouseStopEvent = isPointer ? touchStopEvent : "touchend mouseup",
    mouseMoveEvent = isPointer ? touchMoveEvent : "touchmove mousemove";

    function browserInfo() {
        var browser = {}, clientInfo = [],
        browserClients = {
            webkit: /(chrome)[ \/]([\w.]+)/i, safari: /(webkit)[ \/]([\w.]+)/i, msie: /(msie) ([\w.]+)/i,
            opera: /(opera)(?:.*version|)[ \/]([\w.]+)/i, mozilla: /(mozilla)(?:.*? rv:([\w.]+)|)/i
        };
        for (var client in browserClients) {
            if (browserClients.hasOwnProperty(client)) {
                clientInfo = navigator.userAgent.match(browserClients[client]);
                if (clientInfo) {
                    browser.name = clientInfo[1].toLowerCase();
                    browser.version = clientInfo[2];
                    if (!!navigator.userAgent.match(/Trident\/7\./)) {
                        browser.name = "msie";
                    }
                    break;
                }
            }
        }
        browser.isMSPointerEnabled = (browser.name == 'msie') && browser.version > 9 && window.navigator.msPointerEnabled;
        browser.pointerEnabled = window.navigator.pointerEnabled;
        return browser;
    }
    function initiateCustomEvent(obj, eventType, e) {
        var originalType = e.type;
        e.type = eventType;
        $.event.dispatch.call(obj, e);
        e.type = originalType;
    }
    function copyObject(e, origEvent) {
        if (origEvent) {
            for (prop in origEvent) {
                if (!(prop in e)) {
                    e[prop] = origEvent[prop];
                }
            }
        }
    }
    $.event.special.ejtouchmove = {
        setup: function () {
            var thisObj = this,
				$this = $(thisObj);
            $this.bind(touchStartEvent, startMoveHandler);
            $document.bind(touchStopEvent, clearTouchMoveHandlers);
            function clearTouchMoveHandlers() {
               // $this.unbind(touchMoveEvent, moveHandler)
            }
            var coords = {};
            function startMoveHandler(e) {
                if (!(e.which && e.which !== 1)) {
                    var origTarget = e.target,
					origEvent = e.originalEvent;
                    if (isPointer)
                        coords = { x: origEvent.x, y: origEvent.y };
                    $this.bind(touchMoveEvent, moveHandler);
                }
            }
            function moveHandler(e) {
                if (!(e.which && e.which !== 1)) {
                    var origTarget = e.target,
					origEvent = e.originalEvent;
                    copyObject(e, e.originalEvent);
                    if (!isPointer || !coords || (Math.abs(coords.x - origEvent.x) > 10 || Math.abs(coords.y - origEvent.y) > 10 && isPointer))
                        initiateCustomEvent(thisObj, "ejtouchmove", e);
                }
            }
        }
    };
    function touchObj(e) {
        return e.originalEvent.touches ?
					e.originalEvent.touches[0] : isPointer ? e.originalEvent : e;
    }
    // handles swipeup and swipedown
    $.event.special.swipeupdown = {
        setup: function () {
            var thisObj = this, $this = $(thisObj);
            checkMsieTouch($this);
            $this.bind(touchStartEvent, function (e) {
                var _startevent = e;
                var data = touchObj(e),
                            startPoint = {
                                time: (new Date).getTime(),
                                coords: [data.pageX, data.pageY],
                                origin: $(e.target)
                            },
                            stopPoint;
                function moveHandler(e) {
                    e.preventDefault();
                    e.stopPropagation();
                    if (!startPoint) return;
                    var data = touchObj(e);
                    stopPoint = {
                        time: (new Date).getTime(),
                        coords: [data.pageX, data.pageY]
                    };
                    if (Math.abs(startPoint.coords[1] - stopPoint.coords[1]) > 10) e.preventDefault();
                }

                $this
                            .bind(touchMoveEvent, moveHandler)
                            .one(touchStopEvent, function (e) {
                                e.preventDefault();
                                $this.unbind(touchMoveEvent, moveHandler);
                                if (startPoint && stopPoint) {
                                    if (stopPoint.time - startPoint.time < 1000 &&
                                    Math.abs(startPoint.coords[1] - stopPoint.coords[1]) > 30 &&
                                    Math.abs(startPoint.coords[0] - stopPoint.coords[0]) < 75) {
                                        var _addDetails = { time: stopPoint.time - startPoint.time, _isSwipe: true, _isDelta: true, stopPoint: stopPoint };
                                        var _options = _getOptions(e, _addDetails, _startevent);

                                        startPoint.origin
                                        .trigger($.extend(true, { type: "swipeupdown" }, _options))
                                        .trigger($.extend(true, { type: startPoint.coords[1] > stopPoint.coords[1] ? "swipeup" : "swipedown" }, _options));
                                    }
                                }
                                startPoint = stopPoint = undefined;
                            });
            });
        }
    };
    $.event.special.scrollstart = {
        isEnabled: true,
        setup: function () {
            var thisObj = this, $this = $(thisObj), scrolling, timer;
            function trigger(e, scrollState) {
                scrolling = scrollState;
                initiateCustomEvent(thisObj, scrolling ? "scrollstart" : "scrollstop", e);
            }
            $this.bind(scrollEvent, function (e) {
                if (!$.event.special.scrollstart.isEnabled) return;
                if (!scrolling) trigger(e, true);
                clearTimeout(timer);
                timer = setTimeout(function () {
                    trigger(e, false);
                }, 250);
            });
        }
    };

    // also handles doubletap, taphold
    $.event.special.tap = {
        doubleTapThreshold: 500,
        tapholdThreshold: 750,
        canDoubleTap: function (d) {
            return ((getTimeSpan() - d.doubleTapStartTime) <= $.event.special.tap.doubleTapThreshold);
        },
        setup: function () {
            var thisObj = this, $this = $(thisObj), d = $this.data();
            checkMsieTouch($this);
            d.isDoubleTapWait = false;
            d.stopProcess = false;
            d.preTouchend = null;
            d.preTouchstart = null;

            $this.bind(mouseStartEvent, function (e) {
                d = $this.data();
                d.startTime = getTimeSpan();
                if (!d.isDoubleTapWait) d.doubleTapStartTime = d.startTime;
                if (e.type == "touchstart") d.preTouchstart = d.startTime;
                // checked mousedown event arrives within 300'ms after the touchend completes
                if (e.type == "mousedown" && (d.startTime - d.preTouchend < 300 || d.startTime - d.preTouchstart < 30))
                    d.stopProcess = true;
                else d.stopProcess = false;

                var origTarget = e.currentTarget,
					origEvent = e.originalEvent,
					timer;

                function clearTapHandlers() {
                    clearTimeout(timer);

                    $this.unbind(mouseStopEvent, clickHandler);
                    $this.unbind(touchCancelEvent, clearTapHandlers);
                    $document.unbind(mouseMoveEvent, touchMoveAction);
                }
                function touchMoveAction(e) {
                    var coor1 = e, coor2 = e;
                    if (isPointer) coor1 = e.originalEvent, coor2 = e.originalEvent;
                    else if (e.type == "touchmove" && e.type == "touchstart")
                        coor1 = e.originalEvent.changedTouches[0],
                        coor2 = e.originalEvent.changedTouches[0];
                    if (!(coor1.pageX == coor2.pageX && coor1.pageY == coor2.pageY))
                        clearTapHandlers();
                }
                function clickHandler(e) {
                    if (e.type == "touchend") d.preTouchend = getTimeSpan();
                    clearTapHandlers();

                    // ONLY trigger a 'tap' event if the startPoint target is
                    // the same as the stopPoint target.
                    if (origTarget === e.currentTarget) {
                        initiateCustomEvent(thisObj, "tap", $.extend(_getBaseOptions(e), {
                            time: getTimeSpan() - d.startTime
                        }));

                        if (d.isDoubleTapWait && $.event.special.tap.canDoubleTap(d)) {
                            d.isDoubleTapWait = false;

                            initiateCustomEvent(thisObj, "doubletap", $.extend(_getBaseOptions(e), {
                                time: getTimeSpan() - d.doubleTapStartTime
                            }));
                        }
                        else {
                            if (d.isDoubleTapWait) {
                                d.isDoubleTapWait = false;
                                d.doubleTapStartTime = d.startTime;
                            }
                            if ($.event.special.tap.canDoubleTap(d)) {
                                d.isDoubleTapWait = true;
                            }
                        }
                    }
                }

                if (!(e.which && e.which !== 1) && !d.stopProcess) {

                    $this.bind(mouseStopEvent, clickHandler);
                    $this.bind(touchCancelEvent, clearTapHandlers);
                    $document.bind(mouseMoveEvent, touchMoveAction);

                    timer = setTimeout(function () {
                        if (d.isDoubleTapWait) d.isDoubleTapWait = false;
                        initiateCustomEvent(thisObj, "taphold", $.extend(_getBaseOptions(e), {
                            options: origEvent,
                            time: getTimeSpan() - d.startTime
                        }));

                    }, $.event.special.tap.tapholdThreshold);
                }
                else if (d.stopProcess) d.stopProcess = false;
            });
        }
    };    
    $.event.special.swipe = {
        scrollSupression: 10,
        duration: 1000,
        horizontalDistance: 30,
        verticalDistance: 75,
        pointers: window.navigator.msPointerEnabled,
        startPoint: function (e) {
            var data = touchObj(e);
            return {
                time: (new Date()).getTime(),
                coords: [data.pageX, data.pageY],
                origin: $(e.target)
            };
        },
        stopPoint: function (e) {
            var data = touchObj(e);
            return {
                time: (new Date()).getTime(),
                coords: [data.pageX, data.pageY]
            };
        },
        handleSwipe: function (startPoint, stopPoint, e, _startevent) {

            if (stopPoint.time - startPoint.time < $.event.special.swipe.duration &&
				Math.abs(startPoint.coords[0] - stopPoint.coords[0]) > $.event.special.swipe.horizontalDistance &&
				Math.abs(startPoint.coords[1] - stopPoint.coords[1]) < $.event.special.swipe.verticalDistance) {

                var _addDetails = { time: stopPoint.time - startPoint.time, _isSwipe: true, _isDelta: true, stopPoint: stopPoint };
                var _options = _getOptions(e, _addDetails, _startevent);

                startPoint.origin.trigger($.extend(true, { type: "swipe" }, _options))
					.trigger($.extend(true,
                    { type: startPoint.coords[0] > stopPoint.coords[0] ? "swipeleft" : "swiperight" }, _options));
            }
        },

        setup: function () {
            var thisObj = this, $this = $(thisObj);
            checkMsieTouch($this);

            $this.bind(touchStartEvent, function (e) {
                var startPoint = $.event.special.swipe.startPoint(e),
					stopPoint;
                var _startevent = e;
                $(e.target).data('_dataTouchStart', { event: e, _now: new Date().getTime() });

                function moveHandler(e) {
                    if (!startPoint) return;
                    stopPoint = $.event.special.swipe.stopPoint(e);
                    if (Math.abs(startPoint.coords[0] - stopPoint.coords[0]) > $.event.special.swipe.scrollSupression) e.preventDefault();
                }

                $this.bind(touchMoveEvent, moveHandler)
					.one(touchStopEvent, function (e) {
					    $this.unbind(touchMoveEvent, moveHandler);
					    if (startPoint && stopPoint) {
					        $.event.special.swipe.handleSwipe(startPoint, stopPoint, e, _startevent);
					    }
					    startPoint = stopPoint = undefined;
					});
            });
        }
    };
    // also handles pinchin, pinchout
    $.event.special.pinch = {
        distance: function (e) {
            if (e.originalEvent.touches.length < 2) return null;
            return $.event.special.pinch._getdistance(e.originalEvent.touches[0], e.originalEvent.touches[1]);
        },
        _getdistance: function (coor1, coor2) {
            return Math.sqrt((coor1.pageX - coor2.pageX) * (coor1.pageX - coor2.pageX) +
                (coor1.pageY - coor2.pageY) * (coor1.pageY - coor2.pageY));
        },
        setup: function () {
            var thisObj = this, $this = $(thisObj);
            checkMsieTouch($this);
            $this.bind(touchStartEvent, function (e) {
                var _startevent = e;
                if (e.originalEvent.touches && e.originalEvent.touches.length >= 2) {
                    var startPoint = $.event.special.pinch.distance(e), stopPoint, minDistance = 5;

                    var _pinchDistance = startPoint, moveEvent;
                    var _options = _getOptions(e, { _isPinch: true, _pinchDistance: _pinchDistance }, _startevent);

                    $(e.target).trigger($.extend(true, { type: "pinch" }, _options));

                    function moveHandler(e) {
                        moveEvent = e;
                        stopPoint = $.event.special.pinch.distance(e) || null;
                        if (startPoint && stopPoint && Math.abs(startPoint - stopPoint) > minDistance) {

                            $(e.target).trigger($.extend(true,
                                { type: startPoint > stopPoint ? "pinchin" : "pinchout" }, _getOptions(e,
                                { _isPinch: true, _pinchDistance: _pinchDistance }, _startevent)));

                            startPoint = stopPoint;
                        }
                    }

                    $this.bind(touchMoveEvent, moveHandler)
                        .one(touchStopEvent, function () {
                            $this.unbind(touchMoveEvent, moveHandler);
                            $(e.target).trigger($.extend(true, { type: "pinchstop" }, _getOptions(moveEvent,
                                { _isPinch: true, _pinchDistance: stopPoint }, _startevent)));
                            startPoint = stopPoint = undefined;
                        });
                }
            });
        }
    };
    //  handles touchdrag, touchdrag
    $.event.special.touchdrag = {

        setup: function () {
            var thisObj = this, $this = $(thisObj);
            checkMsieTouch($this);

            $this.bind(touchStartEvent, function (e) {

                var startPoint = touchObj(e),
					stopPoint;
                var _startevent = e;
                $(e.target).data('_dataTouchStart', { event: e, _now: new Date().getTime() });

                function moveHandler(e) {
                    if (!startPoint) {
                        return;
                    }
                    stopPoint = touchObj(e);

                    if ($.event.special.pinch._getdistance(startPoint, stopPoint) > 5)
                        $(e.target).trigger($.extend(true, { type: "touchdrag" },
                            _getOptions(e, { _isdrag: true, stopPoint: stopPoint, _isDelta: true }, _startevent)));
                }

                $this.bind(touchMoveEvent, moveHandler)
					.one(touchStopEvent, function (e) {
					    $this.unbind(touchMoveEvent, moveHandler);
					    startPoint = stopPoint = undefined;
					});
            });
        }
    };
    function _getBaseOptions(e) {
        var _pointer = isPointer ? e.originalEvent.pointerType : (!e.originalEvent.touches ? "mouse" : "touch")
        var pointerType = (isPointer && isIE11Pointer == undefined) ? (_pointer == 4 ? "mouse" : "touch") : _pointer;
        e["pointerType"] = pointerType;
        if (e.type != "mousedown" && e.type != "mouseup") {
            copyObject(e, e.originalEvent);
        }
        return e;
    }
    function _getOptions(e, _details, _startevent) {
        var _distance, _time, _scale, _iDelta = {}, _startXY, _endXY;
        if (_startevent) {
            var coor;
            if (!_startevent.originalEvent.touches) coor = [_startevent.originalEvent, e.originalEvent];
            else coor = [_startevent.originalEvent.touches[0], e.originalEvent.changedTouches[0]];

            if (_details._isSwipe || _details._isdrag) {
                _distance = $.event.special.pinch._getdistance(coor[0], coor[1]);
                _time = _details.time;
                _endXY = { pageX: _details.stopPoint.pageX, pageY: _details.stopPoint.pageY };
            }
            else if (_details._isPinch) {
                _distance = $.event.special.pinch.distance(e);
                _time = e.timeStamp - _startevent.timeStamp;
                _scale = _details._pinchDistance;
            }
            if (_details._isDelta) {
                _iDelta._dTime = e.timeStamp - _startevent.timeStamp;
                _iDelta._x = coor[1].pageX - coor[0].pageX;
                _iDelta._y = coor[1].pageY - coor[0].pageY;
            }
        }

        return {
            options: e,
            delta: {
                time: _iDelta._dTime || null,
                X: _iDelta._x || null,
                Y: _iDelta._y || null
            },
            distance: _distance,
            scale: _details._isPinch ? _scale : null,
            time: _time,
            velocity: {
                XY: _distance / _iDelta._dTime || null,
                X: _iDelta._x / _iDelta._dTime || null,
                Y: _iDelta._y / _iDelta._dTime || null
            },
            currentPosition: { pageX: _endXY ? _endXY.pageX : null, pageY: _endXY ? _endXY.pageY : null }
        };
    }

    function getTimeSpan() {
        var now = new Date();
        return now.getTime();
    }
    function checkMsieTouch($this) {
        if (isPointer)
            $this.css("-ms-touch-action", "pinch-zoom").css("touch-action", "pinch-zoom");
    }

    $.each({
        scrollstop: "scrollstart",
        doubletap: "tap",
        taphold: "tap",
        swipeleft: "swipe",
        swiperight: "swipe",
        swipedown: "swipeupdown",
        swipeup: "swipeupdown",
        pinchin: "pinch",
        pinchout: "pinch",
        pinchstop: "pinch"
    }, function (event, sourceEvent) {

        $.event.special[event] = {
            setup: function () {
                $(this).bind(sourceEvent, $.noop);
            }
        };
    });

})(jQuery, Syncfusion);;
/**
* @fileOverview Plugin to drag the html elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
	* @class ejDraggable
	* @requires jQuery
	* @requires ej.core
	* @classdesc Custom Design for dragging HTML elements.
	* @example 
	* &lt;div  id="dragable" &gt;&lt;/ div &gt; <br> 
	* &lt;script&gt;
	* // Create Dragable
    * $('#dragable').ejDraggable(); 	
	* &lt;/script&gt;
	*/
    ej.widget("ejDraggable", "ej.Draggable", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["div", "span", "a"],

        // default model
        defaults: {
            /**		
			* Used to group sets of draggable and droppable items, in addition to droppable's accept option. A draggable with the same scope value as a droppable will be accepted by the droppable.
			* @default 'default'
			* @type {string}
			* @example 
			* //To set scope API value during initialization  
			* 	$("#dragable").ejDraggable({ scope: 'default' });				* 
			* @example 
			* //Get or set the scope API, after initialization:<br>
			*	//Gets the scope value  
			*	$("#dragable").ejDraggable('option', 'scope');<br>			
			* @memberof ejDraggable
			* @instance
			*/
            scope: 'default', /*Used to group sets of draggable and droppable items, in addition to droppable's accept option. A draggable with the same scope value as a droppable will be accepted by the droppable.*/
            /**		
			* If specified, restricts drag start click to the specified element(s).
			* @default null
			* @type {string}
			* @example 
			* //To set handle API value during initialization  
			* 	$("#dragable").ejDraggable({ handle: null });				* 
			* @example 
			* //Get or set the handle API, after initialization:<br>
			*	//Gets the handle value  
			*	$("#dragable").ejDraggable('option', 'handle');<br>			
			* @memberof ejDraggable
			* @instance
			*/
            handle: null,  /*If specified, restricts drag start click to the specified element(s).*/
            /**		
			* If Drag area is specified.
			* @default false
			* @type {boolean}
			* @example 
			* //To set dragArea API value during initialization  
			* 	$("#dragable").ejDraggable({ dragArea: true });				* 
			* @example 
			* //Get or set the dragArea API, after initialization:<br>
			*	//Gets the dragArea value  
			*	$("#dragable").ejDraggable('option', 'dragArea');<br>			
			* @memberof ejDraggable
			* @instance
			*/
            dragArea: false,
            /**		
            * If clone is specified.
            * @default false
            * @type {boolean}
            * @example 
            * //To set clone API value during initialization  
            * 	$("#dragable").ejDraggable({ clone: true });				* 
            * @example 
            * //Get or set the clone API, after initialization:<br>
            *	//Gets the clone value  
            *	$("#dragable").ejDraggable('option', 'clone');<br>			
            * @memberof ejDraggable
            * @instance
            */
            clone: false,
            /**		
            * Distance in pixels after mousedown the mouse must move before dragging should start. This option can be used to prevent unwanted drags when clicking on an element.
            * @default 1
            * @type {number}
            * @example 
            * //To set distance API value during initialization  
            * 	$("#dragable").ejDraggable({ distance: 1 });				* 
            * @example 
            * //Get or set the distance API, after initialization:<br>
            *	//Gets the distance value  
            *	$("#dragable").ejDraggable('option', 'distance');<br>			
            * @memberof ejDraggable
            * @instance
            */
            distance: 1, /* Distance in pixels after mousedown the mouse must move before dragging should start. This option can be used to prevent unwanted drags when clicking on an element. */
            /**		
            *Sets the offset of the dragging helper relative to the mouse cursor.
            * @default { top: -1, left: -2 }
            * @type {object}
            * @example 
            * //To set cursorAt API value during initialization  
            * 	$("#dragable").ejDraggable({ cursorAt:  { top: 1, left: -2 } });				* 
            * @example 
            * //Get or set the cursorAt API, after initialization:<br>
            *	//Gets the cursorAt value  
            *	$("#dragable").ejDraggable('option', 'cursorAt');<br>			
            * @memberof ejDraggable
            * @instance
            */
            cursorAt: { top: -1, left: -2 }, /* Sets the offset of the dragging helper relative to the mouse cursor.  */
            /**     
			* Supply a callback function to handle the drag start event as an init option.
			* @event
			* @name ejDraggable#dragStart 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the autocomplete model
			* @param {string}  argument.type returns the name of the event
			* @example 
			* //dragStart event for Draggable
            * $("#dragable").ejDraggable({ 
            *   	dragStart: function(args) {}
            * });      
			* @memberof ejDraggable
			* @instance
			*/
            dragStart: null, /* Supply a callback function to handle the drag start event as an init option. */
            /**     
			* This event is triggered when the mouse is moved during the dragging.
			* @event
			* @name ejDraggable#drag 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the autocomplete model
			* @param {string}  argument.type returns the name of the event
			* @example 
			* //drag event for Draggable
            * $("#dragable").ejDraggable({ 
            *   	drag: function(args) {}
            * });      
			* @memberof ejDraggable
			* @instance
			*/
            drag: null, /* This event is triggered when the mouse is moved during the dragging. */
            /**     
            * This event is triggered when the mouse is moved during the dragging.
            * @event
            * @name ejDraggable#dragStop 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //dragStop event for Draggable
            * $("#dragable").ejDraggable({ 
            *   	dragStop: function(args) {}
            * });      
            * @memberof ejDraggable
            * @instance
            */
            dragStop: null, /* This event is triggered when dragging stops. */
            /**     
            * This event is triggered when dragging events are destroyed.
            * @event
            * @name ejDraggable#destroy 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //destroy event for Draggable
            * $("#dragable").ejDraggable({ 
            *   	destroy: function(args) {}
            * });      
            * @memberof ejDraggable
            * @instance
            */
            destroy: null, /* This event is triggered when dragging events are destroyed. */
            /**     
            * This event is triggered when dragged.
            * @event
            * @name ejDraggable#helper 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //helper event for Draggable
            * $("#dragable").ejDraggable({ 
            *   	helper: function () {
                return $('<div class="e-drag-helper" />').html("draggable").appendTo(document.body);}
            * });      
            * @memberof ejDraggable
            * @instance
            */
            helper: function () {
                return $('<div class="e-drag-helper" />').html("draggable").appendTo(document.body);
            }
        },

        // constructor function
        _init: function () {
            this.handler = function () { },
			this.resizables = {},
			helpers = {};
            this._wireEvents();
        },

        _setModel: function (options) {

        },
        /**
        * destroy in the dragable.
        * @return jQuery
        * @example 
        * &lt; div  id="dragable" &gt; &lt;/div &gt; <br> 
        * &lt;script&gt;
        * // Create dragableObj
        * var dragableObj  = $("#dragable").data("ejDraggable");
        * dragableObj.destroy(); 
        * &lt;/script&gt;
        *@memberof ejDraggable
        * @instance
        */
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            $(document)
                .unbind(ej.eventType.mouseUp, this._destroyHandler)
                .unbind(ej.eventType.mouseUp, this._dragStopHandler)
                .unbind(ej.eventType.mouseMove, this._dragStartHandler)
                .unbind(ej.eventType.mouseMove, this._dragHandler)
                .unbind('selectstart', false);

            // this._raise(e, this.destroy);

            ej.widgetBase.droppables[this.scope] = null;
            //helpers[this.handle] = null;
        },

        _initialize: function (e) {
            var ori = e;
            e.preventDefault();
            e = this._getCoordinate(e);
            this.target = $(ori.currentTarget);
            this._initPosition = { x: e.pageX, y: e.pageY };
            
            $(document).bind(ej.eventType.mouseMove, this._dragStartHandler).bind(ej.eventType.mouseUp, this._destroyHandler);
            if (!this.model.clone) {
                var _offset = this.element.offset();
                this._relXposition = e.pageX - _offset.left;
                this._relYposition = e.pageY - _offset.top;
            }
            $(document.documentElement).trigger(ej.eventType.mouseDown, ori); // The next statement will prevent 'mousedown', so manually trigger it.
           //return false;
        },
        _setDragArea: function () {
            var _dragElement = $(this.model.dragArea)[0]; if (!_dragElement) return;
            var over = ($(_dragElement).css("overflow") != 'hidden');

            this.dragArea = [
                (parseInt($(_dragElement).css("borderLeftWidth"), 10) || 0) + (parseInt($(_dragElement).css("paddingLeft"), 10) || 0),
                (parseInt($(_dragElement).css("borderTopWidth"), 10) || 0) + (parseInt($(_dragElement).css("paddingTop"), 10) || 0),
                (over ? Math.max(_dragElement.scrollWidth, _dragElement.offsetWidth) : _dragElement.offsetWidth) - (parseInt($(_dragElement).css("borderLeftWidth"), 10) || 0) - (parseInt($(_dragElement).css("paddingRight"), 10) || 0) - this.helper.outerWidth() - this.margins.left - this.margins.right,
                (over ? Math.max(_dragElement.scrollHeight, _dragElement.offsetHeight) : _dragElement.offsetHeight) - (parseInt($(_dragElement).css("borderTopWidth"), 10) || 0) - (parseInt($(_dragElement).css("paddingBottom"), 10) || 0) - this.helper.outerHeight() - this.margins.top - this.margins.bottom
            ];
            this.relativeArea = $(this.model.dragArea);
        },
        _dragStart: function (e) {
            var ori = e;
            e = this._getCoordinate(e);
            
            this.margins = {
                left: (parseInt(this.element.css("marginLeft"), 10) || 0),
                top: (parseInt(this.element.css("marginTop"), 10) || 0),
                right: (parseInt(this.element.css("marginRight"), 10) || 0),
                bottom: (parseInt(this.element.css("marginBottom"), 10) || 0)
            };
            this.offset = this.element.offset();
            this.offset = {
                top: this.offset.top - this.margins.top,
                left: this.offset.left - this.margins.left
            };
            this.position = this._getMousePosition(ori);
            var x = this._initPosition.x - e.pageX, y = this._initPosition.y - e.pageY;
            var distance = Math.sqrt((x * x) + (y * y));

            if (distance >= this.model.distance) {
                var dragTargetElmnt = this.model.handle = this.helper = this.model.helper({ sender: ori, element: this.target });
                if (this.model.dragArea)
                    this._setDragArea();

                //if (!this.model.clone)
                //    this.position.left = this.position.left - (ori.target.offsetWidth / 2);
                //this.position.top = this.position.top - (ori.target.offsetHeight - ori.offsetY);

                if (this.model.dragStart) {
                    var currTarget = null;
                    if (ori.type == 'touchmove') {
                        var coor = ori.originalEvent.changedTouches[0];
                        currTarget = document.elementFromPoint(coor.pageX, coor.pageY);
                    }
                    else currTarget = ori.originalEvent.target || ori.target;
                    if (this._trigger("dragStart", { event: ori, element: this.element, target: currTarget })) {
                        this._destroy();
                        return false;
                    }
                }

                $(document).unbind(ej.eventType.mouseMove, this._dragStartHandler).unbind(ej.eventType.mouseUp, this._destroyHandler)
                    .bind(ej.eventType.mouseMove, this._dragHandler).bind(ej.eventType.mouseUp, this._dragStopHandler).bind("selectstart", false);
                ej.widgetBase.droppables[this.model.scope] = {
                    draggable: this.element,
                    helper: dragTargetElmnt.css({ position: 'absolute', left: this.position.left, top: this.position.top }),
                    destroy: this._destroyHandler
                }
            }
        },

        _drag: function (e) {
            this.position = this._getMousePosition(e);
            if (this.position.top < 0)
                this.position.top = 0;
            if ($(document).height() < this.position.top)
                this.position.top = $(document).height();
            if ($(document).width() < this.position.left)
                this.position.left = $(document).width();
            var helperElement = ej.widgetBase.droppables[this.model.scope].helper;
            if (this.model.drag) {
                var currTarget = null;
                if (e.type == 'touchmove') {
                    var coor = e.originalEvent.changedTouches[0];
                    currTarget = document.elementFromPoint(coor.pageX, coor.pageY);
                }
                else currTarget = e.originalEvent.target || e.target;
                this._trigger("drag", { event: e, element: this.target, target: currTarget });// Raise the dragging event
            }
            ej.widgetBase.droppables[this.model.scope].helper.css({ left: this.position.left, top: this.position.top });
        },

        _dragStop: function (e) {
            if (e.type == 'mouseup' || e.type == 'touchend') 
                this._destroy(e);
            if (this.model.dragStop) {
                var currTarget = null;
                if (e.type == 'touchend') {
                    var coor = e.originalEvent.changedTouches[0];
                    currTarget = document.elementFromPoint(coor.pageX, coor.pageY);
                }
                else currTarget = e.originalEvent.target || e.target;
                this._trigger("dragStop", { event: e, element: this.target, target: currTarget });// Raise the dragstop event
            }
        },

        _wireEvents: function () {
            this._on(this.element, ej.eventType.mouseDown, this._initialize);
            this._dragStartHandler = $.proxy(this._dragStart, this);
            this._destroyHandler = $.proxy(this._destroy, this);
            this._dragStopHandler = $.proxy(this._dragStop, this);
            this._dragHandler = $.proxy(this._drag, this);
        },
        _getMousePosition: function (event) {
            event = this._getCoordinate(event);
            var pageX = this.model.clone ? event.pageX : event.pageX - this._relXposition;
            var pageY = this.model.clone ? event.pageY : event.pageY - this._relYposition;
            if (this.dragArea) {
                if (this.relativeArea) {
                    var co = this.relativeArea.offset();
                    _area = [this.dragArea[0] + co.left, this.dragArea[1] + co.top, this.dragArea[2] + co.left, this.dragArea[3] + co.top];
                }
                else {
                    _area = this.dragArea;
                }
                if (event.pageX - this.margins.left < _area[0]) pageX = _area[0] + this.margins.left;
                if (event.pageY - this.margins.top < _area[1]) pageY = _area[1] + this.margins.top;
                if (event.pageX - this.margins.left > _area[2]) pageX = _area[2] + this.margins.left;
                if (event.pageY - this.margins.top > _area[3]) pageY = _area[3] + this.margins.top;
            }
            return { left: pageX - this.margins.left - this.model.cursorAt.left, top: pageY - this.margins.top - this.model.cursorAt.top };
        },
        _getCoordinate: function (evt) {
            var coor = evt;
            if (evt.type == "touchmove" || evt.type == "touchstart" || evt.type == "touchend")
                coor = evt.originalEvent.changedTouches[0];
            return coor;
        }
    });

})(jQuery, Syncfusion);

/**
* @fileOverview Plugin to drop the html elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
   * @namespace ej
   * @class ejDroppable
   * @requires jQuery
   * @requires ej.core
   * @classdesc Custom Design for droping HTML elements.
   * @example 
   * &lt;div  id="dropable" &gt;&lt;/ div &gt; <br> 
   * &lt;script&gt;
   * // Create Dragable
   * $('#dropable').ejDroppable(); 	
   * &lt;/script&gt;
   */
    // Example plugin creation code
    // sfSample is the plugin name 
    // "ej.Sample" is "namespace.className" will hold functions and properties

    ej.widget("ejDroppable", "ej.Droppable", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["div", "span", "a"],

        // default model
        defaults: {
            /**		
			* Used to accept the droppable items.
			* @default null
			* @type {object}
			* @example 
			* //To set scope API value during initialization  
			* 	$("#droppable").ejDroppable({ accept: null });				* 
			* @example 
			* //Get or set the accept API, after initialization:<br>
			*	//Gets the accept value  
			*	$("#droppable").ejDroppable('option', 'accept');<br>			
			* @memberof ejDroppable
			* @instance
			*/
            accept: null,
            /**		
			* Used to group sets of droppable items, in addition to droppable's accept option. A draggable with the same scope value as a droppable will be accepted by the droppable.
			* @default 'default'
			* @type {string}
			* @example 
			* //To set scope API value during initialization  
			* 	$("#droppable").ejDroppable({ scope: 'default' });				* 
			* @example 
			* //Get or set the scope API, after initialization:<br>
			*	//Gets the scope value  
			*	$("#droppable").ejDroppable('option', 'scope');<br>			
			* @memberof ejDroppable
			* @instance
			*/
            scope: 'default',
            /**     
			* This event is triggered when the mouse up is moved during the dragging.
			* @event
			* @name ejDroppable#drop 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the autocomplete model
			* @param {string}  argument.type returns the name of the event
			* @example 
			* //drop event for Droppable
            * $("#droppable").ejDroppable({ 
            *   	drop: function(args) {}
            * });      
			* @memberof ejDroppable
			* @instance
			*/
            drop: null,
            /**     
            * This event is triggered when the mouse  is moved over.
            * @event
            * @name ejDroppable#over 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //drop event for Droppable
            * $("#droppable").ejDroppable({ 
            *   	over: function(args) {}
            * });      
            * @memberof ejDroppable
            * @instance
            */
            over: null,
            /**     
            * This event is triggered when the mouse  is moved out.
            * @event
            * @name ejDroppable#out 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //drop event for Droppable
            * $("#droppable").ejDroppable({ 
            *   	out: function(args) {}
            * });      
            * @memberof ejDroppable
            * @instance
            */
            out: null
        },

        // constructor function
        _init: function () {
            if (this.model.accept) {
                $(this.element).delegate(this.accept, 'mouseenter', $.proxy(this._over, this))
							.delegate(this.accept, 'mouseup', $.proxy(this._drop, this))
							.delegate(this.accept, 'mouseleave', $.proxy(this._out, this));
            }
            else {
                $(this.element).bind('mouseup', $.proxy(this._drop, this));
                $(this.element).bind("mouseenter", $.proxy(this._over, this));
                $(this.element).bind("mouseleave", $.proxy(this._out, this));
            }
            this._on($(document), 'touchend', this._drop);
        },

        _setModel: function (options) {

        },
        /**
        * destroy in the Droppable.
        * @return jQuery
        * @example 
        * &lt; div  id="droppable" &gt; &lt;/div &gt; <br> 
        * &lt;script&gt;
        * // Create droppabaleObj
        * var droppabaleObj  = $("#droppable").data("ejDroppable");
        * droppabaleObj.destroy(); 
        * &lt;/script&gt;
        *@memberof ejDroppable
        * @instance
        */
        // all events bound using this._on will be unbind automatically
        _destroy: function () {

        },

        _over: function (e) {
            this._trigger("mouseover", e);  
        },
        _out: function (e) {
            this._trigger("mouseout", e);  
        },
        _drop: function (e) {
            var drag = ej.widgetBase.droppables[this.model.scope];
            var isDragged = !ej.isNullOrUndefined(drag.helper) && drag.helper.is(":visible");
            var area = this._isDropArea(e);
            if (drag && !ej.isNullOrUndefined(this.model.drop) && isDragged && area.canDrop) {
                this.model.drop($.extend(e, { dropTarget: area.target }, true), drag);
            }
        },
        _isDropArea: function (e) {
            // check for touch devices only
            var area = { canDrop: true, target: $(e.target) };
            if (e.type == "touchend") {
                var coor = e.originalEvent.changedTouches[0], _target;
                _target = document.elementFromPoint(coor.pageX, coor.pageY);
                area.canDrop = false;
                var _parents = $(_target).parents();

                for (var i = 0; i < this.element.length; i++) {
                    if ($(_target).is($(this.element[i]))) area = { canDrop: true, target: $(_target) };
                    else for (var j = 0; j < _parents.length; j++) {
                        if ($(this.element[i]).is($(_parents[j]))) {
                            area = { canDrop: true, target: $(_target) };
                            break;
                        }
                    }
                    if (area.canDrop) break;
                }
            }
            return area;
        }
    });

})(jQuery, Syncfusion);

/**
* @fileOverview Plugin to resize the Html elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejResizable
    * @requires jQuery
    * @requires ej.core
    * @classdesc Custom Design for resizing HTML elements.
    * @example 
    * &lt;div  id="resizing" &gt;&lt;/ div &gt; <br> 
    * &lt;script&gt;
    * // Create resizing
    * $('#resizing').ejResizable(); 	
    * &lt;/script&gt;
    */
    ej.widget("ejResizable", "ej.resizable", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["div", "span", "a"],

        // default model
        defaults: {
            /**		
           * Used to group sets of resizeable items.
           * @default 'default'
           * @type {string}
           * @example 
           * //To set scope API value during initialization  
           * 	$("#resizing").ejResizable({ scope: 'default' });				* 
           * @example 
           * //Get or set the scope API, after initialization:<br>
           *	//Gets the scope value  
           *	$("#resizing").ejResizable('option', 'scope');<br>			
           * @memberof ejResizable
           * @instance
           */
            scope: 'default',
            /**		
			* If specified, restricts resize start click to the specified element(s).
			* @default null
			* @type {string}
			* @example 
			* //To set handle API value during initialization  
			* 	$("#resizing").ejResizable({ handle: null });				* 
			* @example 
			* //Get or set the handle API, after initialization:<br>
			*	//Gets the handle value  
			*	$("#resizing").ejResizable('option', 'handle');<br>			
			* @memberof ejResizable
			* @instance
			*/
            handle: null,
            /**		
            * Distance in pixels after mousedown the mouse must move before resizing should start. This option can be used to prevent unwanted drags when clicking on an element.
            * @default 1
            * @type {number}
            * @example 
            * //To set distance API value during initialization  
            * 	$("#resizing").ejResizable({ distance: 1 });				* 
            * @example 
            * //Get or set the distance API, after initialization:<br>
            *	//Gets the distance value  
            *	$("#resizing").ejResizable('option', 'distance');<br>			
            * @memberof ejResizable
            * @instance
            */
            distance: 1,
            /**		
            *Sets the max height for resizing
            * @default null
            * @type {number}
            * @example 
            * //To set maxHeight API value during initialization  
            * 	$("#resizing").ejResizable({ maxHeight: null });				* 
            * @example 
            * //Get or set the maxHeight API, after initialization:<br>
            *	//Gets the maxHeight value  
            *	$("#resizing").ejResizable('option', 'maxHeight');<br>			
            * @memberof ejResizable
            * @instance
            */
            maxHeight: null,
            /**		
            *Sets the max width for resizing
            * @default null
            * @type {number}
            * @example 
            * //To set maxWidth API value during initialization  
            * 	$("#resizing").ejResizable({ maxWidth: null });				* 
            * @example 
            * //Get or set the maxWidth API, after initialization:<br>
            *	//Gets the maxWidth value  
            *	$("#resizing").ejResizable('option', 'maxWidth');<br>			
            * @memberof ejResizable
            * @instance
            */
            maxWidth: null,
            /**		
            *Sets the min Height for resizing
            * @default 10
            * @type {number}
            * @example 
            * //To set minHeight API value during initialization  
            * 	$("#resizing").ejResizable({ minHeight: null });				* 
            * @example 
            * //Get or set the minHeight API, after initialization:<br>
            *	//Gets the minHeight value  
            *	$("#resizing").ejResizable('option', 'minHeight');<br>			
            * @memberof ejResizable
            * @instance
            */
            minHeight: 10,
            /**		
            *Sets the min Width for resizing
            * @default 10
            * @type {number}
            * @example 
            * //To set minWidth API value during initialization  
            * 	$("#resizing").ejResizable({ minWidth: null });				* 
            * @example 
            * //Get or set the minWidth API, after initialization:<br>
            *	//Gets the minWidth value  
            *	$("#resizing").ejResizable('option', 'minWidth');<br>			
            * @memberof ejResizable
            * @instance
            */
            minWidth: 10,
            /**		
            *Sets the offset of the resizing helper relative to the mouse cursor.
            * @default { top: -1, left: -2 }
            * @type {object}
            * @example 
            * //To set cursorAt API value during initialization  
            * 	$("#resizing").ejResizable({ cursorAt:  { top: 1, left: -2 } });				* 
            * @example 
            * //Get or set the cursorAt API, after initialization:<br>
            *	//Gets the cursorAt value  
            *	$("#resizing").ejResizable('option', 'cursorAt');<br>			
            * @memberof ejResizable
            * @instance
            */
            cursorAt: { top: 1, left: 1 },
            /**     
            * This event is triggered when the resizing is start.
            * @event
            * @name ejResizable#resizeStart 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //resizeStart event for Resizable
            * $("#resizing").ejResizable({ 
            *   	resizeStart: function(args) {}
            * });      
            * @memberof ejResizable
            * @instance
            */
            resizeStart: null,
            /**     
            * This event is triggered when the resizing in progress.
            * @event
            * @name ejResizable#resize 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //resizeStart event for Resizable
            * $("#resizing").ejResizable({ 
            *   	resize: function(args) {}
            * });      
            * @memberof ejResizable
            * @instance
            */
            resize: null,
            /**     
            * This event is triggered when the resizing is stop.
            * @event
            * @name ejResizable#resizeStop 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the autocomplete model
            * @param {string}  argument.type returns the name of the event
            * @example 
            * //resizeStop event for Resizable
            * $("#resizing").ejResizable({ 
            *   	resizeStop: function(args) {}
            * });      
            * @memberof ejResizable
            * @instance
            */
            resizeStop: null,
            /**     
           * This event is triggered when the widget destroys.
           * @event
           * @name ejResizable#resizeStop 	
           * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
           * @param {object}  argument.model returns the autocomplete model
           * @param {string}  argument.type returns the name of the event
           * @example 
           * //destroy event for Resizable
           * $("#resizing").ejResizable({ 
           *   	destroy: function(args) {}
           * });      
           * @memberof ejResizable
           * @instance
           */
            destroy: null,
            /**     
           * This event is triggered when resized.
           * @event
           * @name ejResizable#helper 	
           * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
           * @param {object}  argument.model returns the autocomplete model
           * @param {string}  argument.type returns the name of the event
           * @example 
           * //helper event for Resizable
           * $("#resizing").ejResizable({ 
           *   	helper: function () {
               return $('<div class="e-resize-helper" />').html("resizable").appendTo(document.body);}
           * });      
           * @memberof ejResizable
           * @instance
           */
            helper: function () {
                return $('<div class="e-resize-helper" />').html("resizable").appendTo(document.body);
            }
        },
        // constructor function
        _init: function () {
            this.target = this.element;
            if (this.handle != null) {
                $(this.target).delegate(this.handle, ej.eventType.mouseDown, $.proxy(this._mousedown, this))
                .delegate(this.handle, 'resizestart', this._blockDefaultActions);
            }
            else {
                //$(this.target).bind("mousedown", $.proxy(this._mousedown, this));
                $(this.target).bind("mouseover", $.proxy(this._mouseover, this));
                // .bind("resizestart", $.proxy(this, $.Handler(this._init, this)));
            }

            this._resizeStartHandler = $.proxy(this._resizeStart, this);
            this._destroyHandler = $.proxy(this._destroy, this);
            this._resizeStopHandler = $.proxy(this._resizeStop, this);
            this._resizeHandler = $.proxy(this._resize, this);
        },
        _mouseover: function (e) {
            if ($(e.target).hasClass("e-resizable")) {
                $(e.target).css({ cursor: "se-resize" });
                $(this.target).bind(ej.eventType.mouseDown, $.proxy(this._mousedown, this));
            }
            else {
                $(this.target).unbind(ej.eventType.mouseDown);
                $(this.target).css({ cursor: "" });
            }
        },
        _blockDefaultActions: function (e) {
            e.cancelBubble = true;
            e.returnValue = false;
            if (e.preventDefault) e.preventDefault();
            if (e.stopPropagation) e.stopPropagation();
        },
        _setModel: function (options) {

        },
        _mousedown: function (e) {
            var ori = e;
            e = this._getCoordinate(e);
            this.target = $(ori.currentTarget);
            this._initPosition = { x: e.pageX, y: e.pageY };

            $(document).bind(ej.eventType.mouseMove, this._resizeStartHandler).bind(ej.eventType.mouseUp, this._destroyHandler);

            $(document.documentElement).trigger(ej.eventType.mouseDown, ori); // The next statement will prevent 'mousedown', so manually trigger it.
            return false;
        },

        _resizeStart: function (e) {
            if ($(e.target).hasClass("e-resizable")) {
                e = this._getCoordinate(e);
                var x = this._initPosition.x - e.pageX, y = this._initPosition.y - e.pageY;
                var distance = Math.sqrt((x * x) + (y * y));
                if (distance >= this.model.distance) {
                    if (this.model.resizeStart != null)
                        this.model.resizeStart({ element: this.target });  // Raise the resize start event
                    var resizeTargetElmnt = this.model.helper({ element: this.target });
                    var pos = this.getElementPosition(resizeTargetElmnt);
                    $(document).unbind(ej.eventType.mouseMove, this._resizeStartHandler).unbind(ej.eventType.mouseUp, this._destroyHandler)
                        .bind(ej.eventType.mouseMove, this._resizeHandler).bind(ej.eventType.mouseUp, this._resizeStopHandler).bind("selectstart", false);
                    ej.widgetBase.resizables[this.scope] = {
                        resizable: this.target,
                        helper: resizeTargetElmnt.css({ width: (e.pageX - pos.left) + this.model.cursorAt.left, height: (e.pageY - pos.top) + this.model.cursorAt.top }),
                        destroy: this._destroyHandler
                    }
                }
            }
        },

        _resize: function (e) {
            e = this._getCoordinate(e);
            if (this.model.resize != null)
                this.model.resize({ element: this.target });  // Raise the drag start event
            var pos = this.getElementPosition(ej.widgetBase.resizables[this.scope].helper);
            var _width = (e.pageX - pos.left) + this.model.cursorAt.left;
            var _height = (e.pageY - pos.top) + this.model.cursorAt.top;
            if (_width < this.model.minWidth)
                _width = this.model.minWidth;
            if (_height < this.model.minHeight)
                _height = this.model.minHeight;
            if (this.model.maxHeight != null && _height > this.model.maxHeight)
                _height = this.model.maxHeight;
            if (this.model.maxWidth != null && _width > this.model.maxWidth)
                _width = this.model.maxWidth;
            ej.widgetBase.resizables[this.scope].helper.css({ width: _width, height: _height });
        },

        _resizeStop: function (e) {
            if (this.model.resizeStop != null)
                this.model.resizeStop({ element: this.target });  // Raise the resize stop event
            if (e.type == 'mouseup' || e.type == 'touchend')
                this._destroy(e);
        },
        /**
        * destroy in the Resizable.
        * @return jQuery
        * @example 
        * &lt; div  id="resizing" &gt; &lt;/div &gt; <br> 
        * &lt;script&gt;
        * // Create resizingObj
        * var resizingObj  = $("#resizing").data("ejResizable");
        * resizingObj.destroy(); 
        * &lt;/script&gt;
        *@memberof ejResizable
        * @instance
        */
        _destroy: function (e) {
            $(document)
                .unbind(ej.eventType.mouseUp, this._destroyHandler)
                .unbind(ej.eventType.mouseUp, this._resizeStopHandler)
                .unbind(ej.eventType.mouseMove, this._resizeStartHandler)
                .unbind(ej.eventType.mouseMove, this._resizeHandler)
                .unbind('selectstart', false);

            // this._raise(e, this.destroy);

            ej.widgetBase.resizables[this.scope] = null;
            //helpers[this.handle] = null;
        },

        getElementPosition: function (elemnt) {
            if (elemnt != null && elemnt.length > 0)
                return {
                    left: elemnt[0].offsetLeft,
                    top: elemnt[0].offsetTop
                };
            else
                return null;
        },
        _getCoordinate: function (evt) {
            var coor = evt;
            if (evt.type == "touchmove" || evt.type == "touchstart" || evt.type == "touchend")
                coor = evt.originalEvent.changedTouches[0];
            return coor;
        }
    });

})(jQuery, Syncfusion);;
/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, window, undefined) {
    'use strict';
    /**
* @namespace ej
* @class ejScroller
* @requires jQuery
* @requires ej.core.js
* @requires ej.scroller.js
* @requires ej.draggable.js
* @classdesc Custom Design for Html Scroller control.
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
		*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
         *&lt;b&gt;A controller*&lt;/b&gt;  can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
         It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt;     
*&lt;/div&gt; <br> 
* &lt;script&gt;
* // Create Scroller
* $('#scrollcontent').ejScroller(); 	
* &lt;/script&gt;
*/
    ej.widget("ejScroller", "ej.Scroller", {
        defaults: {
            /**		
* Specifies the height of Scroll panel and scrollbars.
* @default 250
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set height API value during initialization  
* 	$("#scrollcontent").ejScroller({height: 200 });	
* &lt;/script&gt;
 * @memberof ejScroller
* @instance
*/
            height: 250,
            /**		
* Specifies the width of Scroll panel and scrollbars.
* @default 0
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set width API value during initialization
* 	$("#scrollcontent").ejScroller({width: 500 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            width: 0,
            /**		
* While press on the arrow key the scrollbar position added to the given pixel value.
* @default 57
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set scrollOneStepBy API value during initialization
* 	$("#scrollcontent").ejScroller({scrollOneStepBy: 40 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            scrollOneStepBy: 57,
            /**		
* Specifies the button height for vertical scrollbar; for horizontal scrollbar specifies the width of the button in the scrollbar.
* @default 18
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set Button Size of Scroller during initialization
* 	$("#scrollcontent").ejScroller({buttonSize: 20 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            buttonSize: 18,
            /**		
* The Scroller content and scrollbars move left with given value. 
* @default 0
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set Scroll left API during initialization
* 	$("#scrollcontent").ejScroller({scrollLeft: 40 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            scrollLeft: 0,
            /**		
* The Scroller content and scrollbars move to top position with specified value. 
* @default 0
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set Scroll top API during initialization
* 	$("#scrollcontent").ejScroller({scrollTop: 40 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            scrollTop: 0,
            /**		
* Indicates the target area to which scroller have to appear. 
* @default null
* @type {string}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //To set Scroller for the specified target panel during initialization
* 	$("#scrollcontent").ejScroller({targetPane: "contentarea" });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            targetPane:null,
            /**		
* Set the Scrollbar height and width for this API; if vertical scrollbar,apply the width else apply the height.
* @default 18
* @type {number}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //Enable scrollerSize on initialization 
* 	//To set scroller Size API value 
* 	$("#scrollcontent").ejScroller({scrollerSize: 20 });	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
            scrollerSize: 18,
            /**		
* Save current model value to browser cookies for state maintanence. While refresh the page Rating control values are retained.  
* @default false
* @type {boolean}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //Enable enablePersistence API on initialization
* 	$("#scrollcontent").ejScroller({enablePersistence: true });
* &lt;/script&gt;	
* @memberof ejScroller
* @instance
*/
            enablePersistence: false,
            /**		
* Indicates the Right to Left direction to scroller  
* @default undefined
* @type {boolean}
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //Enable enableRTL API on initialization
* 	$("#scrollcontent").ejScroller({enableRTL: true });	
* &lt;/script&gt;	
* @memberof ejScroller
* @instance
*/
            enableRTL: undefined,
            /**		
* Enables or Disbale the touch Scroll  
* @default true
* @type {boolean}
* @example 

* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //Disable Touch Scroll API on initialization
* 	$("#scrollcontent").ejScroller({enableTouchScroll: false });	
* &lt;/script&gt;	
* @memberof ejScroller
* @instance
*/
            enableTouchScroll: true,
/**     
* Fires when Scroller control is created.
* @event
* @name ejScroller#create	
* @param {Object} argument Event parameters from scroller     
* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
* @param {object}  argument.model returns the scroller model
* @param {string}  argument.type returns the name of the event.
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //create event for scroller
* $("#scrollcontent").ejScroller({
*    create: function (args) {}
* });   
* &lt;/script&gt;	  
* @memberof ejScroller
* @instance
*/
            create: null,
            /**     
* Fires when Scroller control is destroyed.
* @event
* @name ejScroller#destroy	
* @param {Object} argument Event parameters from scroller     
* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
* @param {object}  argument.model returns the scroller model
* @param {string}  argument.type returns the name of the event.
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* //destroy event for scroller
* $("#scrollcontent").ejScroller({
*    destroy: function (args) {}
* });  
* &lt;/script&gt;	    
* @memberof ejScroller
* @instance
*/
            destroy: null
        },
        validTags: ["div"],
        type: "transclude",
        /**
* Specify the data types for default properties 
* @private
*/
        dataTypes: {
            buttonSize: "number",
            scrollOneStepBy: "number"
        },
        observables: ["scrollTop", "scrollLeft"],
        scrollTop: ej.util.valueFunction("scrollTop"),
        scrollLeft: ej.util.valueFunction("scrollLeft"),
        /**
* Specifies the keys used for keyboard navigation. 
* @private
*/
        keyConfigs: {
            up: "38",
            down: "40",
            left: "37",
            right: "39",
            pageUp: "33",
            pageDown: "34",
            pageLeft: "ctrl+37",
            pageRight: "ctrl+39"
        },
        /**
* Specify the content area for which the scrollerbar is specified.
* @private
*/
        content: function () {
            if (!this._content || !this._content.length || !this._content[0].offsetParent)
                this._content = this.element.children("div").first().addClass("e-content");

            return this._content;
        },
        _setFirst: true,
        /**
* Create the scroller widget
* @private
*/
        _init: function () {
            this.element.addClass("e-widget");
            this.content();
            this._ensureScrollers();
            if (this.model.enableRTL === undefined) {
                this.model.enableRTL = this.element.css("direction") === "rtl";
            }
            if (this.model.enableRTL) {
                this.element.addClass("e-rtl");
            }
            if (this.scrollLeft())
                this.content().scrollLeft(this.scrollLeft());
            if (this.scrollTop())
                this.content().scrollTop(this.scrollTop());

            this._on(this.content(), "scroll", this._scroll);
            this.model.targetPane != null && this._on(this.content().find(this.model.targetPane), "scroll", this._scroll);
        },
        /**
* Ensures the scrollbar height and width.
* @private
*/
        _ensureScrollers: function () {
            var jqVersion = $.fn.jquery, height, width;
            if (this.model.height) {
                this.element.height(this.model.height);
            }
            if (this.model.width) {
                this.element.width(this.model.width);
            }

            this._off(this.content(), "mousedown touchstart");

            if (this.isVScroll()) {
                if (!this._v) {
                    var d1 = this._createScroller("Height", "Y", "Top", "e-v", this.isHScroll());

                    if (this.model.enableTouchScroll)
                        this._on(this.content(), "mousedown touchstart", { d: d1 }, this._mouseDownOnContent);
                }
            } else {
                this._v = null;
                this.element.find(".e-vscroll").remove();
            }
            if (this.isHScroll()) {
                if (!this._h) {
                    var d2 = this._createScroller("Width", "X", "Left", "e-h", this.isVScroll());

                    if (this.model.enableTouchScroll)
                        this._on(this.content(), "mousedown touchstart", { d: d2 }, this._mouseDownOnContent);
                }
            } else {
                this.element.find(".e-hscroll").remove();
                this._h = null;
            }

            if (!this._v && !this._h)
                this.content().css({ width: "auto", height: "auto" });

            if (this.element.find(".e-hscroll").length > 0)
                !this.element.hasClass("e-hscrollbar") && this.element.addClass("e-hscrollbar");
            else {
                if (this.element.hasClass("e-hscrollbar")) {
                    this.element.removeClass("e-hscrollbar");
                    if (this._v) {
                        this.content().outerHeight(this.content().outerHeight() - 1);
                    }
                }
            }

            if (this.isHScroll() || this.isVScroll()) {
                this.content().addClass("e-content");
                jqVersion === "1.7.1" || jqVersion === "1.7.2" ? (height = "height", width = "width") : (height = "outerHeight", width = "outerWidth");
                this.content()[height](this.element.height() - (this.isHScroll() ? this.model.scrollerSize : 0));
                this.content()[width](this.element.width() - (this.isVScroll() ? this.model.scrollerSize : 0));
            } else
                this.content().removeClass("e-content");
        },
        /**
* Returns horizontal scrollbar is shown or not.		
* @return Boolean value
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;

* // To check horizontal scrollbar is rendered or not
* var scrollerObj  = $("#scrollcontent").data("ejScroller");
* scrollerObj.isHScroll(); // Returns horizontal scrollbar is shown or not.
* &lt;/script&gt;
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* // To check horizontal scrollbar is rendered or not
* $("#scrollcontent").ejScroller("isHScroll");	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
        isHScroll: function () {
            if (this.model.width > 0) {
                var $paneObject = this.content().find(this.model.targetPane);
                if (this.model.targetPane != null && $paneObject.length)
                    return ($paneObject[0].scrollWidth + $paneObject.siblings().width()) > this.model.width;
                else
                    return this.content()[0].scrollWidth > this.model.width;
            }
            return false;
        },
        /**
* Returns vertical scrollbar is shown or not.		
* @return Boolean value
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* // To check vertical scrollbar is rendered or not
* var scrollerObj  = $("#scrollcontent").data("ejScroller");
* scrollerObj.isVScroll(); // Returns vertical scrollbar is shown or not.
* &lt;/script&gt;
* @example 
* &lt;div id="scrollcontent" style="width:900px;"&gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* // To check vertical scrollbar is rendered or not
* $("#scrollcontent").ejScrollbar("isVScroll");	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
        isVScroll: function () {
            return this.model.height > 0 && this.content()[0].scrollHeight > this.model.height;
        },
        /**
* To configure the properties at runtime using SetModel		
* @private
*/
        _setModel: function (option) {
            for (var prop in option) {
                if (prop === "enableRTL") {
                    if (option[prop])
                        this.element.addClass("e-rtl");
                    else
                        this.element.removeClass("e-rtl");
                } else if (prop === "scrollLeft") {
                    this.content().scrollLeft(this.scrollLeft());
                } else if (prop === "scrollTop") {
                    this.content().scrollTop(this.scrollTop());
                } else if (prop === "touchScroll") {
                    if (!this.model.enableTouchScroll)
                        this._off(this.content(), "mousedown touchstart");
                    else {
                        if(this._v)
                            this._on(this.content(), "mousedown touchstart", { d: this._v }, this._mouseDownOnContent);
                        if(this._h)
                            this._on(this.content(), "mousedown touchstart", { d: this._h }, this._mouseDownOnContent);
                    }
                } else {
                    this.scrollTop(0);
                    this.scrollLeft(0);
                    this.refresh();
                    break;
                }
            }
        },
        /**
* Creates the scroller in on demand time
* @private
*/
        _createScroller: function (dimension, xy, position, css, isOtherScroll) {
            var temp = css == "e-v" ? "v" : "h", height;
            var d = this["_" + temp] = {};
            var jqVersion = $.fn.jquery;
            d.dimension = dimension;
            d.xy = xy;
            d.position = position;
            d.css = css;
            d.isOtherScroll = isOtherScroll;
            d.uDimension = dimension;

            var dim = dimension === "Width" ? "Height" : "Width";
            jqVersion === "1.7.1" || jqVersion === "1.7.2" ? height = dim.toLowerCase() : height = "outer" + dim;
            this.content()[height](this.element[dim.toLowerCase()]() - (this.isVScroll() ? this.model.scrollerSize : 0));
            this._calculateLayout(d);
            this._createLayout(d);
            var buttons = this[d.main].find(".e-button");

            this._off(buttons, "mousedown")
                ._on(buttons, "mousedown", { d: d, step: 1 }, this._spaceMouseDown);
            this._off(css === "e-v" ? this.element : this[d.scroll], "mousewheel DOMMouseScroll")
                ._on(css === "e-v" ? this.element : this[d.scroll], "mousewheel DOMMouseScroll", { d: d }, this._mouseWheel);
            this._off(this[d.scroll], "mousedown")
                ._on(this[d.scroll], "mousedown", { d: d }, this._spaceMouseDown);
            this._off(this[d.handler], "mousedown touchstart")
                ._on(this[d.handler], "mousedown touchstart", { d: d }, this._mouseDown);
            
            return d;
        },
        /**
* Creates the layout for the scrollbars to be rendered.	
* @private
*/
        _createLayout: function (d) {
            var divString = "<div class='" + d.css + "{0}' style='" + d.dimension + ":{1}px'>{2}</div>";
            var jqVersion = $.fn.jquery;
            var lit = {}, height;
            lit[d.dimension] = d.modelDim;

                var el = ej.buildTag(
                    "div." + d.css + "scroll",
                        String.format(divString, "up e-icon e-button", d.buttonSize) +
                        String.format(divString, "handlespace", d.handleSpace,
                            String.format(divString, "handle", d.handle)) +
                        String.format(divString, "down e-icon e-button", d.buttonSize),
                    lit
                );

            if (d.css == "e-v" && $(this.element.find(".e-content")).length > 0) $(this.element.find(".e-content")).after(el);
            else this.element.append(el);
			if(!this.isVScroll())this.element['height'](this.content()['height']()+this.model.scrollerSize);
            jqVersion === "1.7.1" || jqVersion === "1.7.2" ? height = d.uDimension.toLowerCase() : height = "outer" + d.uDimension; 
            this[d.handler] = this.element.find("." + d.handler)[height](d.handle);
            this[d.scroll] = this[d.handler].parent();
            this[d.main] = this[d.scroll].parent();
            this[d.main].find(".e-button")["outer" + d.uDimension](d.buttonSize);
        },
        /**
* Calculates the scrollbar layout based on the values specified for scrollbr to appear
* @private
*/
        _calculateLayout: function (d) {
            d.enableRTL = this.model.enableRTL === undefined ? this.element.css("direction") === "rtl" : this.model.enableRTL;
            d.enableRTL = d.css === "e-h" ? d.enableRTL : false;

            d.scrollDim = "scroll" + d.dimension;
            d.lPosition = d.position.toLowerCase();
            d.clientXy = "page" + d.xy;
            d.scrollVal = "scroll" + d.position;
            d.scrollOneStepBy = this.model.scrollOneStepBy;
            d.modelDim = this.model[(d.dimension = d.dimension.toLowerCase())] - (d.isOtherScroll ? this.model.scrollerSize : 0);
            d.handler = d.css + "handle";
            d.buttonSize = this.model.buttonSize;
            d.main = d.css + "scroll";
            d.scroll = d.css + "ScrollSpace";
            d.handleSpace = d.modelDim - 2 * d.buttonSize;

            var $pane = this.content().find(this.model.targetPane);
            if (this.model.targetPane != null && $pane.length && d.dimension != "height")
                d.sScrollDim = $pane[0][d.scrollDim] + $pane.parent().width() - $pane.width();
            else
                d.sScrollDim = this.content()[0][d.scrollDim];
            d.scrollable = d.sScrollDim - d.modelDim;
            d.handle = Math.floor(d.modelDim / d.sScrollDim * d.handleSpace);
            if (d.handle < 20) d.handle = 20;
            d.onePx = d.scrollable / (d.handleSpace - d.handle);
            d.fromScroller = false;
            d.up = true;
            d.vInterval = undefined;
            d.scrollable *= d.enableRTL ? -1 : 1;
        },
        /**
* Updates scrollbar layout based on ondemand values
* @private
*/
        _updateLayout: function (d) {
            this.element.find("." + d.css + "scroll").css(d.dimension, d.modelDim + "px")
                .find(".e-button").css(d.dimension, this.model.buttonSize).end()
                .find("." + d.css + "handlespace").css(d.dimension, d.handleSpace + "px")
                .find("." + d.css + "handle").css(d.dimension, d.handle + "px");
        },
        /**
* User refreshes the Scroller control at any time.		
* @return jQuery
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* // To refresh the Scroller control at any time.
* var scrollerObj  = $("#scrollcontent").data("ejScroller");
* scrollerObj.refresh(); // refreshes the Scroller control at any time
* &lt;/script&gt;
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* // Refresh the scroller control
* $("#scrollcontent").ejScroller("refresh");	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
        refresh: function () {
            this._ensureScrollers();

            if (this.scrollLeft())
                this.content().scrollLeft(this.scrollLeft());
            if ((this.scrollTop() && this._v == null) || (this._v != null && !this._v.skipChange))
                this.content().scrollTop(this.scrollTop());

            if (this._v) {
                this._v.dimension = "Height";
                this._v.isOtherScroll = this.isVScroll() && this.isHScroll() ? true: false;
                this.isVScroll() && !this._calculateLayout(this._v) && this._updateLayout(this._v);
            }
            if (this._h) {
                this._h.dimension = "Width";
                this._h.isOtherScroll = this.isVScroll() && this.isHScroll() ? true : false;
                this.isHScroll() && !this._calculateLayout(this._h) && this._updateLayout(this._h);
            }
            this.model.targetPane != null && this._on(this.content().find(this.model.targetPane), "scroll", this._scroll);
        },
        /**
* Section for handling scrollbar based on keypressed
* @private
*/
        _keyPressed: function (action, target) {
            if (["input", "select", "textarea"].indexOf(target.tagName.toLowerCase()) !== -1)
                return true;

            var d, iChar;

            if (["up", "down", "pageUp", "pageDown"].indexOf(action) !== -1) {
                d = this._v;
                iChar = "o";
            } else if (["left", "right", "pageLeft", "pageRight"].indexOf(action) !== -1) {
                d = this._h;
                iChar = "i";
            } else return true;
            if (!d) return true;

            return !this._changeTop(d, (action.indexOf(iChar) < 0 ? -1 : 1) * (action[0] !== "p" ? 1 : 3) * d.scrollOneStepBy, "key");
        },
        /**
* Scroller moves to given pixel in Y (top) position.		
* @return jQuery
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* // Moves scroller to given pixel in Y (top) position.
* var scrollerObj  = $("#scrollcontent").data("ejScroller");
* scrollerObj.scrollY("scrollY", 25, true); // call scrollY method.
* &lt;/script&gt;
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
*&lt;/div&gt; <br> 
* &lt;script&gt;
* $('#scrollcontent').ejScroller(); 	
* //Moves scroller to given pixel in Y (top) position.
* $("#scrollcontent").ejScroller("scrollY", 25, true);	
* &lt;/script&gt;
* @memberof ejScroller
* @instance
*/
        scrollY: function (pixel, noAnimation, source) {
            if (noAnimation) {
                if (this._trigger("scroll", { source: source || "custom", scrollData: this._v, scrollTop: pixel }))
                    return;
                this.scrollTop(pixel);
                this.content().scrollTop(pixel);
                return;
            }
            this.content().stop().animate({
                scrollTop: pixel
            }, 100, 'linear');
        },
        /**
* Scroller moves to given pixel in X (left) position.		
* @return jQuery
* @example 
* &lt;div id="scrollcontent" style="width:900px;" &gt;
*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
		*&lt;/div&gt; <br> 
		* &lt;script&gt;
		* $('#scrollcontent').ejScroller(); 	
		* // Moves scroller to given pixel in X (left) position.
		* var scrollerObj  = $("#scrollcontent").data("ejScroller");
		* scrollerObj.scrollX("scrollX", 25, true); // call scrollX method.
		* &lt;/script&gt;
		* @example 
		* &lt;div id="scrollcontent" style="width:900px;" &gt;
		*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;
         *&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
		*&lt;/div&gt; <br> 
		* &lt;script&gt;
		* $('#scrollcontent').ejScroller(); 	
		* //Moves scroller to given pixel in X (left) position.
		* $("#scrollcontent").ejScroller("scrollX", 25, true);	
		* &lt;/script&gt;
		* @memberof ejScroller
		* @instance
		*/
        scrollX: function (pixel, noAnimation, source) {
            if (noAnimation) {
                if (this._trigger("scroll", { source: source || "custom", scrollData: this._h, scrollLeft: pixel }))
                    return;
                this.scrollLeft(pixel);
                if (this.model.targetPane != null)
                    this.content().find(this.model.targetPane).scrollLeft(pixel);
                else
                    this.content().scrollLeft(pixel);
                return;
            }
            this.content().stop().animate({
                scrollLeft: pixel
            }, 100, 'linear');
        },
        /**
* Updates top value based on scroller movement
* @private
*/
        _changeTop: function (d, step, source) {
            var start = this.model.targetPane != null && d.dimension != "height" ? this.content().find(this.model.targetPane)[d.scrollVal]() : this.content()[d.scrollVal](), t;

            if (d.dimension == "height" && start == 0)
                start = this.scrollTop() != 0 ? this.scrollTop() : 0;
            t = start + step;
            if (!d.enableRTL ? t > d.scrollable : t < d.scrollable) t = d.scrollable;
            if (!d.enableRTL ? t < 0 : t > 0) t = 0;

            if (t !== start) {
                this["scroll" + d.xy](t, true, source);
            }

            return t !== start;
        },
        /**
* To handle scroll based on movement via mouse wheel
* @private
*/
        _mouseWheel: function (e) {
            if (!e.data) return;

            var delta = 0, data = e.data.d, ori = e;
            e = e.originalEvent;
            if (e.wheelDelta) {
                delta = -e.wheelDelta / 120;
                if (window.opera) {
                    if (parseFloat(window.opera.version, 10) < 10)
                        delta = -delta;
                }
            } else if (e.detail) delta = e.detail / 3;

            if (!delta) return;

            if (this._changeTop(data, delta * data.scrollOneStepBy, "wheel")) {
                e.preventDefault ? e.preventDefault() : ori.preventDefault();
                if (data.css === "e-h") {
                    ori.stopImmediatePropagation();
                    ori.stopPropagation();
                }
            }
        },
        /**
* To handle mouse up movement
* @private
*/
        _mouseUp: function (e) {
            if (!e.data) return;

            var d = e.data.d;
            e.type === "mouseup" && this[d.handler].removeClass("e-active");
            if (e.type === "mouseup" || e.type === "touchend" || (!e.toElement && !e.relatedTarget)) {
                this._off($(document), "mousemove touchmove");
                $(document).off("mouseout mouseup touchend", ej.proxy(this._mouseUp, this));
                d.fromScroller = false;
                this[d.scroll].off("mousemove");
                this[d.handler].off("mousemove").css("transition", "");

                if (e.data.source === "thumb" && !ej.isNullOrUndefined(this.model)) {
                    $.when(this.content()).done(ej.proxy(function () {
                        this._trigger("thumbEnd", { originalEvent: e, scrollData: d });
                    }, this));
                }
            }
            d.up = true;
        },
        /**
* To handle mouse down movement on content
* @private
*/
        _mouseDownOnContent: function (down) {
            var d = down.data.d;
			if(this._trigger("thumbStart", { originalEvent: down, scrollData: d }))
				return;
            
            if( down.which ==3 && down.button == 2 ) return;
            d.fromScroller = true;
            this[d.handler].css("transition", "none");

            var prevY = null, skip = 1, min = 5, direction;

            this._on($(document), "mousemove touchmove", (function (move) {
                move.preventDefault();
                var pageXY = move.type == "mousemove" ? move[d.clientXy] : move.originalEvent.changedTouches[0][d.clientXy];

                if (prevY && pageXY !== prevY) {
                    var diff = pageXY - prevY, sTop = this.model[d.scrollVal] - (diff * d.onePx / min);
                    
                    if (skip == 1 && Math.abs(diff) > min) {
                        direction = d.position;
                        skip = 0;
                    }
                    if (skip == 0) prevY = pageXY;

                    if (sTop >= 0 && sTop <= d.scrollable && direction === d.position) {
                        this["scroll" + d.xy](sTop, true, "thumb");
                        this[d.handler].css(d.position.toLowerCase(), sTop / d.onePx + "px");
                        this.content().css("cursor", "pointer");
                        this._trigger("thumbMove", { originalEvent: move, scrollData: d });
                    }
                }
                if (prevY == null) prevY = pageXY;
            }));

            $(document).one("mouseup touchend", { d: d, source: "thumb" }, ej.proxy(this._mouseUp, this));
            $(document).mouseout({ d: d, source: "thumb" }, ej.proxy(this._mouseUp, this));
        },
        /**
* To handle mouse down movement
* @private
*/
        _mouseDown: function (down) {
            //if (down.which !== 1) return;
            var d = down.data.d;

            d.fromScroller = true;
            this[d.handler].css("transition", "none");

            var prevY, top = parseInt(this[d.handler].css(d.lPosition)) || 0;

            this._on($(document), "mousemove touchmove", (function (move) {
                move.preventDefault();
                var skip = 1;
                var pageXY = move.type == "mousemove" ? move[d.clientXy] : move.originalEvent.changedTouches[0][d.clientXy];
                if (prevY && pageXY !== prevY) {
                    top += (pageXY - prevY);

                    if (d.enableRTL ? top > 0 : top < 0) skip = top = 0;

                    if ((top * (d.enableRTL ? -1 : 1)) + d.handle >= d.handleSpace)
                        skip = top = (d.handleSpace - d.handle) * (d.enableRTL ? -1 : 1);

                    this["scroll" + d.xy](Math.ceil(top * d.onePx), true, "thumb");
                    this[d.handler].css(d.position.toLowerCase(), top + "px");
                    this.content().css("cursor", "pointer");
                    this._trigger("thumbMove", { originalEvent: move, scrollData: d });
                }

                if (skip === 1)
                    prevY = pageXY;
            }));

            this._trigger("thumbStart", { originalEvent: down, scrollData: d });

            $(document).one("mouseup touchend", { d: d, source: "thumb" }, ej.proxy(this._mouseUp, this));
            $(document).mouseout({ d: d, source: "thumb" }, ej.proxy(this._mouseUp, this));
        },
        /**
* To handle mouse down based on the interval 
* @private
*/
        _spaceMouseDown: function (e) {
            if (!e.data) return;

            var d = e.data.d;
            
            if (e.which !== 1 || e.target === this[d.handler][0]) return;

            var step = (e.data.step || 3) * d.scrollOneStepBy, hTop = e.data.top || this[d.handler].offset()[d.lPosition];

            e[d.clientXy] = e[d.clientXy] || 0;

            if (e[d.clientXy] < hTop) step *= -1;

            this._changeTop(d, step, step === 3 ? "track" : "button");

            if (e.data.step !== 1) {
                this[d.scroll].mousemove(function () {
                    d.up = true;
                });
            }

            d.up = false;
            d.vInterval = setInterval(ej.proxy(function () {

                if (step < 0 ? hTop + (step / d.onePx) < e[d.clientXy] : hTop + d.handle + (step / d.onePx) > e[d.clientXy])
                    d.up = true;

                if (d.up) {
                    clearInterval(d.vInterval);
                    return;
                }

                this._changeTop(d, step, step === 3 ? "track" : "button");

                hTop = e.data.top || this[d.handler].offset()[d.lPosition];
            }, this), 150);

            $(document).one("mouseup", { d: d }, ej.proxy(this._mouseUp, this));
            $(document).mouseout({ d: d }, ej.proxy(this._mouseUp, this));
        },
        /**
* To handle scroll movement
* @private
*/
        _scroll: function (e) {
            var dS = [this._v, this._h];

            for (var i = 0; i < 2; i++) {
                var d = dS[i];
                if (!d || d.skipChange) continue;

                if (this.model.targetPane != null && i == 1)
                    d.sTop = this.content().find(this.model.targetPane)[0][d.scrollVal];
                else
                    d.sTop = e.target[d.scrollVal];
                this[d.scrollVal](d.sTop);
                if (d.fromScroller) return;
                this[d.handler].css(d.lPosition, (d.sTop / d.onePx) + "px");
            }
        },
        /**
* Changes the vertical handler position	
* @private
*/
        _changevHandlerPosition: function (top) {
            top = this._v != null && top >= this._v.scrollable ? this._v.scrollable : top;
            if (this._v != null && top >= 0 && top <= this._v.scrollable)
                this[this._v.handler].css(this._v.lPosition, (top / this._v.onePx) + "px");
        },
        /**
* Changes the horizontal handler position	
* @private
*/
        _changehHandlerPosition: function (left) {
            left = this._h != null && left >= this._h.scrollable ? this._h.scrollable : left;
            if (this._h != null && left >= 0 && left <= this._h.scrollable)
                this[this._h.handler].css(this._h.lPosition, (left / this._h.onePx) + "px");
        },
        /**
		* destroy the Scroller control
		* all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		* @alias destroy
		* @return jQuery
		* @example 
		* &lt;div id="scrollcontent" style="width:900px;" &gt;
		*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;&lt;li&gt;
        *&lt;b&gt;A controller&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
		*&lt;/ul&gt; 
		*&lt;/div&gt; <br> 
		* &lt;script&gt;
		* $('#scrollcontent').ejScroller(); 	
		* // Destroy Scroller
		* var scrollerObj  = $("#scrollcontent").data("ejScroller");
		* scrollerObj.destroy(); // destroy the scroller
		* &lt;/script&gt;
		* @example 
		* &lt;div id="scrollcontent" style="width:900px;" &gt;
		*&lt;p&gt;Model–view–controller (MVC) is a software architecture pattern which separates the
        * representation of information from the user's interaction with it.
        * The model consists of application data, business rules, logic, and functions. A view can be any
        * output representation of data, such as a chart or a diagram. Multiple views of the same data 
        * are possible, such as a bar chart for management and a tabular view for accountants. 
        *The controller mediates input, converting it to commands for the model or view.The central 
        *ideas behind MVC are code reusability and n addition to dividing the application into three 
        *kinds of components, the MVC design defines the interactions between them.</p>
        *&lt;ul&gt;*&lt;li&gt;
        *&lt;b&gt;A controller*&lt;/b&gt;can send commands to its associated view to change the view's presentation of the model (e.g., by scrolling through a document). 
        *It can also send commands to the model to update the model's state (e.g., editing a document).
        *&lt;/li&gt;
        *&lt;/ul&gt; 
		*&lt;/div&gt; <br> 
		* &lt;script&gt;
		* $('#scrollcontent').ejScroller(); 	
		* // destroy the scroller
		* $("#scrollcontent").ejScroller("destroy");	
		* &lt;/script&gt;
		* @memberof ejScroller
		* @instance
		*/
        _destroy: function () {
            this.element.css({ "width": "", "height": "" }).find(".e-vscroll,.e-hscroll").remove();
            this.content().removeClass("e-content").css({ "width": "", "height": "" });
        }
    });
})(jQuery, Syncfusion, window);;
/**
* @fileOverview Plugin to style the Menu control.
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {

    /**
	
       * @namespace ej
       * @class ejMenu
       * @requires jQuery
       * @requires jquery.easing.1.3.min.js
       * @requires ej.core.js
       * @requires ej.data.js
       * @requires ej.menu.js
       * @requires ej.checkbox.js
       * @classdesc Custom Design for Menu control.
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
       * // Create Menu
       * $("#menu").ejMenu({height: 22}); 	
       * &lt;/script&gt;
       */

    ej.widget("ejMenu", "ej.Menu", {
	
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["ul"],
        _setFirst: false,
        _rootCss: "e-menu",

        // default model
        defaults: {
            /**		
                * Specifies the height of the root menu.
                * @default "auto"
                * @type {string | number}
                * @example 
                * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
                
               * //To set height API value during initialization  
                *   $("#menu").ejMenu({ height: 22 }); 
                * &lt;/script&gt; 
                 * @memberof ejMenu
                * @instance
                */
            height: "",
           /**		
			* Specifies the width of the main menu.
			* @default auto
			* @type {string | number}
			* @example 
			* &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;	
			* //To set width API value during initialization  
      *   //To set width API value 
      *   $("#menu").ejMenu({ width: "800px",height:"30px" });  
      * &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            width: "",
           /**		
			* To enable or disable the Animation while hover or click an menu items..See {@link AnimationType}
			* @default ej.animation.Default
			* @type {enum}
			* @example 
			* &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;	
		* //To set animationType API value during initialization  
      *   //To set animationType API value 
      *   $("#menu").ejMenu({ height:22,animationType: ej.AnimationType.Default }); 
      * &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            animationType: "default",
            /**		
			* Specifies the orientation of normal menu. Normal menu can rendered in horizontal or vertical direction by using this API. See {@link Direction}
			* @default ej.orientation.Horizontal
			* @type {string | enum}
			* @example 
			* &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;	
			* //To set orientation API value during initialization  
      *   //To set orientation API value 
      *   $("#menu").ejMenu({ height:22,orientation: ej.Orientation.Horizontal });
      * &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            orientation: ej.Orientation.Horizontal,
            /**		
			* Specifies the type of the menu. Essential JavaScript Menu consists of two type of menu, they are Normal Menu and Context Menu both Normal and Context Menu mode.See {@link MenuType}
			* @default ej.menuType.NormalMenu 
			* @type {string | enum}
			* @example 
			* &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;	
			* //To set menuType API value during initialization  
      *   //To set menuType API value 
      *   $("#menu").ejMenu({ height:22,menuType: "normalmenu" });
      * &lt;/script&gt; 
			 * @memberof ejMenu
			* @instance
			*/
            menuType: "normalmenu",
            /**		
			*Specifies the target id of context menu. On right clicking the specified contextTarget element, context menu gets shown.
			* @default null 
			* @type {string}
			* @example
			*	&lt;div id="target" class="textarea"&gt;
			*                            HTML is written in the form of HTML elements consisting of tags enclosed in angle
			*                            brackets (like
			*                            &lt;html&gt;
			*                            ),within the web page content. HTML tags most commonly come in pairs like and ,although
			*                            some tags, known as empty elements, are unpaired, for example
			*                            &lt;img&gt;. The purpose of a web browser is to read HTML documents and compose them into
			*                            visible or audible web pages. The browser does not display the HTML tags, but uses
			*                            the tags to interpret the content of the page.
			*                        &lt;/div&gt;
			*                        &lt;ul id="contextMenu"&gt;
			*                            &lt;li&gt;&lt;a&gt;Cut&lt;/a&gt;&lt;/li&gt; 
			*                            &lt;li&gt;&lt;a&gt;Copy&lt;/a&gt;&lt;/li&gt; 
			*                            &lt;li&gt;&lt;a&gt;Paste&lt;/a&gt;&lt;/li&gt; 
			*                       &lt;li class="separator"&gt;&lt;/li&gt; 
			*                            &lt;li&gt;&lt;a&gt;Comments&lt;/a&gt;&lt;/li&gt;
			*                            &lt;li&gt;&lt;a&gt;Links&lt;/a&gt;&lt;/li&gt;
			*                            &lt;li&gt;&lt;a&gt;Clear Formatting&lt;/a&gt;&lt;/li&gt;  
			*                        &lt;/ul&gt;           
			                
      * &lt;script&gt;
		
			* //To set contextMenuTarget API value during initialization  
			* 	//To set contextMenuTarget API value 
			* 	$("#contextMenu").ejMenu({menuType:ej.MenuType.ContextMenu, height:22,contextMenuTarget:"#target"});  
      * &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            contextMenuTarget: null,
            /**		
			* Specify the CSS class to Menu to achieve custom theme.
			* @default ""
			* @type {string}
			* @example 
        * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
	   * &lt;script&gt;
			* //To Set the CSS class during initialization. 			
			* 	$("#menu").ejMenu({ height:22, cssClass:'gradient-lime ' });		
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            cssClass: "",
            /**		
			* Specifies the sub menu items to be show or open only on click.
			* @default false
			* @type {boolean}
			* @example 
        * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set openOnClick API value during initialization  
			* 	//To set openOnClick API value 
			* 	$("#menu").ejMenu({ height:22,openOnClick: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            openOnClick: false,
            /**		
			* Specifies the sub menu popup direction.See {@link Direction}
			* @default ej.direction.Right
			* @type {string | enum}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set subMenuDirection API value during initialization  
			* 	//To set subMenuDirection API value 
			* 	$("#menu").ejMenu({ height:22,subMenuDirection: ej.Direction.Right });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            subMenuDirection: "right",
			/**		
			* Specifies the root menu items to be aligned center in horizontal menu.
			* @default false
			* @type {boolean}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set enableCenterAlign API value during initialization  
			* 	//To set enableCenterAlign API value 
			* 	$("#menu").ejMenu({ height:22,enableCenterAlign: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
			enableCenterAlign: false,
            /**		
			* Specifies the main menu items arrows only to be shown if it contains child items.
			* @default true
			* @type {boolean}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set showRooltLevelArrows API value during initialization  
			* 	//To set showRooltLevelArrows API value 
			* 	$("#menu").ejMenu({ height:22,showRooltLevelArrows: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            showRooltLevelArrows: true,
            /**		
			* Specifies the sub menu items arrows only to be shown if it contains child items.
			* @default true
			* @type {boolean}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set showSubLevelArrows API value during initialization  
			* 	//To set showSubLevelArrows API value 
			* 	$("#menu").ejMenu({ height:22,showSubLevelArrows: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
			
            showSubLevelArrows: true,
			enableAnimation: true,
             /**		
/**		
			* When this property sets to false, the menu list is displayed without any separators.
			* @default true
			* @type {boolean}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set enableSeparator API value during initialization  
			* 	//To set enableSeparator API value 
			* 	$("#menu").ejMenu({ height:22,enableSeparator: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            enableSeparator: true,
           /**		
			* Enable / Disable the Menu control.
			* @default true
			* @type {boolean}
			* @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set enabled API value during initialization  
			* 	//To set enabled API value 
			* 	$("#menu").ejMenu({ height:22,enabled: true });
			* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            enabled: true,
             /**		
			* Fields used to bind the data source and it includes following field members to make databind easier.
			* @default null
			* @type {Object}
			* @example
      *&lt;ul id="menu"&gt;
       * &lt;script&gt; 
			* //To set fields API value during initialization  
			* 	//To set fields API value 
			* 	      $("#menu").ejMenu({ height:22,
            *                fields: { dataSource: window.menu, id: "id", parentId: "parentId", text: "text", spriteCssClass: "sprite" }
            *           });
             * &lt;/script&gt; 
			 * @memberof ejMenu
			* @instance
			*/
            fields: /** @lends ejMenu# */{
                /**		
                * It receives the child data for the inner level. 
                * @alias ejMenu#fields->child
				* @type Object
                */
                child: null,
                 /**		
                * datasource receives  Essential DataManager object and JSON object. 
                * @alias ejMenu#fields->dataSource
				* @type Object
                */
                dataSource: null,
                /**		
				* It receives query to retrieve data from the table (query is same as SQL).  
				* @alias ejMenu#fields->query
				* @type Object
				*/
                query: null,
                /**	
                * It receives table name to execute query on the corresponding table  
				* @alias ejMenu#fields->tableName
				* @type string
				*/
                tableName: null,
                /**	
                * Specifies the id to menu items list
               	* @alias ejMenu#fields->id
				* @type string
				*/
                id:"id",
                /**	
                * Specifies the parent id of the table.
              	* @alias ejMenu#fields->parentId
				* @type string
                */
                parentId:"parentId",
                /**	
               * Specifies the text of menu items list.
             	* @alias ejMenu#fields->text
				* @type string
				*/
                text:"text",
                /**	
                * Specifies the sprite CSS class to “li” item list
              	* @alias ejMenu#fields->spriteCssClass
				* @type string
				*/
                spriteCssClass:"spriteCssClass",
                /**	
                * Specifies the link attribute to “a” tag in item list.
             	* @alias ejMenu#fields->linkAttribute
				* @type string
				*/
                linkAttribute:"linkAttribute",
                /**	
                * Specifies the image attribute to “img” tag inside items list. 
             	* @alias ejMenu#fields->imageAttribute
				* @type string
				*/
                imageAttribute:"imageAttribute",
                /**	
                * Specifies the html attributes to “li” item list.
                * @alias ejMenu#fields->htmlAttribute
				* @type string
				*/
                htmlAttribute:"htmlAttribute",
                /**	
                * Specifies the image URL to “img” tag inside item list.
              	* @alias ejMenu#fields->imageUrl
				* @type string
				*/
                imageUrl:"imageUrl",
            },
            /**		
			* Specifies the menu items to be displayed in right to left direction.
			* @default false
			* @type {boolean}
			* @example 
         * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set rtl API value during initialization  
			* 	//To set rtl API value 
			* 	$("#menu").ejMenu({ height:22,enableRTL: true });
		* &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            enableRTL: false,
            /**		
			* Specifies the title to responsive menu.
			* @default "Menu"
			* @type {string}
			* @example 
         * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			* //To set titleText API value during initialization  
			* 	//To set titleText API value 
			* 	$("#menu").ejMenu({ height:22,titleText: "Menu" });
			 * &lt;/script&gt;
			 * @memberof ejMenu
			* @instance
			*/
            titleText: "Menu",
            /**     
            * Fires before context menu gets open.
            * @event
            * @name ejMenu#beforeContextOpen 	
            * @param {Object} argument Event parameters from context menu     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event
            * @param {object}  argument.target returns the target element
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //before context menu open event for menu
            *  $("#menu").ejMenu({height:22,
            *  beforeOpen: function (args) {}
            *  });   
            * &lt;/script&gt;
            * @memberof ejMenu
            * @instance
            */
            beforeOpen: null,
            /**     
            * Fires when context menu on open.
            * @event
            * @name ejMenu#contextOpen 	
            * @param {Object} argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event
            * @param {object}  argument.target returns the target element
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //context menu open event for menu
            *  $("#menu").ejMenu({height:22,
            *  open: function (args) {}
            *  });   
            * &lt;/script&gt;
            * @memberof ejMenu
            * @instance
            */
            open: null,
            /**     
			 * Fire when context menu on close.
			 * @event
			 * @name ejMenu#contextClose 	
			 * @param {Object} argument Event parameters from menu     
			 * @param {object}  argument.model returns the menu model
			 * @param {string}  argument.type returns the name of the event
			 * @param {object}  argument.target returns the target element
			 * @example 
          * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			 *  //context menu close event for menu
			 *  $("#menu").ejMenu({height:22,
             *  close: function (args) {}
			 *  });   
       * &lt;/script&gt;
			 * @memberof ejMenu
			 * @instance
			 */
            close: null,
             /**     
			 * Fires when mouse over the Menu items.
			 * @event
			 * @name ejMenu#mouseover 	
			 * @param {Object}  argument Event parameters from menu     
			 * @param {object}  argument.model returns the menu model
			 * @param {string}  argument.type returns the name of the event
			 * @param {string}  argument.text returns clicked menu item text
             * @param {object}  argument.element returns clicked menu item element
			 * @param {object}  argument.event returns the event
			 * @example 
          * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
			 *   //mouse over event for menu
			 *  $("#menu").ejMenu({height:22,
             *  mouseover: function (args) {}
			 *  });   
       * &lt;/script&gt;
			 * @memberof ejMenu
			 * @instance
			 */
            mouseover: null,
            /**     
            * Fires when mouse out from menu items.
            * @event
            * @name ejMenu#mouseout 	
            * @param {Object}  argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.text returns clicked menu item text
            * @param {object}  argument.element returns clicked menu item element
			* @param {object}  argument.event returns the event
            * @example
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;  
            *  //mouse out event for menu
            *  $("#menu").ejMenu({height:22,
            *  mouseout: function (args) {}
            *  });   
            * &lt;/script&gt;
            * @memberof ejMenu
            * @instance
            */
            mouseout: null,
            /**     
            * Fires when mouse click on menu items.
            * @event
            * @name ejMenu#click 	
            * @param {Object}  argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.text returns clicked menu item text
            * @param {object}  argument.element returns clicked menu item element
			* @param {object}  argument.event returns the event
            * @param {number}  argument.selectedItem returns the selected item
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //click event for menu
            *  $("#menu").ejMenu({height:22,
            *  click: function (args){}
            *  });   
            * &lt;/script&gt;
            * @memberof ejMenu
            * @instance
            */
            click: null,
           /**     
            * Fires when key down on menu items.
            * @event
            * @name ejMenu#keydown 	
            * @param {Object}  argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.menuText returns clicked menu item text
            * @param {object}  argument.element returns clicked menu item element
            * @param {object}  argument.event returns the event
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //keydown event for menu
            *  $("#menu").ejMenu({height:22,
            *  keydown: function (args){}
            *  });  
            * &lt;/script&gt; 
            * @memberof ejMenu
            * @instance
            */
            keydown: null,
			/**     
            * Fires to create menu items.
            * @event
            * @name ejMenu#create  
            * @param {Object}  argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event           
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //Create event for menu
            *  $("#menu").ejMenu({height:22,
            *  create: function (args){}
            *  });   
            * &lt;/script&gt;
            * @memberof ejMenu
            * @instance
            */
            create: null,
			 /**     
            * Fires to destroy menu items.
            * @event
            * @name ejMenu#destroy 
            * @param {Object}  argument Event parameters from menu     
            * @param {object}  argument.model returns the menu model
            * @param {string}  argument.type returns the name of the event            
            * @example 
               * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt; 
            *  //Destroy event for menu
            *  $("#menu").ejMenu({height:22,
            *  destroy: function (args){}
            *  }); 
            * &lt;/script&gt;  
            * @memberof ejMenu
            * @instance
            */
            destroy: null
        },
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            animationType:"enum",
            cssClass: "string",
            titleText:"string",
            openOnClick: "boolean",
            enabled: "boolean",
            enableCenterAlign: "boolean",
            showArrow: "boolean",
            showRooltLevelArrows: "boolean",
            showSubLevelArrows: "boolean",
            enableSeparator: "boolean",
            enableRTL: "boolean",
            enableAnimation: "boolean",
            fields: {
                dataSource: "data",
                query: "data",
                child: "data"
            }
        },
        
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (jsondata) {
            if (!(this.model.enabled) && ej.isNullOrUndefined(jsondata["enabled"])) return false;
            for (var key in jsondata) {
                switch (key) {
                    case "menuType":
                        this.model.menuType = jsondata[key];
                        this.element.removeClass("e-menu " + this.model.cssClass);
                        this._renderControl();
                        if (jsondata[key] == "contextmenu") this._contextMenuEvents();
                        break;
                    case "fields":
                        this.element.empty().insertBefore(this.wrapper);
                        this.wrapper.remove();
                        $.extend(this.model.fields, jsondata[key]);
                        this._intializeData();
                        break;
                    case "orientation": this._setOrientation(jsondata[key]); break;
                    case "showTopLevelArrow": this._addArrow(jsondata[key], this.model.showBottomLevelArrow); break;
                    case "showBottomLevelArrow": this._addArrow(this.model.showRooltLevelArrows, jsondata[key]); break;
                    case "enableSeparator": this._setSeparator(jsondata[key]); break;
                    case "height": this._setHeight(jsondata[key]); break;
                    case "width": this._setWidth(jsondata[key]); break;
                    case "cssClass": this._setSkin(jsondata[key]); break;
                    case "enableRTL": this._setRTL(jsondata[key]); break;
                    case "enableCenterAlign": this._centerAlign(jsondata[key]); break;
                    case "enabled": this.model.enabled = jsondata[key]; this._controlStatus(jsondata[key]); break;
                    case "animationType":
                        this._setAnimation(jsondata[key]);
                        break;
					case "enableAnimation":
						this.model.enableAnimation=options[key];
						break;
						
					
                }
            }
        },      
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            /// <summary>This function is  used to destroy the Menu Object</summary>
            this._cloneElement.insertBefore(this.element);
            this._cloneElement.removeClass('e-menu');
            this.element.remove();
        },
        /**
       * Create the Menu widget
       * @private
       */
        // constructor function
        _init: function () {
            /// <summary>This function is  used to Initialize the Menu Object</summary>
            this.element.css("visibility", "hidden");
            this._cloneElement = this.element.clone();
            this._setValues();
            this._intializeData();
            this.element.css("visibility", "visible");
        },

        //-------------------------Private Methods---------------------------------------------    
        /**
       * To configure the property values
       * @private
       */
        _setValues: function () {
            this._mouseOver = true;
            this._hoverOpen = true;
            this._hoverClose = true;
            this._isMenuOpen = false;
            this._hideSpeed = 100;
            this._showSpeed = 100;
            this._isSubMenuOpen = false;
            this._isContextMenuOpen = false;
            this._disabledMenuItems = new Array();
            this._delayMenuHover = 0;
            this._delaySubMenuHover = 0;
            this._delaySubMenuShow = 0;
            this._preventContextOpen = true;
            this._setAnimation(this.model.animationType);
        },
        _intializeData: function () {
            if (!ej.isNullOrUndefined(this.model.fields) && this.model.fields["dataSource"] != null) {
                this._generateTemplate(this.model.fields["dataSource"]);
                this._renderMenu();
            }
            else {
                this._renderMenu();
                this._wireEvents("_on");
            }
        },
        _renderMenu: function () {
            this._renderControl();
            this._addArrow(this.model.showRooltLevelArrows, this.model.showSubLevelArrows);
            this._intializeMenu();
        },
        /**
        * Render Section For Different Types Menu		
        * @private
        */
        _renderControl: function () {
            /// <summary>This function is  used to Render the Menu Object</summary>
            var label, checkBox, checkObj, list, spanlist, i;
            this.wrapper = ej.buildTag("div.e-menu-wrap");
            if ((this.model.menuType != ej.MenuType.ContextMenu) && (this.model.orientation != "vertical")) {
                this.resWrap = ej.buildTag('span.e-menu-res-wrap');
                this.inResWrap = ej.buildTag('span.e-in-wrap e-box e-menu-res-in-wrap');
                this.label = ej.buildTag('span.e-res-title', this.model.titleText);
                this.check = ej.buildTag('span.e-check-wrap e-icon');
                this.checkBox = ej.buildTag('input#responsive.e-res-icon', '', {}, { type: 'checkbox' });
                this.wrapper.append(this.resWrap)
                this.resWrap.append(this.inResWrap);
                this.inResWrap.append(this.label).append(this.check);
                this.check.append(this.checkBox);
            }
            if (this.model.menuType != ej.MenuType.ContextMenu) {
                this.wrapper.insertBefore(this.element);
                this.wrapper.append(this.element);
                if (this.checkBox != null) {
                    this.checkBox.ejCheckBox({ size: "medium", change: this._oncheck });

                }
            }
            this.element.addClass("e-menu e-widget").attr({ "role": "menu","tabindex": 0});
            if (this.model.enableRTL) this._setRTL(this.model.enableRTL);
            if (this.model.menuType == "normalmenu") {
                this.model.orientation == "horizontal" ? this.element.addClass(this.model.cssClass + " e-horizontal") : this.element.addClass(this.model.cssClass + " e-vertical");
            }
            //For ContextMenu Mode
            else this._contextMenu_Template();
            //Adding arrows to items with sub items
            this.element.find('li:has("> ul")').find('> a,> span').addClass('aschild');
            this.element.find('>li').addClass('e-list').attr({ "role": "menuitem"});
            list = this.element.find('.e-list a.aschild');
            spanlist = this.element.find('.e-list span.aschild');
            for (i = 0; i < list.length; i++) {
                $(list[i]).siblings().attr({ "aria-hidden": true });
                $(list[i]).parent().attr({ "aria-haspopup": true, "role": "menu"});
                $(list[i]).siblings('ul').children('li').addClass('e-list').attr("role", "menuitem");
            }
            for (i = 0; i < spanlist.length; i++) {
                $(spanlist[i]).siblings().attr({ "aria-hidden": true });
                $(spanlist[i]).parent().attr({ "aria-haspopup": true, "role": "menu"});
                $(spanlist[i]).siblings('ul').children('li').addClass('e-list').attr("role", "menuitem");
            }
            if (this.model.enableCenterAlign) this._centerAlign(this.model.enableCenterAlign);
            if (this.model.enableSeparator) this._setSeparator(true);
            this._controlStatus(this.model.enabled);
        },
        /**
        * Wiring the Events to Responsive Icon 	
        * @private
        */
        _oncheck: function (e) {
            var obj = this.element.parents('.e-menu-wrap').children('.e-menu');
            e.isChecked ? obj.removeClass('e-res-hide').addClass('e-res-show') : obj.removeClass('e-res-show').addClass('e-res-hide');
        },
        /**
        * Render Section For Menu through Remote Data and DataSource	
        * @private
        */
        _generateTemplate: function (data) {
            var proxy = this, queryPromise;
            if (data instanceof ej.DataManager) {
                queryPromise = data.executeQuery(this._columnToSelect(this.model.fields));
                queryPromise.done(function (e) {
					proxy._odataFlag = true;
                    proxy._generateItemTemplate(e.result);
                    proxy._wireEvents("_on");
                });
            } else {
				proxy._odataFlag = false;
                this._generateItemTemplate(proxy.model.fields['dataSource']);
                this._wireEvents("_on");
            }
        },
        /**
        * Render Section For Menu through DataSource		
        * @private
        */
        _generateItemTemplate: function (items) {
            for (var i = 0; i < items.length; i++) {
                if ((items[i][this.model.fields.parentId] == null) || (items[i][this.model.fields.parentId] == 0)) {
                    var subItem = this._menuTemplate(items[i], items, this.model.fields);
                    this.element.append(subItem);
                }
            }
        },
        /**
      * Render Section For Menu template		
      * @private
      */
        _menuTemplate: function (item, tableData, mapper) {
            var liTag, aTag, imgTag, spanTag;
            liTag = $(document.createElement('li'));
            liTag.attr("class", 'e-list');
            if (item[mapper.htmlAttribute]) this._setAttributes(item[mapper.htmlAttribute], liTag);

            if (item[mapper.id]) {
                aTag = $(document.createElement('a'));                
                if (item[mapper.imageUrl] && item[mapper.imageUrl] != "") {
                    imgTag = $(document.createElement('img'));
                    imgTag.attr('src', item[mapper.imageUrl]);
                    if (item[mapper.imageAttribute]) this._setAttributes(item[mapper.imageAttribute], imgTag);
                    aTag.append(imgTag);
                }
                else if (item[mapper.spriteCssClass] && item[mapper.spriteCssClass] != "") {
                    spanTag = $(document.createElement('span'));
                    spanTag.addClass(item[mapper.spriteCssClass]);
                    aTag.append(spanTag);
                }
                aTag.append(item[mapper.text]);
                if (item[mapper.linkAttribute])
                    aTag.attr('href', item[mapper.linkAttribute]);
                else aTag.attr('href', "#");
                liTag.append(aTag);
            }
            if (item[mapper.id]) {
                liTag.prop("id", item[mapper.id]);
            }
            if (!ej.isNullOrUndefined(mapper["child"])) {
                this._odataFlag = true;
                if (mapper["child"]["dataSource"] instanceof ej.DataManager) {
                    var proxy = this, queryManager = ej.Query();
                    queryManager = this._columnToSelect(mapper["child"]);
                    queryManager.where(mapper["child"]["parentId"], ej.FilterOperators.equal, item[mapper.id]);
                    var queryPromise = mapper["child"]["dataSource"].executeQuery(queryManager);
                    queryPromise.done(function (e) {
                        var childItems = e.result;
                        if (childItems && childItems.length > 0) {
                            var ul = $(document.createElement('ul'));
                            for (var i = 0; i < childItems.length; i++) {
                                var liItem = proxy._menuTemplate(childItems[i], mapper["child"]["dataSource"], mapper["child"]);
                                ul.append(liItem);
                            }
                            liTag.append(ul);
                            $(liTag).children('a').addClass('aschild');
                            if ($(liTag).parent().hasClass('e-menu') &&(proxy.model.showRooltLevelArrows))                           
                                    $(liTag).children('a.aschild').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");
                            else if(proxy.model.showSubLevelArrows) 
                               $(liTag).children('a.aschild').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");    
                        }
                    });   
                }
                else {
                    var childItems = ej.DataManager(mapper["child"]["dataSource"]).executeLocal(ej.Query().where(mapper["child"]["parentId"], ej.FilterOperators.equal, item[mapper.id]));
                    if (childItems && childItems.length > 0) {
                        var ul = $(document.createElement('ul'));
                        for (var i = 0; i < childItems.length; i++) {
                            var liItem = this._menuTemplate(childItems[i], mapper["child"]["dataSource"], mapper["child"]);
                            ul.append(liItem);
                        }
                        liTag.append(ul);
                    }
                }
            }
            else if (!this._odataFlag) {
                var childItems = ej.DataManager(mapper["dataSource"]).executeLocal(ej.Query().where(mapper["parentId"], ej.FilterOperators.equal, item[mapper.id]));
                if (childItems && childItems.length > 0) {
                    var ul = ej.buildTag('ul');
                    for (var i = 0; i < childItems.length; i++) {
                        var liItem = this._menuTemplate(childItems[i], mapper["dataSource"], mapper);
                        ul.append(liItem);
                    }
                    liTag.append(ul);
                }
            }
            return liTag;
        },
        /**
        * To configure the Attributes of Menu items
        * @private
        */
        _setAttributes: function (data, element) {
            for (var key in data) {
				if(key == "class")
					element.addClass(data[key]);
				else
                	element.attr(key, data[key]);
            }
        },
        /**
        * To configure the Top and Bottom Level Arrows	
        * @private
        */
        _addArrow: function (topArrows, bottomArrows) {
            if (topArrows)
                this.element.find('>li.e-list:has("> ul")').children('a,span').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");
            else {
                this.element.find('>li.e-list:has("> ul")').children('a,span').removeClass("e-arrow-space").children('span.e-icon').remove();
            }

            if (bottomArrows)
                this.element.find('>li.e-list > ul li.e-list:has(>ul)').children('a,span').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");
            else {
                this.element.find('>li.e-list > ul li.e-list:has(>ul)').children('a,span').removeClass("e-arrow-space").children('span.e-icon').remove();
            }

        },
        /**
         * To initialize the Menu		
		 * @private
         */
        _intializeMenu: function () {
            if (this.model.height != 0) this._setHeight(this.model.height);
            if (this.model.width != 0) this._setWidth(this.model.width);
            if (this.model.menuType == "contextmenu")
                this.model.openOnClick = false;
            if (this.model.openOnClick) {
                this._hoverOpen = false;
                this._hoverClose = false;
            }
        },
        /**
        * To configure the Orientation of Menu	
        * @private
		*/
        _setOrientation: function (val) {
            if (val == "horizontal") {
                this.element.removeClass("e-vertical e-horizontal").addClass("e-horizontal");
            } else {
                this.element.removeClass("e-horizontal e-vertical").addClass("e-vertical");
            }
        },
        /**
        * To configure the height		
        * @private
        */
        _setHeight: function (value) {
            this.element.height(value);
        },
        /**
        * To configure the width		
        * @private
        */
        _setWidth: function (value) {
            this.element.width(value);
        },
        /**
        * To enable or disable the Right to Left behaviour 			
        * @private
        */
        _setRTL: function (isRTL) {
            if (isRTL) {
                this.element.removeClass("e-rtl").addClass("e-rtl");
                this.model.subMenuDirection = "left";
            } else {
                this.element.removeClass("e-rtl");
                this.model.subMenuDirection = "right";
            }
        },
        /**
        * To enable or disable the AnimationType while Hover or Click an Menu items		
        * @private
        */
        _setAnimation: function (value) {
            value === "none" ? (this._showAnim = "none", this._hideAnim = "none") : (this._showAnim = "slideDown", this._hideAnim = "slideUp");
        },
        /**
        * To configure the control status	
        * @private
        */
        _controlStatus: function (value) {
            //disable status
            value != true ? this.disable() : this.enable();
        },
        /**
        * To configure enableCenterAlign of Menu items.		
        * @private
        */
        _centerAlign: function (enableCenterAlign) {
            if (this.model.orientation == "horizontal" && enableCenterAlign)
                this.element.css('text-align', 'center');
            else if (this.model.orientation == "horizontal") this.element.css('text-align', 'inherit');
        },
        _columnToSelect: function (mapper) {
            var column = [], queryManager = ej.Query();
            if (ej.isNullOrUndefined(mapper.query)) {
                for (var col in mapper) {
                    if (col !== "tableName" && col !== "child" && col !== "dataSource")
                        column.push(mapper[col]);
                }
                if (column.length > 0)
                    queryManager.select(column);
                if (!this.model.fields["dataSource"].dataSource.url.match(mapper.tableName + "$"))
                    !ej.isNullOrUndefined(mapper.tableName) && queryManager.from(mapper.tableName);
            }
            else
                queryManager = mapper.query;
            return queryManager;
        },
        /**
        * To Find maximum z-index in the document	
        * @private
        */
        //Gets the maximum z-index in the document
        _max_zindex: function () {
            var parents = this.element.parents(), bodyEle, maxZ;
            bodyEle = $('body').children(), index = bodyEle.index(this.popup);
            bodyEle.splice(index, 1);
            $(bodyEle).each(function (i, ele) { parents.push(ele); });

            if (this.model.menuType == "contextmenu") {
                maxZ = Math.max.apply(null, $.map($('body *'), function (e, n) {
                    if ($(e).css('position') != 'static')
                        return parseInt($(e).css('z-index')) || 1;
                }));
            }
            else {
                 maxZ = Math.max.apply(maxZ, $.map(parents, function (e, n) {
                    if ($(e).css('position') != 'static') return parseInt($(e).css('z-index')) || 1;
                }));
            }
            if (!maxZ || maxZ < 10000) maxZ = 10000;
            else maxZ += 1;
            return maxZ;

        },

        _recursiveFunction: function (items, menuText) {
            var context = this;
            var isFound = false;
            $.each(items, function (key, value) {
                if (value.Text == menuText) {
                    context.selectedItem = value;
                    isFound = true;
                    return false;
                }
                else if (value.ChildItems != null) {
                    context._recursiveFunction(value.ChildItems, menuText);
                }
                if (isFound)
                    return false;
            });
        },
        /**
        * Render section for Context Menu Template	
        * @private
        */
        _contextMenu_Template: function () {
            var oldWrapper = $(".e-menu-wrap #"+this.element.context.id).get(0);
            if (oldWrapper)
                $(oldWrapper.parentElement).remove();
            this.model.orientation = "vertical";
            this._hideAnimation(this.element, this._hideAnim);
            this.element.addClass(this.model.cssClass + " e-context");
            $("body").append(this.element);
            this.wrapper.insertBefore(this.element);
            this.wrapper.append(this.element);
        },
        /**
        * To close currently visible Menu items	
        * @private
        */
        _closeMenu: function () {
            this._hideAnimation(this.element.find('li.e-list:has("> ul")').find('> ul:visible'), this._hideAnim);
        },

        _onMenuIntent: function (element, obj, canOpen) {
            obj._delayMenuHover = window.setTimeout(function () {
                if (obj._mouseOver == true && canOpen) {
                    var showanim = obj._showAnim;
                    var hideanim = obj._hideAnim;
                    var showSpeed = obj._showSpeed;
                    var hideSpeed = obj._hideSpeed;
                    obj._show(element, showanim, hideanim);
                }
            }, this._showSpeed);
        },
        /**
         * To hide Menu items 
		 * @private
         */
        _onHide: function (element, obj, canHide) {
            obj._delaySubMenuHover = window.setTimeout(function () {
                if (obj._mouseOver == false && canHide) {
                    var id = obj._id;
                    var hideanim = obj._hideAnim;
                    var hideSpeed = obj._hideSpeed;
                    obj._closeAll();
                }

            }, obj._hideSpeed);
        },
        /**
        * To configure Sub Menu Position 
        * @private
        */
        _subMenuPos: function (element, direction) {
            var parentPos = $(this.wrapper).parent().offset();
            var pos = $(element).offset();
            var posLeft = pos.left - parentPos.left;
            var subMenu = $('ul:first', element);
            if (pos == null || pos == undefined)
                return false;
            var submenuWidth = subMenu.outerWidth();
            var left = document.documentElement.clientWidth + $(document).scrollLeft();
            if (this.model.menuType == "normalmenu") {
                if ($(element.parentNode).is(this.element)) {
                    if (this.model.orientation == "horizontal")
                        subMenu.css("top", $(element).outerHeight() + "px");
                    else if (direction == "left" && posLeft > submenuWidth)
                        subMenu.css("left", -(submenuWidth + 4) + "px");
                } else if (direction == "left" && posLeft > submenuWidth) {
                    subMenu.css("left", -(submenuWidth + 4) + "px");
                }
            }
            else {
                left -= (pos.left + (2 * submenuWidth) + 4);
                if (left < 0) {
                    var menuLeftPos = (submenuWidth == null) ? "-206.5px" : "-" + (submenuWidth + 5) + "px";
                    subMenu.css("left", menuLeftPos);
                }
                else {
                    if (subMenu.parent('li.e-list').parent('ul').width() && direction == "right") {
                        subMenu.css("left", (subMenu.parent('li.e-list').parent('ul').width() + 4) + "px");
                    }
                    else if (pos.left > submenuWidth)
                        subMenu.css("left", -(submenuWidth + 4) + "px");
                }
            }
        },

        /**
        * To configure the custom theme for Menu using cssClass property		
        * @private
        */
        _setSkin: function (skin) {
            if (this.model.menuType == "normalmenu") {
                if (this.model.orientation == "horizontal") {
                    this.element.removeClass(this.model.cssClass + " e-horizontal");
                    this.element.addClass(skin + " e-horizontal");
                } else {
                    this.element.removeClass(this.model.cssClass + " e-vertical");
                    this.element.addClass(skin + " e-vertical");
                }

            } else {
                this.element.removeClass(this.model.cssClass + " e-context");
                this.element.addClass(skin + " e-context");
            }
        },
        /**
        * To configure seperator for Menu items		
        * @private
        */
        _setSeparator: function (separator) {
            if (separator)
                this.element.addClass("e-separator");
            else this.element.removeClass("e-separator");
        },
        /**
         * Wiring the events to Context Menu 	
		 * @private
         */
        _contextMenuEvents: function (action) {
            this[action]($(this.model.contextMenuTarget), "mousedown taphold", this._ContextMenuHandler);
            this [action](this.element, "contextmenu", this._onDefaultPreventer);
            this[action]($(this.model.contextMenuTarget), "contextmenu", this._onDefaultPreventer);
            this [action]($(document), "click", this._onContextClose);
            this[action]($(document), "keydown", this._onKeyDownHandler);
        },
        /**
        * To show the Menu items		
        * @private
        */
        _show: function (element, showanim, hideanim) {
            var siblingElement;
            var sibling = $('> ul', element);
            sibling.attr({ "aria-hidden": false });
            this._hideAnimation($(element).siblings().find(' > ul:visible'), hideanim);
            if (!($.inArray(this._disabledMenuItems, element) > -1)) {
                if (sibling.css('display') != "none") {
                    siblingElement = this.model.openOnClick ? $(sibling) : sibling.children().find('> ul');
                    this._hideAnimation(siblingElement, hideanim);
                }
                else $('> ul', element).children().find('> ul').hide();
                this._subMenuPos(element, this.model.subMenuDirection);
                sibling.css({ "z-index": this._max_zindex() + 1 });
                if ($('> ul', element).css('display') != 'block') 
                    this._showAnimation(sibling, showanim);
            }
        },
        /**
        * To close all visible Menu items		
        * @private
        */
        _closeAll: function () {
            this._hideAnimation(this.element.find('li.e-list:has("> ul")').find('> ul:visible'), this._hideAnim);
            this._hideAnimation(this.element.find('> ul:visible'), this._hideAnim);
        },
        /**
        * To show the Menu items with animationType		
        * @private
        */
        _showAnimation: function (element, anim) {
            switch (anim) {
                case "slideDown":
                    element.slideDown(this.model.enableAnimation?200:0, "easeOutQuad"); break;
                case "none":
                    element.css("display","block"); break;
            }
        },
        /**
        * To hide the Menu items with animationType		
        * @private
        */
        _hideAnimation: function (element, anim) {
            switch (anim) {
                case "slideUp":
                    $(element).attr({ "aria-hidden": true });
                    element.slideUp(this.model.enableAnimation?100:0, "easeOutQuad"); break;
                case "none":
                    element.css("display","none"); break;
            }
        },

        _removeValue: function (text, disableList) {
            var $browInfo = ej.browserInfo(), elementText;
            $browInfo.version === "8.0" && $browInfo.name === "msie" ? elementText = text[0].outerText : elementText = text[0].textContent;
            var count = $(disableList).length, i = 0;
            while (i <= count)
            {
                if (disableList[i] === $.trim(elementText))
                    return i;
                    i++;
            }
        },
		/**
        * To create sub level Menu items when insert a menu item dynamically	
        * @private
        */
		_createSubLevelItem:function(target,element){
			var ulTag;
			ulTag = $(document.createElement('ul'));
			ulTag.append(element);
			target.append(ulTag);
			target.attr({'role':'menu','aria-haspopup':'true'});
			this.element.find('li:has("> ul")').find('> a,>span').addClass('aschild e-arrow-space');
			this._insertArrows(ulTag);		
		},	
		/**
        * To insert arrows to Menu items when insert a menu item dynamically	
        * @private
        */
		_insertArrows:function(ulTag){
		if (this.model.showRooltLevelArrows)
                ulTag.find('>a,>span').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");
            else 
                ulTag.find('>a,>span').removeClass("e-arrow-space").find('>span.e-icon').remove();
				
            if (this.model.showSubLevelArrows)
                ulTag.parent('li.e-list:has(>ul)').children('a,span').append($('<span>').addClass("e-icon e-arrows")).addClass("e-arrow-space");
            else 
                ulTag.parent('li.e-list:has(>ul)').children('a,span').removeClass("e-arrow-space").find('>span.e-icon').remove();
		},
		/**
        * To create a Menu items when insert a menu item dynamically	
        * @private
        */
		_createMenuItem:function(item){
            var liTag, aTag, imgTag, spanTag;
            liTag = $(document.createElement('li'));
            liTag.attr({"class":'e-list',"role":"menuitem"});
            if (item["htmlAttribute"]) this._setAttributes(item["htmlAttribute"], liTag);
            if (item["text"] && item["text"] != "") {
                aTag = $(document.createElement('a'));
                if (item["imageUrl"] && item["imageUrl"] != "") {
                    imgTag = $(document.createElement('img'));
                    imgTag.attr('src', item["imageUrl"]);
                    if (item["imageAttribute"]) this._setAttributes(item["imageAttribute"], imgTag);
                    aTag.append(imgTag);
                }
                else if (item["spriteCssClass"] && item["spriteCssClass"] != "") {
                    spanTag = $(document.createElement('span'));
                    spanTag.addClass(item["spriteCssClass"]);
                    aTag.append(spanTag);
                }
                aTag.append(item["text"]);
                if (item["linkAttribute"])
                    aTag.attr('href', item["linkAttribute"]);
                else aTag.attr('href', "#");
                liTag.append(aTag);
            }
            if (item["id"]) {
                liTag.prop("id", item["id"]);
            }
            return liTag;
		},
		/**
        * To find out each the item and their target element from item collection and tatrget element collection.	
        * @private
        */
		_insertNode:function(itemCollection,targetNode,operation){
			var item=0,targetList=0,target=0,targetCollection=[];
			typeof (targetNode) ==="string" ? targetCollection.push(this.element.find(targetNode)):typeof (targetNode) ==="undefined" ?targetCollection.push("default"):targetCollection.push(targetNode);
			for(targetList=0;targetList<targetCollection.length;targetList++){
				for(target=0;target<targetCollection[targetList].length;target++)
					for(item=0;item<itemCollection.length;item++)
						this._addItem(itemCollection[item],targetCollection[targetList][target],operation);
		   }
		},
		/**
        * To insert the menu items at their respective place.
        * @private
        */
		_addItem:function(item,target,operation){
				var element,targetElement;
				this._wireEvents("_off");
		        element = this._createMenuItem(item);
				target = target === "default" ? $("#"+item["parentId"]):$(target);
				switch(operation){
				case "insert":
					targetElement= target.children('ul');
					targetElement.length != 0 ? targetElement.append(element):this._createSubLevelItem(target,element);
					break;
				case "insertBefore":
					element.insertBefore(target);
					break;
				case "insertAfter":
					element.insertAfter(target);
					break;
					}
			this._wireEvents("_on");
		},
		/**
        * To remove the root level element while all child level elements are deleted	
        * @private
        */
		_removeItem:function(item){
		  if(item.siblings('li').length == 0 ){
					item.closest("ul").siblings('a.aschild').removeClass("aschild e-arrow-space").children('span.e-icon').remove();
					!item.closest("ul").hasClass("e-menu")?item.closest("ul").remove():item.remove();}
			else
					item.remove();
		},

        //-------------------------Public Methods---------------------------------------------//
		/**
       * Insert the menu item as child of target node.
       * @alias insert
       * @return jQuery
       * @param {ArrayObject}  item  Information about Menu item.
       * @param {string | Object}  target   Selector of target node or Object of target node.
      
       * @example 
         * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To insert menu item 
       *	menuObj.insert([{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
      * &lt;/script&gt;
       * @example 
         * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To insert menu item 
       * $("#menu").ejMenu("insert",[{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
      * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */
		insert:function(item,target){
			this._insertNode(item,target,"insert");
		},	
              /**
       * Insert the menu item before the target node.
       * @alias insertBefore
       * @return jQuery
       * @param {ArrayObject}  item  Information about Menu item.
       * @param {string | Object}  target   Selector of target node or Object of target node.
      
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To insert menu item 
       *	menuObj.insertBefore([{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
      * &lt;/script&gt;
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To insert menu item 
       * $("#menu").ejMenu("insertBefore",[{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
      * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */				
		insertBefore:function(item,target){
			this._insertNode(item,target,"insertBefore");
		},
		/**
       * Insert the menu item after the target node.
       * @alias insertAfter
       * @return jQuery
       * @param {ArrayObject}  item  Information about Menu item.
       * @param {string | Object}  target   Selector of target node or Object of target node.
      
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To insert menu item 
       *	menuObj.insertAfter([{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
     * &lt;/script&gt;
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To insert menu item 
       * $("#menu").ejMenu("insertAfter",[{
	   *          id:"More",
	   *        text:"More"
	   *		}],"#Home");
     * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */	
		insertAfter:function(item,target){
			this._insertNode(item,target,"insertAfter");
		},
		/**
       * Remove Menu item.
       * @alias remove
       * @return jQuery
       * @param {ArrayObject | ArrayString}  target   Selector of target node or Object of target node.
      
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       * var menuObj = $("#menu").data("ejMenu");
       * //To remove menu item 
       * menuObj.remove(["#Home"]);
       * &lt;/script&gt;
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To remove menu item 
       * $("#menu").ejMenu("remove",["#Home"]);
       * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */
		remove:function(targetCollection){
		var target=0,innerTarget=0;   
			 for(target=0;target<targetCollection.length;target++){
				targetCollection[target] = typeof(targetCollection[target]) === "string" ? (this.element.find(targetCollection[target])):targetCollection[target];
					for(innerTarget=0;innerTarget<targetCollection[target].length;innerTarget++)
					(targetCollection[target][innerTarget].tagName === "LI" || targetCollection[target][innerTarget].tagName === "UL")? this._removeItem($(targetCollection[target][innerTarget])):targetCollection[target][innerTarget].remove();
			}
		},	
     /**
       * Shows the Context Menu .
       * @alias showContextMenu
       * @return jQuery
       * @param {number}  locationX  x co-ordinate position of context menu. 
       * @param {number}  locationY   y co-ordinate position of context menu. 
       * @param {object}  targetElement  target element 
       * @param {object}  event name of the event
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To show context menu
       *	menuObj.ShowContextMenu();
       * &lt;/script&gt;
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To show context menu
       * $("#menu").ejMenu("ShowContextMenu");
       * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */
        //Displays the context menu
        _showContextMenu: function (locationX, locationY, targetElement, e) {
            this._closeMenu();
            this._eventArgs = e;
            if ((e != undefined) && e.stopPropagation) e.stopPropagation();
            if (this._trigger("beforeOpen", { target: targetElement })) return false;
            if (this._preventContextOpen) {
                this.element.css({ "left": locationX, "top": locationY });
                this.element.css({ "z-index": this._max_zindex() + 1 });
                this._showAnimation(this.element, this._showAnim);
                this._isContextMenuOpen = true;
               
                    this._trigger("open", { target: targetElement });
            }
            return false;
        },
      /**
       * Hides the Context Menu control.
       * @alias hideContextMenu
       * @return jQuery
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To hide context menu
       *	menuObj.hideContextMenu();
       * &lt;/script&gt;
       * @example 
       * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To hide context menu
       * $("#menu").ejMenu("hideContextMenu");
       * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */
        //Hides the context Menu
        _hideContextMenu: function (e) {
            this._closeMenu();
            this.element.find(".e-mhover").removeClass("e-mhover");
            this.element.find(".e-mfocused").removeClass("e-mfocused");
            this._hideAnimation(this.element, this._hideAnim);
            this._isContextMenuOpen = false;
           
            this._trigger("close", $.extend({ events: e }, e));
        },
        /**
       * Specifies the Menu Item to be disabled by using the Menu Item Text.
       * @alias disableItem 
       * @return jQuery
	   * @param {string} itemtext  Specifies the Menu Item Text to be disabled. 
       * @example 
        * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //initialize the menu object
       *	var menuObj = $("#menu").data("ejMenu");
       *	//To disable Menu item using item text
       *	menuObj.disableItem("Home");
       * &lt;/script&gt;
       * @example 
        * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
       * //To disable Menu item using item text
       * $("#menu").ejMenu("disableItem","Home");
       * &lt;/script&gt;
       * @memberof ejMenu
       * @instance
        */
        //To Disable menu item 
        disableItem: function (itemToDisable) {
           var isMenuItem = $(this.element.find('li.e-list >a ,li.e-list >span')).filter(function () { return $.trim($(this).text()) === itemToDisable; });
            if (isMenuItem.length > 0 && !($.inArray(itemToDisable, this._disabledMenuItems) > -1)) {
                isMenuItem.parent().addClass("e-disable-item").attr({ "aria-disabled": true });
                this._disabledMenuItems.push($.trim(isMenuItem.text()));
            }
        },
         /**
        * Specifies the Menu Item to be disabled by using the Menu Item Id.
		* @alias disableItembyID
		* @return jQuery
		* @param {string|number} itemid  Specifies the Menu Item id to be disabled 
		* @example 
    * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //initialize the menu object
		*	var menuObj = $("#menu").data("ejMenu");
		*	//To disable Menu item using item id
		*	menuObj.disableItemByID("More");
    * &lt;/script&gt;
		* @example 
    * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //To disable Menu item using item id
		* $("#menu").ejMenu("disableItemByID","More");
    * &lt;/script&gt;
		* @memberof ejMenu
		* @instance
        */
        //To disable menu item by id
        disableItemByID: function (itemId) {
            if (itemId && itemId != "") {
                var itemToDisable = this.element.find("#" + itemId) ? this.element.find("#" + itemId)[0] : undefined;
                if (itemToDisable && !($.inArray(itemToDisable, this._disabledMenuItems) > -1)) {
                    $(itemToDisable).addClass("e-disable-item").attr({ "aria-disabled": true });
                    this._disabledMenuItems.push(itemToDisable);
                }
            }
        },

       
        /**
        *Specifies the Menu Item to be enabled by using the Menu Item Text.
		* @alias enableItem
		* @return jQuery
		* @param {string} itemtext  Specifies the Menu Item Text to be enabled.
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //initialize the menu object
		*	var menuObj = $("#menu").data("ejMenu");
		*	//To enable Menu item using item text
		* menuObj.disableItem("Home");
        * menuObj.disableItem("Search Jobs");
		*	menuObj.enableItem("Search Jobs");
     * &lt;/script&gt;
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22}); 
		* //To enable Menu item using item text
        * $("#menu").ejMenu("disableItem","Home");
        * $("#menu").ejMenu("disableItem","Search Jobs");
		* $("#menu").ejMenu("enableItem","Search Jobs");
     * &lt;/script&gt
		* @memberof ejMenu
		* @instance
        */
        //To enable menu item 
        enableItem: function (itemToEnable) {
            var isMenuItem = $(this.element.find('li.e-list >a ,li.e-list >span')).filter(function () { return $.trim($(this).text()) === itemToEnable; });
            if (isMenuItem.length > 0 && ($.inArray(itemToEnable, this._disabledMenuItems) > -1)) {
                isMenuItem.parent().removeClass("e-disable-item").attr({ "aria-disabled": false });
                var index = this._removeValue(isMenuItem, this._disabledMenuItems);
                this._disabledMenuItems.splice(index, 1);
            }
        },
         /**
        *Specifies the Menu Item to be enabled by using the Menu Item Id.
		* @alias enableItembyID
		* @return jQuery
		* @param {string|number} itemid  Specifies the Menu Item id to be enabled. 
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //initialize the menu object
		*	var menuObj = $("#menu").data("ejMenu");
		*	//To enable Menu item using item id
		* menuObj.disable();
		*	menuObj.enableItemByID("More");
     * &lt;/script&gt;
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //To enable Menu item using item id
		*  $("#menu").ejMenu("disable");
		* $("#menu").ejMenu("enableItemByID","More");
     * &lt;/script&gt;
		* @memberof ejMenu
		* @instance
        */
        //To enable menu item by id
        enableItemByID: function (itemId) {
            if (itemId && itemId != "") {
                var itemToEnable = this.element.find("#" + itemId)[0];
                if (itemToEnable && ($.inArray(itemToEnable, this._disabledMenuItems) > -1)) {
                    $(itemToEnable).removeClass("e-disable-item").attr({ "aria-disabled": false });
                    this._disabledMenuItems.pop(itemToEnable);
                }
            }
        },
       /**
        * Disables the Menu control.
		* @alias disable
		* @return jQuery
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //initialize the menu object
		*	var menuObj = $("#menu").data("ejMenu");
		*	//To disable Menu control
		*	menuObj.disable();
    * &lt;/script&gt;
		* @example 
     * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //To disable Menu control
		* $("#menu").ejMenu("disable");
    * &lt;/script&gt;
		* @memberof ejMenu
		* @instance
        */
        //To disable menu
        disable: function () {
            this.model.enabled = false;
            var menuItemCollection = this.element.find('>li[class!=e-separator]');
            var proxy = this;
            $.each(menuItemCollection, function (key, value) {
                $(value).addClass("e-disable-item").attr({ "aria-disabled": true });
                proxy._disabledMenuItems.push(value);
            });
        },
        /**
        * Enables the Menu control.
		* @alias enable
		* @return jQuery
		* @example 
    * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22,}); 
		* //initialize the menu object
		*	var menuObj = $("#menu").data("ejMenu");
		*	//To enable Menu control
		*	menuObj.enable();
     * &lt;/script&gt;
		* @example 
    * &lt;ul id="menu"&gt;
                      * &lt;li id="Home"&gt;&lt;a&gt;Home&lt;/a&gt;&lt;/li&gt;
                      * &lt;li&gt;&lt;a&gt;Search Jobs&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Advanced Search&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Company&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Category&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Location&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Skills&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs by Designation&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                      * &lt;/li&gt;
                      * &lt;li id="Post Resume"&gt;&lt;a&gt;Post Resume&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Job Seeker"&gt;&lt;a&gt;JobSeeker Login&lt;/a&gt;&lt;/li&gt;
                      * &lt;li id="Fast Forward"&gt;&lt;a&gt;Fast Forward&lt;/a&gt;
                         * &lt;ul&gt;
                            * &lt;li&gt;&lt;a&gt;Resume writing&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Certification&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Resume Spotlight&lt;/a&gt;&lt;/li&gt;
                            * &lt;li&gt;&lt;a&gt;Jobs4u&lt;/a&gt;&lt;/li&gt;
                         * &lt;/ul&gt;
                       * &lt;/li&gt;
                       * &lt;li id="More"&gt;&lt;a&gt;More&lt;/a&gt;
                          * &lt;ul&gt;
                             * &lt;li&gt;&lt;a&gt;Mobile&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Pay check&lt;/a&gt;&lt;/li&gt;
                             * &lt;li&gt;&lt;a&gt;Blog&lt;/a&gt;&lt;/li&gt;
                          * &lt;/ul&gt;
                        * &lt;/li&gt;
                    * &lt;/ul&gt;
   
       * <br> 
       * &lt;script&gt;
        * $("#menu").ejMenu({height:22}); 
		* //To enable Menu control
		* $("#menu").ejMenu("enable");
     * &lt;/script&gt;
		* @memberof ejMenu
		* @instance
        */
        //To enable menu
        enable: function () {
            this.model.enabled = true;
            var menuItemCollection = this.element.find('li.e-disable-item');
            $.each(menuItemCollection, function (key, value) {
                $(value).removeClass("e-disable-item").attr({ "aria-disabled": false });
            });
            this._disabledMenuItems.pop(this._disabledMenuItems);
        },

        show: function (locationX, locationY, targetElement, e) {
            /// <summary>This will set hide function of toolbar </summary>
            if (!this.model.enabled) return false;
            if (this.model.menuType == "contextmenu") 
                this._showContextMenu(locationX, locationY, targetElement, e);
              else
                this.element.css("display","block");
        },

        hide: function (e) {
            /// <summary>This will set hide function of toolbar </summary>
            if (!this.model.enabled) return false;
            if (this.model.menuType == "contextmenu")
                this._hideContextMenu(e);
            else
            {
                this._closeMenu();
                this.element.css("display", "none");
            }
        },
        
        //--------- ---------------------------------------------------//
        /**
        * Wiring the events to menu control		
        * @private
        */
        /* Register all the events at initialize*/
        _wireEvents: function (action) {
            this [action](this.element.find("li.e-list"), "mouseout", this._mouseOutHandler);
            this [action](this.element.find("li.e-list"), "mouseover", this._mouseOverHandler);
            this [action](this.element.find("li.e-list"), "click", this._onClickHandler);    
            this [action](this.element, "keydown", this._onKeyDownHandler);
            this [action]($(document), "keydown", this._onDocumentKeyDown);
            this [action](this.element, "focus", this._OnFocusHandler);
            this [action](this.element, "blur", this._OnFocusOutHandler);
            if (this.model.menuType == "contextmenu" && $(this.model.contextMenuTarget)[0] != null) {
                this._contextMenuEvents(action);
            }
            else if (this.model.openOnClick) {
                this [action]($(document), "click", this._onDocumentClick);
            }

        },

        //--------------------------------Handlers--------------------------

        /**
         * Section to track the keydown event on Document		
		 * @private
         */
        _onDocumentKeyDown: function () {
            this._isFocused = true;
        },
        /**
         * Section to track the mouse over event		
		 * @private
         */
        // handles the Mouseover event
        _mouseOverHandler: function (event) {
            var element,itemId="";
            this.element.find(".e-mhover").removeClass("e-mhover e-mfocused");
			event.currentTarget= event.target.parentNode;
            if (this.model.menuType == "contextmenu")
                $(event.currentTarget).addClass("e-mhover e-mfocused");
            if ($(event.currentTarget).hasClass('e-disable-item'))
                event.preventDefault();
            else {
                if (event.stopPropagation)
                    event.stopPropagation();
                if (typeof (this._delaySubMenuHover) !== 'undefined') {
                    clearTimeout(this._delaySubMenuHover);
                }
                if (typeof (this._delaySubMenuHover) !== 'undefined') {
                    clearTimeout(this._delayMenuHover);
                }
                this._mouseOver = true;
                this._isMenuOpen = true;
                if ($(event.currentTarget.parentNode.parentNode).is(this.element)) {
                    this._isSubMenuOpen = false;
                }
                else {
                    this._isSubMenuOpen = true;
                }
                if (event.currentTarget.nodeName == "LI" && !$(event.currentTarget).hasClass('e-separator'))
                    element = event.currentTarget;
                else if (event.currentTarget.parentNode) {
                    if (event.currentTarget.parentNode.nodeName == "LI" && !$(event.currentTarget.parentNode).hasClass('e-separator'))
                        element = event.currentTarget.parentNode;
                    else
                        return false;
                }
                else {
                    event.preventDefault();
                    return false;
                }
                this._onMenuIntent(element, this, this._hoverOpen);
                if (!($.inArray(element, this._disabledMenuItems) > -1)) {
                    var menuText = $(element).children('a,span').text();
					itemId = !ej.isNullOrUndefined(element) ? $(element)[0].id:"";
                    var eventArgs = { "text": menuText, "element": element, "event": event ,"ID":itemId};

                    this._trigger("mouseover", $.extend({ events: eventArgs }, eventArgs));
                }
            }
        },
        /**
        * Section to track the mouse out event		
        * @private
        */
        // handles the Mouseout event
        _mouseOutHandler: function (event) {
            var element,itemId = "";
            if (this.model.menuType == "contextmenu")
                $(event.currentTarget).removeClass("e-mhover e-mfocused");
            if ($(event.currentTarget).hasClass('e-disable-item')) 
                event.preventDefault();
            else {
                if (event.stopPropagation)
                    event.stopPropagation();
                if (typeof (this._delaySubMenuHover) !== 'undefined') {
                    clearTimeout(this._delaySubMenuHover);
                }
                if (typeof (this._delaySubMenuHover) !== 'undefined') {
                    clearTimeout(this._delayMenuHover);
                }
                this._mouseOver = false;
                this._isMenuOpen = false;

                if (event.currentTarget.nodeName == "LI" && !$(event.currentTarget).hasClass('e-separator'))
                    element = event.currentTarget;
                else if (event.currentTarget.parentNode) {
                    if (event.currentTarget.parentNode.nodeName == "LI" && !$(event.currentTarget.parentNode).hasClass('e-separator'))
                        element = event.currentTarget.parentNode;
                    else
                        return false;
                }
                else {
                    event.preventDefault();
                    return false;
                }
                this._onHide(element, this, this._hoverClose);
                if (!($.inArray(element, this._disabledMenuItems) > -1)) {
                    var menuText = $(element).children('a,span').text();		
					itemId = !ej.isNullOrUndefined(element) ? $(element)[0].id:"";
                    var eventArgs = {  "text": menuText, "element": element, "event": event,"ID":itemId };
                   
                    this._trigger("mouseout", $.extend({ events: eventArgs }, eventArgs));
                }
            }
        },
        /**
         * Section For handle click action.
		 * @private
         */
        _onClickHandler: function (event) {
            event.stopPropagation();
            var element,itemId="";
            this._isFocused = false;
            var openOnClickStart = false;
            if (event.target.nodeName == "LI" && !$(event.target).hasClass('e-separator') && !$(event.target).hasClass('e-disable-item'))
                element = event.target;
            else if (event.target.parentNode && event.target.parentNode.nodeName == "LI" &&
                !$(event.target.parentNode).hasClass('e-separator') && !$(event.target.parentNode).hasClass('e-disable-item')) { //&& event.target.parentNode.parentNode.parentNode.nodeName == "LI") {
                element = event.target.parentNode;
            }
            else if ($(event.target).hasClass('e-arrows') && !$(event.target.parentNode.parentNode).hasClass('e-disable-item')) {
                element = event.target.parentNode.parentNode;
            }
            else if (event.target.nodeName == "SPAN" && !$(event.target).hasClass('e-arrows') && !$(event.target.parentNode.parentNode).hasClass('e-disable-item')) {
                element = event.target.parentNode.parentNode;
            }
            else {
                event.preventDefault();
                return false;
            }

            if (!this._hoverOpen && $(element).find(">a,>span").hasClass('aschild') ) {
                this._show(element, this._showAnim, this._hideAnim);
                this._hoverOpen = false;
                openOnClickStart = true;
            }
            if (!($.inArray(element, this._disabledMenuItems) > -1)) {
                //Check if Context Menu, then hide the context menu firing the events
                if (this.model.menuType == "contextmenu") {
                    if (this._isContextMenuOpen) {
                        this._hideAnimation(this.element, this._hideAnim);
                        this._isContextMenuOpen = false;
                        
                        this._trigger("close", $.extend({ events: event }, event));
                    }
                }
                if (!openOnClickStart) {
                    //                    if (window.navigator.appName == "Microsoft Internet Explorer")
                    //                        this._mouseOutHandler(event, true);
                    //                    else
                    if (this.element.find('li.e-list:has("> ul")').find('> a,> span').hasClass('aschild')) {
                        this._closeMenu();
                        if (this.model.openOnClick)
                            this._hoverOpen = false;
                    }
                }
                var menuText = $(element).children('a,span').text();
				
				itemId = !ej.isNullOrUndefined(element) ? $(element)[0].id:"";
                var eventArgs = { "text": menuText, "element": element, "event": event, "selectedItem": this.selectedItem,"ID":itemId };            
                this._trigger("click", $.extend({ events: eventArgs }, eventArgs));
                this.selectedItem = null;
            }
        },

        /**
       * Section to watch the key down action.		
       * @private
       */
        _onKeyDownHandler: function (e) {
            var element,itemId="", hoverElement = this.element.find(".e-mhover"), focusedElement = this.element.find(".e-mfocused");
	     // tab key
            if (e.keyCode == 9) {
                this._isFocused = false;
                this._OnFocusOutHandler();
            }
            else if (e.keyCode == 37 || e.keyCode == 38 || e.keyCode == 39 || e.keyCode == 40)
                e.preventDefault();
            //key down
            if (e.keyCode == 40) {
                if (this.model.orientation != "horizontal" && this.element.find(".e-mhover").length > 0) {
                    focusedElement.removeClass("e-mfocused");
                    if (hoverElement.next().hasClass("e-separator"))
                        hoverElement.next().next().addClass("e-mfocused");
                    else if (hoverElement.is(':last-child')) {
                        hoverElement.siblings().first().addClass("e-mfocused");
                    }
                    else
                        hoverElement.next().addClass("e-mfocused");
                }
                else {
                    if (this.model.menuType == "contextmenu")
                        this.element.find("li").first().addClass("e-mfocused e-mhover");
                }
                if (this.model.orientation == "horizontal" && this.element.find(">li.e-mhover").children("ul").length > 0) {
                    this._show(hoverElement[0], this._showAnim, this._hideAnim);
                    hoverElement.removeClass("e-mhover").children("ul:first").find("li:first").addClass("e-mhover");
                }
                else {
                    if (hoverElement.is(':last-child')) {
                        hoverElement.removeClass("e-mhover").siblings().first().addClass("e-mhover");
                    }
                    else if (hoverElement.next().hasClass("e-separator"))
                        hoverElement.removeClass("e-mhover").next().next().addClass("e-mhover");
                    else {
                        hoverElement.removeClass("e-mhover").next().addClass("e-mhover");
                    }
                }
            }
            //key right
            if (e.keyCode == 39) {
                //for root level li
                if (this.model.orientation == "horizontal" && this.element.find(">li.e-list").hasClass("e-mhover")) {
				
                    if (hoverElement.is(":last-child")) {
					
                        hoverElement.removeClass("e-mhover e-mfocused");
                        if (this.element.find("li.e-list").first().hasClass("e-separator")) this.element.find("li.e-list").first().next().addClass("e-mhover e-mfocused");
                        else this.element.find("li.e-list").first().addClass("e-mhover e-mfocused");
                    }
                    else if (hoverElement.next().hasClass("e-separator")) {
					
                        hoverElement.removeClass("e-mhover e-mfocused").next().next().addClass("e-mhover e-mfocused");
                    }
                    else {
					
                        hoverElement.removeClass("e-mhover e-mfocused").next().addClass("e-mhover e-mfocused");
                    }
                }
                else if (this.element.find("li.e-mhover").children("ul").length > 0) {
                    this._show(hoverElement[0], this._showAnim, this._hideAnim);
                    hoverElement.removeClass("e-mhover").children("ul:first").find("li:first").addClass("e-mhover");
                }
                else if (hoverElement.children("ul").length <= 0) {
                    this.element.find(".e-mfocused >ul , .e-mfocused >ul li.e-list >ul").hide();
                    hoverElement.removeClass("e-mhover");
                    if (focusedElement.next().hasClass("e-separator")) {
                        focusedElement.removeClass("e-mfocused").next().next().addClass("e-mhover e-mfocused");

                    } else if (focusedElement.next().length <= 0) {
                        focusedElement.removeClass("e-mfocused").siblings().first().addClass("e-mhover e-mfocused");
                    } else focusedElement.removeClass("e-mfocused").next().addClass("e-mhover e-mfocused");
                }
            }
            //key up
            if (e.keyCode == 38) {
                if (this.model.orientation != "horizontal" && this.element.find(".e-mhover").length > 0) {
                    hoverElement.children("ul").hide();
                    focusedElement.removeClass("e-mfocused");
                    if (hoverElement.prev().hasClass("e-separator"))
                        hoverElement.prev().prev().addClass("e-mfocused");
                    else if (hoverElement.is(':first-child')) {
                        hoverElement.siblings().last().addClass("e-mfocused");
                    }
                    else
                        hoverElement.prev().addClass("e-mfocused");
                }
                else {
                    if (this.model.menuType == "contextmenu")
                    this.element.find("li").last().addClass("e-mfocused e-mhover");
                }
                if (hoverElement.is(':first-child')) {
                    hoverElement.removeClass("e-mhover e-mfocused").siblings().last().addClass("e-mhover");
                }
                else if (hoverElement.prev().hasClass("e-separator"))
                    hoverElement.removeClass("e-mhover").prev().prev().addClass("e-mhover");
                else
                    hoverElement.removeClass("e-mhover").prev().addClass("e-mhover");

            }
            //Key left
            if (e.keyCode == 37) {
                //for root level li
                if (this.model.orientation == "horizontal" && this.element.find(">li.e-list").hasClass("e-mhover")) {
                    if (hoverElement.is(":first-child")) {
                        hoverElement.removeClass("e-mhover e-mfocused");
                        if (this.element.find(">li.e-list").last().hasClass("e-separator"))
                            this.element.find(">li.e-list").last().prev().addClass("e-mhover e-mfocused");
                        else
                            this.element.find(">li.e-list").last().addClass("e-mhover e-mfocused");
                    }
                    else if (hoverElement.prev().hasClass("e-separator")) {
                        hoverElement.removeClass("e-mhover e-mfocused").prev().prev().addClass("e-mhover e-mfocused");
                    }
                    else {
                        hoverElement.removeClass("e-mhover e-mfocused").prev().addClass("e-mhover e-mfocused");
                    }
                }
                else if (this.element.find("li.e-mhover")) {
                    if (!hoverElement.parent().hasClass("e-context")) {
                    this._hideAnimation(hoverElement.parent(), this._hideAnim);
                    hoverElement.parent().closest("li.e-list").addClass("e-mhover");
                    hoverElement.removeClass("e-mhover");
                }
                }
                else {
                    this._hideAnimation(hoverElement, this._showAnim, this._hideAnim);
                    hoverElement.removeClass("e-mhover").parent().addClass("e-mhover");
                }
            }
            if (e.keyCode == 13) {
                if (this.model.menuType == "contextmenu") {
                    if (this._isContextMenuOpen && hoverElement.length > 0 && !focusedElement.hasClass("e-disable-item")) {
                        var menuText = $(hoverElement).children('a,span').text();
                        itemId = !ej.isNullOrUndefined(hoverElement) ? $(hoverElement)[0].id : "";
                        var eventArgs = { "menuId": this.element[0].id, "menuText": menuText, "selectedItem": focusedElement, "itemId": itemId };
                        if (this.model.click)
                            this._trigger("click", $.extend({ events: eventArgs }, eventArgs));
                        this.selectedItem = null;
                        this._hideContextMenu(e);
                    }
                } else {
                this.element.find(".e-mhover >a,.e-mhover >span ").focus();
                this.element.find("li.e-list").removeClass("e-mhover e-mfocused");
                this._closeAll();
            }
            }
            if (e.keyCode == 27) {
                if (this.model.menuType == "contextmenu")
                    this._hideContextMenu(e);
                else
                this._closeAll();
            }
            if (e.target.nodeName == "DIV" && $(e.target).children().is(this.element))
                element = $(e.target).children()[0];
            else if (e.target.nodeName == "LI" && !$(e.target).hasClass('e-separator'))
                element = e.target;
            else if (e.target.parentNode) {
                if (e.target.parentNode.nodeName == "LI" && !$(e.target.parentNode).hasClass('e-separator'))
                    element = e.target.parentNode;
            }
            else
                return false;
            if (!($.inArray(element, this._disabledMenuItems) > -1)) {
                var menuText = $(element).children('a,span').text();
				
			   itemId = !ej.isNullOrUndefined(element) ? $(element)[0].id:"";
                var eventArgs = { "text": menuText, "element": element, "event": e,"ID":itemId };
                
                this._trigger("keydown", $.extend({ events: eventArgs }, eventArgs));
            }

        },
        /**
         * Section For handle Focus action.
		 * @private
         */
        _OnFocusHandler: function (event) {
            if (this._isFocused) {
                this.element.find(">li:first").addClass("e-mhover e-mfocused");
            }
            else this._isFocused = false;
        },
        /**
         * Section For handle FocusOut action.
		 * @private
         */
        _OnFocusOutHandler: function () {
            if (!this._isFocused) {
                this.element.find("li.e-list").removeClass("e-mhover e-mfocused");
                this._closeAll();
            }
        },
        /**
        * Section For handle Click action on Document 
        * @private
        */
        _onDocumentClick: function (event) {
            if (!$(event.target).parents("ul.e-menu").is(this.element)) {
                this._hoverOpen = false;
                this._closeMenu();
            }
        },
        /**
        * Section For handle the context menu event 
        * @private
        */
        //handles the context menu event
        _ContextMenuHandler: function (e) {
            var isRightClick = false;
            if (e.type == "taphold")
                isRightClick = true;
            else if (e.button)
                isRightClick = (e.button == 2);
            else if (e.which)
                isRightClick = (e.which == 3); //for Opera
            var targetElement = e.target;
            if (isRightClick) {
                var evt = e;
                if (e.type == "taphold") {
                    if (e.options.type == "touchstart") evt = e.options.touches[0];
                    else evt = e.options;
                }
                var locationX = (evt.clientX + this.element.width() < $(window).width()) ? evt.pageX : evt.pageX - this.element.width();
                var locationY = (evt.clientY + this.element.height() < $(window).height()) ? evt.pageY : evt.pageY - this.element.height();
                var showSpeed = this._showSpeed;
                this._showContextMenu(locationX, locationY, targetElement, e);
            }
            else {
                if (this._isContextMenuOpen) {
                    var hideanim = this._hideAnim;
                    var hideSpeed = this._hideSpeed;
                    this._hideContextMenu(hideanim, hideSpeed, e);
                }
            }
        },
        /**
         * Section For handles preventing the default (browser's) context menu
		 * @private
         */
        //handles preventing the default (browser's) context menu
        _onDefaultPreventer: function (e) {
            e.preventDefault();
            e.stopPropagation();
            return false;
        },
        /**
         * Section For handles context close on document click
		 * @private
         */
        //handles context close on document click
        _onContextClose: function (e) {
            var proxy = this;
            if (this._isContextMenuOpen) {
                var isRightClick = false;
                if (e.button)
                    isRightClick = (e.button == 2);
                else if (e.which)
                    isRightClick = (e.which == 3); //for Opera

                if (!isRightClick) {
					var hideanim = this._hideAnim;
					var hideSpeed = this._hideSpeed;
					this._hideContextMenu(hideanim, hideSpeed, e);                    
                    var parentElements = $(e.target).parents();
                    $.each(parentElements, function (index, value) {
                        if (value.id == proxy._ContextTargetId) {
                            return;
                        }
                    });

                }
            }
        }

    });

    /**
	 * Enum for Menu type	 
	 * @enum {string}
	 * @global 
	 */
    ej.MenuType = {
        /**  support for list of items appears as normal menu in horizontal or vertical direction. */
        NormalMenu: "normalmenu",
        /**  support for list of items appears as menu when right clicked on target area, thereby preventing browser’s default right click.. */
        ContextMenu: "contextmenu"
    };
    /**
	 * Enum for Sub Menu Popup direction	 
	 * @enum {string}
	 * @global 
	 */
    ej.Direction = {
        /**  support for Render sub menu popup in left direction. */
        Left: "left",
        /**  support for Render sub menu popup in Right direction. */
        Right: "right"
    };
    /**
	 * Enum for animationType	 
	 * @enum {string}
	 * @global 
	 */
    ej.AnimationType = {
        /**  support for disable the AnimationType while hover or click an menu items. */
        None: "none",
        /**  support for enable the AnimationType while hover or click an menu items. */
        Default: "default"
    };

    //mentions the recursive type of child
    //ej.Menu.prototype.defaults.fields.child = ej.Menu.prototype.defaults.fields;
    //ej.Menu.prototype.dataTypes.fields.child = ej.Menu.prototype.dataTypes.fields;

})(jQuery, Syncfusion);;
/// <reference path="ej.core.js" />

(function ($, ej, wd, undefined) {
    'use strict';

    var options = wd.unobtrusive = {
        dataRole: false,
        ejRole: false,
        directive: false
    };
    var propMaps = {};

    $(function () {
        var ds = $(document.body).data();
        options.ejRole = ds.hasOwnProperty("ejrole") ? readBoolAttr(ds, "ejrole") : options.ejRole;
        options.directive = ds.hasOwnProperty("directive") ? readBoolAttr(ds, "directive") : options.directive;
        if (options.ejRole !== true && options.directive !== true) options.dataRole = true;
        options.dataRole = ds.hasOwnProperty("datarole") ? readBoolAttr(ds, "datarole") : options.dataRole;

        if (options.ejRole !== true && options.dataRole !== true && options.directive !== true)
            return;

        wd.autoInit = ds.hasOwnProperty("autoinit") ? readBoolAttr(ds, "autoinit") : true;

        if (wd.autoInit !== true)
            return;

        var query = [], el;
        if (options.dataRole === true)
            query.push("[data-ej-init]");
        if (options.ejRole === true)
            query.push("[ej-init]");
        el = $(query.join(','));

        if (!el.length) el = $(document);
        wd.init(el);
    });

    wd.init = function (element) {
        if (!element) element = $(document);
        else element = element.jquery ? element : $(element);

        var widgets = wd.registeredWidgets;
        for (var name in widgets) {
            checkUnobtrusive(widgets[name].name, widgets[name].proto, options, element);
        }
    }

    var findElements = function (name, op, el, proto) {
        var query = [], controlName = name.replace("ej", '').toLowerCase(), res = {};

        if (op.dataRole === true) {
            query.push("[data-role='" + name.toLowerCase() + "']");
        }
        if (op.ejRole === true) {
            query.push("[ej-" + controlName + "]");
        }

        res["role"] = el.find(query.join(','));

        if (op.directive === true) {
            res["directive"] = findAndChangeTag(el.find(controlName), (proto.validTags && proto.validTags[0]) || "div", controlName, el);
        }
        return res;
    };

    var findAndChangeTag = function (controls, tag, query, el) {
        var requiresFind = false, len = controls.length;
        for (var i = 0; i < len; i++) {
            if (controls[i].offsetParent) {
                controls[i] = changeTag(controls[i], tag);
            }
            else {
                controls.splice(i--, 1);
                requiresFind = true;
                len--;
            }
        }
        if (requiresFind) {
            controls.push.apply(controls, findAndChangeTag(el.find(query), tag, query, el));
        }
        return controls;
    }

    var readAttributes = function (element, op, plugin) {
        var attributes = element[0].attributes, att, data = {},
            control = plugin.slice(2).toLowerCase(),
            dataName = "data-ej-",
            dataLength = dataName.length,
            ejName = "ej-",
            ejLength = ejName.length,
            value;

        for (var i = 0; i < attributes.length; i++) {
            att = attributes[i];
            if (op.dataRole && att.name.startsWith(dataName)) {
                processAttrib(data, att.name.slice(dataLength), processData(att.value));
            }
            if ((op.ejRole && att.name.startsWith(ejName)) ||
                (op.dataRole === false && op.ejRole === false && op.directive === true && att.name.startsWith(ejName))) {
                processAttrib(data, att.name.slice(ejLength), processData(att.value));
            }
        }

        return data;
    }

    var processData = function (value) {
        return value === "true" ? true :
            value === "false" ? false :
            +value + "" === value ? +value : value;
    }

    var processAttrib = function (obj, name, value) {
        if (name.indexOf("-") === -1) {
            obj[name] = value;
            return;
        }

        ej.createObject(name.replace(/-/g, '.'), value, obj);
    }

    var checkUnobtrusive = function (name, proto, op, el) {
        var controls = findElements(name, op, el, proto), map = propMaps[name];

        if (((controls.role && controls.role.length) || (controls.directive && controls.directive.length)) && !map) {
            propMaps[name] = map = generatePropMap(proto.defaults);

            if (proto._unobtrusive)
                $.extend(true, map, proto._unobtrusive);
        }

        initControls(controls.role, op, name, proto, map);

        if (controls.directive)
            initControls(controls.directive, op, name, proto, map, true);
    };

    var initControls = function (controls, op, name, proto, map, dir) {
        var types = proto.dataTypes, len = controls.length;
        for (var i = 0; i < len; i++) {
            var control = controls.eq(i), model = {};
            iterateAndSetModel(model, readAttributes(control, op, name), map, types);
            control[name](model);
        }
    }

    var div = $(document.createElement("div"));
    var changeTag = function (el, tag) {
        var $el = $(el);
        if (ej.support.outerHTML) {
            div.insertBefore($el);
            var currentTag = el.tagName, res = [];
            res[0] = "<";
            res[1] = el.outerHTML.trim().replace(RegExp("^<" + currentTag + "|" + currentTag + ">$", "ig"), tag);
            if (!res[1].endsWith(">"))
                res[2] = ">";
            el.outerHTML = res.join("");
            el = div.next()[0];
            div.remove();
            return el;
        }
        var clone = $el.clone(), currentTag = el.tagName, html = "";
        $el.html(html);
        html += "<";
        html += div.append(clone).html().replace(RegExp("^<" + currentTag + "|" + currentTag + ">$", "ig"), tag);
        html += ">";
        div.html(html);
        clone = $el.wrap(div.children().first()).parent();
        $el.remove();
        div.empty();
        return clone[0];
    }

    var iterateAndSetModel = function (model, data, map, type) {
        var field = "", current;
        for (var prop in data) {
            field = map && prop in map ? map[prop] : prop;
            current = data[prop];
            if (ej.isPlainObject(current) && (map || type)) {
                model[field] = {};
                iterateAndSetModel(model[field], current, map ? map[prop + ".value"] : map, type ? type[field] : type);
                continue;
            }
            if (type && type[field] === "array") {
                try {
                    current = $.parseJSON(current);
                }
                catch (e) {
                    current = eval(current);
                }
            }
            else if (type && type[field] === "data") {
                if (/^\[{0,1}\{.+\}\]{0,1}$/.test(current))
                    current = $.parseJSON(current);
                else if (current.indexOf('/') === -1) // json instance
                    current = ej.getObject(current.indexOf("window.") === 0 ? current.slice(7) : current, window) || current;
            }

            model[field] = current;
        }
    }

    var generatePropMap = function (obj) {
        var map = {}, field;
        for (var prop in obj) {
            field = prop.toLowerCase();
            if (ej.isPlainObject(obj[prop])) {
                map[field + ".value"] = generatePropMap(obj[prop]);
            }
            map[field] = prop;
        }
        return map;
    };

    var readBoolAttr = function (obj, attr) {
        if (obj.hasOwnProperty(attr))
            return obj[attr] !== false;

        return false;
    }

    // IE8
    String.prototype.trim = String.prototype.trim || function () {
        return this.replace(/^\s+|\s+$/g, '');
    }
})(window.jQuery, window.Syncfusion, window.Syncfusion.widget);;
/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
* Use of this code is subject to the terms of our license.
* A copy of the current license can be obtained at any time by e-mailing
* licensing@syncfusion.com. Any infringement will be prosecuted under
* applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejDiagram
    * @requires jquery.js
    * @requires jquery.easing.min.js
    * @requires jsrender.min.js
    * @requires ej.core.js
    * @requires ej.draggable.js
    * @requires ej.scroller.js
    * @requires ej.touch.js
    * @requires ej.diagram.js
    * @requires ej.diagramcommon.js
    * @requires ej.diagraminteraction.js
    * @requires ej.diagramsvg.js
    * @requires ej.diagramtools.js
    * @requires ej.diagramlayout.js
    * @requires ej.matrix.js
    * @classdesc The diagram control provides 2D surface to visualize the data as shapes, lines, text and images. It can be configured to DOM element such as DIV.
    * @example 
    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * //Create Diagram
    $("#diagram").ejDiagram();
    * &lt;/script&gt
    */

    "use strict";
    //#region ej.Diagram widget
    ej.widget("ejDiagram", "ej.datavisualization.Diagram", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["div"],

        //#region defaults
        defaults: {
            /**Specifies the width of the diagram. 
            * @default null
            * @type {string}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ width:"100%" });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            width: null,
            /**Specifies the height of the diagram.
            * @default null
            * @type {string}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ height:"100%" });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            height: null,
            /**Array of node objects where each object has definition/properties of node.
            * @default []
            * @type {array}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var nodes = [{ name: "node", width: 175, height: 60}];
            * $("#diagram").ejDiagram({ nodes:nodes });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            nodes: [],
            /**Array of connector objects where each object has definition/properties of connector.
            * @default []
            * @type {array}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var connectors = [{ name: "connector" sourceNode: "node1", targetNode: "node2"}];
            * $("#diagram").ejDiagram({ connectors:connectors });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            connectors: [],
            /**Specifies the data source to be viusalized as diagram.
            * @default null
            * @type {array}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var data = [{ firstName: "Maria", LastName: "Anders", children: {{ firstName: "Antonio", LastName: "Moreno" }}}]
            * $("#diagram").ejDiagram({ dataSource:data });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            dataSource: null,
            /**The default connector properties which will be used to create connectors during data binding.
            * @default null
            * @type {object}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ connectorDefaults:{ lineColor: "gray", lineWidth: 2 }});
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            connectorDefaults: null,
            /**The default node properties which will be used to create nodes during data binding.
            * @default null
            * @type {object}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ nodeDefaults: { fillColor: "#83A93F", borderColor: "#000000" }});
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            nodeDefaults: null,
            /**The template function which will be trigger to create nodes dynamically by user during data binding.
            * @event
            * @name ejDiagram#nodeTemplate 	
			* @param {Object} argument Data passed to user when process the dataSource data.
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * function templateFunction(option) { 
            *     return { name: option.firstName, width: 100, height: 100, shape: { ej.datavisualization.Diagram.Shapes.Ellipse } };
            * }
            * $("#diagram").ejDiagram({ nodeTemplate: templateFunction});
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            nodeTemplate: null,
            /**Specifies the schema for data source.
            * @default { model: { children: "children" }}
            * @type {object}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ dataSourceSchema: { model: { children: "items" }}});
            * &lt;/script&gt
               * @memberof ejDiagram
              * @instance
            */
            dataSourceSchema: {
                /**Specifies the model for data source.
           * @default { model: { children: "children" }}
           * @type {object}
           * @example
           * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           * $("#diagram").ejDiagram({ dataSourceSchema: { model: { children: "items" }}});
           * &lt;/script&gt
            * @alias ejDiagram#dataSourceSchema->model
              * @memberof ejDiagram
             * @instance
           */
                model: {
                    /**Specifies the children for model of data source.
           * @default { model: { children: "children" }}
           * @type {object}
           * @example
           * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           * $("#diagram").ejDiagram({ dataSourceSchema: { model: { children: "items" }}});
           * &lt;/script&gt
            * @alias ejDiagram#dataSourceSchema->model->children
              * @memberof ejDiagram
             * @instance
           */
                    children: "children"
                }
            },
            /**Specifies the snap settings of the diagram.
            * @type {object}
               * @memberof ejDiagram
              * @instance
            */
            snapSettings: /** @lends ejDiagram# */ {
                /**Specifies the settings of horizontal grid lines.
                * @type {object}
                * @alias ejDiagram#snapSettings->horizontalGridLines
                */
                horizontalGridLines: {
                    /**Specifies the space between horizontal grid lines
                    * @default [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75]
                    * @type {array}
                    * @example
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { 
                    *     horizontalGridLines: { linesInterval: [1, 14, 0.25, 15, 0.25, 15, 0.25, 15, 0.25, 15] }
                    * }}); 
                    * &lt;/script&gt
                    * @alias ejDiagram#snapSettings->horizontalGridLines->linesInterval
                    */
                    linesInterval: [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75],
                    /**Specifies the snap intervals for horizontal grid lines.
                    * @default [20]
                    * @type {array}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { horizontalGridLines: { snapInterval: [10] }}}); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->horizontalGridLines->snapInterval
                    */
                    snapInterval: [20],
                    /**Specifies the pattern of dashes and gaps used to stroke horizontal grid lines
                    * @default "0"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * $("#diagram").ejDiagram({ snapSettings: { horizontalGridLines: { lineDashArray: "2 2"}}}); 
                    * &lt;/script&gt
                     * @alias ejDiagram#snapSettings->horizontalGridLines->lineDashArray
                    */
                    lineDashArray: "0",
                    /**		
                    * Line color for horizontal gridlines
                    * @default "lightgray"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * var gridline = { "snapConstraints":"lineColor": "blue" };
                    * //Linecolor of the horizontal gridlines
                    * $("#diagramContent").ejDiagram({snapSettings: { horizontalGridLines: gridline} }); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->horizontalGridLines->lineColor
                    */
                    lineColor: "lightgray"
                },
                /**Specifies the settings of vertical grid lines.
                * @type {object}
                * @alias ejDiagram#snapSettings->verticalGridLines
                */
                verticalGridLines: {
                    /**Specifies the space between vertical grid lines
                    * @default [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75]
                    * @type {array}
                    * @example
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { 
                    *     verticalGridLines: { linesInterval: [1, 14, 0.25, 15, 0.25, 15, 0.25, 15, 0.25, 15] }
                    * }}); 
                    * &lt;/script&gt
                    * @alias ejDiagram#snapSettings->verticalGridLines->linesInterval
                    */
                    linesInterval: [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75],
                    /**Specifies the snap intervals for vertical grid lines.
                    * @default [20]
                    * @type {array}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { verticalGridLines: { snapInterval: [10] }}}); 
                    * &lt;/script&gt
                  * @alias ejDiagram#snapSettings->verticalGridLines->snapInterval
                    */
                    snapInterval: [20],
                    /**Specifies the pattern of dashes and gaps used to stroke vertical grid lines
                    * @default "0"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * $("#diagram").ejDiagram({ snapSettings: { verticalGridLines: { lineDashArray: "2 2"}}}); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->verticalGridLines->lineDashArray
                    */
                    lineDashArray: "0",
                    /**		
               * Line Color of vertical grid lines
               * @default "lightgray"
               * @type {string}
               * @example 
               * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
               * &lt;/script&gt
               * var gridline = { "snapConstraints":"lineColor": "blue" };
               * //Linecolor of the vertical gridlines
               * $("#diagramContent").ejDiagram({snapSettings: { verticalGridLines: gridline} });
               * &lt;/script&gt
              * @alias ejDiagram#snapSettings->verticalGridLines->lineColor
               */
                    lineColor: "lightgray"
                },
                /**		
           * Enables or disables the snapconstraints of gridlines see{@link snapConstraints}
           * @name SnapConstraints
           * @default SnapConstraints.ShowLines 
           * @type {enum}
           * @example 
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;/script&gt
           * var gridline = { "snapConstraints": ej.datavisualization.Diagram.SnapConstraints.ShowLines};
           * //snap constraints of gridlines
           * $("#diagramContent").ejDiagram({snapSettings: gridline} });
           * &lt;/script&gt
           * @alias ejDiagram#snapSettings->snapConstraints
           */
                snapConstraints: 1 | 2 | 4 | 8,
                /**		
            * Enables or disables the snap object 
            * @default true
            * @type {Boolean}
            * @example 
            *var snap = {"enableSnapToObject":true};
            * //enableSnapToObject: 
            * $("#diagramContent").ejDiagram({snapSettings: snap}); 
            * @alias ejDiagram#snapSettings->enableSnapToObject
            */
                enableSnapToObject: true,
                /**		
         * The Angle to which the object to be snapped
         * @default 5
         * @type {Number}
         * @example 
         *var snap = {"snapAngle":5};
         * //enableSnapToObject: 
         *$("#diagramContent").ejDiagram({snapSettings: snap}); 
         * @alias ejDiagram#snapSettings->snapAngle
         */
                snapAngle: 5,
                /**		
            * Relative distance between the nearer object and selected object
            * @default 5
            * @type {Number}
            * @example 
            *var snap = {"snapObjectDistance":5};
            * //snapObjectDistance
            *$("#diagramContent").ejDiagram({snapSettings: snap}); 
            * @alias ejDiagram#snapSettings->snapObjectDistance
            */
                snapObjectDistance: 5
            },
            /**		
            * The pageSetting of the diagram
               * @memberof ejDiagram
              * @instance*/
            pageSettings: /** @lends ejDiagram# */ {
                /**		
         * This is used to set the width of the page 
         * @default null
         * @type {Number}
         * @example 
         * //pageWidth
         *$("#diagramContent").ejDiagram({pageSettings: {pageWidth: 4500}}); 
         * @alias ejDiagram#pageSettings->pageWidth
         */
                pageWidth: null,
                /**		
         * This is used to set the height of the page 
         * @default null
         * @type {Number}
         * @example 
         * //pageHeight of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageHeight: 4500}}); 
         * @alias ejDiagram#pageSettings->pageHeight
         */
                pageHeight: null,
                /**		
         * Enables or disables the multiple page
         * @default false
         * @type {Boolean}
         * @example 
         * //multiplePage of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {multiplePage: false}}); 
         * @alias ejDiagram#pageSettings->multiplePage
         */
                multiplePage: false,
                /**		
         *This is used to set the width of the page border 
         * @default 0
         * @type {Number}
         * @example 
         * //pageBorderWidth of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageBorderWidth: 3}}); 
         * @alias ejDiagram#pageSettings->pageBorderWidth
         */

                pageBorderWidth: 0,
                /**		
          * Used set the background color of the page 
          * @default "#ffffff"
          * @type {String}
          * @example 
          * //pageBackgroundColor of the diagram
          * $("#diagramContent").ejDiagram({pageSettings: {pageBackgroundColor: "#ffffff"}}); 
          * @alias ejDiagram#pageSettings->pageBackgroundColor
          */
                pageBackgroundColor: "#ffffff",
                /**		
         * Used to set the border color of the page
         * @default "#565656"
         * @type {String}
         * @example 
         * //pageBorderColor of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageBorderColor: "#565656"}}); 
         * @alias ejDiagram#pageSettings->pageBorderColor
         */
                pageBorderColor: "#565656",
                /**		
         * Margin of the page
         * @default 24
         * @type {Number}
         * @example 
         * //pageMargin of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageMargin: 24}}); 
         * @alias ejDiagram#pageSettings->pageMargin
         */
                pageMargin: 24,
                /**		
         * Enables or disables the page breaks in diagram
         * @default false
         * @type {Boolean}
         * @example 
         * //showPageBreak of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {showPageBreak: false}}); 
         * @alias ejDiagram#pageSettings->showPageBreak
         */
                showPageBreak: false,
                /**		
          * Orientation allows placement of element on a page that set through page set up see{@link PageOrientations}
          * @name pageOrientation
          * @default "portrait"
          * @type {enum}
          * @example 
          * //pageOrientation of the diagram
          *$("#diagramContent").ejDiagram({pageSettings: {pageOrientation: "portrait"}}); 
          * @alias ejDiagram#pageSettings->pageOrientation
          */
                pageOrientation: "portrait"
            },

            locale:"en-US",
            /**		
           *The contextmenu of the diagram
              * @memberof ejDiagram
              * @instance*/
            contextMenu: {
                /**		
      * Collection of items of Contextmenu
      * @default []
      * @type {Object}                          
      * @example 
	  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * //Collection of  items
      *var menucollection = [{ "name": "hyperLink", "text": "Hyperlink", "image": "", "style": "" }];
	  *var contextMenu = { items: menucollection};
      *$("#diagramContent").ejDiagram({contextMenu: contextMenu}); 
      * &lt;/script&gt
      * @alias ejDiagram#contextMenu->items
       * @memberof ejDiagram
         * @instance
        */

                items: [],
                /**
               *Events to trigger action, when click option in diagram
               * @event
               * @name ejDiagram#contextMenu#click
               * @param {Object} argument args parameter from diagram 
               * @param {Object} argument.element parameter returns node or connector 
               * @example
                * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                                         * &lt;script&gt;
               * //  click event for Contextmenu item
               *var contextMenu = { items: menucollection, onClick: contextMenuClick};
               *$("#diagramContent").ejDiagram({contextMenu: contextMenu}); 
                * &lt;/script&gt
               });
                 * @alias ejDiagram#contextMenu->click
               */
                click: null,
                /**
*Events to trigger before, open context menu
* @event
* @name ejDiagram#contextMenu#beforeOpen
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns node or connector 
* @example
* //  beforeOpen event for Contextmenu item
 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                          * &lt;script&gt;
* //  click event for Contextmenu item
*var contextMenu = { items: menucollection, onBeforeOpen: contextMenuBeforeOpen};
*$("#diagramContent").ejDiagram({contextMenu: contextMenu}); 
 * &lt;/script&gt
});
*/

                beforeOpen: null,
                /**To display or hide items of contextmenu
                          * @default true
                          * @type {Boolean}
                          * @example
                          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                          * &lt;script&gt;
                          * $("#diagramcontent").ejDiagram({showCustomMenuItemsOnly: true});
                          * &lt;/script&gt
						    * @alias ejDiagram#contextMenu->showCustomMenuItemsOnly
                             * @memberof ejDiagram
                             * @instance
                          */

                showCustomMenuItemsOnly: false
            },
            enableContextMenu: true,
            /** Enables or disables Auto scroll in diagram
           * @default true
           * @type {Boolean}
           * @example
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           * $("#diagramcontent").ejDiagram({enableAutoScroll: true});
           * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
           */
            enableAutoScroll: true,
            /** Enables or disables tooltip of diagram
         * @default true
         * @type {Boolean}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({showTooltip: true});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            showTooltip: true,
            /** To set custom style for tool tip of diagram
         * @default ""
         * @type {String}
         * @example
         * &lt;script type="text/x-jsrender" id="toolTipId"&gt;
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         *&lt;span &gt;{{:offsetX}}{{:x}}{{:offsetY}}{{:y}}
         * &lt;/script&gt
         *&lt;/span&gt;
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ tooltipTemplateId: "toolTipId"});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            tooltipTemplateId: "",
            /** Distance between the node and the viewport from where autoscroll should start
         * @default 20
         * @type {Number}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({autoScrollMargin: 20});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            autoScrollMargin: 20,
            /** To arrange elements on the page in diagram
               * @memberof ejDiagram
              * @instance*/
            layout: /** @lends ejDiagram# */{
                /**		
          * Type of the layout on the page
          * @default "none"
          * @type {String}
          * @example 
          * //type of the layout
          * $("#diagramContent").ejDiagram({layout: {type: "none"}}); 
          * @alias ejDiagram#layout->type
          */
                type: "none",
                /**		
          * Alignment of elements based on some specific direction see {@link LayoutOrientations}
          * @default "topToBottom"
          * @type {String}
          * @example 
          * //orientation of the layout
          *$("#diagramContent").ejDiagram({layout: {orientation: "topToBottom"}}); 
          * @alias ejDiagram#layout->orientation
          */
                orientation: "toptobottom",
                /**		
          * Horizontal Spacing between the nodes in layout
          * @default 30
          * @type {Number}
          * @example 
          * //horizontalSpacing of the layout
          *$("#diagramContent").ejDiagram({layout: {horizontalSpacing: 30}}); 
          * @alias ejDiagram#layout->horizontalSpacing
          */
                horizontalSpacing: 30,
                /**		
          * Vertical Spacing between the nodes in layout
          * @default 30
          * @type {Number}
          * @example 
          * //verticalSpacing of the layout
          *$("#diagramContent").ejDiagram({layout: {verticalSpacing: 30}}); 
          * @alias ejDiagram#layout->verticalSpacing
          */
                verticalSpacing: 30,
                /**		
         * Margin value along X -Axis 
         * @default 0
         * @type {Number}
         * @example 
         * //marginX of the layout
         *$("#diagramContent").ejDiagram({layout: {marginX: 0}}); 
         * @alias ejDiagram#layout->marginX
         */
                marginX: 0,
                /**		
          * Margin value along y -Axis
          * @default 0
          * @type {Number}
          * @example 
          * // marginY of the layout
          *$("#diagramContent").ejDiagram({layout: { marginY: 0}}); 
          * @alias ejDiagram#layout-> marginY
          */
                marginY: 0,
                /**	 Nodes position is set as fixed and draw all node based on the fixed node
             * @default ""
             * @type {String}
             * @example 
             * //fixedNode of the layout
             *$("#diagramContent").ejDiagram({layout: { fixedNode: "nodename"}}); 
             * @alias ejDiagram#layout-> fixedNode
             */
                fixedNode: "",
            },
            /** To add frequently using commands around selector
         * @default ""
         * @type {string}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var userHandle= [];
         * function createUserHandles() {
         * var cloneHandle = ej.datavisualization.Diagram.UserHandle();
         * userhandle.push(cloneHandles);
         * }
         * $("#diagramcontent").ejDiagram({userHandles:userHandle});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            userHandles: [],
            /** Enables to choose which interactive feature to be performed
         * @default ""
         * @type {Object}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ drawingTools: {textTool: ej.datavisualization.Diagram.TextTool()}});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            drawingTools: {},
            /** Image to be used as an background of the elements
         * @default null
         * @type {String}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ backgroundImage: "Syncfusion.png"});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            backgroundImage: null,
            /**		
              * Enables or disables the selector constraints see{@link SelectorConstraints}
              * @default SelectorConstraints.All 
              * @type {enum}
              * @example 
              * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
              * &lt;script&gt;
              *$("#diagramContent").ejDiagram({selectorConstraints: ej.datavisualization.Diagram.SelectorConstraints.None} }); 
              * &lt;/script&gt
                 * @memberof ejDiagram
              * @instance
              */
            selectorConstraints: 1 << 1 | 1 << 2 | 1 << 3,
            /**		
   * Allow to set the factor by which we can zoom in or zoom out
  * @default 1
  * @type {Number}
  * @example 
  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
  * &lt;script&gt;
  *$("#diagramContent").ejDiagram({zoomFactor: 1}); 
  * &lt;/script&gt
     * @memberof ejDiagram
              * @instance
  */
            zoomFactor: 1,
            /**
  *Triggers When node collection get change
  * @event
  * @name ejDiagram#nodeCollectionChange
  * @param {Object} argument args parameter from diagram              
  * @param {String} argument.changetype return should be insert or remove
  * @param {Object} argument.element parameter returns node which to be added or deleted
  * @example
  * // nodeCollectionChange event for diagram
  * $("#diagramcontent").ejDiagram({
  * nodeCollectionChange:function (args)  {}
   *  });
  */
            nodeCollectionChange: null,
            /**
   *Triggers When connector collection get change
   * @event
   * @name ejDiagram#connectorCollectionChange
   * @param {Object} argument args parameter from diagram              
   * @param {String} argument.changetype return should be insert or remove
   * @param {Object} argument.element parameter returns connector which to be added or deleted
   * @example
   * // connectorCollectionChange event for diagram
   * $("#diagramcontent").ejDiagram({
   * connectorCollectionChange:function (args) {}
        });
   */
            connectorCollectionChange: null,
            /**
 *Triggers When selection get change
 * @event
 * @name ejDiagram#selectionChanged
 * @param {Object} argument args parameter from diagram 
 * @param {String} argument.changetype return should be inserted or removed
 * @param {Object} argument.element parameter returns node or connector which to be added or deleted
 * @example
 * //  selectionChange event for diagram
 * $("#diagramcontent").ejDiagram({
 * selectionChange:function (args)  {}
    });
 */
            selectionChange: null,
            /**
*Triggers When mouse leaves node/connector
* @event
* @name ejDiagram#mouseLeave
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns node or connector 
* @example
* //  mouseLeave event for diagram
* $("#diagramcontent").ejDiagram({
* mouseLeave:function (args)  {}
   });
*/
            mouseLeave: null,
            /**
*Triggers When mouse enter node/connector
* @event
* @name ejDiagram#mouseEnter
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns node or connector 
* @example
* //  mouseEnter event for diagram
* $("#diagramcontent").ejDiagram({
* mouseEnter:function (args)  {}
  });
*/
            mouseEnter: null,
            /**
*Triggers When mouse Hover on node/connector
* @event
* @name ejDiagram#mouseOver
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.diagram parameter returns node or connector 
* @example
* //  mouseOver event for diagram
* $("#diagramcontent").ejDiagram({
* mouseOver:function (args)  {}
  });
*/
            mouseOver: null,
            /**
*Triggers When click node/connector
* @event
* @name ejDiagram#click
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns diagram
* @example
* //  click event for diagram
* $("#diagramcontent").ejDiagram({
* click:function (args)  {}
 });
*/
            click: null,
            /**
*Triggers When doubleClick node/connector
* @event
* @name ejDiagram#doubleClick
* @param {Object} argument args parameter from diagram 
* @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
* @param {Object} argument.element parameter returns selected object in list
* @example
* //  doubleClick event for diagram
* $("#diagramcontent").ejDiagram({
* doubleClick:function (args)  {}
   });
*/
            doubleClick: null,
            /**
*Triggers When drag and drop symbols from palette to drawing area 
* @event
* @name ejDiagram#drop
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns node or connector
* @example
* //  drop event for diagram
* $("#diagramcontent").ejDiagram({
* drop:function (args)  {}
});
*/
            drop: null,
            drag: null,
            /**
*Triggers When label edit gets ended 
* @event
* @name ejDiagram#textchanged
* @param {Object} argument args parameter from diagram 
* @param {Object} argument.element parameter returns shape
* @param {String} argument.value parameter returns value in label edit box
* @example
* // textChanged event for diagram
* $("#diagramcontent").ejDiagram({
* textChanged:function (args)  {}
});
*/
            textChange: null,
            /**
   *Triggers When node size has been change
  * @event
  * @name ejDiagram#nodeSizeChange
  * @param {Object} argument args parameter from diagram 
  * @param {Object} argument.element parameter returns node that was resized
  * @param {Number} argument.offset parameter returns size of the node
 * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
 * @example
      * // sizeChange event for diagram
      * $("#diagramcontent").ejDiagram({
      * sizeChange:function (args)  {}
         });
      */
            sizeChange: null,
            /**
     *Triggers When connection changes has been done
     * @event
     * @name ejDiagram#connectionChange
     * @param {Object} argument args parameter from diagram 
     * @param {Object} argument.element parameter returns connector
     * @param {String} argument.connection parameter returns source or target node that was connected
     * @param {port} argument.port parameter returns source or target port that was connected
     * @example
     * // connectionChange event for diagram
     * $("#diagramcontent").ejDiagram({
     * connectionChange:function (args)  {}
        }); 
     */
            connectionChange: null,
            /**
     *Triggers When rotate node
     * @event
     * @name ejDiagram#rotationChange
     * @param {Object} argument args parameter from diagram 
     * @param {Object} argument.element parameter returns node
     * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
     * @example
     * // rotationChange event for diagram
     * $("#diagramcontent").ejDiagram({
     * rotationChange:function (args)  {}
        });
     */
            rotationChange: null
        },

        dataTypes: {
            nodes: "array",
            connectors: "array",
            dataSource: "data",
            enableContextMenu: "boolean",
            enableAutoScroll: "boolean",
            showTooltip: "boolean",
            autoScrollMargin: "number",
            userHandles: "array",
            zoomFactor: "number",
            contextMenu: {
                items: "array",
                showCustomMenuItemsOnly: "boolean"
            },
            layout: {
                type: "enum",
                orientation: "enum",
                horizontalSpacing: "number",
                verticalSpacing: "number",
                marginX: "number",
                marginY: "number"
            },
            pageSettings: {
                multiplePage: "boolean",
                pageBorderWidth: "number",
                pageMargin: "number",
                showPageBreak: "boolean",
                pageOrientation: "enum"
            },
            snapSettings: {
                horizontalGridLines: {
                    linesInterval: "array",
                    snapInterval: "array",
                },
                verticalGridLines: {
                    linesInterval: "array",
                    snapInterval: "array",
                },
                enableSnapToObject: "boolean",
                snapAngle: "number",
                snapObjectDistance: "number"
            }
        },

        //#endregion

        //#region Local members
        _canvas: null,
        _svg: null,
        _toolToActivate: null,
        _inAction: false,
        _isEditing: false,
        _nodeToHit: null,
        _currentCursor: null,
        _pasteIndex: null,
        _page: null,
        _view: null,
        _currentLabel: null,
        _zOrder: 0,
        _clipboardData: null,
        _historyList: {
            currentEntry: {
                next: null,
                previous: null
            },
            canUndo: false,
            canRedo: false
        },

        _defaultContextMenuItems: [
            { name: "cut", text: "Cut" },
            { name: "copy", text: "Copy" },
            { name: "paste", text: "Paste" },
            { name: "undo", text: "Undo" },
            { name: "redo", text: "Redo" },
            { name: "selectAll", text: "Select All" },
            {
                name: "grouping",
                text: "Grouping",
                subItems: [
                            { name: "group", text: "Group" },
                            { name: "ungroup", text: "Ungroup" }
                ]
            },
            {
                name: "order",
                text: "Order",
                subItems: [
                            { name: "bringToFront", text: "Bring To Front" },
                            { name: "moveForward", text: "Move Forward" },
                            { name: "sendToBack", text: "Send To Back" },
                            { name: "sendBackward", text: "Send Backward" }
                ]
            }
        ],

        _hScrollOffset: 0,
        _vScrollOffset: 0,
        _scrollPixel: 30,
        //#endregion

        //#region public members
        activeTool: null,
        selectionList: [],
        tools: null,
        nameTable: {},
        //#endregion

        //#region Initialization
        _updateScrollOffset: function (hScrollOffset, vScrollOffset, canScale) {
            this._hScrollOffset = hScrollOffset;
            this._vScrollOffset = vScrollOffset;
            ej.datavisualization.Diagram.ScrollUtil._transform(this, hScrollOffset, vScrollOffset, canScale);
            var diagram = this;
            this._views.forEach(function (viewid) {
                var view = diagram._views[viewid];
                if (view.type == "overview") {
                    var ovw = $("#" + viewid).ejOverview("instance");
                    if (ovw)
                        ovw._scrollOverviewRect(hScrollOffset, vScrollOffset, diagram.model.zoomFactor);
                }
            });
        },

        _init: function () {
            this._spatialSearch = ej.datavisualization.Diagram.SpatialSearch();
            this._initDefaults();
            this._initViews();
            this._initData();
            this._doLayout();
            this._initCanvas();
            this._initVisualGuide();
            this._wireEvents();
            this._initHandles();
            this._initContextMenu();
            this._drawingTool = false;
            this._isDropped = false;
        },

        _setModel: function (options) {
            for (var option in options) {
                switch (option) {
                    case "nodes":
                        this.model.nodes = options[option];
                        this._initNodeCollection();
                        this.element.remove(".ej-d-node");
                        this.element.remove(".ej-d-group");
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._renderNodes(view);
                        });
                        break;
                    case "connectors":
                        this.model.connectors = options[option];
                        this._initConnectorCollection();
                        this.element.remove(".ej-d-connector");
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._renderConnectors(view);
                        });
                        break;
                    case "contextMenu":
                        this.model.contextMenu = options[option];
                        this._initContextMenu();
                        break;
                    case "snapSettings":
                        $.extend(true, this.model.snapSettings, {}, options[option]);
                        ej.datavisualization.Diagram.SvgContext._renderGrid(this._canvas, this._svg, this._page, this);
                        break;
                    case "selectorConstraints":
                        this._setSelectorConstraints(options[option]);
                        break;
                    case "userHandles":
                        this.model.userHandles = options[option];
                        this._initHandles();
                        break;
                    case "drawingTools":
                        this.model.drawingTools = options[option];
                        this._registerDrawingTools();
                        break;
                    case "backgroundImage":
                        this.model.backgroundImage = options[option];
                        ej.datavisualization.Diagram.SvgContext._renderBackground(this._canvas, this._svg, this._page, this.model);
                        break;
                    case "enableAutoScroll":
                        this.model.enableAutoScroll = options[option];
                        break;
                    case "autoScrollMargin":
                        this.model.autoScrollMargin = options[option];
                        break;
                    case "layout":
                        this.model.layout = $.extend(true, {}, this.model.layout, options[option]);
                        this._setLayout(options[option]);
                        break;
                    case "pageSettings":
                        $.extend(true, this.model.pageSettings, {}, options[option]);
                        ej.datavisualization.Diagram.PageUtil._updatePageSize(this);
                        break;
                    case "locale":
                        this.model.locale = options[option];
                        var contextmenu = document.getElementById(this.element[0].id + "_contextMenu");
                        contextmenu.parentNode.removeChild(contextmenu);
                        this._renderContextMenu();
                        break;
                }
            }
        },

        _initData: function () {
            var dataSource = this.model.dataSource;
            if (dataSource && dataSource.length > 0) {
                this._initDataSource(dataSource);
            } else {
                this._initNodeCollection();
                this._initConnectorCollection();
            }
        },

        _initDataSource: function (items, grandParent) {
            var item, subItem;
            var nodeTemplate, childTemplate;
            var parent = null, child = null, children;
            var schema = this.model.dataSourceSchema.model.children;
            var i, len;
            for (i = 0, len = items.length; i < len; i++) {
                item = items[i];
                if (!this.model.nodeDefaults) {
                    nodeTemplate = this.model.nodeTemplate.call(this, item);
                    if (nodeTemplate.group && nodeTemplate.children) {
                        this._add(nodeTemplate.children);
                        this._add(nodeTemplate.group);
                        parent = this.nameTable[nodeTemplate.group.name];
                    } else {
                        this._add(nodeTemplate);
                        parent = this.nameTable[nodeTemplate.name];
                    }
                } else {
                    nodeTemplate = ej.datavisualization.Diagram.Node(this.model.nodeDefaults);
                    nodeTemplate.name += ej.datavisualization.Diagram.Util.randomId();
                    this._add(nodeTemplate);
                    parent = this.nameTable[nodeTemplate.name];
                }
                if (grandParent) {
                    this._addConnection(grandParent, parent);
                }
                if (item[schema] && item[schema].length > 0) {
                    children = item[schema];
                    for (var j = 0; j < children.length; j++) {
                        subItem = children[j];
                        if (!this.model.nodeDefaults) {
                            childTemplate = this.model.nodeTemplate.call(this, subItem);
                            if (childTemplate.group && childTemplate.children) {
                                this._add(childTemplate.children);
                                this._add(childTemplate.group);
                                child = this.nameTable[childTemplate.group.name];
                            } else {
                                this._add(childTemplate);
                                child = this.nameTable[childTemplate.name];
                            }
                        } else {
                            childTemplate = ej.datavisualization.Diagram.Node(this.model.nodeDefaults);
                            childTemplate.name += ej.datavisualization.Diagram.Util.randomId();
                            this._add(childTemplate);
                            child = this.nameTable[childTemplate.name];
                        }
                        if (parent && child) {
                            this._addConnection(parent, child);
                        }
                        if (subItem[schema] && subItem[schema].length > 0) {
                            this._initDataSource(subItem[schema], child);
                        }
                    }
                }
            }
        },

        _addConnection: function (source, target) {
            var connection = $.extend(true, {}, this.model.connectorDefaults, { sourceNode: source.name, targetNode: target.name });
            connection = ej.datavisualization.Diagram.Connector(connection);
            connection.name += ej.datavisualization.Diagram.Util.randomId();
            this._add(connection);
        },

        _initViews: function () {
            this._views = [];
            this._views.push(this._id);
            this._views[this._id] = {
                "type": "mainview", "context": ej.datavisualization.Diagram.SvgContext,
                "style": "position:relative; height:" + this.model.height + "; width:" + this.model.width + ";"
            };
        },
        _setOverview: function (overview, id) {
            if (overview) {
                this._overview = overview;
                if (!this._views[overview._id]) {
                    this._views.push(overview._id);
                    this._views[overview._id] = { "context": ej.datavisualization.Diagram.SvgContext, "type": "overview" };
                    overview._renderDocument(this._views[overview._id]);
                    this._renderNodes(this._views[overview._id]);
                    this._renderConnectors(this._views[overview._id]);
                    overview._updateOverview(this._views[overview._id]);
                }
            }
            else {
                var overview = $("#" + id).ejOverview("instance");
                overview._removeDocument(this._views[id]);
                this._views[id] = undefined;
                var index = this._views.indexOf(id);
                this._views.splice(index, 1);
                //this._overview = null;
            }

        },

        _initNodeCollection: function () {
            var nodes = this.model.nodes;
            for (var i = 0, len = nodes.length; i < len; i++) {
                if (nodes[i].isGroup) {
                    nodes[i] = ej.datavisualization.Diagram.Group(nodes[i]);
                    this.nameTable[nodes[i].name] = nodes[i];
                }
                else {
                    nodes[i] = ej.datavisualization.Diagram.Node(nodes[i]);
                    this.nameTable[nodes[i].name] = nodes[i];
                    ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, nodes[i]);
                }
                this.nameTable[nodes[i].name] = nodes[i];
            }
        },

        _initConnectorCollection: function () {
            var connectors = this.model.connectors;
            var connector;
            for (var i = 0, len = connectors.length; i < len; i++) {
                connector = connectors[i] = ej.datavisualization.Diagram.Connector(connectors[i]);
                this.nameTable[connector.name] = connector;
                ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, connector);
                this._dock(connector, this.nameTable);
                this._updateEdges(connector);
                // @fix
                //this._setZorder(connector);
            }
        },

        _initDefaults: function () {
            this._initTools();
        },

        _initCanvas: function () {
            this._renderCanvas();
        },

        _initVisualGuide: function () {
            if (this.model.showTooltip && !this.model.tooltipTemplateId) {
                var script = document.createElement("script");
                var attr = {
                    "id": this.element[0].id + "_defaultTooltip",
                    "type": "text/x-jsrender"
                };
                ej.datavisualization.Diagram.Util.attr(script, attr);
                script.innerHTML = "<span class=\"e-diagram-tooltipLabel-default\"> {{:type}}{{:x}}{{:type1}}{{:y}}</span>";
                this._canvas.appendChild(script);
            }
            else {
                this.element.remove("#" + this.element[0].id + "_defaultTooltip");
            }
        },

        _initTools: function () {
            this.tools = {
                "select": new ej.datavisualization.Diagram.SelectTool(this),
                "move": new ej.datavisualization.Diagram.MoveTool(this),
                "resize": new ej.datavisualization.Diagram.ResizeTool(this),
                "rotate": new ej.datavisualization.Diagram.RotateTool(this),
                //"pivot": new ej.datavisualization.Diagram.PivotTool(this),
                "endPoint": new ej.datavisualization.Diagram.EndPointTool(this),
                "panTool": new ej.datavisualization.Diagram.PanTool(this),
                "straightLine": new ej.datavisualization.Diagram.StraightLineTool(this),
                "orthogonalLine": new ej.datavisualization.Diagram.OrthogonalLineTool(this)
            };
            this._toolToActivate = "select";
            this.activeTool = this.tools[this._toolToActivate];
            this._registerDrawingTools();
        },

        _initHandles: function () {
            var userHandles = this.model.userHandles;
            if (userHandles) {
                for (var i = 0; i < userHandles.length; i++) {
                    userHandles[i] = ej.datavisualization.Diagram.UserHandle(userHandles[i]);
                    if (userHandles[i].tool) {
                        userHandles[i].tool.diagram = this;
                        this.tools[userHandles[i].name] = userHandles[i].tool;
                    }
                }
            }
        },

        _destroy: function () {
            this.element.ejScroller("destroy");
            this.element.empty().removeClass("e-datavisualization-diagram");
        },
        //#endregion       

        /**
     *update Node with their specific properties
     *@return jQuery
     *@param {String} name  to identify the Node from the model
     *@param {String} options to specify which property of the Node to be update
     *@example
     *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
     *&lt;script&gt;
     *var diagram=$("#diagramcontent").ejDiagram("instance");
     *var value = ej.datavisualization.Diagram.NodeConstraints.Default & ~ej.datavisualization.Diagram.NodeConstraints.Connect;
     *diagram.updateNode(node.name, { constraints: value });
     *&lt;/script&gt;
     *@memberof ejDiagram
     *@instance
     */
        //#region Public methods
        updateNode: function (name, options) {
            if (name) {
                var node = this._findNode(name);
                if (node) {
                    if (options.offsetX) {
                        this._translate(node, options.offsetX - node.offsetX, 0, this.nameTable);
                    }
                    if (options.offsetY) {
                        this._translate(node, 0, options.offsetY - node.offsetY, this.nameTable);
                    }
                    if (options.rotateAngle) {
                        this._rotate(node, options.rotateAngle - node.rotateAngle, this.nameTable);
                    }
                    if (options.width) {
                        node.width = node.width ? node.width : 1;
                        this._scale(node, options.width / node.width, 1, new ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    }
                    if (options.height) {
                        node.height = node.height ? node.height : 1;
                        this._scale(node, 1, options.height / node.height, new ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    }
                    if (options.constraints) {
                        node.constraints = options.constraints;
                        if (this.selectionList[0] && this.selectionList[0].name === node.name) {
                            ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);
                            ej.datavisualization.Diagram.SvgContext.renderSelector(this.selectionList[0], this._svg, this._adornerLayer, this.model.zoomFactor, this.model.selectorConstraints);
                            if (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                                ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.userHandles, this.selectionList[0], this._svg, this.selectionList[0].isPseudoGroup,
                                    this.model.zoomFactor, this._adornerLayer);
                        }
                    }
                    if (!node.isGroup) {
                        if (options.fillColor) {
                            node.fillColor = options.fillColor;
                        }
                        if (options.borderColor) {
                            node.borderColor = options.borderColor;
                        }
                        if (options.borderWidth) {
                            node.borderWidth = options.borderWidth;
                        }
                        if (options.borderDashArray) {
                            node.borderDashArray = options.borderDashArray;
                        }
                        if (options.gradient !== undefined)
                            node.gradient = options.gradient;
                    }
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    if (options.shape) {
                        if (ej.browserInfo().name === "msie") {
                            if (node.shape && node.shape.html) {
                                var htmlelement = document.getElementById(node.name + "_parentdiv");
                                htmlelement.parentNode.removeChild(htmlelement);
                            }
                        }
                        node.shape = ej.datavisualization.Diagram.Shape(options.shape);
                        ej.datavisualization.Diagram.DiagramContext.setNodeShape(node, this);
                    }
                    if (this.selectionList[0] && this.selectionList[0].name === node.name)
                        ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                }
            }
        },

        /**
       *update Connector with their specific properties
       *@return jQuery
       *@param {String} name  to identify the connector from the model
       *@param {object} options to specify which property of the Connector to be update
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *var value = ej.datavisualization.Diagram.ConnectorConstraints.Default;
       *diagram.updateConnector(connector.name, { constraints: value });      
       *&lt;/script&gt;
       *@memberof ejDiagram
       *@instance
       */
        updateConnector: function (name, options) {
            if (name) {
                var connector = this._findConnector(name);
                if (connector) {
                    if (options.constraints) {
                        connector.constraints = options.constraints;
                    }
                    if (options.lineColor) {
                        connector.lineColor = options.lineColor;
                    }
                    if (options.lineWidth) {
                        connector.lineWidth = options.lineWidth;
                    }
                    if (options.lineDashArray) {
                        connector.lineDashArray = options.lineDashArray;
                    }
                    ej.datavisualization.Diagram.DiagramContext.update(connector, this);
                    if (options.line) {
                        this._clearSelection();
                        connector.line = ej.datavisualization.Diagram.Line(options.line);
                        this._dock(connector, this.nameTable);
                        this._updateQuad(this, connector);
                        ej.datavisualization.Diagram.DiagramContext.setLine(connector, this);
                        this.addSelection(connector);
                    }
                    var decorator;
                    if (options.targetDecorator) {
                        if (connector.targetDecorator) {
                            decorator = $.extend(true, {}, connector.targetDecorator, options.targetDecorator);
                        } else {
                            decorator = ej.datavisualization.Diagram.Decorator(options.targetDecorator);
                        }
                        connector.targetDecorator = decorator;
                    }
                    if (options.sourceDecorator) {
                        if (connector.sourceDecorator) {
                            decorator = $.extend(true, {}, connector.sourceDecorator, options.sourceDecorator);
                        } else {
                            decorator = ej.datavisualization.Diagram.Decorator(options.sourceDecorator);
                        }
                        connector.sourceDecorator = decorator;
                    }
                    if (options.sourceDecorator || options.targetDecorator) {
                        ej.datavisualization.Diagram.DiagramContext.clearDecorators(connector, this);
                        ej.datavisualization.Diagram.DiagramContext.renderDecorators(connector, this);
                    }
                    if (this.selectionList[0] && this.selectionList[0].name === connector.name)
                        ej.datavisualization.Diagram.SvgContext.updateSelector(connector, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                }
            }
        },
        /**
       *To bring the specified portion of the diagram content to center of the diagram viewport
       *@return jQuery
       *@param {Object} rect pass bounds value (x,y,height,width)
       *@example
       
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.bringToCenter(ej.datavisualization.Diagram.Rectangle(700, 500, 80, 80));
       *&lt;/script&gt;
       *@memberof ejDiagram
        *@instance
       */
        bringToCenter: function (rect) {
            var scale = this.model.zoomFactor;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            var hoffset = rect.x + (rect.width) / 2 - viewPort.width / 2;
            var voffset = rect.y + (rect.height) / 2 - viewPort.height / 2;
            hoffset = Math.max(0, hoffset) * scale;
            voffset = Math.max(0, voffset) * scale;
            ej.datavisualization.Diagram.ZoomUtil._applyTransform(this, scale, ej.datavisualization.Diagram.Point(-hoffset, -voffset), null);
        },
        /**
        *To bring the specified portion of the diagram content to the diagram viewport
        *@return jQuery
        *@param {Object} bounds pass bounds value (x,y,height,width)
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.bringIntoView(ej.datavisualization.Diagram.Rectangle(700, 500, 80, 80));
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        bringIntoView: function (bounds) {
            var x = 0, y = 0;
            bounds.right = bounds.right ? bounds.right : bounds.x + bounds.width;
            bounds.bottom = bounds.bottom ? bounds.bottom : bounds.y + bounds.height;
            var hoffset = this._hScrollOffset;
            var voffset = this._vScrollOffset;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            if (bounds.right > (-hoffset + viewPort.width)) {
                x = bounds.right - viewPort.width;
            }
            if (bounds.x < -hoffset) {
                x = bounds.x;
            }
            if (bounds.bottom > (-voffset + viewPort.height)) {
                y = bounds.bottom - viewPort.height;
            }
            if (bounds.y < -voffset) {
                y = bounds.y;
            }
            ej.datavisualization.Diagram.ZoomUtil._applyTransform(this, this.model.zoomFactor, ej.datavisualization.Diagram.Point(-x, -y), null);

        },
        exportAsImage: function () {
            var bounds = this._getDigramBounds();
            var canvas = new ej.datavisualization.Diagram.Canvas({ "id": "mycanvas", "width": bounds.width, "height": bounds.height });
            for (var i = 0; i < this.model.nodes.length; i++) {
                ej.datavisualization.Diagram.CanvasContext.renderNode(this.model.nodes[i], canvas);
            }
            for (var i = 0; i < this.model.connectors.length; i++) {
                ej.datavisualization.Diagram.CanvasContext.renderConnector(this.model.connectors[i], canvas);
            }
            var url = canvas.document.toDataURL('image/png');
            return url;
        },
        save: function () {
            var drawingTools = this.model.drawingTools;
            var userHandles = this.model.userHandles;
            this.model.drawingTools = null;
            this.model.userHandles = null;
            if (this.nameTable["multipleSelection"]) {
                ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, this.nameTable["multipleSelection"]);
            }
            var model = jQuery.extend(true, {}, this.model);
            this.model.drawingTools = drawingTools;
            this.model.userHandles = userHandles;
            return model;
        },
        load: function (data) {
            this.clear();
            var contextmenu = document.getElementById(this.element[0].id + "_contextMenu");
            contextmenu.parentNode.removeChild(contextmenu);
            var load = {
                nodes: data.nodes,
                connectors: data.connectors,
                contextMenu: data.contextMenu,
                snapSettings: data.snapSettings,
                backgroundImage: data.backgroundImage,
                enableAutoScroll: data.enableAutoScroll,
                autoScrollMargin: data.autoScrollMargin,
                layout: data.layout,
                pageSettings: data.pageSettings,
                click: data.click,
                connectionChange: data.connectionChange,
                connectorDefaults: data.connectorDefaults,
                dataSource: data.dataSource,
                dataSourceSchema: data.dataSourceSchema,
                doubleClick: data.doubleClick,
                enableContextMenu: data.enableContextMenu,
                showTooltip: data.showTooltip,
                handles: data.handles,
                height: data.height,
                mouseEnter: data.mouseEnter,
                mouseOver: data.mouseOver,
                mouseLeave: data.mouseLeave,
                nodeDefaults: data.nodeDefaults,
                nodeTemplate: data.nodeTemplate,
                rotationChange: data.rotationChange,
                selectorConstraints: data.selectorConstraints,
                tooltipTemplateId: data.tooltipTemplateId,
                width: data.width,
                zoomFactor: data.zoomFactor,

            };
            $("#" + this._id).ejDiagram(load);
        },

        layout: function () {
            this._setLayout();
        },

        _setLayout: function () {
            this._doLayout();
            ej.datavisualization.Diagram.PageUtil._updatePageSize(this);
            this._clearSelection();
            this._updateNodes();
            this._updateConnectors();
        },
        /**
               *Select the target node
               *@return jQuery
               *@param {Object} node pass target node to be updated
               *@example
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *var node=diagram.model.nodes[0];
               *diagram.addSelection(node);
               *&lt;/script&gt;
               *@memberof ejDiagram
*@instance
               */
        addSelection: function (node) {
            this._addSelection(node);
        },
        /**
        *Update the selection of target node/connector
        *@return jQuery
        *@param {Boolean} isDragging pass true/false whether to drag or not
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.updateSelection(true);
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        updateSelection: function (isDragging) {
            this._updateSelectionHandle(isDragging);
        },
        /**
        *To activate registered tool 
        *@return jQuery
        *@param {String} toolName name of the tool to be activated
        *@param {Boolean} singleAction default value set to true tool action to be performed only once
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.activateTool("panTool");
                 *&lt;/script&gt;

          *@example
            *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                 *&lt;script&gt;
                 *var diagram=$("#diagramcontent").ejDiagram("instance");                 
                 *diagram.activateTool("orthogonalTool",false);
                 *&lt;/script&gt;
                 *@memberof ejDiagram
*@instance
        */
        activateTool: function (toolName, singleAction) {

            if (this.tools[toolName]) {
                if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                    this.activeTool._showAllPorts(true);
                }
                this._toolToActivate = toolName;
                this.activeTool = this.tools[this._toolToActivate];
                if (singleAction != undefined)
                    this.activeTool.singleAction = singleAction;
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.ImageTool && this.activeTool.autoOpenUpload) {
                this.activeTool._showPopup();
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                this._currentCursor = "pointer";
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                this.activeTool._showAllPorts();
            }
            this._drawingTool = true;
        },
        /**
       *Deactivate the current activated tool
       *@return jQuery
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.deactivateTool();
       *&lt;/script&gt;
       *@memberof ejDiagram
*@instance
       */
        deactivateTool: function () {
            if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                this.activeTool._showAllPorts(true);
            }
            this._toolToActivate = "select";
            this.activeTool = this.tools[this._toolToActivate];
            this._drawingTool = false;
        },

        /**
                    *Update the given label style
                    *@return jQuery
                    *@param {String} nodeName pass the name of node/connector
                    *@param {Object} label pass the label to be modified
                    *@param {Object} obj pass the new porperties of the label
                    *@example
                    
                    *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                    *&lt;script&gt;
                    *var diagram=$("#diagramcontent").ejDiagram("instance");
                    *var node=diagram.selectionList[0];
                    *var label = [];
                    *label =[{"name":"node1" "text": "node", "bold": true, "italic": true}]
                    *diagram.setLabelStyle(node.name,node.labels[0],label);
                    *&lt;/script&gt;
                    *@memberof ejDiagram
*@instance
                    */
        setLabelStyle: function (nodeName, label, obj) {
            if (nodeName) {
                var mNode = this._findNode(nodeName);
                if (!mNode)
                    mNode = this._findConnector(nodeName);
                if (!obj.name || label.name == obj.name) {
                    if (mNode) {
                        for (var prop in obj)
                            if (label.hasOwnProperty(prop)) {
                                label[prop] = obj[prop];
                            }
                        if (mNode.line || (mNode.shape && mNode.shape.type !== "text")) {
                            ej.datavisualization.Diagram.DiagramContext.updateLabelStyle(mNode, label, this);
                            ej.datavisualization.Diagram.DiagramContext.updateLabel(mNode, label, this);
                        } else if (mNode.shape && mNode.shape.type === "text") {
                            ej.datavisualization.Diagram.DiagramContext.updateTextBlock(mNode, label, this);
                        }
                    }
                }
            }
        },
        /**
                    *Starts the editing of the specified label in the given node
                    *@return jQuery
                    *@param {Object} node pass the node/connector to which label to be edited
                      *@param {Object} label pass the label to be edited
                    *@example
                    
                    *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                    *&lt;script&gt;
                    *var diagram=$("#diagramcontent").ejDiagram("instance");
                    *var node=diagram.selectionList[0];
                    *diagram.startLabelEdit(node,node.labels[0]);
                    *&lt;/script&gt;
                    *@memberof ejDiagram
*@instance
                    */
        startLabelEdit: function (node, label) {
            if (node) {
                //Disables the edit mode of labels in the selectionList
                for (var i = 0; i < this.selectionList.length; i++) {
                    var mNode = this.selectionList[i];
                    if (mNode !== node && typeof mNode.labels.length != "undefined") {
                        for (var j = 0; j < mNode.labels.length; j++)
                            mNode.labels[j].mode = ej.datavisualization.Diagram.LabelEditMode.View;
                    }
                }
                if (this._setLabelEditing(label))
                    this._startEdit(node);
                else {
                    this._endEdit();
                }
            }
        },

        _setSelectorConstraints: function (constraints) {
            this.model.selectorConstraints = constraints;
            if (this.selectionList[0]) {
                ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);
                ej.datavisualization.Diagram.SvgContext.renderSelector(this.selectionList[0], this._svg, this._adornerLayer, this.model.zoomFactor, constraints);
                if (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                    ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.userHandles, this.selectionList[0], this._svg, this.selectionList[0].isPseudoGroup,
                        this.model.zoomFactor, this._adornerLayer);
            }
        },
        /**
        *Group the selected node and connector
        *@return jQuery
        *@example
       
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.group(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        group: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup) {
                var selectionList = [];
                var i;
                for (i = 0; i < this.selectionList[0].children.length; i++)
                    selectionList.push(this.nameTable[this.selectionList[0].children[i]]);
                this._sortByZIndex(selectionList, true);
                var element;
                var groupName = ej.datavisualization.Diagram.Util.randomId();
                var group = new ej.datavisualization.Diagram.Group({ name: groupName, });
                this._clearSelection();
                for (i = 0; i < selectionList.length; i++) {
                    this._isUndo = true;
                    group.children.push(selectionList[i].name);
                    selectionList[i].parent = groupName;
                    ej.datavisualization.Diagram.Util.removeItem(this.selectionList, selectionList[i].name);
                    if (ej.browserInfo().name === "msie") {
                        if (selectionList[i].shape && selectionList[i].shape.type == "html") {
                            element = document.getElementById(selectionList[i].name + "_parentdiv");
                            element.parentNode.removeChild(element);
                        }
                        else {
                            if (selectionList[i].isGroup)
                                this._checkForHtmlNode(selectionList[i]);
                        }
                    }
                    // $("#" + selectionList[i].name)[0].parentNode.removeChild($("#" + selectionList[i].name)[0]);
                    element = document.getElementById(selectionList[i].name);
                    element.parentNode.removeChild(element);
                }
                ej.datavisualization.Diagram.Util.clear(this.selectionList);

                this.add(group);
                this._addSelection(group);
                var entry = { type: "groupchanged", object: group, actionType: "group" };
                this.addHistoryEntry(entry);
                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.GroupHandleCmd(group, "group"));
                //this.historyManager.addHistoryEntry(entry);
                this._isUndo = false;
            }
        },

        _checkForHtmlNode: function (group) {
            for (var i = 0; i < group.children.length; i++) {
                var child = this.nameTable[group.children[i]];
                if (child.isGroup) {
                    this._checkForHtmlNode(child);
                }
                else {
                    if (child.shape && child.shape.type == "html") {
                        var element = document.getElementById(child.name + "_parentdiv");
                        element.parentNode.removeChild(element);
                    }
                }
            }
        },
        _removeChildren: function (group) {
            for (var i = 0; i < group.children.length; i++) {
                var child = this.nameTable[group.children[i]];
                ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, child);
                if (child.isGroup) {
                    this._removeChildren(child);
                }
                else {
                    ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(this._spatialSearch, this._spatialSearch.quadTable[child.name], child);
                    ej.datavisualization.Diagram.SpatialUtil._updateBounds(this, this._spatialSearch, child);
                    delete this.nameTable[child.name];
                }
            }
        },
        /**
*Ungroup the selected group
*@return jQuery
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.ungroup(); 
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/
        ungroup: function () {
            if (this.selectionList[0] && this.selectionList[0].isGroup) {
                this._isUndo = true;
                var selectionList = this.selectionList[0].children;
                var i, node;
                node = this.selectionList[0];
                $("#" + this.selectionList[0].name)[0].parentNode.removeChild($("#" + this.selectionList[0].name)[0]);
                if (ej.browserInfo().name === "msie")
                    this._checkForHtmlNode(this.selectionList[0]);
                this._clearSelection();
                var object;
                ej.datavisualization.Diagram.Util.clear(this.selectionList);
                for (i = 0; i < selectionList.length; i++) {
                    selectionList[i].parent = null;
                    var item = this.nameTable[selectionList[i]];
                    if (item.line) {
                        object = item;
                        object.parent = "";
                        this._updateEdges(object);
                        this._dock(object, this.nameTable);
                        ej.datavisualization.Diagram.DiagramContext.renderConnector(object, this);
                    } else {
                        object = item;
                        object.parent = "";
                        if (object.isGroup) {
                            this._updateChildrenEdges(object);
                            ej.datavisualization.Diagram.DiagramContext.renderGroup(object, this);
                        }
                        else
                            ej.datavisualization.Diagram.DiagramContext.renderNode(object, this);
                    }

                }
                //this._clearSelection();
                ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, this._findNode(node.name));

                var entry = { type: "groupchanged", object: node, actionType: "ungroup" };
                this.addHistoryEntry(entry);

                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.GroupHandleCmd(node, "ungroup"));
                //this.historyManager.addHistoryEntry(entry);
                this._isUndo = false;

            }
        },


        /**
       *Executes nudge command tp move selected node/connector one pixel 
       *@return jQuery
       *@param {String} direction  specify the driection to move the selected objects ("left","right",top","bottom")
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.nudge("direction"); 
       *&lt;/script&gt;
       *@memberof ejDiagram
       *@instance
       */

        nudge: function (direction) {
            var dir = { up: { x: 0, y: -1 }, down: { x: 0, y: 1 }, left: { x: -1, y: 0 }, right: { x: 1, y: 0 } };
            var nudge = dir[direction];
            if (nudge && this.selectionList[0]) {
                this._nudge(this.selectionList[0], nudge.x, nudge.y);
            }
        },

        /**
              *Select all nodes and connector in diagram
              *@return jQuery
              *@example
             
              *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
              *&lt;script&gt;
              *var diagram=$("#diagramcontent").ejDiagram("instance");
              *diagram.selectAll(); 
              *&lt;/script&gt;
              *@memberof ejDiagram
              *@instance
              */
        selectAll: function () {
            var collection, nodes, i, len;
            this._clearSelection();
            collection = ej.datavisualization.Diagram.Group({ isPseudoGroup: true, name: "multipleSelection" });
            nodes = this.model.nodes;
            for (i = 0, len = nodes.length; i < len; i++) {
                if (ej.datavisualization.Diagram.Util.canSelect(nodes[i])) {
                    if (nodes[i].parent == "") {
                        collection.children.push(nodes[i].name);
                    }
                }
            }
            var connectors = this.model.connectors;
            for (i = 0, len = connectors.length; i < len; i++) {
                if (ej.datavisualization.Diagram.Util.canSelect(connectors[i])) {
                    if (connectors[i].parent == "") {
                        collection.children.push(connectors[i].name);
                    }
                }
            }
            ej.datavisualization.Diagram.Util._updateGroupBounds(collection, this.nameTable);
            //ej.datavisualization.Diagram.Util.clear(this.selectionList);
            this.model.nodes.push(collection);
            this.nameTable[collection.name] = collection;
            if (collection.children.length > 0)
                this._addSelection(collection);
        },
        /**
        *Align selected object based on reference object and direction
        *@return jQuery
        *@param {String} direction To specify the driection for alignment ("left","right",top","bottom")
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.align("left"); 
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        align: function (direction) {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var cNode;
                if (direction === "left")
                    cNode = this._findCornerNodes().left;
                else if (direction === "right")
                    cNode = this._findCornerNodes().right;
                else if (direction === "top")
                    cNode = this._findCornerNodes().top;
                else if (direction === "bottom")
                    cNode = this._findCornerNodes().bottom;
                var cNodeBounds;
                if (cNode)
                    cNodeBounds = ej.datavisualization.Diagram.Util.bounds(cNode);
                else if (direction === "center" || direction === "middle") {
                    cNodeBounds = ej.datavisualization.Diagram.Util.bounds(this.selectionList[0]);
                }
                if (cNodeBounds) {
                    var i, bounds, node, x = 0, y = 0;
                    for (i = 0; i < list.length; i++) {
                        node = this.nameTable[list[i]];
                        bounds = ej.datavisualization.Diagram.Util.bounds(node);
                        if (direction === "left")
                            x = -(bounds.x - cNodeBounds.x);
                        else if (direction === "right")
                            x = -((bounds.x + bounds.width) - (cNodeBounds.x + cNodeBounds.width));
                        else if (direction === "top")
                            y = -(bounds.y - cNodeBounds.y);
                        else if (direction === "bottom")
                            y = -((bounds.y + bounds.height) - (cNodeBounds.y + cNodeBounds.height));
                        else if (direction === "center")
                            x = -((bounds.x + bounds.width / 2) - (cNodeBounds.x + cNodeBounds.width / 2));
                        else if (direction === "middle")
                            y = -((bounds.y + bounds.height / 2) - (cNodeBounds.y + cNodeBounds.height / 2));
                        this._moveNode(x, y, node);
                    }
                    ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this.nameTable);
                    ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                }
            }
        },
        /**
        *Update size of the object in the selection list to the size of first object in selction list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameSize(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sameSize: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.line)) {
                        element.height = fNodeBounds.height;
                        element.width = fNodeBounds.width;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this.nameTable);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            }
        },
        /**
        *Update height of the object in the selection list to the height of first object in selection list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameHeight(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sameHeight: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.line)) {
                        element.height = fNodeBounds.height;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this.nameTable);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            }
        },
        /**
        *Update width of the object in the selection list to the width of first object in selection list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameWidth(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sameWidth: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.line)) {
                        element.width = fNodeBounds.width;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this.nameTable);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            }
        },
        /**
        *Update vertical space between the object is set with selection boundary
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.spaceDown(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        spaceDown: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup) {
                var lstSelections = this.selectionList[0].children;
                this._sortByYvalue(this.selectionList[0].children);
                var selectionCount = lstSelections.length, fSpacing;
                if (lstSelections && selectionCount > 2) {
                    var cornerNodes = this._findCornerNodes();
                    var firstNode = cornerNodes.top;
                    var lastNode = cornerNodes.bottom;
                    if (firstNode && lastNode) {
                        var bFirst = ej.datavisualization.Diagram.Util.bounds(firstNode);
                        var bLast = ej.datavisualization.Diagram.Util.bounds(lastNode);
                        fSpacing = (bLast.y - bFirst.y) / (selectionCount - 1);
                        var y = 1;
                        for (var i = 0; i < lstSelections.length; i++) {
                            var inode = this.nameTable[lstSelections[i]];
                            if (inode !== firstNode && inode !== lastNode) {
                                inode.offsetY = bFirst.y + (y * fSpacing) + (inode.height / 2);
                                this._updateQuad(this, inode);
                                y += 1;
                                ej.datavisualization.Diagram.DiagramContext.update(inode, this);
                            }
                        }
                    }
                }
            }
        },
        /**
        *Update horizontal space between the object is set with selection boundary
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.spaceAcross(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        spaceAcross: function () {
            if (this.selectionList[0] && this.selectionList[0].isPseudoGroup) {
                var lstSelections = this.selectionList[0].children;
                this._sortByXvalue(this.selectionList[0].children);
                var selectionCount = lstSelections.length, fSpacing;
                if (lstSelections && selectionCount > 2) {
                    var cornerNodes = this._findCornerNodes();
                    var firstNode = cornerNodes.left;
                    var lastNode = cornerNodes.right;
                    if (firstNode && lastNode) {
                        var bFirst = ej.datavisualization.Diagram.Util.bounds(firstNode);
                        var bLast = ej.datavisualization.Diagram.Util.bounds(lastNode);
                        fSpacing = (bLast.x - bFirst.x) / (selectionCount - 1);
                        var x = 1;
                        for (var i = 0; i < lstSelections.length; i++) {
                            var inode = this.nameTable[lstSelections[i]];
                            if (inode !== firstNode && inode !== lastNode) {
                                inode.offsetX = bFirst.x + (x * fSpacing) + (inode.width / 2);
                                this._updateQuad(this, inode);
                                x += 1;
                                ej.datavisualization.Diagram.DiagramContext.update(inode, this);
                            }
                        }
                    }
                }
            }
        },
        /**
        *Decrease the Z-index value of selected object by 1
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sendBackward(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sendBackward: function () {
            var ovarLapNodes, i;
            var prevNode;
            if (this.selectionList[0] && !this.selectionList[0].isPseudoGroup) {
                var node = this.selectionList[0];
                if (node) {
                    ovarLapNodes = this._findOverlapNode(node);
                    this._sortByZIndex(ovarLapNodes);
                    for (var k = 0; k < ovarLapNodes.length; k++)
                        if (node.zOrder > ovarLapNodes[k].zOrder) {
                            if (ovarLapNodes[k].parent == "") {
                                prevNode = ovarLapNodes[k];
                                break;
                            }
                        }
                    var start = node.zOrder;
                    if (prevNode) {
                        var end = prevNode.zOrder;
                        for (i = end; i < start; i++) {
                            if (node.parent != "")
                                this._findObjectByIndex(i, true).zOrder += 1;
                            else
                                this._findObjectByIndex(i).zOrder += 1;
                        }
                        if (node.parent != "") {
                            this._findChildren(node.parent, node.name).zOrder = end;
                        } else
                            this._findObjectByName(node.name).zOrder = end;
                        this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name));
                        ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this.model.zoomFactor,
                        this.model.selectorConstraints);
                    }
                }
            }
        },
        /**
               *Increase the Z-index value of selected object by 1
               *@return jQuery
               *@example
              
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *diagram.moveForward(); 
               *&lt;/script&gt;
               *@memberof ejDiagram
*@instance
               */
        moveForward: function () {
            var ovarLapNodes, i;
            var prevNode;
            if (this.selectionList[0] && !this.selectionList[0].isPseudoGroup) {
                var node = this.selectionList[0];
                if (node) {
                    ovarLapNodes = this._findOverlapNode(node);
                    this._sortByZIndex(ovarLapNodes);
                    for (var k = ovarLapNodes.length - 1; k >= 0; k--)
                        if (node.zOrder < ovarLapNodes[k].zOrder) {
                            if (ovarLapNodes[k].parent == "") {
                                prevNode = ovarLapNodes[k];
                                break;
                            }
                        }

                    var start = node.zOrder;
                    if (prevNode) {
                        var end = prevNode.zOrder;
                        for (i = end; i > start; i--) {
                            if (node.parent != "")
                                this._findObjectByIndex(i, true).zOrder -= 1;
                            else
                                this._findObjectByIndex(i).zOrder -= 1;
                        }
                        if (node.parent != "")
                            this._findChildren(node.parent, node.name).zOrder = end;
                        else
                            this._findObjectByName(node.name).zOrder = end;
                        this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name).nextSibling);
                        ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this.model.zoomFactor,
                        this.model.selectorConstraints);

                    }
                }
            }
        },
        /**
        *Move the selected object behind other object
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sendToBack(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sendToBack: function () {
            var node = this.selectionList[0];
            var prevNode;
            if (node && !node.isPseudoGroup) {
                var ovarLapNodes = this._findOverlapNode(node);
                var nodes = this._sortByZIndex(ovarLapNodes);
                var start = node.zOrder;
                var end = node.zOrder;
                for (var i = 0; i < nodes.length; i++) {
                    if (nodes[i].zOrder < end) {
                        if (nodes[i].parent == "") {
                            end = nodes[i].zOrder;
                            prevNode = nodes[i];
                        }
                    }
                }
                if (prevNode) {
                    for (i = end; i < start; i++) {
                        if (node.parent != "")
                            this._findObjectByIndex(i, true).zOrder += 1;
                        else
                            this._findObjectByIndex(i).zOrder += 1;
                    }
                    if (node.parent != "") {
                        this._findChildren(node.parent, node.name).zOrder = end;
                    } else
                        this._findObjectByName(node.name).zOrder = end;
                    this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name));
                    ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this.model.zoomFactor,
                        this.model.selectorConstraints);
                }
            }
        },
        /**
        *Move the selected object over other object
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.bringToFront(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        bringToFront: function () {
            var node = this.selectionList[0];
            var prevNode;
            if (node && !node.isPseudoGroup) {
                var ovarLapNodes = this._findOverlapNode(node);
                var nodes = this._sortByZIndex(ovarLapNodes);
                var start = node.zOrder;
                var end = node.zOrder;
                for (var i = 0; i < nodes.length; i++) {
                    if (nodes[i].zOrder > end) {
                        if (nodes[i].parent == "") {
                            end = nodes[i].zOrder;
                            prevNode = nodes[i];
                        }
                    }
                }
                if (prevNode) {
                    for (i = 0; i < nodes.length; i++) {
                        if (nodes[i].zOrder > start) {
                            nodes[i].zOrder -= 1;
                        }
                    }
                    if (node.parent) {
                        this._findChildren(node.parent, node.name).zOrder = end;
                    } else
                        this._findObjectByName(node.name).zOrder = end;

                    this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name).nextSibling);
                    ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this.model.zoomFactor,
                        this.model.selectorConstraints);
                }
            }
        },
        /**
        *Reverse the last action thta was performed
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.undo(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        undo: function () {
            var args;
            this._isUndo = true;
            //this.historyManager.undo();
            var entryItem = this.getUndoEntry();
            switch (entryItem && entryItem.type) {
                case "positionchanged":
                    args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordPinPointChanged(args);
                    break;
                case "rotationchanged":
                    args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordRotationChanged(args);
                    break;
                case "sizechanged":
                    args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordSizeChanged(args);
                    break;
                case "endpointchanged":
                    args = { undoObject: entryItem.undoObject, redoObject: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode, _isUndo: true };
                    this._recordEndPointChanged(args);
                    break;
                case "collectionchanged":
                    args = { changeType: entryItem.changeType, childTable: entryItem.childTable, isUndo: true, sourcePorts: entryItem.sourcePorts, targetPorts: entryItem.targetPorts };
                    args.object = jQuery.extend(true, {}, entryItem.object);
                    this._recordCollectionChanged(args);
                    break;
                case "labelchanged":
                    args = { object: entryItem.shape, label: entryItem.previousLabelValue };
                    this._recordLabelChanged(args);
                    break;
                case "groupchanged":
                    args = { object: entryItem.object, isUndo: true, actionType: entryItem.actionType };
                    this._recordGroupChanged(args);
                    break;
            }

            this._isUndo = false;
        },
        /**
        *Restore the last action thta was performed
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.redo(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        redo: function () {
            this._isUndo = true;
            //this.historyManager.redo();
            var entryItem = this.getRedoEntry();
            switch (entryItem && entryItem.type) {
                case "positionchanged":
                    var args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordPinPointChanged(args);
                    break;
                case "rotationchanged":
                    args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordRotationChanged(args);
                    break;
                case "sizechanged":
                    args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordSizeChanged(args);
                    break;
                case "endpointchanged":
                    args = { undoObject: entryItem.undoObject, redoObject: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode, _isUndo: false };
                    this._recordEndPointChanged(args);
                case "collectionchanged":
                    args = { changeType: entryItem.changeType, childTable: entryItem.childTable, isUndo: false };
                    args.object = jQuery.extend(true, {}, entryItem.object);
                    this._recordCollectionChanged(args);
                    break;
                case "labelchanged":
                    args = { object: entryItem.shape, label: entryItem.updatedLabelValue };
                    this._recordLabelChanged(args);
                    break;
                case "groupchanged":
                    args = { object: entryItem.object, actionType: entryItem.actionType, isUndo: false };
                    this._recordGroupChanged(args);
                    break;
            }
            this._isUndo = false;
        },

        addHistoryEntry: function (entry) {
            if (this._historyList.currentEntry != null) {
                var cEntry = this._historyList.currentEntry;
                if (cEntry.next) {
                    if (cEntry.previous) {
                        var entry1 = cEntry.next;
                        entry1.previous = null;
                        cEntry.next = entry;
                        entry.previous = cEntry;
                    }
                } else {
                    cEntry.next = entry;
                    entry.previous = cEntry;
                }
            }
            this._historyList.currentEntry = entry;
            this._historyList.canUndo = true;
            this._historyList.canRedo = false;
        },

        clearHistory: function () {
            var hList = this._historyList;
            hList.currentEntry = null;
            hList.canUndo = false;
            hList.canRedo = false;
        },

        getUndoEntry: function () {
            var undoEntry = null;
            var currentEntry;
            var hList = this._historyList;
            if (hList.canUndo) {
                undoEntry = hList.currentEntry;
                currentEntry = hList.currentEntry.previous;
                if (currentEntry) {
                    hList.currentEntry = currentEntry;
                    if (!hList.canRedo)
                        hList.canRedo = true;
                } else {
                    hList.canRedo = true;
                    hList.canUndo = false;
                }
            }
            return undoEntry;
        },

        getRedoEntry: function () {
            var redoEntry = null;
            var entryCurrent;
            var hList = this._historyList;
            if (hList.canRedo) {
                if (!hList.currentEntry.previous && !hList.canUndo) {
                    entryCurrent = hList.currentEntry;
                } else
                    entryCurrent = hList.currentEntry.next;
                if (entryCurrent) {
                    hList.currentEntry = entryCurrent;
                    if (!hList.canUndo)
                        hList.canUndo = true;
                    if (!entryCurrent.next) {
                        hList.canRedo = false;
                        hList.canUndo = true;
                    }
                }
                redoEntry = hList.currentEntry;
            }
            return redoEntry;
        },
        /**
        *cut the selected object from diagram to diagram internal clipboard
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.cut(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        cut: function () {
            this._pasteIndex = 0;
            this._setClipboard();
            this._delete();
        },

        addPort: function (name, ports) {
            var node = this.nameTable[name];
            if (node && ports) {
                var port;
                for (var i = 0; i < ports.length; i++) {
                    port = ej.datavisualization.Diagram.Port(ports[i]);
                    node.ports.push(port);
                    ej.datavisualization.Diagram.DiagramContext.renderPort(node, port, this);
                }
            }
        },


        /**
        *copy the selected object from internal clipboard
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.copy(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        copy: function () {
            this._pasteIndex = 1;
            this._setClipboard();
        },
        /**
        *paste the selected object from internal clipboard to diagram
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.paste(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        paste: function () {
            //this._isUndo = true;
            this._paste();
            //this._isUndo = false;
        },

        _setClipboard: function () {
            if (this.selectionList.length > 0) {
                var data, node = this.selectionList[0];
                var childTable = {};
                if (node.isGroup || node.isPseudoGroup) {
                    var temp, i, j;
                    for (i = 0; i < node.children.length; i++) {
                        for (j = i + 1; j < node.children.length; j++) {
                            var nodei = this.nameTable[node.children[i]];
                            var nodej = this.nameTable[node.children[j]];
                            if (nodej.zOrder < nodei.zOrder) {
                                temp = node.children[i];
                                node.children[i] = node.children[j];
                                node.children[j] = temp;
                            }
                        }
                    }
                    childTable = this._getChildTable(node, childTable);
                }
                data = $.extend(true, {}, { "childTable": childTable, "node": node });
                if (data.node.line) {
                    data.node.targetNode = null;
                    data.node.targetPort = null;
                    data.node.sourceNode = null;
                    data.node.sourcePort = null;
                }
                this._preserveHtmlContent(node, data.node);
                if (data.node.children && data.node.children.length > 0) {
                    for (var child in data.childTable) {
                        this._preserveHtmlContent(childTable[child], data.childTable[child]);
                    }
                }
                this._clipboardData = data;
            }
        },

        _preserveHtmlContent: function (node, cloneNode) {
            if (node.shape) {
                if (cloneNode.shape.type === "html") {
                    if (!(typeof (node.shape.html) === 'string'))
                        cloneNode.shape.html = node.shape.html.cloneNode(true);
                }
                else if (cloneNode.shape.type === "native") {
                    cloneNode.shape.content = node.shape.content.cloneNode(true);
                }
            }
        },

        _getChildTable: function (group, childTable) {
            var child, names, name;
            names = group.children;
            if (names) {
                for (var i = 0; i < names.length; i++) {
                    name = names[i];
                    child = this.nameTable[name];
                    if (child && (child.parent === group.name || group.isPseudoGroup)) {
                        var node = childTable[child.name] = $.extend(true, {}, child);
                        if (node.isGroup || node.isPseudoGroup)
                            childTable = this._getChildTable(node, childTable);
                    }
                }
            }
            return childTable;
        },

        _paste: function () {
            if (this._clipboardData) {
                var data = this._clipboardData;
                var dx, child;
                data = $.extend(true, {}, { "childTable": data.childTable, "node": data.node });
                this._preserveHtmlContent(this._clipboardData.node, data.node);
                if (data.node.children && data.node.children.length > 0) {
                    for (child in data.childTable) {
                        this._preserveHtmlContent(this._clipboardData.childTable[child], data.childTable[child]);
                    }
                }
                var node = data.node;
                if (node.isPseudoGroup) {
                    var names = node.children;
                    var pseudoGroup = ej.datavisualization.Diagram.Group({ isPseudoGroup: true, "name": "multipleSelection" });
                    this._isUndo = true;
                    for (var i = 0; i < names.length; i++) {
                        var name = names[i];
                        child = data.childTable[name];
                        if (child) {
                            name = name + ej.datavisualization.Diagram.Util.randomId();
                            delete (data.childTable[child.name]);
                            child.name = name;
                            child.parent = "";
                            data.childTable[child.name] = child;
                            this._preserveConnection(data.childTable, child);
                            pseudoGroup.children.push(name);
                            if (child.isGroup) {
                                this._pasteChildren(data.childTable, child);
                            }
                            dx = this._pasteIndex * 10;
                            this._translate(child, dx, dx, this.nameTable);
                            this.add(child);
                        }
                    }
                    this._clearSelection();
                    this.model.nodes.push(pseudoGroup);
                    this.nameTable[pseudoGroup.name] = pseudoGroup;
                    ej.datavisualization.Diagram.Util._updateGroupBounds(pseudoGroup, this.nameTable);
                    this._addSelection(pseudoGroup);
                    var childTable = {};
                    childTable = this._getChildTable(this.selectionList[0], childTable);
                    var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, this.selectionList[0]), childTable: jQuery.extend(true, {}, childTable), changeType: "insert" };
                    this.addHistoryEntry(entry);
                    this._isUndo = false;
                }
                else {
                    node.name = node.name + ej.datavisualization.Diagram.Util.randomId();
                    node.parent = "";
                    if (node.isGroup) {
                        this._pasteChildren(data.childTable, node);
                    }
                    else if (node.line) {
                        //this._disConnect(node);
                    }
                    else if (!node.line) {
                        //@Fix
                        //this._disConnect(node);
                        node.inEdges = [];
                        node.outEdges = [];
                    }
                    dx = this._pasteIndex * 10;
                    this._translate(node, dx, dx, this.nameTable);
                    this.add(node);
                    // ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    this._clearSelection();
                    this._addSelection(node);
                }
                this._pasteIndex++;
            }
        },

        _pasteChildren: function (childTable, group) {
            var child, names, name;
            var childNames = [];
            names = group.children;
            for (var i = 0; i < names.length; i++) {
                name = names[i];
                child = childTable[name];
                if (child) {
                    name = name + ej.datavisualization.Diagram.Util.randomId();
                    delete (childTable[child.name]);
                    child.name = name;
                    childTable[child.name] = child;
                    this._preserveConnection(childTable, child);
                    child.parent = group.name;
                    childNames.push(name);
                    if (child.isGroup) {
                        this._pasteChildren(childTable, child);
                    }
                    this.add(child);
                }
            }
            group.children = childNames;
            this._preserveConnection(childTable, group);
        },

        _preserveConnections: function (childTable, group) {
            var child, names;
            names = group.children;
            for (var i = 0; i < names.length; i++) {
                child = childTable[names[i]];
                if (child) {
                    this._preserveConnection(childTable, child);
                    if (child.isGroup)
                        this._preserveConnections(childTable, group);
                }
            }
        },

        _preserveConnection: function (childTable, child) {
            var i, connection, len;
            if (!child.line) {
                len = child.inEdges.length;
                if (len > 0) {
                    for (i = 0; i < len; i++) {
                        connection = childTable[child.inEdges[i]];
                        if (connection) {
                            connection.targetNode = child.name;
                        }
                    }
                    child.inEdges = [];
                }
                len = child.outEdges.length;
                if (len > 0) {
                    for (i = 0; i < child.outEdges.length; i++) {
                        connection = childTable[child.outEdges[i]];
                        if (connection) {
                            connection.sourceNode = child.name;
                        }
                    }
                    child.outEdges = [];
                }
            } else {
                var node;
                if (child.targetNode) {
                    node = childTable[child.targetNode];
                    if (node)
                        node.inEdges.push(child.name);
                    //else
                    //    child.targetNode = null;
                }
                if (child.sourceNode) {
                    node = childTable[child.sourceNode];
                    if (node)
                        node.outEdges.push(child.name);
                    //else
                    //    child.sourceNode = null;
                }
            }
        },
        /**
        *Used to zoomIn/zoomOut diagram
        *@return jQuery
        *@param {Object} zoom pass zoom commands of the diagram
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *var zoom =  ej.datavisualization.Diagram.Zoom();
        *zoom.zoomFactor = .1;
        *zoom.zoomCommand = ej.datavisualization.Diagram.ZoomCommand.ZoomIn;
        *diagram.zoomTo(zoom);
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        zoomTo: function (zoom) {
            if (!zoom) {
                zoom = new ej.datavisualization.Diagram.Zoom();
            }
            if (zoom.zoomCommand & ej.datavisualization.Diagram.ZoomCommand.ZoomIn) {
                if (this.model.zoomFactor > 30) {
                    this.model.zoomFactor = 30 / this.model.zoomFactor;
                }
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 + zoom.zoomFactor), 0, 0, zoom.focusPoint, true);
            } else {
                if (this.model.zoomFactor < 0.25) {
                    this.model.zoomFactor = 0.25 / this.model.zoomFactor;
                }
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 - zoom.zoomFactor), 0, 0, zoom.focusPoint, true);
            }
        },
        /**
        *Removes either given node/connector or the selected element from diagram
        *@return jQuery
        *@param {Object} node pass node/connector to be removed
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.remove(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        remove: function (node) {
            if (node && this.nameTable[node.name]) {
                this._remove(node);
            }
            else
                this._delete();
        },
        /**
               *Remove all the elements from diagram
               *@return jQuery
               *@example
               
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *diagram.clear(); 
               *&lt;/script&gt;
               *@memberof ejDiagram
*@instance
               */
        clear: function () {
            this._clearSelection();
            var i;
            for (i = this.model.nodes.length - 1; i >= 0; i--) {
                this._remove(this.model.nodes[i]);
            }
            for (i = this.model.connectors.length - 1; i >= 0; i--) {
                this._remove(this.model.connectors[i]);
            }
            this.clearHistory();
        },

        _add: function (node, render) {
            var success = false;
            if (node.length > 0) {
                for (var i = 0; i < node.length; i++) {
                    this.add(node[i]);
                }
            } else {
                if (node.line) var type = "connector"; else type = "node";
                var args = { changeType: "insert", element: node, cancel: false };
                this._raiseEvent(type + "CollectionChange", args);
                if (!args.cancel) {
                    this._setZorder(node);
                    if (!node.line) {
                        if (node.isGroup)
                            node = ej.datavisualization.Diagram.Group(node);
                        else {
                            node = ej.datavisualization.Diagram.Node(node);
                        }
                        success = this.model.nodes.push(node);
                        this.nameTable[node.name] = node;
                        if (success) {
                            if (node.isGroup) {
                                this._updateParent(node);
                                ej.datavisualization.Diagram.Util._updateGroupBounds(node, this.nameTable);
                                this._updateChildrenEdges(node);
                                if (render)
                                    ej.datavisualization.Diagram.DiagramContext.renderGroup(node, this);
                            } else {
                                ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, node);
                                if (render && !node.parent)
                                    ej.datavisualization.Diagram.DiagramContext.renderNode(node, this);
                            }
                            this.nameTable[node.name] = node;
                            if (render) {
                                this._clearSelection();
                                this._addSelection(node);
                            }
                        }
                    } else {
                        node = ej.datavisualization.Diagram.Connector(node);
                        success = this.model.connectors.push(node);
                        if (success) {
                            ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, node);
                            this._updateEdges(node);
                            this._dock(node, this.nameTable);
                            if (!node.parent) {
                                if (render)
                                    ej.datavisualization.Diagram.DiagramContext.renderConnector(node, this);
                            }
                            this.nameTable[node.name] = node;
                            if (render) {
                                this._clearSelection();
                                this._addSelection(node);
                            }
                        }
                    }
                }
            }
            if (!this._isUndo) {
                if (node.parent == "") {
                    var childTable = {};
                    if (this.selectionList && this.selectionList.length > 0)
                        childTable = this._getChildTable(this.selectionList[0], childTable);
                    var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, node), childTable: jQuery.extend(true, {}, childTable), changeType: "insert" };
                    this.addHistoryEntry(entry);
                }
            }
            return success;
        },
        /**
              *Add node/connector
              *@return jQuery
              *@param {Object} node pass node/connector to be added
              *@example
              
              *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
              *&lt;script&gt;
              *var diagram=$("#diagramcontent").ejDiagram("instance");
              *var node = [];
              *node=[{ name: "node", width: 175, height: 60, offsetX: 400, offsetY: 60, shape: { type: "Rectangle"}];
              *diagram.add(node);
              *&lt;/script&gt;
              *@memberof ejDiagram
*@instance
              */
        add: function (node) {
            return this._add(node, true);
        },
        /**
           *Update userhandles of given node
           *@return jQuery
            *@param {Object} node pass node/connector 
           *@example
          
           *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
           *&lt;script&gt;
           *var diagram=$("#diagramcontent").ejDiagram("instance");
           * var node = diagram.selectionList[0];
           * diagram.updateUSerHandles(node); 
           *&lt;/script&gt;
           *@memberof ejDiagram
*@instance
           */
        updateUserHandles: function (node) {
            ej.datavisualization.Diagram.SvgContext.updateUserHandles(this.model.userHandles, node, this._svg, false, false, this.model.zoomFactor);
        },
        /**
           *Update offsetX of given node
           *@return jQuery
            *@param {Object} node pass node/connector to be added
           *@example
          
           *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
           *&lt;script&gt;
           *var diagram=$("#diagramcontent").ejDiagram("instance");
           * var node = diagram.selectionList[0];
           * diagram.scrollToNode(node); 
           *&lt;/script&gt;
           *@memberof ejDiagram
*@instance
           */
        scrollToNode: function (node) {
            var nodeX, nodeY;
            var curZoomfactor = this.model.zoomFactor;
            var elementBounds = this.element[0].getBoundingClientRect();
            var nodeBounds = ej.datavisualization.Diagram.Util.bounds(node);
            nodeX = (nodeBounds.x + nodeBounds.width / 2) * curZoomfactor;
            nodeY = (nodeBounds.y + nodeBounds.height / 2) * curZoomfactor;
            var hScrollOffset = this._hScrollOffset, vScrollOffset = this._vScrollOffset;
            if (elementBounds.width + this._hScrollOffset < nodeX + nodeBounds.width / 2) {
                hScrollOffset = (nodeX + (nodeBounds.width * curZoomfactor) - elementBounds.width);
            }
            if (elementBounds.height + this._vScrollOffset < nodeY + nodeBounds.height / 2) {
                vScrollOffset = (nodeY + (nodeBounds.height * curZoomfactor) - elementBounds.height);
            }
            this._updateScrollOffset(hScrollOffset, vScrollOffset);
        },
        //#endregion

        //#region support methods

        _registerDrawingTools: function () {
            for (var toolname in this.model.drawingTools) {
                var tool = this.model.drawingTools[toolname];
                tool.diagram = this;
                this.tools[tool.name] = tool;
            }
        },

        _sortByXvalue: function (nodes) {
            var temp, i, j;
            var fNode, lNode;
            for (i = 0; i < nodes.length; i++) {
                for (j = i + 1; j < nodes.length; j++) {
                    var nodei = this.nameTable[nodes[i]];
                    var nodej = this.nameTable[nodes[j]];
                    fNode = ej.datavisualization.Diagram.Util.bounds(nodei);
                    lNode = ej.datavisualization.Diagram.Util.bounds(nodej);
                    if (fNode.x > lNode.x) {
                        temp = nodes[i];
                        nodes[i] = nodes[j];
                        nodes[j] = temp;
                    }
                }
            }
            return nodes;
        },

        _sortByYvalue: function (nodes) {
            var temp, i, j;
            var fNode, lNode;
            for (i = 0; i < nodes.length; i++) {
                for (j = i + 1; j < nodes.length; j++) {
                    var nodei = this.nameTable[nodes[i]];
                    var nodej = this.nameTable[nodes[j]];
                    fNode = ej.datavisualization.Diagram.Util.bounds(nodei);
                    lNode = ej.datavisualization.Diagram.Util.bounds(nodej);
                    if (fNode.y > lNode.y) {
                        temp = nodes[i];
                        nodes[i] = nodes[j];
                        nodes[j] = temp;
                    }
                }
            }
            return nodes;
        },

        _sortByZIndex: function (nodes, asc) {
            var temp, i, j;
            if (!asc) {
                for (i = 0; i < nodes.length; i++) {
                    for (j = i + 1; j < nodes.length; j++) {
                        if (nodes[i].zOrder < nodes[j].zOrder) {
                            temp = nodes[i];
                            nodes[i] = nodes[j];
                            nodes[j] = temp;
                        }
                    }

                }
            }
            else {
                for (i = 0; i < nodes.length; i++) {
                    for (j = i + 1; j < nodes.length; j++) {
                        if (nodes[i].zOrder > nodes[j].zOrder) {
                            temp = nodes[i];
                            nodes[i] = nodes[j];
                            nodes[j] = temp;
                        }
                    }

                }
            }
            return nodes;
        },

        _findCornerNodes: function () {
            var lNode, rNode, tNode, bNode, i, nBounds;
            var list = this.selectionList[0].children;
            var fnode = this.nameTable[this.selectionList[0].children[0]];
            lNode = fnode, rNode = fnode, tNode = fnode, bNode = fnode;

            if (list.length > 1) {
                for (i = 0; i < list.length; i++) {
                    var node = this.nameTable[list[i]];
                    nBounds = ej.datavisualization.Diagram.Util.bounds(node);

                    var rNodeBounds = ej.datavisualization.Diagram.Util.bounds(rNode);    //Right Node
                    if ((nBounds.x + nBounds.width) > (rNodeBounds.x + rNodeBounds.width))
                        rNode = node;

                    var bNodeBounds = ej.datavisualization.Diagram.Util.bounds(bNode);    //Bottom Node
                    if ((nBounds.y + nBounds.height) > (bNodeBounds.y + bNodeBounds.height))
                        bNode = node;

                    var lNodeBounds = ej.datavisualization.Diagram.Util.bounds(lNode);    //Left Node
                    if (nBounds.x < lNodeBounds.x)
                        lNode = node;

                    var tNodeBounds = ej.datavisualization.Diagram.Util.bounds(tNode);    //top Node
                    if (nBounds.y < tNodeBounds.y)
                        tNode = node;

                }
            }
            return { left: lNode, right: rNode, top: tNode, bottom: bNode };
        },

        _moveNode: function (diffX, diffY, node) {
            this._translate(node, diffX, diffY, this.nameTable);
            ej.datavisualization.Diagram.DiagramContext.update(node, this);
        },

        _nudge: function (node, x, y) {
            this._translate(node, x, y, this.nameTable);
            ej.datavisualization.Diagram.DiagramContext.update(node, this);
            ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
        },

        _findObjectByName: function (name) {
            var node = null;
            if (this._findNode(name))
                node = this._findNode(name);
            if (this._findConnector(name))
                node = this._findConnector(name);
            return node;
        },

        _findObjectByIndex: function (index, group) {
            var nodes, findNode = null, node, m, k;
            if (group) {
                nodes = this.selectionList[0].parent.children;
                for (k = 0; k < nodes.length; k++) {
                    node = this.nameTable[nodes[k]];
                    if (node.zOrder === index)
                        findNode = nodes[k];
                }
            } else {
                for (m = 0; m < this.model.nodes.length; m++) {
                    node = this.model.nodes[m];
                    if (node.zOrder === index)
                        findNode = node;
                }
                for (m = 0; m < this.model.connectors.length; m++) {
                    node = this.model.connectors[m];
                    if (node.zOrder === index)
                        findNode = node;
                }
            }

            return findNode;
        },

        _findOverlapNode: function (node) {
            var oNodes = [], m, i, rNodes = [];
            if (!node.parent) {
                for (m = 0; m < this.model.nodes.length; m++) {
                    oNodes.push(this.model.nodes[m]);
                }
                for (m = 0; m < this.model.connectors.length; m++) {
                    oNodes.push(this.model.connectors[m]);
                }
                var nBound = ej.datavisualization.Diagram.Util.bounds(node);
                if (node) {
                    for (i = 0; i < oNodes.length; i++) {
                        var chBound = ej.datavisualization.Diagram.Util.bounds(oNodes[i]);
                        if (node.name !== oNodes[i].name) {
                            if (this._intersect(nBound, chBound))
                                rNodes.push(oNodes[i]);
                        }
                    }
                }
            } else {
                for (m = 0; m < node.parent.children.length; m++) {
                    if (node.parent.children[m] !== node.name)
                        rNodes.push(node.parent.children[m]);
                }
            }
            return rNodes;
        },

        _intersect: function (a, b) {
            return (a.x <= (b.x + b.width) &&
                b.x <= (a.x + a.width) &&
                a.y <= (b.y + b.height) &&
                b.y <= (a.y + a.height));
        },
        //#endregion 

        //#region Rendering
        _createTooltipDiv: function () {
            var div = document.createElement("div");
            var attr = {
                "id": this.element[0].id + "_tooltipDiv",
                "class": "e-diagram-tooltip-default", "style": "padding-top:3px; height: 24px;",
            };
            ej.datavisualization.Diagram.Util.attr(div, attr);
            this._canvas.appendChild(div);
            return div;
        },

        _renderTooltip: function (object) {
            if (this.model.showTooltip && $.templates) {
                var tooltipDiv = $("#" + this.element[0].id + "_tooltipDiv")[0];
                if (!tooltipDiv) {
                    tooltipDiv = this._createTooltipDiv();
                }
                var template;
                var objectValues;
                var html;

                var curZoomfactor = this.model.zoomFactor;
                if (!this.model.tooltipTemplateId) {
                    template = $.templates("#" + this.element[0].id + "_defaultTooltip");
                    if (this.activeTool instanceof ej.datavisualization.Diagram.MoveTool) {
                        tooltipDiv.style.width = "150px";
                        objectValues = [{ type: "X : ", type1: "Y : ", x: Math.round((object.offsetX - object.width / 2)) + "px  ", y: Math.round((object.offsetY - object.height / 2)) + "px" }];
                    }
                    else if (this.activeTool instanceof ej.datavisualization.Diagram.ResizeTool) {
                        tooltipDiv.style.width = "150px";
                        objectValues = [{ type: "W : ", type1: "H : ", x: Math.round(object.width) + "px  ", y: Math.round(object.height) + "px" }];
                    }
                    else if (this.activeTool instanceof ej.datavisualization.Diagram.RotateTool) {
                        tooltipDiv.style.width = "50px";
                        objectValues = [{ type: "", type1: "", x: Math.round(object.rotateAngle) + "&deg; ", y: "" }];
                    }
                    if (objectValues) {
                        tooltipDiv.style.top = -this._vScrollOffset + ((object.offsetY * curZoomfactor - (object.height / 2) * curZoomfactor) + (object.height * curZoomfactor) + 15) + "px";
                        tooltipDiv.style.left = -this._hScrollOffset + ((object.offsetX * curZoomfactor - (object.width / 2) * curZoomfactor)) + (object.width / 2 * curZoomfactor - $(tooltipDiv).width() / 2) + "px";
                        html = template.render(objectValues);
                        $(tooltipDiv).html(html);
                    }
                    else {
                        this._removeTooltip();
                    }
                }
                else {
                    tooltipDiv.style.top = -this._vScrollOffset + ((object.offsetY * curZoomfactor - (object.height / 2) * curZoomfactor) + (object.height * curZoomfactor) + 15) + "px";
                    tooltipDiv.style.left = -this._hScrollOffset + ((object.offsetX * curZoomfactor - (object.width / 2) * curZoomfactor)) + (object.width / 2 * curZoomfactor - $(tooltipDiv).width() / 2) + "px";
                    template = $.templates("#" + this.model.tooltipTemplateId);
                    objectValues = [{ name: this.activeTool.selectedObject.name, x: (object.offsetX - object.width / 2) + "px", y: (object.offsetY - object.height / 2) + "px", width: object.width + "px", height: object.height + "px", rotationAngle: object.rotateAngle }];
                    html = template.render(objectValues);
                    $(tooltipDiv).html(html);
                }
            }
        },

        _removeTooltip: function () {
            var tooltipDiv = document.getElementById(this.element[0].id + "_tooltipDiv");
            if (tooltipDiv) {
                tooltipDiv.parentNode.removeChild(tooltipDiv);
            }
        },

        _renderCanvas: function () {
            this._canvas = document.createElement("div");
            this._canvas.setAttribute("id", this.element[0].id + "_canvas");
            this._canvas.setAttribute("class", "drawing");
            this._canvas.setAttribute("style", "position:relative; height:" + this.model.height + "; width:" + this.model.width + ";");
            this.element.css({
                overflow: "hidden", outline: "none", display: "block", height: this.model.height, width: this.model.width
            });
            this._views[this._id].canvas = this._canvas;
            this.element[0].setAttribute("tabindex", 0);
            this.element.append(this._canvas);
            this._renderDiagram();
        },

        _getDigramBounds: function () {
            var left, top, right, bottom;
            left = Math.max(0, this._spatialSearch.pageLeft);
            top = Math.max(0, this._spatialSearch.pageTop);
            if (!this.model.pageSettings.pageWidth) {
                right = this._spatialSearch.pageRight;
            }
            if (!this.model.pageSettings.pageHeight) {
                bottom = this._spatialSearch.pageBottom;
            }
            if (this.model.pageSettings && this.model.pageSettings.multiplePage) {
                left = Math.max(0, this._spatialSearch.pageLeft);
                top = Math.max(0, this._spatialSearch.pageTop);
                if (this.model.pageSettings.pageWidth) {
                    left = Math.floor(left / this.model.pageSettings.pageWidth) * this.model.pageSettings.pageWidth;
                    right = Math.ceil(this._spatialSearch.pageRight / this.model.pageSettings.pageWidth) * this.model.pageSettings.pageWidth;
                }
                if (this.model.pageSettings.pageHeight) {
                    top = Math.floor(top / this.model.pageSettings.pageHeight) * this.model.pageSettings.pageHeight;
                    bottom = Math.ceil(this._spatialSearch.pageBottom / this.model.pageSettings.pageHeight) * this.model.pageSettings.pageHeight;
                }
                if (this._spatialSearch.pageRight === null) {
                    if (this.model.pageSettings.pageWidth !== 0) {
                        right = this.model.pageSettings.pageWidth;
                    }
                }
                if (this._spatialSearch.pageBottom === null) {
                    if (this.model.pageSettings.pageHeight !== 0) {
                        bottom = this.model.pageSettings.pageHeight;
                    }
                }
            }
            else {
                if (this.model.pageSettings.pageWidth) {
                    left = Math.min(0, this._spatialSearch.pageLeft);
                    right = this.model.pageSettings.pageWidth;
                }
                if (this.model.pageSettings.pageHeight) {
                    top = Math.min(0, this._spatialSearch.pageTop);

                    bottom = this.model.pageSettings.pageHeight;
                }
            }
            var svgBounds = new ej.datavisualization.Diagram.Rectangle();
            svgBounds.x = left;
            svgBounds.y = top;
            svgBounds.width = right;
            svgBounds.height = bottom;
            return svgBounds;
        },

        _initContextMenu: function () {
            if (!this.model.contextMenu.showCustomMenuItemsOnly) {
                this.model.contextMenu.items = $.extend([], this._defaultContextMenuItems, this.model.contextMenu.items);
            }
            if (this.model.enableContextMenu) {
                this._renderContextMenu();
            }
            else {
                this.element.remove("#" + this.element[0].id + "_contextMenu");
            }
        },

        _renderContextMenuItem: function (item) {
            var li = document.createElement("li");
            var a = document.createElement("a");
            var menu = ej.datavisualization.Diagram.Locale[this.model.locale];
            $.each(menu, function (otext, ntext) {
                if (item.name === otext) {
                    a.innerHTML = ntext;
                    item.text = ntext;
                }
            });           
            li.setAttribute("id", this.element[0].id + "_contextMenu_" + item.name);

            var div = document.createElement("span");
            div.setAttribute("id", item.text + "_image");
            div.setAttribute("style", "margin-top:-5px;");
            div.setAttribute("class", "sf-d-menuitem " + item.name);
            a.appendChild(div);
            if (item.subItems && item.subItems.length > 0) {
                var subUl = document.createElement("ul");
                var i = 0, subli;
                for (i; i < item.subItems.length; i++) {
                    subli = this._renderContextMenuItem(item.subItems[i], subUl);
                    subUl.appendChild(subli);
                }
                li.appendChild(subUl);
            }
            li.appendChild(a);
            return li;
        },

        _renderContextMenu: function () {
            var menuCollection = this.model.contextMenu.items;
            var i = 0, item, mItem;
            var ul = document.createElement("ul");
            ul.setAttribute("id", this.element[0].id + "_contextMenu");
            for (i; i < menuCollection.length; i++) {
                item = menuCollection[i];
                mItem = this._renderContextMenuItem(item, ul);
                ul.appendChild(mItem);
            }
            this._canvas.appendChild(ul);
            $("#" + this.element[0].id + "_contextMenu").ejMenu({
                menuType: ej.MenuType.ContextMenu,
                contextMenuTarget: this.element[0].id + "_canvas_svg",
                click: $.proxy(this._onMenuItemClick, this),
                beforeOpen: $.proxy(this._onContextMenuOpen, this),
                mouseover: $.proxy(this._onMenuItemMouseOver, this),
                mouseout: $.proxy(this._onMenuItemMouseOut, this),
                close: $.proxy(this._onContextMenuClose, this),
            });
        },

        _onContextMenuClose: function () {
            this.element[0].focus();
        },

        _onContextMenuOpen: function (args) {
            var diagramId = this.element[0].id;
            if (this.model.enableContextMenu) {
                document.getElementById(diagramId + "_contextMenu_cut").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_copy").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_paste").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_undo").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_redo").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_selectAll").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_cut").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_grouping").style.display = "block";
                document.getElementById(diagramId + "_contextMenu_order").style.display = "block";
                if (this.selectionList.length == 0) {
                    document.getElementById(diagramId + "_contextMenu_cut").style.display = "none";
                    document.getElementById(diagramId + "_contextMenu_copy").style.display = "none";
                    document.getElementById(diagramId + "_contextMenu_cut").style.display = "none";
                    document.getElementById(diagramId + "_contextMenu_grouping").style.display = "none";
                    document.getElementById(diagramId + "_contextMenu_order").style.display = "none";
                }
            }
            var obj = ({ diagram: this, contextmenu: args });
            this._trigger(this.model.contextMenu.beforeOpen, obj);
        },

        _onMenuItemClick: function (args) {
            var menuId = args.events.ID.replace(this._id + "_" + "contextMenu_", "");
            switch (menuId) {
                case "cut":
                    this.cut();
                    break;
                case "copy":
                    this.copy();
                    break;
                case "paste":
                    this.paste();
                    break;
                case "undo":
                    this.undo();
                    break;
                case "redo":
                    this.redo();
                    break;
                case "selectAll":
                    this.selectAll();
                    break;
                case "group":
                    this.group();
                    break;
                case "ungroup":
                    this.ungroup();
                    break;
                case "bringToFront":
                    this.bringToFront();
                    break;
                case "sendToBack":
                    this.sendToBack();
                    break;
                case "moveForward":
                    this.moveForward();
                    break;
                case "sendBackward":
                    this.sendBackward();
                    break;
                default:
                    break;
            }
            this._trigger(this.model.contextMenu.click, args);
        },

        _onMenuItemMouseOver: function (args) {
            var t = args.events.element.lastChild.childNodes[1];
            $(t).addClass("hover");
        },

        _onMenuItemMouseOut: function (args) {
            var t = args.events.element.lastChild.childNodes[1];
            $(t).removeClass("hover");
        },

        _renderDiagram: function () {
            var diagram = this;
            this._views.forEach(function (viewid) {
                var view = diagram._views[viewid];
                view.context._renderDocument(view, diagram); if (view.type == "mainview" && view.context == ej.datavisualization.Diagram.SvgContext) {
                    diagram._createScroller(diagram._canvas);
                    ej.datavisualization.Diagram.ScrollUtil._initScroller(diagram);
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
                if (diagram.model.layout && diagram.model.layout.type !== ej.datavisualization.Diagram.LayoutTypes.None) {
                    diagram._doLayout();
                };
                diagram._renderNodes(view);
                diagram._renderConnectors(view);
            });
        },

        _createScroller: function (canvas) {
            var scroller = document.createElement("div");
            scroller.setAttribute("id", canvas.id + "_scroller");
            var contentHolder = document.createElement("div");
            contentHolder.setAttribute("id", canvas.id + "_contentHolder");
            scroller.appendChild(contentHolder);
            var content = document.createElement("div");
            content.setAttribute("id", contentHolder.id + "_content");
            contentHolder.appendChild(content);
            canvas.appendChild(scroller);
        },

        _doLayout: function () {
            if (this.model.layout && this.model.layout.type !== ej.datavisualization.Diagram.LayoutTypes.None) {
                this._updateEdgeCollection();
                ej.datavisualization.Diagram.Layout.doLayout(this);
            }
        },

        _updateNodes: function () {
            var nodes = this.model.nodes;
            for (var i = 0; i < nodes.length; i++) {
                ej.datavisualization.Diagram.DiagramContext.update(nodes[i], this);
            }
        },

        _updateConnectors: function () {
            var connections = this.model.connectors;
            for (var i = 0; i < connections.length; i++) {
                ej.datavisualization.Diagram.DiagramContext.update(connections[i], this);
            }
        },

        _updateEdgeCollection: function () {
            for (var i = 0; i < this.model.connectors.length; i++) {
                this._updateEdges(this.model.connectors[i]);
            }
        },
        /**
        *To update viewport when window resize
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.updateViewPort();
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        updateViewPort: function () {
            ej.datavisualization.Diagram.DiagramContext.updateViewPort(this);
        },

        _setZorder: function (node) {
            if (node) {
                node.zOrder = this._zOrder;
                this._zOrder++;
                if (node.isGroup) {
                    var i = 0;
                    for (i; i < node.children.length; i++) {
                        this.nameTable[node.children[i]].zOrder = i;
                    }
                }
            }
        },

        _renderNodes: function (view) {
            if (this.model.nodes) {
                var nodes = this.model.nodes;
                for (var i = 0, len = nodes.length; i < len; ++i) {
                    var node = nodes[i];
                    this._setZorder(node);
                    var panel = view.svg || view._canvas;
                    if (node.isGroup) {
                        this._updateChildBounds(node, this.nameTable);
                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, this.nameTable);
                        view.context.renderGroup(node, panel, view.diagramLayer, this);
                    }
                    else {
                        if (!node.parent)
                            view.context.renderNode(node, panel, view.diagramLayer, this);
                    }
                }
            }
        },

        _renderConnectors: function (view) {
            if (this.model.connectors) {
                var connectors = this.model.connectors;
                var panel = view.svg || view._canvas;
                var connector;
                for (var i = 0, len = connectors.length; i < len; ++i) {
                    connector = connectors[i];
                    view.context.renderConnector(connector, panel, view.diagramLayer, this);
                }
            }
        },

        //#endregion

        //#region Events
        _wireEvents: function () {
            //svg document events
            var svgDocument = $(this._canvas);
            this._on(svgDocument, ej.eventType.mouseDown, this._mousedown);
            this._on(svgDocument, ej.eventType.mouseMove, this._mousemove);
            this._on(svgDocument, ej.eventType.mouseUp, this._mouseup);
            this._on(svgDocument, ej.eventType.mouseLeave, this._documentmouseup);
            this._on(svgDocument, "dblclick", this._doubleclick);
            this._on(svgDocument, "doubletap", this._doubleclick);

            this._on(this.element, "keydown", this._keydown);
            //this._on(this.element, "contextmenu", this._contextmenu);
            this._on(svgDocument, "pinchin", this._pinchin);
            this._on(svgDocument, "pinchout", this._pinchout);
            this._on(this.element, "touchstart", this._handleTouchStart);
            if (ej.browserInfo().name === "mozilla") {
                this._on(this.element, "DOMMouseScroll", this._handleMouseWheel);
            }
            else
                this._on(this.element, "mousewheel", this._handleMouseWheel);
            //window document event
            this._on($(document), "mouseup", this._documentmouseup);

            if (window) {
                this._on($(window), "resize", this.updateViewPort);
            }
            var obj = this;
            $(svgDocument).ejDroppable({
                drop: function (event, ui) {
                    obj._svgdrop(event, ui);
                    obj._isDropped = true;
                }
            });
        },

        _mousePosition: function (evt, exOffset) {
            var e = this._isTouchEvent(evt);
            var scrollLeft = this._canvas.scrollLeft;
            var scrollTop = this._canvas.scrollTop;
            var controlBBox = this._canvas.getBoundingClientRect();
            var layerx = (e.clientX + scrollLeft) - controlBBox.left;
            var layery = (scrollTop + e.clientY) - controlBBox.top;
            if (!exOffset) {
                layerx = (layerx + this._hScrollOffset) / this.model.zoomFactor;
                layery = (layery + this._vScrollOffset) / this.model.zoomFactor;
            }
            return new ej.datavisualization.Diagram.Point(layerx, layery);
        },

        _contextmenu: function (evt) {
            evt.preventDefault();
            evt.stopPropagation();
        },

        _pinchin: function (evt) {
            evt.preventDefault();
        },

        _pinchout: function (evt) {
            evt.preventDefault();
        },

        _handleTouchStart: function (evt) {
            evt.preventDefault();
        },

        _mousedown: function (evt) {
            if (this._invoke(evt)) {
                if (!this._isForeignObject(evt.originalEvent.target))
                    evt.preventDefault();
                if (this.model.contextMenu && $("#" + this.element[0].id + "_contextMenu").css("display") !== "none") {
                    evt.cancel = true;
                }
                if (this._isEditing)
                    this._endEdit();
                if (evt.which === 1 || (evt.which === 0 && evt.originalEvent.changedTouches)) {
                    if (evt.which === 0 && evt.originalEvent.changedTouches) {
                        var node = null;
                        var point = this._mousePosition(evt);
                        var isUserHandle = this._isUserHandle(evt);
                        if ((this._isInternalTool(this.activeTool) && !this.activeTool.inAction)) {
                            if (!isUserHandle) {
                                node = this._findNodeUnderMouse(evt);
                                this._raiseMouseEvents(node);
                            }
                            if (!node && this.selectionList[0]) {
                                node = this.selectionList[0];
                            }
                            this._checkToolToActivate(evt, node, point);
                        }
                    }
                    this.activateTool(this._toolToActivate);
                    this.activeTool.mousedown(evt);
                }
            }
        },

        _invoke: function (evt) {
            var className = evt.originalEvent.target.className;
            if (evt.originalEvent.target && (className == "edit" || className == "editBox" || className == "e-hhandle" || className == "e-hhandlespace" || className == "e-vhandle" || className == "e-vhandlespace")) {
                return false;
            }

            return true;
        },

        _handleMouseWheel: function (evt) {
            if (evt.originalEvent.preventDefault)
                evt.originalEvent.preventDefault();
            var position = new ej.datavisualization.Diagram.Point(0, 0);
            //this.deactivateTool();
            if (evt.ctrlKey) {
                position.x = (evt.originalEvent.layerX + this._hScrollOffset) / this.model.zoomFactor;
                position.y = (evt.originalEvent.layerY + this._vScrollOffset) / this.model.zoomFactor;
                if (evt.originalEvent.wheelDelta > 0 || -40 * evt.originalEvent.detail > 0) {
                    ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 + 0.2), 0, 0, position, true);
                }
                else {
                    ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 - 0.2), 0, 0, position, true);
                }
            }
            else {
                var offsetY = 0;
                if (evt.originalEvent.wheelDelta > 0 || -40 * evt.originalEvent.detail > 0) {
                    if ((this._vScrollOffset - this._scrollPixel) >= 0) {
                        this._updateScrollOffset(this._hScrollOffset, (this._vScrollOffset - this._scrollPixel));
                        offsetY = -this._scrollPixel;
                    }
                    else {
                        this._updateScrollOffset(this._hScrollOffset, 0);
                        offsetY = 0;
                    }
                }
                else {
                    if (document.getElementById(this.element[0].id).getElementsByClassName('e-vhandle').length > 0) {
                        var content = $("#" + this._canvas.id + "_contentHolder_content");
                        var cHeight = content.height();
                        var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
                        if ((cHeight - viewPort.height) >= (this._vScrollOffset + this._scrollPixel)) {
                            this._updateScrollOffset(this._hScrollOffset, (this._vScrollOffset + this._scrollPixel));
                            offsetY = this._scrollPixel;
                        }
                        else if ((cHeight - viewPort.height) >= (this._vScrollOffset)) {
                            var v = (cHeight - viewPort.height);
                            var o = this._vScrollOffset;
                            this._updateScrollOffset(this._hScrollOffset, this._vScrollOffset + (v - o));
                            offsetY = 0;
                        }
                    }
                }
                this._updateEditBox(0, offsetY);
            }
        },

        _mousemove: function (evt) {
            var node = null;
            var point = this._mousePosition(evt);
            var isUserHandle = this._isUserHandle(evt);
            if ((this._isInternalTool(this.activeTool) && !this.activeTool.inAction)) {
                if (!isUserHandle) {
                    node = this._findNodeUnderMouse(evt);
                    if (node) {
                        if (this._nodeToHit && this._nodeToHit != node && this._nodeToHit.shape) {
                            this.activeTool._showPort(this._nodeToHit, true);
                        }
                        if (node.shape) {
                            this.activeTool._showPort(node);
                        }
                    }
                    this._raiseMouseEvents(node);
                }
                if (!node && this.selectionList[0]) {
                    node = this.selectionList[0];
                }
                this._checkToolToActivate(evt, node, point);
            }
            else {
                if (!this.activeTool.inAction && !this.activeTool.singleAction) {
                    this._toolToActivate = this.activeTool.name;
                    this._currentCursor = this.activeTool.cursor;
                }
                node = this._findNodeUnderMouse(evt);
                this._raiseMouseEvents(node);
            }
            this._updateCursor();
            this.activeTool.mousemove(evt);
            if (this.activeTool.inAction && this.model.enableAutoScroll) {
                var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
                var pt = this._mousePosition(evt, true);
                if (pt.x + 15 >= viewPort.width - 15) {
                    this._beginAutoScroll("right", evt);
                    this._canAutoScroll = true;
                }
                else if (pt.x <= 15 && this._hScrollOffset > 0) {
                    this._beginAutoScroll("left", evt);
                    this._canAutoScroll = true;
                }
                else if (pt.y + 15 >= viewPort.height - 15) {
                    this._beginAutoScroll("bottom", evt);
                    this._canAutoScroll = true;
                }
                else if (pt.y <= 15 && this._vScrollOffset > 0) {
                    this._beginAutoScroll("top", evt);
                    this._canAutoScroll = true;
                }
                else {
                    this._canAutoScroll = false;
                }
            }
        },

        _setActiveTool: function (evt) {
            var point = this._mousePosition(evt);
            if (!this.activeTool.inAction && (this._isUserHandleActive(this.activeTool.name) || !this.model.userHandles || !this.model.userHandles.length)) {
                if (this._isInternalTool(this.activeTool) || this.activeTool.singleAction) {
                    var node;
                    var success = false;
                    //var handle = this._isHandle(evt);
                    if (this.selectionList[0]) {
                        node = this.selectionList[0];
                        success = this._checkToolToActivate(evt, node, point);
                    }
                    if (!success) {
                        node = this._findNodeUnderMouse(evt);
                        if (this._isUserHandle(evt)) {
                            var handleName = $(evt.target).parents("g").first().context.id.split("_")[0];
                            this._checkToolToActivate(evt, node, point, handleName);
                            this.activeTool = this.tools[this._toolToActivate];
                        }
                        else {
                            this._checkToolToActivate(evt, node, point);
                            this._raiseMouseEvents(node);
                            if (this._isUserHandleActive(this.activateTool.name) && !this._drawingTool)
                                this.activeTool = this.tools[this._toolToActivate];
                        }
                    }
                }
            }
        },

        _beginAutoScroll: function (option, evt) {
            var callBack = this;
            var left = 0, top = 0;
            var content = $("#" + this._canvas.id + "_contentHolder_content");
            var cWidth = content.width();
            var cHeight = content.height();
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            if (this._canAutoScroll) {
                switch (option) {
                    case "right":
                        if (this._hScrollOffset + viewPort.width < cWidth) {
                            left = 10;
                        }
                        break;
                    case "left":
                        if (this._hScrollOffset - 10 >= 0) {
                            left = -10;
                        }
                        break;
                    case "bottom":
                        if (this._vScrollOffset + viewPort.height < cHeight) {
                            top = 10;
                        }
                        break;
                    case "top":
                        if (this._vScrollOffset - 10 >= 0) {
                            top = -10;
                        }
                        break;
                }
                setTimeout(function () {
                    callBack._updateScrollBar(left, top, option, evt);
                }, 100);
            }
        },

        _updateScrollBar: function (x, y, option, evt) {
            if (x === 0 && y === 0) {
                this._canAutoScroll = false;
            }
            else if (this.activeTool.inAction && !this._drawingTool) {
                if (this._enableAutoScroll(x, y)) {
                    var hScrollOffset = this._hScrollOffset + (x * this.model.zoomFactor);
                    var vScrollOffset = this._vScrollOffset + (y * this.model.zoomFactor);
                    this._updateSelectionOnScroll(x, y);
                    this._updateScrollOffset(hScrollOffset, vScrollOffset);
                    this._beginAutoScroll(option, evt);
                }
            }
        },

        _enableAutoScroll: function (x, y) {
            var enableScroll = true;
            var content = $("#" + this._canvas.id + "_contentHolder_content");
            var cWidth = content.width();
            var cHeight = content.height();
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            if (x < 0 && this._hScrollOffset + x < 0) {
                enableScroll = false;
            }
            if (y < 0 && this._vScrollOffset + y < 0) {
                enableScroll = false;
            }
            if (this.activeTool.name === "select" && this._vScrollOffset + viewPort.height + y > cHeight) {
                enableScroll = false;
            }
            if (this.activeTool.name === "select" && this._hScrollOffset + viewPort.width + x > cWidth) {
                enableScroll = false;
            }
            if (this.activeTool.name === "endPoint") {
                enableScroll = false;
            }
            return enableScroll;
        },

        _updateSelectionOnScroll: function (x, y) {
            var tool = this.activeTool;
            if (tool.name === "select") {
                tool.currentPoint = new ej.datavisualization.Diagram.Point(tool.currentPoint.x + x, tool.currentPoint.y + y);
                tool._updateHelper();
            }
            else if (this.selectionList.length > 0) {
                var node = this.selectionList[0];
                tool.currentPoint.x = (tool.currentPoint.x + x);
                tool.currentPoint.y = (tool.currentPoint.y + y);
                if (tool.name === "move") {
                    this._translate(node, x, y, this.nameTable);
                }
                else if (tool.name === "resize") {
                    ej.datavisualization.Diagram.SnapUtil._removeGuidelines(diagram);
                    tool._updateSize(node, tool.previousPoint, tool.currentPoint, x, y);
                }
                ej.datavisualization.Diagram.DiagramContext.update(node, this);
                this._updateSelectionHandle();
                this._renderTooltip(node);
            }
        },

        _isUserHandle: function (evt) {
            if (evt.target.parentNode.className.animVal === "userHandle") {
                return true;
            }
            else {
                return false;
            }
        },

        _isUserHandleActive: function (name) {
            var userHandleActive = false;
            if (this.model.userHandles && this.model.userHandles.length > 0) {
                var i = 0;
                var length = this.model.userHandles.length;
                for (i; i < length; i++) {
                    if (this.model.userHandles[i].name === name) {
                        userHandleActive = true;
                        break;
                    }
                    else
                        userHandleActive = true;
                }
            }
            return userHandleActive;
        },

        _raiseMouseEvents: function (node) {
            if (!node && this._nodeToHit) {
                this._trigger("mouseLeave", { element: this._nodeToHit });
               
                if (this._nodeToHit != null && (this._nodeToHit.shape) && !(this.activeTool instanceof ej.datavisualization.Diagram.LineTool)) {
                    this.activeTool._showPort(this._nodeToHit, true);
                   
                }
            }
            if (node) {
                if (this._nodeToHit !== node) {
                    this._nodeToHit = node;
                    this._trigger("mouseEnter", { element: node });
                }
            }
            else {
                this._nodeToHit = null;
            }
            if (node) {
                this._trigger("mouseOver", { diagram: node });
            }
        },

        _isHandle: function (evt) {
            var handle = $(evt.target).parent("g.handle");
            if (handle.length > 0) {
                return true;
            }
            return false;
        },

        _findNodeUnderMouse: function (evt) {
            var node = null;
            var type;
            var parent = $(evt.target).parents(".ej-d-node,.ej-d-connector");
            if (parent) {
                type = parent.attr("class");
                if (type === "ej-d-node" || type === "ej-d-group") {
                    node = this._findNode(parent.attr("id"));
                }
                else if (type === "ej-d-connector") {
                    node = this._findConnector(parent.attr("id"));
                }
            }
            return node;
        },

        _isForeignObject: function (target) {
            var foreignObj = target.parentNode;
            if (foreignObj) {
                while (foreignObj.parentNode != null) {
                    if (foreignObj.className === "foreignObject") {
                        return foreignObj;
                    }
                    else {
                        foreignObj = foreignObj.parentNode;
                    }
                }
            }
            return null;
        },

        _mouseup: function (evt) {
            if (this._invoke(evt)) {
                var foreignObject = this._isForeignObject(evt.originalEvent.target);
                if (!foreignObject)
                    evt.preventDefault();
                if (evt.target.id === this._id + "_canvas_svg")
                    this._trigger("click", { element: this });
                this.activeTool.mouseup(evt);
                if (this.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                    document.onmousemove = null;
                    document.onmouseup = null;
                }
                if ((!(this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) && !(this.activeTool instanceof ej.datavisualization.Diagram.TextTool)) && document.activeElement && document.activeElement.id !== this.element[0].id)
                    if (!this._isEditing && !foreignObject)
                        this.element[0].focus();
                this._currentCursor = this.activeTool.cursor;
                this._updateCursor();
            }
        },

        _doubleclick: function (evt) {
            var args;
            if (!this.activeTool.inAction && this.selectionList.length > 0) {
                args = this._trigger("doubleClick", { element: this.selectionList[0], cancel: false });
                var obj = this.selectionList[0];
                if (!(obj.isPseudoGroup) && !args.cancel) {
                    if (!this._isEditing && obj.shape && obj.shape.type === "text" && this._setLabelEditing(obj.shape.textBlock)) {
                        this.scrollToNode(obj);
                        this._startEdit(obj);
                    }
                    else if (!this._isEditing && ((obj.labels.length === 0 || typeof obj.labels.length === "undefined") || (obj.labels.length > 0 && this._setLabelEditing(obj.labels[0])))) {
                        this.scrollToNode(obj);
                        this._startEdit(obj);
                    }
                }
            }
            else if (this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) {
                this.activeTool.doubleclick(evt);
            }
        },

        _keydown: function (evt) {
            var keycode = evt.keyCode ? evt.keyCode : evt.which;
            if (keycode === 113) {
                if (this.selectionList.length > 0) {
                    var shape = this.selectionList[0];
                    if (!(shape.isPseudoGroup)) {
                        if (shape.shape.type === "text" && this._setLabelEditing(shape.shape.textBlock))
                            this._startEdit(shape);
                        else if (shape.labels.length > 0 && this._setLabelEditing(shape.labels[0]))
                            this._startEdit(shape);
                    }
                }
            }
            else if (this._isEditing && keycode === 27) {
                this._endEdit();
            }
            else if (!this._isEditing && keycode === 46) {
                this._delete();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 88) {
                this.cut();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 67) {
                this.copy();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 86) {
                this.paste();
            }
            else if (evt.ctrlKey && keycode === 65) {
                if (this._isEditing)
                    this._endEdit();
                evt.preventDefault();
                this.selectAll();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 89) {
                this.redo();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 90) {
                this.undo();
            }
            if (!this._isEditing && (keycode === 37 || keycode === 38 || keycode === 39 || keycode === 40)) {
                evt.preventDefault();
                if (keycode === 37) { //left
                    this.nudge("left");
                } else if (keycode === 38) { //up
                    this.nudge("up");
                } else if (keycode === 39) { //right
                    this.nudge("right");
                } else if (keycode === 40) { //down
                    this.nudge("down");
                }
            }
            this.activeTool.keydown(evt);
        },

        _registerHistoryEvents: function () {
            this.historyManager.addEventHandler("collectionchanged", $.proxy(this._recordCollectionChanged, this));
            this.historyManager.addEventHandler("positionchanged", $.proxy(this._recordPinPointChanged, this));
            this.historyManager.addEventHandler("sizechanged", $.proxy(this._recordResizeChanged, this));
            this.historyManager.addEventHandler("rotationchanged", $.proxy(this._recordRotationChanged, this));
            this.historyManager.addEventHandler("endpointchanged", $.proxy(this._recordEndPointChanged, this));
            this.historyManager.addEventHandler("labelchanged", $.proxy(this._recordLabelChanged, this));
            this.historyManager.addEventHandler("groupingchanged", $.proxy(this._recordGroupChanged, this));
        },

        _updatePoints: function (helper, startPoint, endPoint, isTarget) {
            var offset = new ej.datavisualization.Diagram.Point(endPoint.x - startPoint.x, endPoint.y - startPoint.y);
            if (!ej.datavisualization.Diagram.Geometry.isEmptyPoint(offset)) {
                helper._updateEndPoint(offset.x, offset.y, isTarget);
            }
        },

        _recordCollectionChanged: function (args) {
            this._clearSelection();
            this._isUndo = true;
            var i;
            var changeType = args.changeType;
            if (args.isUndo) {
                if (args.changeType == "insert")
                    changeType = "remove";
                else
                    changeType = "insert";
            }
            if (changeType == "insert") {
                if (!args.object.isPseudoGroup) {
                    if (!args.object.line) {
                        var port = null;
                        if (args.object.inEdges.length > 0) {
                            for (i = 0; i < args.object.inEdges.length; i++) {
                                this.nameTable[args.object.inEdges[i]].targetNode = args.object.name;
                                port = args.targetPorts[args.object.inEdges[i]];
                                if (port)
                                    this.nameTable[args.object.inEdges[i]].targetPort = port;
                            }
                        }
                        if (args.object.outEdges.length > 0) {
                            for (i = 0; i < args.object.outEdges.length; i++) {
                                this.nameTable[args.object.outEdges[i]].sourceNode = args.object.name;
                                port = args.sourcePorts[args.object.outEdges[i]];
                                if (port)
                                    this.nameTable[args.object.outEdges[i]].sourcePort = port;
                            }
                        }
                    }
                    if (args.object.isGroup)
                        this._addChildren(args.object, args.childTable);
                    this.add(args.object);
                    this.addSelection(args.object);
                }
                else {
                    delete this.nameTable["multipleSelection"];
                    var node, j;
                    var pseudoGroup = ej.datavisualization.Diagram.Group({ "name": "multipleSelection", isPseudoGroup: true });
                    for (i = 0; i < args.object.children.length; i++) {
                        pseudoGroup.children.push(args.object.children[i]);
                        node = args.childTable[args.object.children[i]];
                        node.parent = "";
                        if (node.isGroup)
                            this._addChildren(node, args.childTable);
                        this.add(args.childTable[args.object.children[i]]);
                    }
                    for (i = 0; i < pseudoGroup.children.length; i++) {
                        node = this.nameTable[pseudoGroup.children[i]];
                        if (!node.line) {
                            if (node.inEdges.length > 0) {
                                for (j = 0; j < node.inEdges.length; j++)
                                    this.nameTable[node.inEdges[j]].targetNode = node.name;
                            }
                            if (node.outEdges.length > 0) {
                                for (j = 0; j < node.outEdges.length; j++)
                                    this.nameTable[node.outEdges[j]].sourceNode = node.name;
                            }
                        }
                    }
                    this._clearSelection();
                    this.model.nodes.push(pseudoGroup);
                    pseudoGroup.offsetX = args.object.offsetX;
                    pseudoGroup.offsetY = args.object.offsetY;
                    pseudoGroup.height = args.object.height;
                    pseudoGroup.width = args.object.width;
                    pseudoGroup.rotateAngle = args.object.rotateAngle;
                    this.addSelection(pseudoGroup);
                    this.nameTable[pseudoGroup.name] = pseudoGroup;
                }
            }
            else if (changeType == "remove") {
                if (!args.object.isPseudoGroup) {
                    this._remove(args.object);
                }
                else {
                    for (i = 0; i < args.object.children.length; i++) {
                        this._remove(this.nameTable[args.object.children[i]]);
                    }
                }
            }
            this._isUndo = false;
        },

        _addChildren: function (group, childTable) {
            for (var i = 0; i < group.children.length; i++) {
                var node = childTable[group.children[i]];
                if (node.isGroup)
                    this._addChildren(node, childTable);
                else
                    this.nameTable[group.children[i]] = node;
            }
        },

        _updateRecordPinPoint: function (node, childTable, isMultipleSelection) {
            var object, i, item, objNode;
            // this._clearSelection();
            if (node.isPseudoGroup) {
                var undoObj = node;
                for (i = 0; i < node.children.length; i++) {
                    item = this.nameTable[node.children[i]];
                    objNode = childTable[node.children[i]];
                    if (objNode) {
                        if (!item.line) {
                            this._translate(item, objNode.offsetX - item.offsetX, objNode.offsetY - item.offsetY, this.nameTable);
                        } else {
                            var objLine = childTable[item.name];
                            item.line.startPoint = objLine.line.startPoint;
                            item.line.endPoint = objLine.line.endPoint;
                            item.line.points = objLine.line.points;
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(item, this);
                    }
                }
                if (this.selectionList[0]) {
                    if (this.selectionList[0].name === undoObj.name) {
                        this.selectionList[0].offsetX = undoObj.offsetX;
                        this.selectionList[0].offsetY = undoObj.offsetY;
                    }
                }
                ej.datavisualization.Diagram.SvgContext.updateSelector(undoObj, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            } else {
                if (node.line) {
                    if (isMultipleSelection) {
                        object = childTable[node.name];
                        node.line.startPoint = object.line.startPoint;
                        node.line.endPoint = object.line.endPoint;
                        node.line.points = object.line.points;
                        ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    } else {
                        this._clearSelection();
                        object = this._findConnector(node.name);
                        var obj;

                        if (node.targetNode) {
                            obj = this.nameTable[node.targetNode];
                            ej.datavisualization.Diagram.Util.removeItem(obj.inEdges, node);
                        }
                        if (node.sourceNode) {
                            obj = this.nameTable[node.sourceNode];
                            ej.datavisualization.Diagram.Util.removeItem(obj.outEdges, node);
                        }
                        if (node.targetNode) {
                            obj = this.nameTable[node.targetNode];
                            obj.inEdges.push(node.name);
                        }
                        if (node.sourceNode) {
                            obj = this.nameTable[node.sourceNode];
                            obj.outEdges.push(node.name);
                        }
                        object.targetNode = node.targetNode;
                        object.sourceNode = node.sourceNode;
                        object.targetPort = node.targetPort;
                        object.sourcePort = node.sourcePort;

                        object.line.startPoint = node.line.startPoint;
                        object.line.endPoint = node.line.endPoint;
                        object.line.points = node.line.points;
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                        ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                        this.addSelection(node);
                    }
                } else {
                    if (isMultipleSelection) {
                        object = childTable[node.name];
                        this._translate(node, object.offsetX - node.offsetX, object.offsetY - node.offsetY, childTable);
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                    } else {
                        this._clearSelection();
                        object = this._findNode(node.name);
                        this._translate(object, node.offsetX - object.offsetX, node.offsetY - object.offsetY, this.nameTable);
                        if (node.parent) {
                            ej.datavisualization.Diagram.Util._updateGroupBounds(this.nameTable[object.parent], this.nameTable);
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                        this.addSelection(object);
                    }
                }
            }
        },
        _recordPinPointChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            this._updateRecordPinPoint(node, childTable);
        },
        _updateRecordRotation: function (object, childTable) {
            var node, i, item, objNodeChild;
            if (object.isPseudoGroup) {
                node = this.nameTable[object.name];

                for (i = 0; i < object.children.length; i++) {
                    item = this.nameTable[object.children[i]];
                    objNodeChild = childTable[object.children[i]];
                    if (item) {
                        if (!item.line) {
                            if (objNodeChild) {
                                this._translate(item, objNodeChild.offsetX - item.offsetX, objNodeChild.offsetY - item.offsetY, this.nameTable);
                                this._rotate(item, objNodeChild.rotateAngle - item.rotateAngle, this.nameTable);
                            }
                        } else {
                            var objLine = childTable[item.name];
                            item.line.startPoint = objLine.line.startPoint;
                            item.line.endPoint = objLine.line.endPoint;
                            item.line.points = objLine.line.points;
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(item, this);
                    }
                }
                if (node) {
                    var newangle = object.rotateAngle - node.rotateAngle;
                    node.rotateAngle += newangle;
                    if (this.selectionList[0])
                        this.selectionList[0].rotateAngle = node.rotateAngle;
                }
                ej.datavisualization.Diagram.SvgContext.updateSelector(object, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            }
            else {
                if (object) {
                    this._clearSelection();
                    node = this._findNode(object.name);
                    this._rotate(node, object.rotateAngle - node.rotateAngle, this.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    this.addSelection(node);
                }
            }
        },
        _recordSizeChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            this._updateRecordSize(node, childTable);
        },
        _updateRecordSize: function (object, childTable) {
            var node, i, childObj;
            if (object.isGroup || object.isPseudoGroup) {
                if (object.isPseudoGroup)
                    this.nameTable[object.name] = object;
                node = this._findNode(object.name);
                for (i = 0; i < node.children.length; i++) {
                    var item = this.nameTable[object.children[i]];
                    childObj = childTable[object.children[i]];
                    if (childObj) {
                        if (!item.line) {
                            this._translate(item, childObj.offsetX - item.offsetX, childObj.offsetY - item.offsetY, this.nameTable);
                            this._scale(item, (childObj.width / item.width), (childObj.height / item.height), ej.datavisualization.Diagram.Point(item.offsetX, item.offsetY), this.nameTable);
                            ej.datavisualization.Diagram.DiagramContext.update(item, this);
                        } else {
                            var kk = childTable[item.name];
                            item.line.startPoint = kk.line.startPoint;
                            item.line.endPoint = kk.line.endPoint;
                            item.line.points = kk.line.points;
                            ej.datavisualization.Diagram.DiagramContext.update(item, this);
                        }
                    }
                }
                //if (node.name === object.name) {
                node.offsetX = object.offsetX;
                node.offsetY = object.offsetY;
                node.width = object.width;
                node.height = object.height;
                //}
                ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
            }
            else {
                if (!object.line) {
                    node = this._findNode(object.name);
                    this._translate(node, object.offsetX - node.offsetX, object.offsetY - node.offsetY, this.nameTable);
                    this._scale(node, object.width / node.width, object.height / node.height, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                }
                else {

                }
            }

        },
        _recordRotationChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            this._updateRecordRotation(node, childTable);
        },
        _recordEndPointChanged: function (args) {

            var connector, currentObject, previousObject, obj;
            if (args._isUndo) {
                connector = currentObject = args.undoObject;
                previousObject = args.redoObject;
            }
            else {
                connector = currentObject = args.redoObject;
                previousObject = args.undoObject;
            }
            if (connector.parent) {

                connector = this._findChildren(connector.parent, connector.name);
            }
            else
                connector = this._findConnector(connector.name);

            if (previousObject.targetNode) {
                obj = this.nameTable[previousObject.targetNode];
                ej.datavisualization.Diagram.Util.removeItem(obj.inEdges, previousObject);
            }
            if (previousObject.sourceNode) {
                obj = this.nameTable[previousObject.sourceNode];
                ej.datavisualization.Diagram.Util.removeItem(obj.outEdges, previousObject);
            }
            if (currentObject.targetNode) {
                obj = this.nameTable[currentObject.targetNode];
                obj.inEdges.push(currentObject.name);
            }
            if (currentObject.sourceNode) {
                obj = this.nameTable[currentObject.sourceNode];
                obj.outEdges.push(currentObject.name);
            }
            connector.targetNode = currentObject.targetNode;
            connector.sourceNode = currentObject.sourceNode;
            connector.targetPort = currentObject.targetPort;
            connector.sourcePort = currentObject.sourcePort;
            connector.line.startPoint = currentObject.line.startPoint;
            connector.line.endPoint = currentObject.line.endPoint;
            connector.line.points = currentObject.line.points;
            if (connector.line.type === "bezier") {
                connector.line._point1 = currentObject.line._point1;
                connector.line._point2 = currentObject.line._point2;
            }
            this._updateEdges(connector);
            this._dock(connector, this.nameTable);
            ej.datavisualization.Diagram.DiagramContext.update(connector, this);
            this._updateSelectionHandle();
            ej.datavisualization.Diagram.SvgContext.updateSelector(connector, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
        },

        _recordLabelChanged: function (args) {
            var node = this.nameTable[args.object.name];
            if (args.object.shape && args.object.shape.type === "text") {
                node.shape.textBlock.text = args.label;
                ej.datavisualization.Diagram.DiagramContext.updateTextBlock(node, node.shape.textBlock, this);
            } else {
                node.labels[0].text = args.label;
                ej.datavisualization.Diagram.DiagramContext.updateLabel(node, node.labels[0], this);
            }
        },

        _recordGroupChanged: function (args) {
            this._clearSelection();
            var actionType = args.actionType;
            if (args.isUndo) {
                if (args.actionType === "group")
                    actionType = "ungroup";
                if (args.actionType === "ungroup")
                    actionType = "group";
            }
            var selectionList = args.object.children;
            if (actionType === "group") {
                var group = new ej.datavisualization.Diagram.Group({ name: args.object.name });
                for (i = 0; i < selectionList.length; i++) {
                    group.children.push(selectionList[i]);
                    this.nameTable[selectionList[i]].parent = group.name;
                    $("#" + selectionList[i])[0].parentNode.removeChild($("#" + selectionList[i])[0]);
                }
                //group.name = args.object.name;
                this.add(group);
                this._addSelection(group);
            }
            else {
                var i, node;
                node = args.object;
                if ($("#" + node.name)[0])
                    $("#" + node.name)[0].parentNode.removeChild($("#" + node.name)[0]);
                for (i = 0; i < node.children.length; i++) {
                    var childNode = this.nameTable[node.children[i]];
                    childNode.parent = "";
                    this._isUndo = true;
                    if (childNode.line) {
                        ej.datavisualization.Diagram.DiagramContext.renderConnector(childNode, this);
                    }
                    else if (!childNode.isGroup) {
                        ej.datavisualization.Diagram.DiagramContext.renderNode(childNode, this);
                    } else {
                        ej.datavisualization.Diagram.DiagramContext.renderGroup(childNode, this);
                    }
                    this._isUndo = false;
                }
                ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, this._findNode(node.name));
            }
        },

        _svgdrop: function (evt, ui) {
            var args = {};
            var e = evt.originalEvent;
            if (e.preventDefault)
                e.preventDefault();
            else
                e.returnValue = false;
            var scale = this.model.zoomFactor;
            var offset = $("#" + this.element[0].id).offset();
            var coor = this._isTouchEvent(evt);
            var pageX;
            var pageY;
            if (coor) {
                pageX = coor.pageX;
                pageY = coor.pageY;
            }
            else {
                pageX = evt.pageX;
                pageY = evt.pageY;
            }
            var x = pageX + this._hScrollOffset - offset.left;
            var y = pageY + this._vScrollOffset - offset.top;
            var symbolPaletteId = ui.helper[0].getAttribute("paletteId");
            var symbolPalette = $("#" + symbolPaletteId).ejSymbolPalette("instance");
            if (symbolPaletteId) {
                var paletteItem = $.extend(true, {}, symbolPalette.selectedItem);
                paletteItem.name += ej.datavisualization.Diagram.Util.randomId();
                if (paletteItem.line) {
                    var connector = paletteItem;
                    if (connector.line.points) {
                        var points = connector.line.points;
                        var bounds = ej.datavisualization.Diagram.Geometry.rect(points);
                        for (var i = 0, len = points.length; i < len; ++i) {
                            var point = ej.datavisualization.Diagram.Geometry.translate(points[i], -bounds.x, -bounds.y);
                            point = ej.datavisualization.Diagram.Geometry.translate(point, x, y);
                            points[i] = point;
                            var endpoint = new ej.datavisualization.Diagram.Point(point.x / scale, point.y / scale);
                            if (i === 0)
                                this._setEndPoint(connector, endpoint, false);
                            if (i === points.length - 1)
                                this._setEndPoint(connector, endpoint, true);

                        }
                    }
                    args = { element: paletteItem };
                    this._raiseDropEvent(args);
                    if (!args.cancel) {
                        this.add(paletteItem);
                    }
                }
                else {

                    var palNameTable = $.extend(true, {}, symbolPalette.nameTable);
                    paletteItem.offsetX = x / scale;
                    paletteItem.offsetY = y / scale;
                    if (paletteItem.isGroup) {
                        for (var j = 0; j < paletteItem.children.length; j++) {
                            var newObj = $.extend(true, {}, palNameTable[paletteItem.children[j]]);
                            newObj.parent = paletteItem.name;
                            newObj.name = paletteItem.name + newObj.name;
                            paletteItem.children[j] = newObj.name;
                            this.nameTable[newObj.name] = newObj;
                            this.model.nodes.push(newObj);
                            ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, newObj);
                        }
                        paletteItem.height = paletteItem.width = 0;
                        this._updateChildBounds(paletteItem, this.nameTable);
                    }
                    args = { element: paletteItem };
                    this._raiseDropEvent(args);
                    if (!args.cancel) {
                        this.add(paletteItem);
                    }
                }
                this.scrollToNode(paletteItem);
                if (paletteItem.labels.length > 0 && paletteItem.labels[0].mode === "edit") {
                    this._isEditing = true;
                    this.startLabelEdit(paletteItem, paletteItem.labels[0]);
                }
                else
                    this.element[0].focus();
            }
            else {
                var node = null;
                node = this._findNodeUnderMouse(evt);
                args = { element: ui.helper, e: evt, draggable: ui.draggable, targetNode: node };
                this._raiseDropEvent(args);
            }
        },

        _isTouchEvent: function (evt) {
            if (evt.type == "touchmove" || evt.type == "touchstart" || evt.type == "touchend") {
                return evt.originalEvent.changedTouches[0];
            }
            return evt;
        },

        _raiseDropEvent: function (args) {
            this._trigger("drop", args);
        },

        _documentmouseup: function (evt) {
            if (this.activeTool && this.activeTool.inAction && !(this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) && !(this.activeTool instanceof ej.datavisualization.Diagram.TextTool)) {
                this.activeTool.mouseup(evt);
            }
        },
        //#endregion

        //#region Helper methods
        _updateEdges: function (connector) {
            var node;
            if (ej.datavisualization.Diagram.Util.isTargetConnected(connector)) {
                node = this.nameTable[connector.targetNode];
                if (node && node.inEdges.indexOf(connector.name) == -1)
                    node.inEdges.push(connector.name);
            }
            if (ej.datavisualization.Diagram.Util.isSourceConnected(connector)) {
                node = this.nameTable[connector.sourceNode];
                if (node && node.outEdges.indexOf(connector.name) == -1)
                    node.outEdges.push(connector.name);
            }
        },

        _updateChildrenEdges: function (object) {
            for (var i = 0; i < object.children.length; i++) {
                var child = object.children[i];
                if (child.line) {
                    this._updateEdges(child);
                    this._dock(child, this.nameTable);
                }
                else if (child.isGroup) {
                    this._updateChildrenEdges(child);
                }
            }
        },
        _updateParent: function (object) {
            for (var i = 0; i < object.children.length; i++) {
                var child = ej.datavisualization.Diagram.Node(this.nameTable[object.children[i]]);
                if (child && child.isGroup) {
                    this._updateParent(child);
                }
                else if (child) {
                    child.parent = object.name;
                    this.nameTable[child.name] = child;
                }
            }
        },
        _findPortAtPoint: function (point, node) {
            var ports;
            var port;
            var location;
            var size, pt, x, y;
            var bounds;
            if (node) {
                bounds = ej.datavisualization.Diagram.Util.bounds(node, true);
                ports = node.ports;
                var matrix;
                for (var i = 0, len = ports.length; i < len; ++i) {
                    port = ports[i];
                    size = ej.datavisualization.Diagram.Size(port.size, port.size);
                    pt = ej.datavisualization.Diagram.Util._getPortPosition(port, bounds);
                    matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, node.rotateAngle, node.offsetX, node.offsetY);
                    pt = ej.Matrix.transform(matrix, pt);
                    x = pt.x - port.size / 2;
                    y = pt.y - port.size / 2;
                    location = ej.datavisualization.Diagram.Rectangle(x, y, size.width, size.height);
                    if (ej.datavisualization.Diagram.Geometry.containsPoint(location, point)) {
                        return port;
                    }
                }

            }
            return null;
        },

        _findLabelAtPoint: function (point, node) {
            var labels, label = null;
            var location;
            var size, pt, x, y, width, height;
            var bounds, textBounds, matrix;
            if (node) {
                bounds = ej.datavisualization.Diagram.Util.bounds(node);
                labels = node.labels;
                if (labels.length > 0) {
                    label = labels[0];
                    for (var i = 0, len = labels.length; i < len; i++) {
                        label = labels[i];
                        textBounds = this._svg.getElementById(node.name + "_" + label.name).getBBox();
                        width = textBounds.width == 0 ? bounds.width : textBounds.width;
                        height = textBounds.height == 0 ? label.fontSize : textBounds.height;
                        size = ej.datavisualization.Diagram.Size(width, height);
                        pt = ej.datavisualization.Diagram.Util._getLabelPosition(label, bounds);
                        pt.x = bounds.x + pt.x;
                        pt.y = bounds.y + pt.y;
                        matrix = ej.Matrix.identity();
                        if (!node.line)
                            ej.Matrix.rotate(matrix, node.rotateAngle, node.offsetX, node.offsetY);
                        else
                            ej.Matrix.rotate(matrix, 0, bounds.x + bounds.width / 2, bounds.y + bounds.height / 2);
                        pt = ej.Matrix.transform(matrix, pt);
                        x = pt.x - size.width / 2;
                        y = pt.y - size.height / 2;
                        location = ej.datavisualization.Diagram.Rectangle(x, y, size.width, size.height);
                        if (ej.datavisualization.Diagram.Geometry.containsPoint(location, point)) {
                            break;
                        }
                    }
                }
            }
            return label;
        },

        _findNode: function (id) {
            return this.nameTable[id];
        },

        _findPort: function (node, portId) {
            var ports = node.ports;
            for (var i = 0, len = ports.length; i < len; i++) {
                if (ports[i].name === portId) {
                    return ports[i];
                }
            }
            return null;
        },

        _findConnector: function (id) {
            return this.nameTable[id];
        },

        _findChildren: function (group, name) {
            var child, innerchild;
            for (var i = 0; i < group.children.length; i++) {
                child = this.nameTable[group.children[i]];
                if (name == child.name) {
                    return child;
                }
                if (child.isGroup) {
                    innerchild = this._findChildren(child, name);
                    if (innerchild) return innerchild;
                }
            }
            return null;
        },

        _delete: function () {
            if (this.selectionList[0]) {
                var childTable = {};
                childTable = this._getChildTable(this.selectionList[0], childTable);
                if (!this._isUndo) {
                    var sourcePorts = {}, targetPorts = {}, connector, count, i;
                    if (!this.selectionList[0].line) {
                        if (this.selectionList[0].outEdges.length > 0) {
                            count = this.selectionList[0].outEdges.length;
                            for (i = 0; i < count; i++) {
                                connector = this.nameTable[this.selectionList[0].outEdges[i]];
                                if (connector.sourcePort)
                                    sourcePorts[connector.name] = connector.sourcePort;
                            }

                        }
                        if (this.selectionList[0].inEdges.length > 0) {
                            count = this.selectionList[0].inEdges.length;
                            for (i = 0; i < count; i++) {
                                connector = this.nameTable[this.selectionList[0].inEdges[i]];
                                if (connector.targetPort)
                                    targetPorts[connector.name] = connector.targetPort;
                            }

                        }
                    }
                    var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, this.selectionList[0]), childTable: jQuery.extend(true, {}, childTable), sourcePorts: sourcePorts, targetPorts: targetPorts, changeType: "remove" };
                    this.addHistoryEntry(entry);
                }
                if (this.selectionList.length > 0) {
                    var obj = this.selectionList[0];
                    if (obj.isPseudoGroup) {
                        var children = obj.children;
                        for (var i = children.length - 1; i >= 0; i--) {
                            this._remove(this.nameTable[children[i]]);
                            this._isUndo = true;
                        }
                        this._isUndo = false;
                    }
                    else {
                        if (this._nodeToHit === obj)
                            this._nodeToHit = null;
                            this._remove(obj);
                    }
                }
                this._clearSelection();
            }
        },

        _remove: function (obj) {
            if (obj) {
                if (obj.line) var type = "connector";
                else type = "node";
                var args = { changeType: "remove", element: obj, cancel: false };
                this._raiseEvent(type + "CollectionChange", args);
                if (!args.cancel) {
                    if (ej.datavisualization.Diagram.Util.canDelete(obj)) {
                        var name = obj.name;
                        if (!obj.line) {
                            this._disConnect(obj);
                            ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, this.nameTable[obj.name]);
                        } else {
                            this._removeEdges(obj);
                            obj.sourceNode = obj.sourcePort = obj.targetNode = obj.targetPort = null;
                            ej.datavisualization.Diagram.Util.removeItem(this.model.connectors, this.nameTable[obj.name]);
                        }
                        if (obj.shape || obj.line) {
                            ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(this._spatialSearch, this._spatialSearch.quadTable[obj.name], obj);
                            ej.datavisualization.Diagram.SpatialUtil._updateBounds(this, this._spatialSearch, obj);
                        }
                        if (obj.parent) {
                            var parent = this.nameTable[obj.parent];
                            if (parent && parent.isGroup) {
                                ej.datavisualization.Diagram.Util.removeItem(parent.children, obj.name);
                                ej.datavisualization.Diagram.Util._updateGroupBounds(parent, this.nameTable);
                            }
                        }
                        delete this.nameTable[name];
                        var element = this._svg.getElementById(obj.name);
                        if (ej.browserInfo().name === "msie") {
                            if (obj.shape && obj.shape.html && element) {
                                var htmlelement = document.getElementById(obj.name + "_parentdiv");
                                htmlelement.parentNode.removeChild(htmlelement);
                            } else if (obj.isGroup)
                                this._checkForHtmlNode(obj);
                        }
                        if (obj.isGroup && !obj.isPseudoGroup) {
                            this._removeChildren(obj);
                        }
                        this._removeElement(obj);
                        if (element)
                            element.parentNode.removeChild(element);
                        if (this.selectionList[0]) {
                            this._clearSelection();
                        }
                    }
                }
            }
        },
        _removeElement: function (element) {
            for (var i = 1; i < this._views.length; i++) {
                var view = this._views[i];
                this._views[view].context.removeChild(element, this._views[view]);
            }

        },
        _disConnect: function (node) {
            var edges;
            var connector;
            var i, len;
            if (node.inEdges.length > 0) {
                edges = node.inEdges;
                for (i = 0, len = edges.length; i < len; i++) {
                    connector = this.nameTable[edges[i]];
                    connector.targetNode = null;
                    connector.targetPort = null;
                }
            }
            if (node.outEdges.length > 0) {
                edges = node.outEdges;
                for (i = 0, len = edges.length; i < len; i++) {
                    connector = this.nameTable[edges[i]];
                    connector.sourceNode = null;
                    connector.sourcePort = null;
                }
            }
        },

        _removeEdges: function (connector) {
            if (connector.targetNode) {
                ej.datavisualization.Diagram.Util.removeItem(this.nameTable[connector.targetNode].inEdges, connector.name);
            }
            if (connector.sourceNode) {
                ej.datavisualization.Diagram.Util.removeItem(this.nameTable[connector.sourceNode].outEdges, connector.name);
            }
        },

        _selectionContains: function (node) {
            if (this._hasSelection())
                for (var i = 0; i < this.selectionList.length; i++) {
                    if (node.name === this.selectionList[i].name)
                        return true;
                }
            return false;
        },

        _addSelection: function (selectedShape) {
            if (selectedShape && ej.datavisualization.Diagram.Util.canSelect(selectedShape)) {
                if (!this._selectionContains(selectedShape)) {
                    this.selectionList.push(selectedShape);
                    var args = { changeType: "insert", element: selectedShape, cancel: false };
                    this._raiseEvent("selectionChange", args);

                    if (!args.cancel) {
                        ej.datavisualization.Diagram.SvgContext.renderSelector(selectedShape, this._svg, this._adornerLayer, this.model.zoomFactor,
                            this.model.selectorConstraints);
                        if ((this.model.userHandles !== null && this.model.userHandles.length > 0)) {
                            var isMultipleSelection = false;
                            if (selectedShape.isPseudoGroup)
                                isMultipleSelection = true;
                            if (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                                ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.userHandles, selectedShape, this._svg, isMultipleSelection, this.model.zoomFactor, this._adornerLayer);
                        }
                    }
                    else {
                        ej.datavisualization.Diagram.Util.removeItem(this.selectionList, selectedShape);
                    }
                }
            }
        },
        _raiseEvent: function (type, args) {
            this._trigger(type, args);
            return args;
        },
        _clearSelection: function () {
            if (this._isEditing && this.selectionList.length > 0) {
                this._endEdit();
            }
            var args = { changeType: "remove", element: this.selectionList, cancel: false };
            this._raiseEvent("selectionChange", args);
            if (!args.cancel) {
                if (this.selectionList[0] && this.selectionList[0].isPseudoGroup) {
                    ej.datavisualization.Diagram.Util.removeItem(this.model.nodes, this.selectionList[0]);
                    delete this.nameTable[this.selectionList[0].name];
                }
                ej.datavisualization.Diagram.Util.clear(this.selectionList);
                ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);

            }
        },

        _updateSelectionHandle: function (isDragging) {
            if (this.selectionList.length > 0) {
                var shape = this.nameTable[this.selectionList[0].name];
                ej.datavisualization.Diagram.SvgContext.updateSelector(shape, this._svg, this.model.zoomFactor, this, this.model.selectorConstraints);
                if ((this.model.userHandles !== null && this.model.userHandles.length > 0)) {
                    var isMultipleSelection = false;
                    if (shape.isPseudoGroup)
                        isMultipleSelection = true;
                    if (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                        ej.datavisualization.Diagram.SvgContext.updateUserHandles(this.model.userHandles, shape, this._svg, isMultipleSelection, isDragging, this.model.zoomFactor);
                }
            }
        },

        _hasSelection: function () {
            return this.selectionList.length > 0;
        },

        _checkToolToActivate: function (evt, node, point) {
            var success = false;
            if (node) {
                if (this._selectionContains(node)) {
                    if (node.line) {
                        success = this._canActivateEndPointTool(evt, node, point);
                    }
                    else {
                        success = this._canActivateResizeTool(evt, node, point);
                        if (!success) {
                            success = this._canActivateRotateTool(evt, node, point);
                        }
                    }
                    if (!success) {
                        success = this._canActivateUserHandle(evt, node, point);
                    }
                    if (!success) {
                        success = this._canActivateMoveTool(evt, node, point);
                    }
                }
                else {
                    success = this._canActivateMoveTool(evt, node, point);
                }
            }
            if (!success) {
                this._toolToActivate = "select";
                this._currentCursor = "default";
            }
            if (this._toolToActivate != "rotate") {
                this._svg.document.removeAttribute("class");
            }
            return success;
        },

        _canActivateUserHandle: function (evt) {
            if (this._isUserHandle(evt)) {
                var handleName = $(evt.target).parents("g").first().context.id.split("_")[0];
                this._toolToActivate = handleName;
                this._currentCursor = this.tools[this._toolToActivate].cursor;
                return true;
            }
            return false;
        },

        _canActivateEndPointTool: function (evt, connector) {
            if (connector) {
                var endPointHandle = evt.target.getAttribute("class");
                if ((endPointHandle === "targetEndPoint" && ej.datavisualization.Diagram.Util.canDragTargetEnd(connector)) || (endPointHandle === "sourceEndPoint" && ej.datavisualization.Diagram.Util.canDragSourceEnd(connector)) ||
                (endPointHandle === "bezierpoint1" || endPointHandle === "bezierpoint2") && ej.datavisualization.Diagram.Util.canDragSegmentThumbs(connector)) {
                    this._toolToActivate = "endPoint";
                    this._currentCursor = "move";
                    return true;
                }
            }
            return false;
        },

        _canActivateResizeTool: function (evt, node) {
            if (ej.datavisualization.Diagram.Util.canResize(node) && (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.Resizer)) {
                var dir = evt.target.getAttribute("class");
                if (dir === "nw-resize" || dir === "n-resize" || dir === "ne-resize" || dir === "w-resize" || dir === "e-resize" || dir === "sw-resize" || dir === "s-resize" || dir === "se-resize") {
                    this._toolToActivate = "resize";
                    this._currentCursor = dir;
                    return true;
                }
            }
            return false;
        },

        _canActivateMoveTool: function (evt, node) {
            var findNode = this._findNodeUnderMouse(evt);
            if (findNode && findNode.name === node.name) {
                if (ej.datavisualization.Diagram.Util.canMove(node)) {
                    this._toolToActivate = "move";
                    if (this.selectionList.length > 0 && (this._selectionContains(node) || (this.selectionList[0].children && this._findChildren(this.selectionList[0], node.name)))) {
                        this._currentCursor = "move";
                    }
                    else {
                        this._currentCursor = "default";
                    }
                    return true;
                }
            }
            return false;
        },

        _canActivateRotateTool: function (evt, node) {
            if (ej.datavisualization.Diagram.Util.canRotate(node) && (this.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.Rotator)) {
                var rotateHandle = evt.target.getAttribute("class");
                if (rotateHandle === "rotate") {
                    this._toolToActivate = "rotate";
                    this._svg.document.setAttribute("class", "svg-rotate");
                    this._currentCursor = "";
                    return true;
                }
            }
            return false;
        },

        _canActivatePivotTool: function (evt) {
            var pivotHandle = evt.target.getAttribute("class");
            if (pivotHandle === "pivot") {
                this._toolToActivate = "pivot";
                this._currentCursor = "default";
                return true;
            }

            return false;
        },

        _updateCursor: function () {
            this._svg.document.style.cursor = this._currentCursor;
        },

        _getResizeCursor: function (resizeDirection) {
            var cursor = "default";
            switch (resizeDirection) {
                case "topleft": cursor = "nw-resize";
                    break;
                case "topcenter": cursor = "n-resize";
                    break;
                case "topright": cursor = "ne-resize";
                    break;
                case "middleleft": cursor = "w-resize";
                    break;
                case "middleright": cursor = "e-resize";
                    break;
                case "bottomleft": cursor = "sw-resize";
                    break;
                case "bottomcenter": cursor = "s-resize";
                    break;
                case "bottomright": cursor = "se-resize";
                    break;
            }
            return cursor;
        },

        _startEdit: function (shape) {
            var label;
            var centerX, centerY;
            var bbox;
            var nodeBounds;
            var bounds;
            var curZoomfactor;
            if (shape.shape && shape.shape.type === "text") {
                if (this._svg.getElementById(shape.name + "_shape") !== null)
                    bbox = this._svg.getElementById(shape.name + "_shape").getBBox();
                else
                    bbox = { x: shape.offsetX - shape.width / 2, y: shape.offsetY - shape.height / 2, width: shape.width, height: shape.height };
                label = shape.shape.textBlock;
                if (label) {
                    nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
                    bounds = new ej.datavisualization.Diagram.Rectangle(bbox.x - label.fontSize, bbox.y - label.fontSize, bbox.width + label.fontSize / 2, bbox.height + label.fontSize / 2);
                    curZoomfactor = this.model.zoomFactor;
                    centerX = shape.offsetX;
                    centerY = shape.offsetY;
                    if (bbox.width === 0 || bbox.height === 0) {
                        bbox = ej.datavisualization.Diagram.Util.bounds(shape);
                        bounds.width = bbox.width == 0 ? 50 : nodeBounds.width * curZoomfactor;
                        bounds.x = (centerX * curZoomfactor - bounds.width / 2 * curZoomfactor) - this._hScrollOffset;

                        bounds.height = label.fontSize;
                        bounds.y = (centerY * curZoomfactor - bounds.height / 2 * curZoomfactor) - this._vScrollOffset;
                    }
                    else {
                        bounds.width = 50;
                        bounds.height = label.fontSize;
                        bounds.x = (centerX * curZoomfactor - (bounds.width / 2 * curZoomfactor)) - this._hScrollOffset;
                        bounds.y = (centerY * curZoomfactor - (bounds.height / 2 * curZoomfactor)) - this._vScrollOffset;
                    }
                    this._boundingBox = bounds;
                    this._createEditBox(label, bounds.x, bounds.y, bounds.width, bounds.height, shape);
                    this._isEditing = true;
                }
            }
            else {
                if (shape.labels.length > 0) {
                    if (this.activeTool.name === "textTool") {
                        label = this.activeTool.getLabelUnderMouse();
                        if (label)
                            label = shape.labels[0];
                    }
                    else
                        label = shape.labels[0];
                }
                else {
                    var mNode = this._findNode(shape.name);
                    label = new ej.datavisualization.Diagram.Label({ "name": "label" + ej.datavisualization.Diagram.Util.randomId() });
                    shape.labels.push(label);
                    var parent = (mNode !== shape) ? mNode : null;
                    ej.datavisualization.Diagram.DiagramContext.addNodeLabel(shape, label, parent, diagram);
                    if (this.activeTool.name === "textTool")
                        this.activateTool.activeLabel = label;
                }
                if (label && !label.readOnly) {
                    bbox = this._svg.getElementById(shape.name + "_" + label.name).getBBox();
                    nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
                    bounds = new ej.datavisualization.Diagram.Rectangle(bbox.x, bbox.y, bbox.width, bbox.height);
                    curZoomfactor = this.model.zoomFactor;
                    if (shape.line) {
                        centerX = nodeBounds.x + nodeBounds.width / 2;
                        centerY = nodeBounds.y + nodeBounds.height / 2;
                    }
                    else {
                        centerX = shape.offsetX;
                        centerY = shape.offsetY;
                    }
                    if (bbox.width === 0 || bbox.height === 0) {
                        bbox = ej.datavisualization.Diagram.Util.bounds(shape);
                        if (!shape.shape) {
                            bounds.width = bbox.width < 50 ? 50 : nodeBounds.width * curZoomfactor;
                            bounds.x = (centerX * curZoomfactor - bounds.width / 2 * curZoomfactor) - this._hScrollOffset;
                        }
                        else {
                            bounds.width = bbox.width < 50 ? 50 : (nodeBounds.width * curZoomfactor);
                            bounds.x = (centerX * curZoomfactor - bounds.width / 2) - this._hScrollOffset;
                        }
                        bounds.height = label.fontSize;
                        bounds.y = (centerY * curZoomfactor - bounds.height / 2 * curZoomfactor) - this._vScrollOffset;
                    }
                    else {
                        bounds.x = (centerX * curZoomfactor - (bounds.width / 2 * curZoomfactor)) - this._hScrollOffset;
                        bounds.y = (centerY * curZoomfactor - (bounds.height / 2 * curZoomfactor)) - this._vScrollOffset;
                    }
                    this._boundingBox = bounds;
                    this._createEditBox(label, bounds.x, bounds.y, bounds.width, bounds.height, shape);
                    this._isEditing = true;
                }
            }
        },

        _createEditBox: function (label, x, y, width, height, shape) {
            var nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var div = document.createElement("div");

            var attr = {
                "id": this.element[0].id + "_editBoxDiv",
                "class": "edit",
                "style": "top:" + y + "px;left:" + x + "px;width:" + width + "px;height:" + height + "px;" +
                    "font-family:" + label.fontFamily + ";font-size:" + label.fontSize + "px;min-width: 50px;min-height:" + label.fontSize + "px;",
            };
            ej.datavisualization.Diagram.Util.attr(div, attr);
            var textBox = document.createElement("textarea");
            attr = {
                "id": this.element[0].id + "_editBox",
                "class": "editBox",
                "style": "font-size:" + label.fontSize + "px;font-family:" + label.fontFamily + ";min-height:" + label.fontSize + "px;line-height:" + label.fontSize + "px;",
                "nodeWidth": nodeBounds.width, "nodeHeight": nodeBounds.height, "fontSize": label.fontSize, "nodeOffsetX": shape.offsetX, "nodeOffsetY": shape.offsetY, "containerName": shape.name
            };
            ej.datavisualization.Diagram.Util.attr(textBox, attr);
            textBox.value = label.text;
            div.appendChild(textBox);
            $(this._canvas).append(div);

            if (label.text !== "") {
                this._updateEditor(null, div, textBox, nodeBounds.width, label.fontSize);
            }
            this._on($(textBox), "focusout", this._editboxfocusout);
            this._on($(textBox), "keyup", this._editBoxKeyUp);
            this._on($(textBox), "input", this._editBoxTextChange);
            textBox.focus();
            textBox.select();
        },

        _editBoxKeyUp: function (evt) {
            this._updateLabelPosition(evt);
        },

        _editBoxTextChange: function (evt) {
            this._updateLabelPosition(evt);
        },

        _updateEditBox: function (x, y) {
            var editBox = document.getElementById(this.element[0].id + "_editBoxDiv");
            if (editBox) {
                editBox.style.left = editBox.offsetLeft - x + "px";
                editBox.style.top = editBox.offsetTop - y + "px";
            }
        },

        _editboxfocusout: function () {
            this._endEdit();
        },

        _updateLabelPosition: function (evt) {
            var minWidth = 50;
            var curZoomfactor = this.model.zoomFactor;
            var parentBoundary = this._boundingBox;
            var fontSize = Number(evt.target.getAttribute("fontSize"));
            var nodeWidth = Number(evt.target.getAttribute("nodeWidth"));
            var conCenterX = parentBoundary.x + (parentBoundary.width / 2);
            var conCenterY = parentBoundary.y + (parentBoundary.height / 2);
            var bounds = this._textLength(evt);

            var width;
            if (bounds.width === 0) {
                width = parentBoundary.width < minWidth ? minWidth : parentBoundary.width;
                evt.target.parentNode.style.width = width + "px";
                evt.target.parentNode.style.left = conCenterX - width / 2 + "px";
            }
            else {
                if (bounds.width <= (nodeWidth * curZoomfactor))
                    width = bounds.width < minWidth ? minWidth : bounds.width;
                else
                    width = nodeWidth < minWidth ? minWidth : (nodeWidth * curZoomfactor);
                evt.target.parentNode.style.width = width + "px";
                evt.target.parentNode.style.left = conCenterX - (width / 2) + "px";
            }
            if (bounds.height === 0) {
                evt.target.style.height = fontSize + "px";
                evt.target.parentNode.style.top = conCenterY - fontSize / 2 + 'px';
            }
            else {
                this._updateEditor(evt, evt.target.parentNode, evt.target, nodeWidth, fontSize);
            }
        },

        _updateEditor: function (evt, div, textBox, nodeWidth, fontSize) {
            var offsetX, offsetY;
            var elHeight;
            var bounds = this._textLength(evt);
            var curZoomfactor = this.model.zoomFactor;
            var minWidth = 50;
            var x = this._boundingBox.x;
            var y = this._boundingBox.y;
            var width = this._boundingBox.width;
            var height = this._boundingBox.height;

            var str = textBox.value;
            var line = str.split('\n');

            var temp = (nodeWidth * curZoomfactor) < bounds.width ? (nodeWidth * curZoomfactor) : bounds.width;
            var elWidth = temp < minWidth ? minWidth : temp;
            div.style.width = elWidth + "px";
            if (evt)
                offsetX = (elWidth - width) / 2;
            else
                offsetX = (elWidth - width * curZoomfactor) / 2;
            div.style.left = x - offsetX + "px";

            if (line.length > 1 || bounds.width >= nodeWidth) {
                if (ej.browserInfo().name === "mozilla")
                    elHeight = textBox.scrollHeight;
                else
                    elHeight = textBox.scrollHeight - 4;
                textBox.style.height = 'auto';
            }
            else
                elHeight = fontSize;

            textBox.style.height = elHeight + "px";
            if (evt)
                offsetY = (elHeight - height) / 2;
            else
                offsetY = (elHeight - height * curZoomfactor) / 2;
            this._boundingBox = new ej.datavisualization.Diagram.Rectangle(x - offsetX, y - offsetY, elWidth, elHeight);
            div.style.top = y - offsetY + "px";
        },

        _textLength: function (evt) {
            var temp = document.createElement("div");
            var textElement = document.getElementById(this.element[0].id + "_editBox");
            var attr = {
                "id": this.element[0].id + "_editBoxHiddenDiv",
                "style": "position:absolute; width:" + textElement.width + "px;height:" + textElement.height + "px;" +
                         "font-size:" + textElement.style.fontSize + "px;font-family:" + textElement.style.fontFamily + ";padding: 4px;word-wrap: break-word;white-space:pre-wrap;",
            };
            ej.datavisualization.Diagram.Util.attr(temp, attr);
            if (evt) {
                temp.innerHTML = evt.target.value;
            } else {
                temp.innerHTML = textElement.value;
            }
            document.body.appendChild(temp);
            var bounds = temp.getBoundingClientRect();
            document.body.removeChild(temp);
            return bounds;
        },

        _endEdit: function () {
            var args, entry;
            var editBox = document.getElementById(this.element[0].id + "_editBox");
            if (editBox) {
                var shape = this._findNode(editBox.getAttribute("containerName"));;
                if (this.activeTool.name === "textTool")
                    shape = this.activeTool.selectedObject;
                else if (!shape) {
                    for (var i = 0; i < this.selectionList.length; i++) {
                        var mNode = this.selectionList[i];
                        if (typeof mNode.labels.length != "undefined" && mNode.labels.length > 0 && mNode.labels[0].mode === ej.datavisualization.Diagram.LabelEditMode.Edit)
                            shape = this.selectionList[i];
                    }
                }

                if (shape) {
                    this._isEditing = false;
                    args = this._trigger("textChange", { element: shape, value: editBox.value });

                    if (!args) {
                        if (shape && shape.shape !== undefined && shape.shape.type === "text") {
                            var oldText = shape.shape.textBlock.text;
                            shape.shape.textBlock.text = editBox.value;
                            shape.shape.textBlock.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                            if (!this._findNode(shape.name)) {
                                if (editBox.value !== "") {
                                    var height = Number(editBox.style.height.substring(0, editBox.style.height.length - 2));
                                    if (shape.height < height) {
                                        shape.offsetY = (shape.offsetY - (shape.height / 2)) + (height / 2);
                                        shape.height = height;
                                    }
                                    if (this.selectionList.length > 0)
                                        this._clearSelection();
                                    this.add(shape);
                                }
                                this.activeTool.selectedObject = null;
                            } else {
                                ej.datavisualization.Diagram.DiagramContext.update(shape, this);

                                entry = { type: "labelchanged", shape: shape, previousLabelValue: oldText, updatedLabelValue: editBox.value };
                                this.addHistoryEntry(entry);
                                //entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.TextChangeCmd(shape, shape.shape.textBlock.text, editBox.value));
                                //this.historyManager.addHistoryEntry(entry);
                            }
                        } else if (shape != undefined && !(shape.isPseudoGroup)) {
                            var label;
                            if (this.activeTool.name === "textTool")
                                label = this.activeTool.getLabelUnderMouse();
                            else
                                label = shape.labels[0];
                            if (label != undefined) {
                                if (label.text != editBox.value) {

                                    entry = { type: "labelchanged", shape: shape, previousLabelValue: label.text, updatedLabelValue: editBox.value };
                                    this.addHistoryEntry(entry);
                                    //entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.LabelChangeCmd(shape, label.text, editBox.value));
                                    //this.historyManager.addHistoryEntry(entry);
                                }
                                label.text = editBox.value;
                                label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                                ej.datavisualization.Diagram.DiagramContext.updateLabel(shape, label, this);
                            }
                            else if (shape.labels.length == 0) {
                                label = ej.datavisualization.Diagram.Label();
                                label.text = editBox.value;
                                label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                                shape.labels.push(label);
                                ej.datavisualization.Diagram.DiagramContext.addNodeLabel(shape, label, null, this);
                            }
                        }
                    }
                }

                this._off($(editBox), "focusout", this._editboxfocusout);
                this._off($(editBox), "keyup", this._editBoxKeyUp);
                this._off($(editBox), "input", this._editBoxTextChange);
                var element = $("#" + this.element[0].id + "_editBoxDiv")[0];
                if (element)
                    element.parentNode.removeChild(element);
            }
        },

        _setLabelEditing: function (label) {
            var success;
            if (label.readOnly) {
                label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                success = false;
            }
            else {
                if (this._currentLabel)
                    this._currentLabel.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                label.mode = ej.datavisualization.Diagram.LabelEditMode.Edit;
                this._currentLabel = label;
                success = true;
            }
            return success;
        },

        _isInternalTool: function (tool) {
            if (tool instanceof ej.datavisualization.Diagram.SelectTool || tool instanceof ej.datavisualization.Diagram.EndPointTool || tool instanceof ej.datavisualization.Diagram.MoveTool || tool instanceof ej.datavisualization.Diagram.ResizeTool
                || tool instanceof ej.datavisualization.Diagram.RotateTool || tool instanceof ej.datavisualization.Diagram.PivotTool)
                return true;
            else
                return false;
        },

        _translate: function (node, dx, dy, nameTable) {
            if (ej.datavisualization.Diagram.Util.canMove(node)) {
                if (!node.line) {
                    node.offsetX += dx;
                    node.offsetY += dy;
                    if (node.isGroup) {
                        var nodes = node.children;
                        var child;
                        for (var i = 0; i < nodes.length; i++) {
                            child = nameTable[nodes[i]];
                            this._translate(child, dx, dy, nameTable);
                            if (child.parent && (child.parent != node.name && !node.isPseudoGroup))
                                ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], nameTable);
                        }

                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, nameTable);
                    }
                    this._updateAssociatedConnectorEnds(node, nameTable);
                } else {
                    ej.datavisualization.Diagram.Util._translateLine(node.line, dx, dy, node);
                    this._dock(node, nameTable);
                }
                this._updateQuad(node);
            }
        },

        _rotate: function (node, angle, nameTable) {
            if (ej.datavisualization.Diagram.Util.canRotate(node)) {
                if (!node.line) {
                    node.rotateAngle += angle;
                    node.rotateAngle %= 360;
                    if (node.rotateAngle < 0) node.rotateAngle += 360;
                    if (node.isGroup) {
                        var matrix = ej.Matrix.identity();
                        var child, pinx, piny;
                        ej.Matrix.rotate(matrix, angle, node.offsetX, node.offsetY);
                        var nodes = node.children;
                        for (var i = 0; i < nodes.length; i++) {
                            child = nameTable[nodes[i]];
                            if (!(child.line)) {
                                this._rotate(child, angle, nameTable);
                                pinx = child.offsetX;
                                piny = child.offsetY;
                                var actualpt = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(pinx, piny));
                                this._translate(child, actualpt.x - pinx, actualpt.y - piny, nameTable);
                                this._updateAssociatedConnectorEnds(child, nameTable);
                            } else {
                                if (!child.sourceNode)
                                    this._setEndPoint(child, ej.Matrix.transform(matrix, child.line.startPoint), false);
                                if (!child.targetNode)
                                    this._setEndPoint(child, ej.Matrix.transform(matrix, child.line.endPoint), true);
                            }
                            if (child.parent && (child.parent != node.name && !node.isPseudoGroup))
                                ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], nameTable);
                        }

                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, nameTable);
                    }
                    this._updateQuad(node);
                    this._updateAssociatedConnectorEnds(node, nameTable);
                }
            }
        },

        _scale: function (node, sw, sh, pivot, nameTable) {
            //if (ej.datavisualization.Diagram.Util.canResize(node)) {
            var matrix = ej.Matrix.identity();
            if (!node.line) {
                if (node.isGroup) {
                    var nodes = node.children;
                    var child;
                    for (var i = 0; i < nodes.length; i++) {
                        child = nameTable[nodes[i]];
                        if (child) {
                            this._scale(child, sw, sh, pivot, nameTable);
                            if (child.parent && (child.parent != node.name && !node.isPseudoGroup))
                                ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], nameTable);
                        }
                    }
                    ej.datavisualization.Diagram.Util._updateGroupBounds(node, nameTable);
                }
                else {
                    ej.Matrix.rotate(matrix, -node.rotateAngle, pivot.x, pivot.y);
                    ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                    ej.Matrix.rotate(matrix, node.rotateAngle, pivot.x, pivot.y);
                    var newPosition = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY));
                    var width = node.width * sw;
                    var height = node.height * sh;
                    if (width > 1) {
                        node.width = width;
                        node.offsetX = newPosition.x;
                    }
                    if (height > 1) {
                        node.height = height;
                        node.offsetY = newPosition.y;
                    }

                } this._updateAssociatedConnectorEnds(node, nameTable);
            } else {
                ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                if (!node.sourceNode)
                    ej.datavisualization.Diagram.Util._setLineEndPoint(node, ej.Matrix.transform(matrix, node.line.startPoint), false);
                if (!node.targetNode)
                    ej.datavisualization.Diagram.Util._setLineEndPoint(node, ej.Matrix.transform(matrix, node.line.endPoint), true);
                if (node.sourceNode || node.targetNode)
                    this._dock(node, nameTable);
            }
            this._updateQuad(node);
            //}
        },

        _dock: function (connector, nameTable) {
            ej.datavisualization.Diagram.Util.dock(connector, nameTable);
            this._updateQuad(connector);
        },

        _setEndPoint: function (connector, point, isTarget) {
            ej.datavisualization.Diagram.Util._setLineEndPoint(connector, point, isTarget);
            this._updateQuad(connector);
        },

        _updateAssociatedConnectorEnds: function (node, nameTable) {
            var i, len;
            var connector;
            for (i = 0, len = node.inEdges.length; i < len; i++) {
                connector = nameTable[node.inEdges[i]];
                if (connector)
                    this._dock(connector, nameTable);
            }
            for (i = 0, len = node.outEdges.length; i < len; i++) {
                connector = nameTable[node.outEdges[i]];
                if (connector)
                    this._dock(connector, nameTable);
            }
        },
        _updateChildBounds: function (node, nameTable) {
            var offX, offY;
            if (node.width == 0 && node.height == 0) {
                offX = node.offsetX;
                offY = node.offsetY;
                ej.datavisualization.Diagram.Util._updateGroupBounds(node, nameTable);
                this._translate(node, offX - node.offsetX, offY - node.offsetY, nameTable);
            }
            else {
                offX = node.offsetX;
                offY = node.offsetY;
                var childBounds = ej.datavisualization.Diagram.Util._getChildrenBounds(node, nameTable);
                node.offsetX = (childBounds.x + childBounds.width / 2);
                node.offsetY = (childBounds.y + childBounds.height / 2);
                var dx = offX - node.offsetX;
                var dy = offX - node.offsetY;
                this._translate(node, dx, dy, nameTable);
                var deltaWidth = node.width / childBounds.width;
                var deltaHeight = node.height / childBounds.height;
                this._scale(node, deltaWidth, deltaHeight, node.pivot, nameTable);;
                this._translate(node, offX - node.offsetX, offY - node.offsetY, nameTable);
            }
        },
        _updateQuad: function (object) {
            if (this._spatialSearch && this._spatialSearch.quadTable[object.name])
                if (object.line || object.shape)
                    ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, object);
        }
        //#endregion
    });
    ej.datavisualization.Diagram.Locale = {};
    ej.datavisualization.Diagram.Locale["en-US"] = {
        cut: "Cut",
        copy: "Copy",
        paste: "Paste",
        undo: "Undo",
        redo: "Redo",
        selectAll: "SelectAll",
        grouping: "Grouping",
        group: "Group",
        ungroup: "Ungroup",
        order: "Order",
        bringToFront: "BringToFront",
        moveForward: "MoveForward",
        sendBackward: "SendBackward",
        sendToBack: "SendToBack"
    }

    //#endregion

})(jQuery, Syncfusion);;
(function ($, ej) {
    "use strict";
    ej.MatrixTypes = { Identity: 0, Translation: 1, Scaling: 2, Unknown: 4 };
    ej.MatrixDefaults = { m11: 1, m12: 0, m21: 0, m22: 1, offsetX: 0, offsetY: 0, type: ej.MatrixTypes.Identity };
    ej.Matrix = {
        identity: function () {
            return $.extend(true, {}, ej.MatrixDefaults);
        },
        multiply: function (matrix1, matrix2) {
            var type = matrix1.type;
            var type2 = matrix2.type;
            if (type2 == ej.MatrixTypes.Identity) {
                return;
            }
            if (type == ej.MatrixTypes.Identity) {
                matrix1.m11 = matrix2.m11;
                matrix1.m12 = matrix2.m12;
                matrix1.m21 = matrix2.m21;
                matrix1.m22 = matrix2.m22;
                matrix1.offsetX = matrix2.offsetX;
                matrix1.offsetY = matrix2.offsetY;
                matrix1.type = matrix2.type;
                return;
            }
            if (type2 == ej.MatrixTypes.Translation) {
                matrix1.offsetX += matrix2.offsetX;
                matrix1.offsetY += matrix2.offsetY;
                if (type != ej.MatrixTypes.Unknown) {
                    matrix1.type |= ej.MatrixTypes.Translation;
                }
                return;
            }
            if (type != ej.MatrixTypes.Translation) {
                var num = type << 4 | type2;
                switch (num) {
                    case 34:
                        matrix1.m11 *= matrix2.m11;
                        matrix1.m22 *= matrix2.m22;
                        return;
                    case 35:
                        matrix1.m11 *= matrix2.m11;
                        matrix1.m22 *= matrix2.m22;
                        matrix1.offsetX = matrix2.offsetX;
                        matrix1.offsetY = matrix2.offsetY;
                        matrix1.type = (ej.MatrixTypes.Translation | ej.MatrixTypes.Scaling);
                        return;
                    case 36: break;
                    default:
                        {
                            switch (num) {
                                case 50:
                                    matrix1.m11 *= matrix2.m11;
                                    matrix1.m22 *= matrix2.m22;
                                    matrix1.offsetX *= matrix2.m11;
                                    matrix1.offsetY *= matrix2.m22;
                                    return;
                                case 51:
                                    matrix1.m11 *= matrix2.m11;
                                    matrix1.m22 *= matrix2.m22;
                                    matrix1.offsetX = matrix2.m11 * matrix1.offsetX + matrix2.offsetX;
                                    matrix1.offsetY = matrix2.m22 * matrix1.offsetY + matrix2.offsetY;
                                    return;
                                case 52: break;
                                default:
                                    switch (num) {
                                        case 66:
                                        case 67:
                                        case 68: break;
                                        default: return;
                                    }
                                    break;
                            }
                            break;
                        }
                }
                var result = this.identity();
                this._setMatrix(result, matrix1.m11 * matrix2.m11 + matrix1.m12 * matrix2.m21,
                    matrix1.m11 * matrix2.m12 + matrix1.m12 * matrix2.m22, matrix1.m21 * matrix2.m11 + matrix1.m22 * matrix2.m21,
                    matrix1.m21 * matrix2.m12 + matrix1.m22 * matrix2.m22,
                    matrix1.offsetX * matrix2.m11 + matrix1.offsetY * matrix2.m21 + matrix2.offsetX, matrix1.offsetX * matrix2.m12 + matrix1.offsetY * matrix2.m22 + matrix2.offsetY);
                if (result.m21 || result.m12) {
                    result.type = ej.MatrixTypes.Unknown;
                }
                else {
                    if (result.m11 && result.m11 != 1.0 || result.m22 && result.m22 != 1.0) {
                        result.type = ej.MatrixTypes.Scaling;
                    }
                    if (result.offsetX || result.offsetY) {
                        result.type |= ej.MatrixTypes.Translation;
                    }
                    if ((result.type & (ej.MatrixTypes.Translation | ej.MatrixTypes.Scaling)) == ej.MatrixTypes.Identity) {
                        result.type = ej.MatrixTypes.Identity;
                    }
                }
                matrix1.m11 = result.m11;
                matrix1.m12 = result.m12;
                matrix1.m21 = result.m21;
                matrix1.m22 = result.m22;
                matrix1.offsetX = result.offsetX;
                matrix1.offsetY = result.offsetY;
                matrix1.type = result.type;
                return;
            }
            var offsetX = matrix1.offsetX;
            var offsetY = matrix1.offsetY;
            matrix1.m11 = matrix2.m11;
            matrix1.m12 = matrix2.m12;
            matrix1.m21 = matrix2.m21;
            matrix1.m22 = matrix2.m22;
            matrix1.offsetX = matrix2.offsetX;
            matrix1.offsetY = matrix2.offsetY;
            matrix1.type = matrix2.type;
            matrix1.offsetX = offsetX * matrix2.m11 + offsetY * matrix2.m21 + matrix2.offsetX;
            matrix1.offsetY = offsetX * matrix2.m12 + offsetY * matrix2.m22 + matrix2.offsetY;
            if (type2 == ej.MatrixTypes.Unknown) {
                matrix1.type = ej.MatrixTypes.Unknown;
                return;
            }
            matrix1.type = (ej.MatrixTypes.Translation | ej.MatrixTypes.Scaling);
        },
        transform: function (matrix, point) {
            return this._multiplyPoint(matrix, point.x, point.y);
        },
        rotate: function (matrix, angle, centerX, centerY) {
            angle %= 360.0;
            this.multiply(matrix, this._createRotationRadians(angle * 0.017453292519943295, centerX ? centerX : 0, centerY ? centerY : 0));
        },
        scale: function (matrix, scaleX, scaleY, centerX, centerY) {
            this.multiply(matrix, this._createScaling(scaleX, scaleY, centerX ? centerX : 0, centerY ? centerY : 0));
        },
        translate: function (matrix, offsetX, offsetY) {
            if (matrix.type & ej.MatrixTypes.Identity) {
                this._setMatrix(matrix, 1.0, 0.0, 0.0, 1.0, offsetX, offsetY, ej.MatrixTypes.Translation);
                return;
            }
            if (matrix.type & ej.MatrixTypes.Unknown) {
                matrix.offsetX += offsetX;
                matrix.offsetY += offsetY;
                return;
            }
            matrix.offsetX += offsetX;
            matrix.offsetY += offsetY;
            matrix.type |= ej.MatrixTypes.Translation;
        },
        _createScaling: function (scaleX, scaleY, centerX, centerY) {
            var result = this.identity();
            this._setMatrix(result, scaleX, 0.0, 0.0, scaleY, centerX - scaleX * centerX, centerY - scaleY * centerY,
                !(centerX || centerY) ? ej.MatrixTypes.Scaling : ej.MatrixTypes.Scaling | ej.MatrixTypes.Translation);
            return result;
        },
        _createRotationRadians: function (angle, centerX, centerY) {
            var result = this.identity();
            var num = Math.sin(angle);
            var num2 = Math.cos(angle);
            var offsetX = centerX * (1.0 - num2) + centerY * num;
            var offsetY = centerY * (1.0 - num2) - centerX * num;
            this._setMatrix(result, num2, num, -num, num2, offsetX, offsetY, ej.MatrixTypes.Unknown);
            return result;
        },
        _multiplyPoint: function (matrix, x, y) {
            switch (matrix.type) {
                case ej.MatrixTypes.Identity: break;
                case ej.MatrixTypes.Translation:
                    x += matrix.offsetX;
                    y += matrix.offsetY;
                    break;
                case ej.MatrixTypes.Scaling:
                    x *= matrix.m11;
                    y *= matrix.m22;
                    break;
                case ej.MatrixTypes.Translation | ej.MatrixTypes.Scaling:
                    x *= matrix.m11;
                    x += matrix.offsetX;
                    y *= matrix.m22;
                    y += matrix.offsetY;
                    break;
                default:
                    var num = y * matrix.m21 + matrix.offsetX;
                    var num2 = x * matrix.m12 + matrix.offsetY;
                    x *= matrix.m11;
                    x += num;
                    y *= matrix.m22;
                    y += num2;
                    break;
            }
            return { x: x, y: y };
        },
        _setMatrix: function (matrix, m11, m12, m21, m22, offsetX, offsetY, type) {
            matrix.m11 = m11;
            matrix.m12 = m12;
            matrix.m21 = m21;
            matrix.m22 = m22;
            matrix.offsetX = offsetX;
            matrix.offsetY = offsetY;
            matrix.type = type || ej.MatrixTypes.Identity;
        }
    };
})(jQuery, Syncfusion);;
/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej) {

    "use strict";

    //#region HitTesting
    ej.datavisualization.Diagram.HitTesting = {
        _getResizeHandleCenter: function (shape, position, scale) {
            if (!scale) scale = 1;
            var corners = this.bounds(shape);
            var center = ej.datavisualization.Diagram.Point(0, 0);
            switch (position) {
                case "topleft":
                    center = corners.topLeft;
                    break;
                case "topcenter":
                    center = corners.top;
                    break;
                case "topright":
                    center = corners.topRight;
                    break;
                case "middleleft":
                    center = corners.left;
                    break;
                case "middleright":
                    center = corners.right;
                    break;
                case "bottomleft":
                    center = corners.bottomLeft;
                    break;
                case "bottomcenter":
                    center = corners.bottom;
                    break;
                case "bottomright":
                    center = corners.bottomRight;
                    break;
                case "pivot":
                    center = ej.datavisualization.Diagram.Point(shape.offsetX, shape.offsetY);
                    break;
                case "rotate":
                    var thumbHeight = 20;
                    var dist = 20 / scale; //distance between element top and rotator thumb
                    var pt = ej.datavisualization.Diagram.Point(shape.offsetX, (shape.offsetY - shape.height * shape.pivot.y) - thumbHeight / 2 - dist);
                    var matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, shape.rotateAngle, shape.offsetX, shape.offsetY);
                    center = ej.Matrix.transform(matrix, pt);
                    break;
            }
            return center;
        },
        findResizeHandleAtPoint: function (node, point) {
            var resizeDirection = null;
            if (node) {
                var center;
                var success;
                var directions = ["topleft", "topcenter", "topright", "middleleft", "middleright", "bottomleft", "bottomcenter", "bottomright"];
                for (var i = 0, len = directions.length; i < len; i++) {
                    center = this._getResizeHandleCenter(node, directions[i]);
                    if (center !== ej.datavisualization.Diagram.Point(0, 0)) {
                        success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(center.x, center.y), 7); // right now 7 is default handle radius size, need to give as constant variable
                        if (success) {
                            resizeDirection = directions[i];
                            break;
                        }
                    }
                }
            }
            return resizeDirection;
        },
        findRotationHandleAtPoint: function (node, point, scale) {
            var center = this.xxx_getResizeHandleCenter(node, "rotate", scale);
            var success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(center.x, center.y), 10); // right now 7 is default handle radius size, need to give as constant variable
            if (success) {
                return true;

            }
            return false;
        },
        findPivotHandleAtPoint: function (node, point) {
            var center = this._getResizeHandleCenter(node, "pivot");
            var success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(center.x, center.y), 7); // right now 7 is default handle radius size, need to give as constant variable
            if (success) {
                return true;

            }
            return false;
        },
        findEndPointHandleAtPoint: function (connector, point) {
            var endPointHandle = null;
            if (connector) {
                var success;
                var points = connector.line.points;
                var pt = points[points.length - 1];
                success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(pt.x, pt.y), 7); // right now 7 is default handle radius size, need to give as constant variable
                if (success) {
                    endPointHandle = "targetEndPoint";
                }
                if (!success) {
                    pt = points[0];
                    success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(pt.x, pt.y), 7); // right now 7 is default handle radius size, need to give as constant variable
                    if (success) {
                        endPointHandle = "sourceEndPoint";
                    }
                }
                if (!success && connector.line.type === "bezier") {
                    pt = connector.line._point1;
                    success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(pt.x, pt.y), 7); // right now 7 is default handle radius size, need to give as constant variable
                    if (success) {
                        endPointHandle = "bezierpoint1";
                    }
                    if (!success) {
                        var pt1 = connector.line._point2;
                        success = ej.datavisualization.Diagram.Geometry.checkPointOnCircle(point, ej.datavisualization.Diagram.Point(pt1.x, pt1.y), 7); // right now 7 is default handle radius size, need to give as constant variable
                        if (success) {
                            endPointHandle = "bezierpoint2";
                        }
                    }
                }
            }
            return endPointHandle;
        }
    };
    //#endregion

    //#region Util
    ej.datavisualization.Diagram.Util = {
        findPortByName: function (node, portName) {
            var port;
            if (node.ports)
                for (var i = 0, len = node.ports.length; i < len; i++) {
                    port = node.ports[i];
                    if (port.name === portName) {
                        return port;
                    }
                }
            return null;
        },
        attr: function (element, attributes) {
            for (var atr in attributes) {
                element.setAttribute(atr.toString(), attributes[atr]);
            }
        },
        removeItem: function (array, item) {
            var index = array.indexOf(item);
            if (index >= 0)
                array.splice(index, 1);
        },
        clear: function (array) {
            while (array.length > 0) {
                array.pop();
            }
        },
        randomId: function () {
            var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz";
            var id = "";
            //get 4 random chars
            for (var i = 0; i < 4; i++) {
                var num = Math.floor(Math.random() * chars.length);
                id += chars.substring(num, num + 1);
            }
            return id;
        },
        htmlEncode: function (html) {
            var str = html.replace(/&amp;/g, '&').replace(/&lt;/g, '<').replace(/&gt;/g, '>').replace(/&quot;/g, '"').replace(/&apos;/g, '\'');
            return str;
        },
        canMove: function (node) {
            if (node.line) {
                return node.constraints & ej.datavisualization.Diagram.ConnectorConstraints.Drag;
            } else
                return node.constraints & ej.datavisualization.Diagram.NodeConstraints.Drag;
        },
        canRotate: function (node) {
            if (node.line) {
                return node.constraints & ej.datavisualization.Diagram.ConnectorConstraints.Rotate;

            } else
                return node.constraints & ej.datavisualization.Diagram.NodeConstraints.Rotate;
        },
        canSelect: function (node) {
            if (node.line) {
                return node.constraints & ej.datavisualization.Diagram.ConnectorConstraints.Select;
            } else
                return node.constraints & ej.datavisualization.Diagram.NodeConstraints.Select;
        },
        canDelete: function (node) {
            if (node.line) {
                return node.constraints & ej.datavisualization.Diagram.ConnectorConstraints.Delete;
            } else
                return node.constraints & ej.datavisualization.Diagram.NodeConstraints.Delete;
        },
        canDragSourceEnd: function (connector) {
            return connector.constraints & ej.datavisualization.Diagram.ConnectorConstraints.DragSourceEnd;
        },
        canDragTargetEnd: function (connector) {
            return connector.constraints & ej.datavisualization.Diagram.ConnectorConstraints.DragTargetEnd;
        },
        canDragSegmentThumbs: function (connector) {
            return connector.constraints & ej.datavisualization.Diagram.ConnectorConstraints.DragSegmentThumb;
        },
        isTargetConnected: function (connector) {
            return connector.targetNode ? true : false;
        },
        isSourceConnected: function (connector) {
            return connector.sourceNode ? true : false;
        },
        bounds: function (object, excludeRotation) {
            var rect;
            if (object.line) {
                rect = ej.datavisualization.Diagram.Geometry.rect(object.line.points);
            }
            else if (object.shape || object.isGroup) {
                rect = ej.datavisualization.Diagram.Rectangle(object.offsetX - object.width * object.pivot.x, object.offsetY - object.height * object.pivot.y, object.width, object.height);
            }
            else
                rect = object;
            if (rect) {
                var bounds = {};
                bounds["width"] = rect.width;
                bounds["height"] = rect.height;
                bounds["x"] = bounds["left"] = rect.x;
                bounds["right"] = rect.x + rect.width;
                bounds["y"] = bounds["top"] = rect.y;
                bounds["bottom"] = rect.y + rect.height;
                bounds["center"] = ej.datavisualization.Diagram.Point(rect.x + rect.width / 2, rect.y + rect.height / 2);
                bounds["topLeft"] = ej.datavisualization.Diagram.Point(rect.x, rect.y);
                bounds["topCenter"] = ej.datavisualization.Diagram.Point(rect.x + rect.width / 2, rect.y);
                bounds["topRight"] = ej.datavisualization.Diagram.Point(rect.x + rect.width, rect.y);
                bounds["middleLeft"] = ej.datavisualization.Diagram.Point(rect.x, rect.y + rect.height / 2);
                bounds["middleRight"] = ej.datavisualization.Diagram.Point(rect.x + rect.width, rect.y + rect.height / 2);
                bounds["bottomLeft"] = ej.datavisualization.Diagram.Point(rect.x, rect.y + rect.height);
                bounds["bottomCenter"] = ej.datavisualization.Diagram.Point(rect.x + rect.width / 2, rect.y + rect.height);
                bounds["bottomRight"] = ej.datavisualization.Diagram.Point(rect.x + rect.width, rect.y + rect.height);
                if (object.rotateAngle && object.rotateAngle !== 0 && !excludeRotation) {
                    var matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, object.rotateAngle, object.offsetX, object.offsetY);
                    bounds.topLeft = ej.Matrix.transform(matrix, bounds.topLeft);
                    bounds.topCenter = ej.Matrix.transform(matrix, bounds.topCenter);
                    bounds.topRight = ej.Matrix.transform(matrix, bounds.topRight);
                    bounds.middleLeft = ej.Matrix.transform(matrix, bounds.middleLeft);
                    bounds.middleRight = ej.Matrix.transform(matrix, bounds.middleRight);
                    bounds.bottomLeft = ej.Matrix.transform(matrix, bounds.bottomLeft);
                    bounds.bottomCenter = ej.Matrix.transform(matrix, bounds.bottomCenter);
                    bounds.bottomRight = ej.Matrix.transform(matrix, bounds.bottomRight);
                    var rbounds = ej.datavisualization.Diagram.Geometry.rect([bounds.topLeft, bounds.topRight, bounds.bottomRight, bounds.bottomLeft]);
                    bounds.x = bounds.left = rbounds.x;
                    bounds.y = bounds.top = rbounds.y;
                    bounds.right = rbounds.x + rbounds.width;
                    bounds.bottom = rbounds.y + rbounds.height;
                    bounds.center = ej.datavisualization.Diagram.Point(rbounds.x + rbounds.width / 2, rbounds.y + rbounds.height / 2);
                }
                bounds["points"] = [bounds.topLeft, bounds.topRight, bounds.bottomRight, bounds.bottomLeft];
                return bounds;
            }
            return rect;
        },
        canResize: function (node) {
            return node.constraints & ej.datavisualization.Diagram.NodeConstraints.Resize;
        },
        canConnect: function (node, isPort) {
            var connect = null;
            if (isPort) {
                connect = node.constraints & ej.datavisualization.Diagram.PortConstraints.Connect;
            }
            else if (!node.line)
                connect = node.constraints & ej.datavisualization.Diagram.NodeConstraints.Connect;
            return connect;
        },
        dock: function (connector, nameTable) {
            var targetNode, targetPort = null, sourceNode, sourcePort = null;
            targetNode = nameTable[connector.targetNode];
            if (targetNode)
                targetPort = this.findPortByName(targetNode, connector.targetPort);
            sourceNode = nameTable[connector.sourceNode];
            if (sourceNode)
                sourcePort = this.findPortByName(sourceNode, connector.sourcePort);
            var sourceConnected = this.isSourceConnected(connector);
            var targetConnected = this.isTargetConnected(connector);
            if (targetConnected && sourceConnected && targetPort && sourcePort) {
                this._dockPortToPort(connector, targetNode, targetPort, sourceNode, sourcePort);
            }
            else if (targetConnected && targetPort) {
                if (sourceConnected) {
                    if ((connector.line.type !== "orthogonal")) {
                        this._dockPortToNode(connector, targetNode, targetPort, sourceNode, sourcePort, false);
                        this._dockNode(connector, sourceNode, null, targetConnected, sourceConnected);
                    }
                    else {
                        this._dockNode(connector, sourceNode, null, targetConnected, sourceConnected);
                        this._dockPortToNode(connector, targetNode, targetPort, sourceNode, sourcePort, false);
                    }
                }
                else {
                    this._dockPortToPoint(connector, targetNode, targetPort, true);
                }
            }
            else if (sourceConnected && sourcePort) {
                if (targetConnected) {
                    if ((connector.line.type !== "orthogonal")) {
                        this._dockPortToNode(connector, sourceNode, sourcePort, targetNode, targetPort, true);
                        this._dockNode(connector, targetNode, null, targetConnected, sourceConnected);
                    }
                    else {
                        this._dockNode(connector, targetNode, null, targetConnected, sourceConnected);
                        this._dockPortToNode(connector, sourceNode, sourcePort, targetNode, targetPort, true);
                    }
                }
                else {
                    this._dockPortToPoint(connector, sourceNode, sourcePort, false);
                }
            }
            else if (targetConnected && sourceConnected) {
                this._dockNode(connector, targetNode, sourceNode, targetConnected, sourceConnected);
            }
            else if (targetConnected) {
                this._dockNode(connector, targetNode, null, targetConnected, sourceConnected);
            }
            else if (sourceConnected) {
                this._dockNode(connector, sourceNode, null, targetConnected, sourceConnected);
            }
        },
        _dockPortToPort: function (connector, targetNode, targetPort, sourceNode, sourcePort) {
            var portLocation;
            if (targetNode)
                var targetBounds = this.bounds(targetNode, true);
            if (sourceNode)
                var sourceBounds = this.bounds(sourceNode, true);
            var matrix;
            if (connector.line.type !== "orthogonal") {
                if (targetPort) {
                    portLocation = this._getPortPosition(targetPort, targetBounds);
                    matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                    portLocation = ej.Matrix.transform(matrix, portLocation);
                    this._setLineEndPoint(connector, portLocation, true);
                }
                if (sourcePort) {
                    portLocation = this._getPortPosition(sourcePort, sourceBounds);
                    matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, sourceNode.rotateAngle, sourceNode.offsetX, sourceNode.offsetY);
                    portLocation = ej.Matrix.transform(matrix, portLocation);
                    this._setLineEndPoint(connector, portLocation, false);
                }
                if (connector.line.type === "bezier")
                    this._updateBezierPoints(connector.line, targetNode, targetPort, targetBounds, sourceNode, sourcePort, sourceBounds);
            }
            else {
                var targetPortLocation = this._getPortPosition(targetPort, targetBounds);
                var sourcePortLocation = this._getPortPosition(sourcePort, sourceBounds);
                var targetDirection = this._swapDirection(targetNode.rotateAngle, this._getDirection(targetBounds, targetPortLocation));
                var sourceDirection = this._swapDirection(sourceNode.rotateAngle, this._getDirection(sourceBounds, sourcePortLocation));
                matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, sourceNode.rotateAngle, sourceNode.offsetX, sourceNode.offsetY);
                sourcePortLocation = ej.Matrix.transform(matrix, sourcePortLocation);
                matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                targetPortLocation = ej.Matrix.transform(matrix, targetPortLocation);
                targetBounds = this.bounds(targetNode);
                sourceBounds = this.bounds(sourceNode);
                this._constructSegements(connector, targetBounds, targetPortLocation, targetDirection, sourceBounds, sourcePortLocation, sourceDirection);
            }
        },
        _dockPortToNode: function (connector, targetNode, targetPort, sourceNode, sourcePort, isTarget) {
            if (targetNode)
                var targetBounds = this.bounds(targetNode, true);
            if (sourceNode)
                var sourceBounds = this.bounds(sourceNode, true);
            var matrix;
            if (connector.line.type !== "orthogonal") {
                var portLocation = this._getPortPosition(targetPort, targetBounds);
                matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                portLocation = ej.Matrix.transform(matrix, portLocation);
                this._setLineEndPoint(connector, portLocation, isTarget);
            }
            else {
                var targetPortLocation = this._getPortPosition(targetPort, targetBounds);
                var targetDirection = this._swapDirection(targetNode.rotateAngle, this._getDirection(targetBounds, targetPortLocation));
                matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                targetPortLocation = ej.Matrix.transform(matrix, targetPortLocation);
                var sourcePortLocation;
                if (!isTarget) {
                    sourcePortLocation = connector.line.startPoint;
                }
                else {
                    sourcePortLocation = connector.line.endPoint;
                }
                var sourceDirection = this._swapDirection(sourceNode.rotateAngle, this._getDirection(sourceBounds, sourcePortLocation));
                if (sourceDirection) {
                    targetBounds = this.bounds(targetNode);
                    sourceBounds = this.bounds(sourceNode);
                    if (isTarget) {
                        this._constructSegements(connector, sourceBounds, sourcePortLocation, sourceDirection, targetBounds, targetPortLocation, targetDirection);
                    }
                    else {
                        this._constructSegements(connector, targetBounds, targetPortLocation, targetDirection, sourceBounds, sourcePortLocation, sourceDirection);
                    }
                }
            }
        },
        _constructSegements: function (connector, targetBounds, targetPortLocation, targetDirection, sourceBounds, sourcePortLocation, sourceDirection) {
            this._setLineEndPoint(connector, targetPortLocation, true);
            this._setLineEndPoint(connector, sourcePortLocation, false);
            var points, reverse;
            if (sourceDirection === "right") {
                if (targetDirection === "left") {
                    points = this._rightToLeft(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                else if (targetDirection === "right") {
                    points = this._rightToRight(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                else if (targetDirection === "top") {
                    points = this._rightToTop(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                else if (targetDirection === "bottom") {
                    points = this._rightToBottom(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
            }
            if (sourceDirection === "left") {
                if (targetDirection === "right") {
                    points = this._rightToLeft(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "left") {
                    points = this._leftToLeft(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                if (targetDirection === "top") {
                    points = this._leftToTop(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                if (targetDirection === "bottom") {
                    points = this._leftToBottom(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
            }
            if (sourceDirection === "top") {
                if (targetDirection === "left") {
                    points = this._leftToTop(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "right") {
                    points = this._rightToTop(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "top") {
                    points = this._topToTop(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
                if (targetDirection === "bottom") {
                    points = this._topToBottom(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
            }
            if (sourceDirection === "bottom") {
                if (targetDirection === "left") {
                    points = this._leftToBottom(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "right") {
                    points = this._rightToBottom(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "top") {
                    points = this._topToBottom(sourceBounds, sourcePortLocation, targetBounds, targetPortLocation);
                    reverse = true;
                }
                if (targetDirection === "bottom") {
                    points = this._bottomToBottom(targetBounds, targetPortLocation, sourceBounds, sourcePortLocation);
                }
            }
            if (reverse) {
                points.reverse();
            }
            var point1 = points[points.length - 1];
            var point2 = points[points.length - 2];
            if (point1.x == point2.x && point1.y == point2.y) {
                points.splice(points.length - 1, 1);
            }
            point1 = points[0];
            point2 = points[1];
            if (point1.x == point2.x && point1.y == point2.y) {
                points.splice(0, 1);
            }
            this._setPoints(connector.line, points);
        },
        _dockPortToPoint: function (connector, targetNode, targetPort, isTarget) {
            if (connector.line.type !== "orthogonal") {
                this._dockPortToNode(connector, targetNode, targetPort, null, null, isTarget);
            }
            else {
                var targetBounds = this.bounds(targetNode, true);
                var targetPortLocation = this._getPortPosition(targetPort, targetBounds);
                var targetDirection = this._swapDirection(targetNode.rotateAngle, this._getDirection(targetBounds, targetPortLocation));
                var matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                targetPortLocation = ej.Matrix.transform(matrix, targetPortLocation);
                var sourcePortLocation;
                if (isTarget)
                    sourcePortLocation = connector.line.startPoint;
                else
                    sourcePortLocation = connector.line.endPoint;
                var sourceBounds = this.bounds(ej.datavisualization.Diagram.Rectangle(sourcePortLocation.x, sourcePortLocation.y, 0, 0));
                targetBounds = this.bounds(targetNode);
                var sourceDirection = "top";
                if (!isTarget) {
                    this._constructSegements(connector, sourceBounds, sourcePortLocation, sourceDirection, targetBounds, targetPortLocation, targetDirection);
                }
                else {
                    this._constructSegements(connector, targetBounds, targetPortLocation, targetDirection, sourceBounds, sourcePortLocation, sourceDirection);
                }
            }
        },
        _dockNode: function (connector, targetNode, sourceNode, targetConnected, sourceConnected) {
            if (targetConnected && sourceConnected && !connector.targetPort && !connector.sourcePort) {
                this._dock(connector, targetNode, sourceNode, true);
                this._dock(connector, sourceNode, targetNode, false);
            }
            else if (targetConnected && !connector.targetPort) {
                this._dock(connector, targetNode, sourceNode, true);
            }
            else if (sourceConnected && !connector.sourcePort) {
                this._dock(connector, targetNode, sourceNode, false);
            }
        },
        _dock: function (connector, targetNode, sourceNode, isTarget) {
            var targetBounds;
            var sourceBounds;
            var points;
            var line = connector.line;
            if (line.type !== "orthogonal") {
                if (targetNode) {
                    targetBounds = this.bounds(targetNode);
                    if (sourceNode) {
                        sourceBounds = this.bounds(sourceNode);
                        this._setLineEndPoint(connector, sourceBounds.center, !isTarget);
                        this._setLineEndPoint(connector, targetBounds.center, isTarget);
                        this._dockBounds(sourceNode, connector, sourceBounds, !isTarget);
                    }
                    this._setLineEndPoint(connector, targetBounds.center, isTarget);
                    this._dockBounds(targetNode, connector, targetBounds, isTarget);
                }
            }
            else {
                this._updateOrthogonalPoints(line);
                var x, y;
                var dockSegment;
                var targetDirection;
                var sourceDirection;
                if (targetNode) {
                    targetBounds = this.bounds(targetNode);
                    if (sourceNode) {
                        sourceBounds = this.bounds(sourceNode);
                        this._setLineEndPoint(connector, sourceBounds.center, !isTarget);
                        this._setLineEndPoint(connector, targetBounds.center, isTarget);
                        dockSegment = this._getDockSegment(connector, sourceNode.rotateAngle, sourceBounds);
                        if (dockSegment) {
                            this._setLineEndPoint(connector, dockSegment.dockPoint, !isTarget);
                            sourceDirection = dockSegment.direction;
                        }
                    }
                    this._setLineEndPoint(connector, targetBounds.center, isTarget);
                    dockSegment = this._getDockSegment(connector, targetNode.rotateAngle, targetBounds);
                    if (dockSegment) {
                        this._setLineEndPoint(connector, dockSegment.dockPoint, isTarget);
                        targetDirection = dockSegment.direction;
                    }
                }
                var temp;
                if (!isTarget && sourceDirection) {
                    temp = targetDirection;
                    targetDirection = sourceDirection;
                    sourceDirection = temp;
                }
                if (targetDirection && sourceDirection) {
                    if ((targetDirection === "left" || targetDirection === "right") && (sourceDirection === "right" || sourceDirection === "left")) {
                        this._updateOrthogonalPoints(line, true);
                    }
                    else if ((targetDirection === "top" || targetDirection === "bottom") && (sourceDirection === "bottom" || sourceDirection === "top")) {
                        this._updateOrthogonalPoints(line, false);
                    }
                    else {
                        points = [];
                        points.push(line.startPoint);
                        if ((targetDirection === "top" || targetDirection === "bottom") && (sourceDirection === "right" || sourceDirection === "left")) {
                            points.push(ej.datavisualization.Diagram.Point(line.endPoint.x, line.startPoint.y));
                        }
                        else {
                            points.push(ej.datavisualization.Diagram.Point(line.startPoint.x, line.endPoint.y));
                        }
                        points.push(line.endPoint);
                        this._setPoints(line, points);
                    }
                }
                else if (targetDirection) {
                    points = [];
                    points.push(line.startPoint);
                    if (isTarget) {
                        if (targetDirection === "left" || targetDirection === "right") {
                            x = line.startPoint.x;
                            y = line.endPoint.y;
                        }
                        else {
                            x = line.endPoint.x;
                            y = line.startPoint.y;
                        }
                    }
                    else {
                        if (targetDirection === "left" || targetDirection === "right") {
                            x = line.endPoint.x;
                            y = line.startPoint.y;
                        }
                        else {
                            x = line.startPoint.x;
                            y = line.endPoint.y;
                        }
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    points.push(line.endPoint);
                    this._setPoints(line, points);
                }
            }
        },
        _getDockSegment: function (connector, rotateAngle, bounds) {
            var direction = "", segment, intersecSeg;
            var line = connector.line;
            var segments = this._getEdges(rotateAngle, bounds);
            intersecSeg = ej.datavisualization.Diagram.Segment(line.startPoint, line.endPoint);
            if (ej.datavisualization.Diagram.Geometry.intersectSegment(intersecSeg, segments.left)) {
                segment = segments.left;
                direction = "left";
            }
            else if (ej.datavisualization.Diagram.Geometry.intersectSegment(intersecSeg, segments.top)) {
                segment = segments.top;
                direction = "top";
            }
            else if (ej.datavisualization.Diagram.Geometry.intersectSegment(intersecSeg, segments.right)) {
                segment = segments.right;
                direction = "right";
            }
            else if (ej.datavisualization.Diagram.Geometry.intersectSegment(intersecSeg, segments.bottom)) {
                segment = segments.bottom;
                direction = "bottom";
            }
            direction = this._swapDirection(rotateAngle, direction);
            if (segment) {
                return { "dockPoint": ej.datavisualization.Diagram.Geometry.midPoint(segment), "direction": direction };
            }
            return null;
        },
        _getEdges: function (rotateAngle, bounds) {
            var points = bounds.points;
            var segments = {};
            var angle = rotateAngle % 360;
            var temp;
            segments.left = ej.datavisualization.Diagram.Segment(points[3], points[0]);
            segments.top = ej.datavisualization.Diagram.Segment(points[0], points[1]);
            segments.right = ej.datavisualization.Diagram.Segment(points[1], points[2]);
            segments.bottom = ej.datavisualization.Diagram.Segment(points[2], points[3]);
            if (angle < 0) {
                angle += 360;
            }
            if (angle > 315 || angle < 45) {

            }
            else if (angle < 135) {
                temp = segments.top;
                segments.top = segments.left;
                segments.left = segments.bottom;
                segments.bottom = segments.right;
                segments.right = temp;
            }
            else if (angle < 225) {
                temp = segments.top;
                segments.top = segments.bottom;
                segments.bottom = temp;
                temp = segments.left;
                segments.left = segments.right;
                segments.right = temp;
            }
            else {
                temp = segments.bottom;
                segments.bottom = segments.left;
                segments.left = segments.top;
                segments.top = segments.right;
                segments.right = temp;
            }
            return segments;
        },
        _swapDirection: function (rotateAngle, direction) {
            var dir;
            var angle = rotateAngle % 360;
            if (angle < 0) {
                angle += 360;
            }
            var dirs;
            if (angle > 315 || angle < 45) {
                dir = direction;
            }
            else if (angle < 135) {
                dirs = { left: "top", top: "right", right: "bottom", bottom: "left" };
                dir = dirs[direction];
            }
            else if (angle < 225) {
                dirs = { left: "right", top: "bottom", right: "left", bottom: "top" };
                dir = dirs[direction];
            }
            else {
                dirs = { left: "bottom", top: "left", right: "top", bottom: "right" };
                dir = dirs[direction];
            }
            return dir;
        },
        _dockBounds: function (node, connector, bounds, isTarget) {
            var thisSegment, line = connector.line, segmentPoints = [];
            if (line.type === "straight") {
                thisSegment = ej.datavisualization.Diagram.Segment(line.startPoint, line.endPoint);
            }
            else {
                if (isTarget) {
                    if (line.point2)
                        thisSegment = ej.datavisualization.Diagram.Segment(line._point2, line.endPoint);
                    else
                        thisSegment = ej.datavisualization.Diagram.Segment(line.startPoint, line.endPoint);
                } else {
                    if (line.point1) {
                        thisSegment = ej.datavisualization.Diagram.Segment(line.startPoint, line._point1);
                    }
                    else
                        thisSegment = ej.datavisualization.Diagram.Segment(line.startPoint, line.endPoint);
                }
            }

            if (node.shape.type === "polygon") {
                segmentPoints = node.shape.points;
                ej.datavisualization.Diagram.Geometry.updatePolygonPoints(node, segmentPoints);
                for (var i = 0; i < segmentPoints.length; i++) {
                    var pt1 = ej.datavisualization.Diagram.Point(segmentPoints[i].x + (node.offsetX - node.width / 2), segmentPoints[i].y + (node.offsetY - node.height / 2));
                    segmentPoints[i] = pt1;
                }
            }
            else if (node.shape.type === "path") {
                var svg = document.createElementNS('http://www.w3.org/2000/svg', 'svg');
                svg.setAttribute('xlink', 'http://www.w3.org/1999/xlink');
                document.body.appendChild(svg);

                var pathEl = document.createElementNS('http://www.w3.org/2000/svg', "path");
                pathEl.setAttributeNS(null, "d", node.shape.pathData);
                svg.appendChild(pathEl);

                var pathBounds = pathEl.getBBox();
                var pathData = ej.datavisualization.Diagram.Geometry.updatePath(0, 0, node.width, node.height, node.shape.pathData, svg, pathBounds);
                pathEl.setAttributeNS(null, "d", pathData);
                var length = pathEl.getTotalLength(), pts=[];
                for (var i = 0; i < length - 1; i++) {
                    var pathSeg = pathEl.getPointAtLength(i);
                    pts[i] = ej.datavisualization.Diagram.Point(pathSeg.x + (node.offsetX - node.width / 2), pathSeg.y + (node.offsetY - node.height / 2));
                }
                segmentPoints = pts;
                document.body.removeChild(svg);
            }          
            else {
                segmentPoints = bounds.points;
            }
            var len = segmentPoints.length, intersection;
            if (node.shape.type === "ellipse") {
                intersection = this._getEllipseIntersectCoords(node, thisSegment, connector);                
            }
            else {
                intersection = this._getIntersectionPoint(node, thisSegment, segmentPoints);
            }
            if (intersection) {
                this._setLineEndPoint(connector, intersection, isTarget);
                if (line.type === "straight") {
                    this._updateBezierPoints(line);
                }
            }
        },

        _getIntersectionPoint: function (node, connectorSeg, segmentPoints) {
            var intersection, len = segmentPoints.length, i;
            var segment = ej.datavisualization.Diagram.Segment(segmentPoints[len - 1], segmentPoints[0]);
            if (node.shape.type != 'ellipse') {
                intersection = ej.datavisualization.Diagram.Geometry.intersectSegment(connectorSeg, segment);
            }
            if (!intersection) {
                for (i = 0; i < len - 1; i++) {
                    segment = ej.datavisualization.Diagram.Segment(segmentPoints[i], segmentPoints[i + 1]);
                    intersection = ej.datavisualization.Diagram.Geometry.intersectSegment(connectorSeg, segment);
                    if (intersection)
                        return intersection;
                }
            }
            else
                return intersection;
        },

        _getEllipseIntersectCoords: function (node, connectorSeg, connector) {
            var segmentPoints = [], intersection;
            var rx = node.width / 2;
            var ry = node.height / 2;
            var cx = node.offsetX - node.width / 2;
            var cy = node.offsetY - node.height / 2;

            //Convert Top Round Side to Path
            var topArchPath = "M " + (node.offsetX - node.width / 2) + ", " + (node.offsetY) + " A " + rx + " " + ry + " 0 0 " + 1 + " " + (node.offsetX + node.width / 2) + ", " + (node.offsetY);
            var path = document.createElementNS('http://www.w3.org/2000/svg', "path");
            path.setAttributeNS(null, "d", topArchPath);
            var len = path.getTotalLength(), pts = [], pt1, pt2, coor;
            for (var i = 0; i < len - 1; i++) {
                var pathSeg = path.getPointAtLength(i);
                pts[i] = pathSeg;
            }
            segmentPoints = pts;
            intersection = this._getIntersectionPoint(node, connectorSeg, segmentPoints);
            if (intersection)
                return intersection;

            segmentPoints = [];
            segmentPoints[0] = path.getPointAtLength(0);
            //Convert bottom Round Side to Path
            var bottomArchPath = "M " + (node.offsetX - node.width / 2) + ", " + (node.offsetY ) + " A " + rx + " " + ry + " 0 0 " + 0 + " " + (node.offsetX + node.width / 2) + ", " + (node.offsetY);
            path.setAttributeNS(null, "d", bottomArchPath);
            len = path.getTotalLength();
            segmentPoints[1] = path.getPointAtLength(0);
            intersection = this._getIntersectionPoint(node, connectorSeg, segmentPoints);
            if (intersection)
                return intersection;

            segmentPoints = [];
            for (i = 0; i < len - 1; i++) {
                segmentPoints[i] = path.getPointAtLength(i);                
            }
            intersection = this._getIntersectionPoint(node, connectorSeg, segmentPoints);
            if (intersection)
                return intersection;

            segmentPoints = [];
            segmentPoints[0] = path.getPointAtLength(len);
            path.setAttributeNS(null, "d", topArchPath);
            len = path.getTotalLength();
            segmentPoints[1] = path.getPointAtLength((len - 1));
            intersection = this._getIntersectionPoint(node, connectorSeg, segmentPoints);
            if (intersection)
                return intersection;
        },

        _rightToLeft: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            if (targetPortLocation.x > sourcePortLocation.x) {
                if ((sourcePortLocation.x + 5) >= targetBounds.left) {
                    x = sourceBounds.right + 15;
                    y = sourcePortLocation.y;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetPortLocation.y > sourceBounds.top) {
                        y = targetPortLocation.y;
                    }
                    else {
                        y = targetBounds.bottom + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetPortLocation.y <= sourceBounds.top) {
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetPortLocation.x;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    x = sourceBounds.right + (targetBounds.left - sourceBounds.right) / 2;
                    y = sourcePortLocation.y;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetPortLocation.y;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            else {
                //5 segment
                if (Math.abs(targetBounds.top - sourceBounds.bottom) < 30 || Math.abs(targetBounds.bottom - sourceBounds.top) < 30) {
                    if ((sourcePortLocation.x + 15) > targetBounds.right) {
                        x = sourcePortLocation.x + 15;
                        y = sourcePortLocation.y;
                    }
                    else {
                        x = targetBounds.right + 15;
                        y = sourcePortLocation.y;
                    }
                }
                else {
                    x = sourceBounds.right + 15;
                    y = sourcePortLocation.y;
                }
                points.push(ej.datavisualization.Diagram.Point(x, y));
                if ((targetBounds.top - sourceBounds.bottom) >= 30) {
                    y = targetBounds.top - 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                else if (sourcePortLocation.y > targetPortLocation.y) {
                    if ((sourceBounds.top - targetBounds.bottom) < 30) {
                        y = targetBounds.top - 15;
                    }
                    else {
                        y = targetBounds.bottom + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                else {
                    y = targetBounds.bottom + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                x = targetBounds.left - 15;
                points.push(ej.datavisualization.Diagram.Point(x, y));
                y = targetPortLocation.y;
                points.push(ej.datavisualization.Diagram.Point(x, y));
            }
            points.push(targetPortLocation);
            return points;
        },
        _rightToRight: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (targetBounds.right >= sourceBounds.left) {
                if (sourcePortLocation.y >= targetBounds.top && sourcePortLocation.y <= targetBounds.bottom) {
                    x = sourcePortLocation.x + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (sourcePortLocation.y >= targetBounds.center.y) {
                        if (sourcePortLocation.x > targetBounds.left) {
                            if (sourcePortLocation.y > targetPortLocation.y) {
                                y = targetBounds.bottom + 15;
                            }
                            else {
                                y = targetBounds.top - 15;
                            }
                        }
                        else {
                            y = targetBounds.top - 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else if (targetBounds.right < sourceBounds.right) {
                    x = sourceBounds.right + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    points.push(ej.datavisualization.Diagram.Point(x, targetPortLocation.y));
                } else {
                    x = targetPortLocation.x + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    points.push(ej.datavisualization.Diagram.Point(x, targetPortLocation.y));
                }
            }
            else {
                x = sourcePortLocation.x + 15;
                points.push(ej.datavisualization.Diagram.Point(x, y));
                if (targetPortLocation.y >= sourceBounds.top && targetPortLocation.y <= sourceBounds.bottom) {
                    if (targetPortLocation.y <= sourceBounds.center.y) {
                        y = sourceBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = sourceBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            points.push(ej.datavisualization.Diagram.Point(x, targetPortLocation.y));
            points.push(targetPortLocation);
            return points;
        },
        _rightToTop: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                if ((sourcePortLocation.y + 15) >= targetPortLocation.y && targetBounds.height !== 0) {
                    if (targetBounds.left <= sourceBounds.right) {
                        x = targetBounds.right + 15;
                    }
                    else if ((targetBounds.left - sourceBounds.right) > 30) {
                        x = sourceBounds.right + 15;
                    }
                    else {
                        x = sourceBounds.right + (targetBounds.left - sourceBounds.right) / 2;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetBounds.top - 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            else {
                if (sourceBounds.bottom >= targetBounds.top) {
                    if ((sourcePortLocation.x + 15) <= targetBounds.right) {
                        x = targetBounds.right + 15;
                    }
                    else {
                        x = sourceBounds.right + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (sourceBounds.top >= targetBounds.top) {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                    }
                    else {
                        y = sourceBounds.top - 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                else {
                    x = sourcePortLocation.x + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if ((targetBounds.top - sourceBounds.bottom) < 30 && targetBounds.height !== 0) {
                        if ((sourceBounds.left - targetBounds.right) >= 30) {
                            y = sourceBounds.bottom + 15;
                            points.push(ej.datavisualization.Diagram.Point(x, y));
                            x = sourceBounds.left - 15;
                            points.push(ej.datavisualization.Diagram.Point(x, y));
                            y = targetBounds.top - 15;
                            points.push(ej.datavisualization.Diagram.Point(x, y));
                        }
                        else {
                            y = targetBounds.top - (targetBounds.top - sourceBounds.bottom) / 2;
                            points.push(ej.datavisualization.Diagram.Point(x, y));
                        }
                    }
                    else {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _rightToBottom: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                if (sourcePortLocation.y <= targetBounds.bottom) {
                    if (targetBounds.left > (sourceBounds.right + 15)) {
                        x = sourcePortLocation.x + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if ((sourceBounds.right + 15) > targetPortLocation.x) {
                        x = sourcePortLocation.x + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((sourceBounds.top - targetBounds.bottom) > 30) {
                            y = targetBounds.bottom + 15;
                        }
                        else {
                            y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = sourcePortLocation.y;
                    }
                }
            }
            else {
                if (sourcePortLocation.y <= targetBounds.bottom) {
                    if ((sourceBounds.right + 15) > targetBounds.right) {
                        x = sourceBounds.right + 15;
                    }
                    else {
                        x = targetBounds.right + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetBounds.bottom + 15;
                    if (y <= (sourceBounds.bottom + 15)) {
                        y = sourceBounds.bottom + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                else {
                    if ((targetBounds.bottom) < sourceBounds.top) {
                        x = sourceBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((sourceBounds.top - targetBounds.bottom) < 30) {
                            y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        }
                        else {
                            y = targetBounds.bottom + 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        x = sourceBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = sourceBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _leftToLeft: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                x = sourceBounds.left - 15;
                points.push(ej.datavisualization.Diagram.Point(x, y));
                if (sourcePortLocation.y > targetPortLocation.y) {
                    if ((targetPortLocation.y + 15) >= sourceBounds.top) {
                        y = sourceBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((targetBounds.left - sourceBounds.right) > 30) {
                            x = targetBounds.left - 15;
                        }
                        else {
                            x = sourceBounds.right + (targetBounds.left - sourceBounds.right) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetPortLocation.y;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetPortLocation.x;
                    }
                }
                else {
                    if ((sourceBounds.bottom + 15) < targetPortLocation.y) {
                        y = targetPortLocation.y;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetPortLocation.x;
                    }
                    else {
                        y = sourceBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((targetBounds.left - sourceBounds.right) > 30) {
                            x = targetBounds.left - 15;
                        }
                        else {
                            x = sourceBounds.right + (targetBounds.left - sourceBounds.right) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            else {
                if (targetPortLocation.y > sourcePortLocation.y) {
                    if (sourcePortLocation.y > (targetBounds.top - 15)) {
                        if ((sourceBounds.left - targetBounds.right) < 30) {
                            x = targetBounds.right + (sourceBounds.left - targetBounds.right) / 2;
                        }
                        else {
                            x = sourceBounds.left - 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if ((targetBounds.bottom + 15) >= sourcePortLocation.y) {
                        if ((sourceBounds.left - targetBounds.right) < 30) {
                            x = targetBounds.right + (sourceBounds.left - targetBounds.right) / 2;
                        }
                        else {
                            x = sourceBounds.left - 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.left - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                x = targetBounds.left - 15;
                points.push(ej.datavisualization.Diagram.Point(x, y));
            }
            points.push(ej.datavisualization.Diagram.Point(x, targetPortLocation.y));
            points.push(targetPortLocation);
            return points;
        },
        _leftToTop: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (sourcePortLocation.x <= targetPortLocation.x) {
                if (sourcePortLocation.y > targetPortLocation.y && targetBounds.left <= sourceBounds.left) {
                    x = targetBounds.left - 15;
                }
                else {
                    x = sourceBounds.left - 15;
                }
                points.push(ej.datavisualization.Diagram.Point(x, y));
                if (sourceBounds.bottom <= targetBounds.top) {
                    if ((sourceBounds.bottom + 15) < targetBounds.top) {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                    }
                    else if (targetPortLocation.x < sourceBounds.right) {
                        y = sourceBounds.bottom + (targetBounds.top - sourceBounds.bottom) / 2;
                    }
                    else {
                        y = sourceBounds.top - 15;
                    }
                }
                else {
                    if (sourceBounds.top >= targetBounds.top) {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                    }
                    else {
                        y = sourceBounds.top - 15;
                    }
                }
                points.push(ej.datavisualization.Diagram.Point(x, y));
            }
            else {
                if (targetPortLocation.y <= (sourcePortLocation.y + 15) && targetBounds.height !== 0) {
                    if ((sourceBounds.left - targetBounds.right) > 30) {
                        x = sourceBounds.left - 15;
                    }
                    else {
                        if (targetBounds.right >= sourceBounds.left) {
                            x = targetBounds.left - 15;
                        }
                        else {
                            x = targetBounds.right + (sourceBounds.left - targetBounds.right) / 2;
                        }
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetBounds.top - 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _leftToBottom: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            y = sourcePortLocation.y;
            if (sourcePortLocation.x <= targetPortLocation.x) {
                if (targetBounds.left <= sourcePortLocation.x && sourcePortLocation.y <= targetBounds.top) {
                    x = targetBounds.left - 15;
                }
                else {
                    x = sourceBounds.left - 15;
                }
                points.push(ej.datavisualization.Diagram.Point(x, y));
                if (targetBounds.bottom < sourceBounds.top) {
                    if ((sourceBounds.top - targetBounds.bottom) < 30) {
                        y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                    }
                    else {
                        y = targetBounds.bottom + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
                else {
                    if (targetBounds.bottom < sourceBounds.bottom) {
                        y = sourceBounds.bottom + 15;
                    }
                    else {
                        y = targetBounds.bottom + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            else {
                if (!(sourcePortLocation.y > targetPortLocation.y)) {
                    if (targetBounds.right >= sourceBounds.left) {
                        x = targetBounds.left - 15;
                    }
                    else if ((sourceBounds.left - targetBounds.right) < 30) {
                        x = sourceBounds.left - (sourceBounds.left - targetBounds.right) / 2;
                    }
                    else {
                        x = sourceBounds.left - 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetBounds.bottom + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _topToTop: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            x = sourcePortLocation.x;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                if (targetPortLocation.y >= sourcePortLocation.y) {
                    y = sourceBounds.top - 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetPortLocation.x <= sourceBounds.right) {
                        x = sourceBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if (targetBounds.height !== 0) {
                            if ((targetBounds.top - sourceBounds.bottom) > 30) {
                                y = targetBounds.top - 15;
                            }
                            else {
                                y = sourceBounds.bottom + (targetBounds.top - sourceBounds.bottom) / 2;
                            }
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (targetBounds.left <= sourcePortLocation.x) {
                        if ((sourceBounds.top - targetBounds.bottom) > 30) {
                            y = sourceBounds.top - 15;
                        }
                        else {
                            y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.left - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            else {
                if (targetPortLocation.y >= sourcePortLocation.y) {
                    y = sourceBounds.top - 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetPortLocation.x >= sourceBounds.left) {
                        x = sourceBounds.left - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if (targetBounds.height !== 0) {
                            if ((targetBounds.top - sourceBounds.bottom) > 30) {
                                y = targetBounds.top - 15;
                            }
                            else {
                                y = sourceBounds.bottom + (targetBounds.top - sourceBounds.bottom) / 2;
                            }
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (targetBounds.right >= sourcePortLocation.x) {
                        if ((sourceBounds.top - targetBounds.bottom) > 30) {
                            y = sourceBounds.top - 15;
                        }
                        else {
                            y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.top - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        if (targetBounds.height !== 0) {
                            y = targetBounds.top - 15;
                        }
                        else {
                            y = targetPortLocation.y;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            x = targetPortLocation.x;
            points.push(ej.datavisualization.Diagram.Point(x, y));
            points.push(targetPortLocation);
            return points;
        },
        _topToBottom: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            x = sourcePortLocation.x;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                if (sourceBounds.top >= targetBounds.bottom) {
                    if ((sourceBounds.top - targetBounds.bottom) >= 30) {
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((targetBounds.left - sourceBounds.right) >= 30) {
                            x = sourceBounds.right + 15;
                        }
                        else {
                            x = sourceBounds.right + (targetBounds.left - sourceBounds.right) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (targetBounds.top < sourceBounds.top) {
                        if (targetBounds.left >= (sourceBounds.right + 15)) {
                            y = sourceBounds.top - 15;
                        }
                        else {
                            y = targetBounds.top - 15;
                        }
                    }
                    else {
                        y = sourceBounds.top - 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetBounds.left >= (sourceBounds.right + 15)) {
                        x = sourceBounds.right + 15;
                    }
                    else {
                        x = targetBounds.right + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    y = targetBounds.bottom + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            else {
                if (sourceBounds.top >= targetBounds.bottom) {
                    if ((sourceBounds.top - targetBounds.bottom) > 30) {
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if ((sourceBounds.left - targetBounds.right) >= 30) {
                            x = sourceBounds.left - 15;
                        }
                        else {
                            x = targetBounds.right + (sourceBounds.left - targetBounds.right) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (sourceBounds.left >= (targetBounds.right + 15)) {
                        y = sourceBounds.top - 15;
                    }
                    else {
                        y = sourceBounds.top - 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (sourceBounds.left >= (targetBounds.right + 15)) {
                        x = targetBounds.right + 15;
                    }
                    else {
                        x = sourceBounds.right + 15;
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (sourceBounds.left >= (targetBounds.right + 15)) {
                        y = targetBounds.bottom + 15;
                    }
                    else {
                        if (targetBounds.bottom <= sourceBounds.bottom) {
                            y = sourceBounds.bottom + 15;
                        }
                        else {
                            y = targetBounds.bottom + 15;
                        }
                    }
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _bottomToBottom: function (targetBounds, targetPortLocation, sourceBounds, sourcePortLocation) {
            var points = [];
            var x, y;
            points.push(sourcePortLocation);
            x = sourcePortLocation.x;
            if (targetPortLocation.x >= sourcePortLocation.x) {
                if (sourceBounds.bottom >= targetBounds.bottom) {
                    y = sourceBounds.bottom + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if ((targetPortLocation.x) < sourceBounds.right) {
                        x = sourceBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if (sourceBounds.top >= targetBounds.bottom) {
                            if ((sourceBounds.top - targetBounds.bottom) >= 30) {
                                y = targetBounds.bottom + 15;
                            }
                            else {
                                y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                            }
                        }
                        else {
                            y = targetBounds.bottom + 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (sourcePortLocation.x > targetBounds.left) {
                        if ((targetBounds.bottom - sourceBounds.bottom) >= 30) {
                            y = sourceBounds.bottom + 15;
                        }
                        else {
                            y = sourceBounds.bottom + (targetBounds.bottom - sourceBounds.bottom) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.left - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            else {
                if (sourceBounds.bottom >= targetBounds.bottom) {
                    y = sourceBounds.bottom + 15;
                    points.push(ej.datavisualization.Diagram.Point(x, y));
                    if (targetPortLocation.x > sourceBounds.left) {
                        x = sourceBounds.left - 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        if (sourceBounds.top >= targetBounds.bottom) {
                            if ((sourceBounds.top - targetBounds.bottom) >= 30) {
                                y = targetBounds.bottom + 15;
                            }
                            else {
                                y = targetBounds.bottom + (sourceBounds.top - targetBounds.bottom) / 2;
                            }
                        }
                        else {
                            y = targetBounds.bottom + 15;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
                else {
                    if (sourcePortLocation.x < targetBounds.right) {
                        if ((targetBounds.bottom - sourceBounds.bottom) >= 30) {
                            y = sourceBounds.bottom + 15;
                        }
                        else {
                            y = sourceBounds.bottom + (targetBounds.bottom - sourceBounds.bottom) / 2;
                        }
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        x = targetBounds.right + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                    else {
                        y = targetBounds.bottom + 15;
                        points.push(ej.datavisualization.Diagram.Point(x, y));
                    }
                }
            }
            points.push(ej.datavisualization.Diagram.Point(targetPortLocation.x, y));
            points.push(targetPortLocation);
            return points;
        },
        _addOrthogonalPoints: function (points, startPoint, endPoint) {
            var ctrlPoints = this._constructOrthogonalPoints(startPoint, endPoint);
            points.push(ctrlPoints[0]);
            points.push(ctrlPoints[1]);
        },
        _constructOrthogonalPoints: function (startPoint, endPoint, update) {
            var divideX = false;
            if (update != undefined) {
                divideX = update;
            }
            else {
                var dx = Math.abs(startPoint.x - endPoint.x);
                var dy = Math.abs(startPoint.y - endPoint.y);
                if (dx > dy) {
                    divideX = true;
                }
            }
            var points = [];
            var ctrlPoint1;
            var ctrlPoint2;
            if (divideX) {
                ctrlPoint1 = ej.datavisualization.Diagram.Point(startPoint.x + (endPoint.x - startPoint.x) / 2, startPoint.y);
                ctrlPoint2 = ej.datavisualization.Diagram.Point(startPoint.x + (endPoint.x - startPoint.x) / 2, endPoint.y);
            } else {
                ctrlPoint1 = ej.datavisualization.Diagram.Point(startPoint.x, startPoint.y + (endPoint.y - startPoint.y) / 2);
                ctrlPoint2 = ej.datavisualization.Diagram.Point(endPoint.x, startPoint.y + (endPoint.y - startPoint.y) / 2);
            }
            points.push(ctrlPoint1);
            points.push(ctrlPoint2);
            return points;
        },
        _updateOrthogonalPoints: function (line, side) {
            var points = [];
            points.push(line.startPoint);
            var ctrlPoints = this._constructOrthogonalPoints(line.startPoint, line.endPoint, side);
            points.push(ctrlPoints[0]);
            points.push(ctrlPoints[1]);
            points.push(line.endPoint);
            line.points = points;
        },
        _resetOrthogonalPoints: function (line) {
            var points = [];
            points.push(line.startPoint);
            points.push(line.endPoint);
            line.points = [];
            line.startPoint = points[0];
            line.points.push(points[0]);
            var ctrlPoints = this._constructOrthogonalPoints(points[0], points[1]);
            line.points.push(ctrlPoints[0]);
            line.points.push(ctrlPoints[1]);
            line.endPoint = points[1];
            line.points.push(points[1]);
        },
        _updateBezierPoints: function (line, targetNode, targetPort, targetBounds, sourceNode, sourcePort, sourceBounds) {
            var bounds;
            var angles = { "right": 0, "left": 180, "top": 270, "bottom": 90 };
            if (line.point1 == null || line.point2 == null) {
                var target = line.endPoint;
                var source = line.startPoint;
                var dir;
                var matrix;
                if (!sourcePort)
                    dir = this._getBezierDirection(source, target);
                else {
                    bounds = sourceBounds;
                    source = this._getPortPosition(sourcePort, bounds);
                    if (sourceNode.rotateAngle !== 0) {
                        matrix = ej.Matrix.identity();
                        ej.Matrix.rotate(matrix, sourceNode.rotateAngle, sourceNode.offsetX, sourceNode.offsetY);
                        source = ej.Matrix.transform(matrix, source);
                    }
                    dir = this._getDirection(bounds, source);
                }
                line._point1 = line.point1 || this._getBezierAdjPoint(angles[dir], line.startPoint, line.endPoint);
                if (!targetPort) {
                    dir = this._getBezierDirection(target, source);
                }
                else {
                    bounds = targetBounds;
                    target = this._getPortPosition(targetPort, bounds);
                    if (targetNode.rotateAngle !== 0) {
                        matrix = ej.Matrix.identity();
                        ej.Matrix.rotate(matrix, targetNode.rotateAngle, targetNode.offsetX, targetNode.offsetY);
                        target = ej.Matrix.transform(matrix, target);
                    }
                    dir = this._getDirection(bounds, target);
                }
                line._point2 = line.point2 || this._getBezierAdjPoint(angles[dir], line.endPoint, line.startPoint);
            }
        },
        _getBezierDirection: function (src, tar) {
            if (Math.abs(tar.x - src.x) > Math.abs(tar.y - src.y)) {
                return src.x < tar.x ? "right" : "left";
            }
            else {
                return src.y < tar.y ? "bottom" : "top";
            }
        },
        _getDirection: function (bounds, point) {
            var points = bounds.points;
            var center = bounds.center;
            var direction;
            var angle = ej.datavisualization.Diagram.Geometry.findAngle(point, center);
            if (angle > ej.datavisualization.Diagram.Geometry.findAngle(points[0], center) && angle <= ej.datavisualization.Diagram.Geometry.findAngle(points[1], center)) {
                direction = "top";
            }
            else if (angle >= ej.datavisualization.Diagram.Geometry.findAngle(points[1], center) && angle <= ej.datavisualization.Diagram.Geometry.findAngle(points[2], center)) {
                direction = "right";
            }
            else if (angle >= ej.datavisualization.Diagram.Geometry.findAngle(points[3], center) || angle < ej.datavisualization.Diagram.Geometry.findAngle(points[0], center)) {
                direction = "left";
            }
            else if (angle >= ej.datavisualization.Diagram.Geometry.findAngle(points[2], center) && angle <= ej.datavisualization.Diagram.Geometry.findAngle(points[3], center)) {
                direction = "bottom";
            }
            else {
                direction = "right";
            }
            return direction;
        },
        _getBezierAdjPoint: function (angle, srcEnd, tarEnd) {
            var distance = 60;
            var endAdj = ej.datavisualization.Diagram.Point(0, 0);
            var dir;
            if (angle > 45 && angle < 135) {
                dir = "Bottom";
            }
            else if (angle > 135 && angle < 225) {
                dir = "Left";
            }
            else if (angle > 225 && angle < 315) {
                dir = "Top";
            }
            else {
                dir = "Right";
            }
            switch (dir) {
                case "Right":
                    distance = Math.min(Math.abs(srcEnd.x - tarEnd.x) * 0.45, distance);
                    endAdj = ej.datavisualization.Diagram.Point(srcEnd.x + distance, srcEnd.y);
                    break;
                case "Bottom":
                    distance = Math.min(Math.abs(srcEnd.y - tarEnd.y) * 0.45, distance);
                    endAdj = ej.datavisualization.Diagram.Point(srcEnd.x, srcEnd.y + distance);
                    break;
                case "Left":
                    distance = Math.min(Math.abs(srcEnd.x - tarEnd.x) * 0.45, distance);
                    endAdj = ej.datavisualization.Diagram.Point(srcEnd.x - distance, srcEnd.y);
                    break;
                case "Top":
                    distance = Math.min(Math.abs(srcEnd.y - tarEnd.y) * 0.45, distance);
                    endAdj = ej.datavisualization.Diagram.Point(srcEnd.x, srcEnd.y - distance);
                    break;
            }
            return endAdj;
        },
        _setLineEndPoint: function (connector, point, isTarget, dock) {
            var line = connector.line;
            if (line.type === "orthogonal") {
                if (!this.isTargetConnected(connector) || !this.isSourceConnected(connector)) {
                    this._resetOrthogonalPoints(line);
                }
            }
            if (isTarget) {
                line.endPoint = line.points[line.points.length - 1] = point;
            }
            else {
                line.startPoint = line.points[0] = point;
            }
            if (line.type === "orthogonal") {
                this._updateOrthogonalPoints(line, dock);
            }
            else if (line.type === "bezier") {
                this._updateBezierPoints(line);
            }
        },
        _setBezierPoint: function (connector, point, whichpoint) {
            var line = connector.line;
            if (whichpoint === "bezierpoint1") {
                line.point1 = line._point1 = point;
            }
            else {
                line.point2 = line._point2 = point;
            }
        },
        _setPoints: function (line, points) {
            line.startPoint = line.points[0] = points[0];
            line.endPoint = line.points[line.points.length - 1] = points[points.length - 1];
            line.points = points;
            if (line.type === "bezier") {
                line.point1 = points[2] || line.point1;
                line.point2 = points[3] || line.point2;
                if (!line.point1)
                    line._point1 = line.point1;
                if (!line.point2)
                    line._point2 = line.point2;
                this._updateBezierPoints(line);
            }
        },
        _translateLine: function (line, dx, dy, parent) {
            if (line.type === ej.datavisualization.Diagram.Lines.Orthogonal && parent) {
                if (!this.isTargetConnected(parent) || !this.isSourceConnected(parent)) {
                    this._resetOrthogonalPoints(line);
                }
            }
            var points = line.points;
            for (var i = 0, len = points.length; i < len; ++i) {
                points[i] = ej.datavisualization.Diagram.Geometry.translate(points[i], dx, dy);
            }
            line.startPoint = points[0];
            line.endPoint = points[points.length - 1];
            if (line.type === ej.datavisualization.Diagram.Lines.Bezier) {
                line._point1 = ej.datavisualization.Diagram.Geometry.translate(line._point1, dx, dy);
                line._point2 = ej.datavisualization.Diagram.Geometry.translate(line._point2, dx, dy);
                if (line.point1) { line.point1 = line._point1; }
                if (line.point2) { line.point2 = line._point2; }
            }
        },
        _getLabelPosition: function (label, bounds) {
            var x = (bounds.width * label.offset.x);
            var y = (bounds.height * label.offset.y);
            return ej.datavisualization.Diagram.Point(x, y);
        },
        _getPortPosition: function (port, bounds, bExcludeBoundsLocation) {
            if (bExcludeBoundsLocation) {
                return ej.datavisualization.Diagram.Point(bounds.width * port.offset.x, bounds.height * port.offset.y);
            }
            else {
                var x = bounds.x + (bounds.width * port.offset.x);
                var y = bounds.y + (bounds.height * port.offset.y);
                return ej.datavisualization.Diagram.Point(x, y);
            }
        },
        _updateGroupBounds: function (node, nameTable) {
            if (node && node.isGroup && node.children.length > 0) {
                this._updateRotateAngle(node, nameTable);
                var bounds = this._getChildrenBounds(node, nameTable);
                var x = bounds.x + bounds.width * node.pivot.x;
                var y = bounds.y + bounds.height * node.pivot.y;
                var matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, node.rotateAngle);
                var newposition = ej.Matrix.transform(matrix, { x: x, y: y });
                if (bounds) {
                    node.offsetX = newposition.x;
                    node.offsetY = newposition.y;
                    node.width = bounds.width;
                    node.height = bounds.height;
                }
            }
        },
        _getChildrenBounds: function (group, nameTable) {
            var children = group.children, rect, bounds = null, child;
            if (children.length > 0) {
                child = nameTable[children[0]];
                bounds = this._rotateChildBounds(child, group);
            }
            for (var i = 1, len = children.length; i < len; i++) {
                child = nameTable[children[i]];
                if (child.isGroup) {
                    this._updateGroupBounds(child, nameTable);
                    rect = this._rotateChildBounds(child, group);
                } else
                    rect = this._rotateChildBounds(child, group);
                if (rect)
                    bounds = ej.datavisualization.Diagram.Geometry.union(bounds, rect);
            }
            return bounds;
        },

        _updateRotateAngle: function (node, nameTable) {
            if (node.offsetX == 0 && node.offsetY == 0 && node.width == 0 && node.height == 0) {
                for (var i = 0; i < node.children.length; i++) {
                    var child = nameTable[node.children[i]];
                    if (!child.line && !node.rotateAngle) {
                        node.rotateAngle = child.rotateAngle;
                        return;
                    }
                }
            }
        },

        _rotateChildBounds: function (child, group) {
            var matrix = ej.Matrix.identity();
            ej.Matrix.rotate(matrix, -group.rotateAngle);
            var bounds = this.bounds(child);
            var topleft = ej.Matrix.transform(matrix, bounds.topLeft);
            var topright = ej.Matrix.transform(matrix, bounds.topRight);
            var bottomLeft = ej.Matrix.transform(matrix, bounds.bottomLeft);
            var bottomRight = ej.Matrix.transform(matrix, bounds.bottomRight);
            var x = Math.min(topleft.x, topright.x, bottomLeft.x, bottomRight.x);
            var y = Math.min(topleft.y, topright.y, bottomLeft.y, bottomRight.y);
            return {
                x: x,
                width: Math.max(topleft.x, topright.x, bottomLeft.x, bottomRight.x) - x,
                y: y,
                height: Math.max(topleft.y, topright.y, bottomLeft.y, bottomRight.y) - y
            };
        },
    };
    //#endregion

    //#region Geometry
    ej.datavisualization.Diagram.Geometry = {
        checkPointOnCircle: function (point, center, radius) {
            var r2 = Math.pow(radius, 2);
            var x2 = Math.pow((point.x - center.x), 2);
            var y2 = Math.pow((point.y - center.y), 2);
            if ((x2 + y2) <= r2) {
                return true;
            }
            return false;
        },
        rect: function (points) {
            var rectangle = ej.datavisualization.Diagram.Rectangle();
            if (arguments.length === 1) {
                var left = Number.MAX_VALUE;
                var top = Number.MAX_VALUE;
                var right = Number.MIN_VALUE;
                var bottom = Number.MIN_VALUE;
                var len = points.length;
                var x, y;
                for (var i = 0; i < len; i++) {
                    x = points[i].x;
                    y = points[i].y;
                    if (x < left) {
                        left = x;
                    }
                    if (x > right) {
                        right = x;
                    }
                    if (y < top) {
                        top = y;
                    }
                    if (y > bottom) {
                        bottom = y;
                    }
                }
                rectangle = ej.datavisualization.Diagram.Rectangle(left, top, right - left, bottom - top);
            }
            else if (arguments.length === 2) {
                var ptStart = ej.datavisualization.Diagram.Point(arguments[0]);
                var ptEnd = ej.datavisualization.Diagram.Point(arguments[1]);
                var swap;
                if (ptStart.x > ptEnd.x) {
                    swap = ptStart.x;
                    ptStart.x = ptEnd.x;
                    ptEnd.x = swap;
                }
                if (ptStart.y > ptEnd.y) {
                    swap = ptStart.y;
                    ptStart.y = ptEnd.y;
                    ptEnd.y = swap;
                }
                rectangle = ej.datavisualization.Diagram.Rectangle(ptStart.x, ptStart.y, ptEnd.x - ptStart.x, ptEnd.y - ptStart.y);
            }
            return rectangle;
        },
        union: function (rect1, rect2) {
            var x = Math.min(rect1.x, rect2.x);
            var y = Math.min(rect1.y, rect2.y);
            var width = Math.max(rect1.x + rect1.width, rect2.x + rect2.width);
            var height = Math.max(rect1.y + rect1.height, rect2.y + rect2.height);
            return ej.datavisualization.Diagram.Rectangle(x, y, width - x, height - y);
        },
        distance: function (pt1, pt2) {
            return Math.sqrt(Math.pow(pt2.x - pt1.x, 2) + Math.pow(pt2.y - pt1.y, 2));
        },
        translate: function (pt1, dx, dy) {
            return ej.datavisualization.Diagram.Point(pt1.x + dx, pt1.y + dy);
        },
        intersectsRect: function (rect1, rect2) {
            return ((((rect2.x < (rect1.x + rect1.width)) && (rect1.x < (rect2.x + rect2.width)))
                && (rect2.y < (rect1.y + rect1.height))) && (rect1.y < (rect2.y + rect2.height)));
        },
        findAngle: function (point1, point2) {
            var angle = Math.atan2(point2.y - point1.y, point2.x - point1.x);
            angle = (180 * angle / Math.PI);
            angle %= 360;
            if (angle < 0) {
                angle += 360;
            }
            return angle;
        },
        intersectSegment: function (segment1, segment2) {
            var x1 = segment1.point1.x;
            var y1 = segment1.point1.y;
            var x2 = segment1.point2.x;
            var y2 = segment1.point2.y;
            var x3 = segment2.point1.x;
            var y3 = segment2.point1.y;
            var x4 = segment2.point2.x;
            var y4 = segment2.point2.y;
            var a1, a2, b1, b2, c1, c2, x, y;
            var r1, r2, r3, r4;
            var denom, offset, num;
            a1 = y2 - y1;
            b1 = x1 - x2;
            c1 = (x2 * y1) - (x1 * y2);
            r3 = ((a1 * x3) + (b1 * y3) + c1);
            r4 = ((a1 * x4) + (b1 * y4) + c1);
            if ((r3 !== 0) && (r4 !== 0) && this.sameSign(r3, r4)) {
                return null;
            }
            a2 = y4 - y3;
            b2 = x3 - x4;
            c2 = (x4 * y3) - (x3 * y4);
            r1 = (a2 * x1) + (b2 * y1) + c2;
            r2 = (a2 * x2) + (b2 * y2) + c2;
            if ((r1 !== 0) && (r2 !== 0) && (this.sameSign(r1, r2))) {
                return null;
            }
            denom = (a1 * b2) - (a2 * b1);

            if (denom === 0) {
                return null;
            }

            if (denom < 0) {
                offset = -denom / 2;
            }
            else {
                offset = denom / 2;
            }
            num = (b1 * c2) - (b2 * c1);
            if (num < 0) {
                x = (num - offset) / denom;
            }
            else {
                x = (num + offset) / denom;
            }

            num = (a2 * c1) - (a1 * c2);
            if (num < 0) {
                y = (num - offset) / denom;
            }
            else {
                y = (num + offset) / denom;
            }
            return ej.datavisualization.Diagram.Point(x, y);
        },

        updatePath: function (x, y, width, height, pathData, svg, bounds) {
            var bBox, isInit;
            if (svg && svg.pathBounds) {
                isInit = true;
                bBox = svg.pathBounds(pathData);
            }
            else {
                isInit = false;
                bBox = bounds;
            }

            var newX = 0, newY = 0;
            var isResize = false;
            if (x.toString() !== bBox.x || y.toString() !== bBox.y) {
                newX = x - Number(bBox.x);
                newY = y - Number(bBox.y);
            }
            if (width !== bBox.width || height !== bBox.height) {
                newX = width / Number(bBox.width);
                newY = height / Number(bBox.height);
                isResize = true;
            }
            return ej.datavisualization.Diagram.Geometry.processPathData(pathData, newX, newY, isResize, bBox.x, bBox.y, x, y, isInit, svg);
        },

        processPathData: function (path, newX, newY, isResizing, oldX, oldY, offsetX, offsetY, isInit, svg) {
            var shape = document.createElementNS('http://www.w3.org/2000/svg', "path");
            shape.setAttribute("d", path);
            if (isInit && svg) {
                path = svg.absolutePath(shape).getAttribute('d');
                shape.setAttribute("d", path);
            }
            var x0, y0, x1, y1, x2, y2, segs = shape.pathSegList;
            for (var x = 0, y = 0, i = 0, length = segs.numberOfItems; i < length; ++i) {
                var seg = segs.getItem(i), char = seg.pathSegTypeAsLetter;

                if ('x1' in seg) x1 = seg.x1;
                if ('x2' in seg) x2 = seg.x2;
                if ('y1' in seg) y1 = seg.y1;
                if ('y2' in seg) y2 = seg.y2;
                if ('x' in seg) x = seg.x;
                if ('y' in seg) y = seg.y;


                if (isResizing) {
                    if (x != undefined) {
                        x = ej.datavisualization.Diagram.Geometry.scalePathData(x, newX, oldX, offsetX);
                    }
                    if (y != undefined) {
                        y = ej.datavisualization.Diagram.Geometry.scalePathData(y, newY, oldY, offsetY);
                    }
                    if (x1 != undefined) {
                        x1 = ej.datavisualization.Diagram.Geometry.scalePathData(x1, newX, oldX, offsetX);
                    }
                    if (y1 != undefined) {
                        y1 = ej.datavisualization.Diagram.Geometry.scalePathData(y1, newY, oldY, offsetY);
                    }
                    if (x2 != undefined) {
                        x2 = ej.datavisualization.Diagram.Geometry.scalePathData(x2, newX, oldX, offsetX);
                    }
                    if (y2 != undefined) {
                        y2 = ej.datavisualization.Diagram.Geometry.scalePathData(y2, newY, oldY, offsetY);
                    }
                }

                else {
                    if (x != undefined) {
                        x = (x + newX);
                    }
                    if (y != undefined) {
                        y = (y + newY);
                    }
                    if (x1 != undefined) {
                        x1 = (x1 + newX);
                    }
                    if (y1 != undefined) {
                        y1 = (y1 + newY);
                    }
                    if (x2 != undefined) {
                        x2 = (x2 + newX);
                    }
                    if (y2 != undefined) {
                        y2 = (y2 + newY);
                    }
                }

                switch (char) {
                    case 'M':
                        segs.replaceItem(shape.createSVGPathSegMovetoAbs(x, y), i);
                        break;
                    case 'L':
                        segs.replaceItem(shape.createSVGPathSegLinetoAbs(x, y), i);
                        break;
                    case 'H':
                        segs.replaceItem(shape.createSVGPathSegLinetoHorizontalAbs(x), i);
                        break;
                    case 'V':
                        segs.replaceItem(shape.createSVGPathSegLinetoVerticalAbs(y), i);
                        break;
                    case 'C':
                        segs.replaceItem(shape.createSVGPathSegCurvetoCubicAbs(x, y, x1, y1, x2, y2), i);
                        break;
                    case 'S':
                        segs.replaceItem(shape.createSVGPathSegCurvetoCubicSmoothAbs(x, y, x2, y2), i);
                        break;
                    case 'Q':
                        segs.replaceItem(shape.createSVGPathSegCurvetoQuadraticAbs(x, y, x1, y1), i);
                        break;
                    case 'T':
                        segs.replaceItem(shape.createSVGPathSegCurvetoQuadraticSmoothAbs(x, y), i);
                        break;
                    case 'A':
                        var r1 = seg.r1, r2 = seg.r2;
                        if (isResizing) {
                            r1 = (r1 * newX);
                            r2 = (r2 * newY);
                        }
                        segs.replaceItem(shape.createSVGPathSegArcAbs(x, y, r1, r2, seg.angle, seg.largeArcFlag, seg.sweepFlag), i);
                        break;
                    case 'Z':
                        x = x0; y = y0;
                        break;
                }
                // Record the start of a subpath
                if (char === 'M' || char === 'm') x0 = x, y0 = y;
            }
            var pathData = shape.getAttribute("d");
            return pathData;
        },

        scalePathData: function (val, scaleFactor, oldOffset, newOffset) {
            if (val !== oldOffset) {
                if (newOffset !== oldOffset) {
                    val = (((val * scaleFactor) - (Number(oldOffset) * scaleFactor - Number(oldOffset)))
                        + (newOffset - Number(oldOffset)));
                }
                else
                    val = ((Number(val) * scaleFactor) - (Number(oldOffset) * scaleFactor - Number(oldOffset)));
            }
            else {
                if (newOffset !== oldOffset) {
                    val = newOffset;
                }
            }
            return val;
        },

        updatePolygonPoints: function (node, points) {
            if (node.shape.points) {
                if (!points)
                    points = node.shape.points;
                ej.datavisualization.Diagram.Geometry.scalePoints(points, node);
                var bounds = ej.datavisualization.Diagram.Geometry.rect(points);
                for (var i = 0, len = points.length; i < len; ++i) {
                    var point = ej.datavisualization.Diagram.Geometry.translate(points[i], -bounds.x, -bounds.y);
                    point = ej.datavisualization.Diagram.Geometry.translate(point, 0, 0);
                    points[i] = point;
                }
            }
        },

        scalePoints: function (points, node) {
            var bounds = ej.datavisualization.Diagram.Geometry.rect(points);
            if (bounds.width > 0 && bounds.height > 0) {
                var scaleX = node.width / bounds.width;
                var scaleY = node.height / bounds.height;
                for (var i = 0, len = points.length; i < len; ++i) {
                    points[i].x = points[i].x * scaleX;
                    points[i].y = points[i].y * scaleY;
                }
            }
        },

        sameSign: function (a, b) {
            return ((a * b) >= 0);
        },
        containsPoint: function (rect, point) {
            return ((((rect.x <= point.x) && (point.x < (rect.x + rect.width)))
            && (rect.y <= point.y)) && (point.y < (rect.y + rect.height)));
        },
        containsRect: function (rect, value) {
            return ((((rect.x <= value.x) && ((value.x + value.width) <= (rect.x + rect.width)))
               && (rect.y <= value.y)) && ((value.y + value.height) <= (rect.y + rect.height)));
        },
        inflate: function (rect, x, y) {
            rect.x -= x;
            rect.y -= y;
            rect.width += 2 * x;
            rect.height += 2 * y;
        },
        isEmptyRect: function (rect) {
            return rect.x === 0 && rect.y === 0 && rect.width === 0 && rect.height === 0;
        },
        isEmptyPoint: function (point) {
            return point.x === 0 && point.y === 0;
        },
        isEmptySize: function (size) {
            return size.width === 0 && size.height === 0;
        },
        length: function (segment) {
            return ej.datavisualization.Diagram.Geometry.distance(segment.point1, segment.point2);
        },
        midPoint: function (segment) {
            return ej.datavisualization.Diagram.Point((segment.point1.x + segment.point2.x) / 2, (segment.point1.y + segment.point2.y) / 2);
        }
    };
    ej.datavisualization.Diagram.Segment = function (point1, point2) {
        return { "point1": point1, "point2": point2 };
    };
    ej.datavisualization.Diagram.Point = function (x, y) {
        return { "x": Number(x) || 0, "y": Number(y) || 0 };
    };
    ej.datavisualization.Diagram.Size = function (width, height) {
        return { "width": Number(width) || 0, "height": Number(height) || 0 };
    };
    ej.datavisualization.Diagram.Rectangle = function (x, y, width, height) {
        return { "x": Number(x) || 0, "y": Number(y) || 0, "width": Number(width) || 0, "height": Number(height) || 0 };
    };
    //#endregion

    //#region Enums
    /**
    * Enum for various decorator shapes in diagram	 
    * @enum {string}
    * @global 
    */
    ej.datavisualization.Diagram.DecoratorShapes = {
        /**Used to set decorator shape as none */
        None: "none",
        /**Used to set decorator shape as Arrow*/
        Arrow: "arrow",
        /**Used to set decorator shape as Open Arrow */
        OpenArrow: "openarrow",
        /**Used to set decorator shape as Circle */
        Circle: "circle",
        /**Used to set decorator shape as Diamond */
        Diamond: "diamond",
        /**Used to set decorator shape as path */
        Path: "path"
    };
    /**
    * Enum for various port shapes in diagram	 
    * @enum {string}
    * @global 
    */
    ej.datavisualization.Diagram.PortShapes = {
        /**Used to set port shape as X*/
        X: "x",
        /**Used to set port shape as Circle*/
        Circle: "circle",
        /**Used to set port shape as Square*/
        Square: "square",
        /**Used to set port shape as Path*/
        Path: "path"
    };
    /**
 * Enum for port visibility in diagram	 
 * @enum {PortVisibility}
 * @global 
 */
    ej.datavisualization.Diagram.PortVisibility = {
        /**Set the port visibility as Visible*/
        Visible: 1 << 0,
        /**Set the port visibility as Hidden*/
        Hidden: 1 << 1,
        /**Port get visible when hover connector on node*/
        Hover: 1 << 2,
        /** Port gets visibile when connect connector to node*/
        Connect: 1 << 3,
        /**Specifies the port visibility as default*/
        Default: 1 << 2 | 1 << 3
    };
    /**
* Enum for the Text Alignment in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.TextAlign = {
        /** Used to align text on left side of node/connector*/
        Left: "left",
        /** Used to align text on center of node/connector*/
        Center: "center",
        /** Used to align text on Right side of node/connector*/
        Right: "right"
    };
    /**
* Enum for Horizontal Alignment of text in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.HorizontalAlignment = {
        /** Used to align text horizontally on left side of node/connector*/
        Left: "left",
        /** Used to align text horizontally on center of node/connector*/
        Center: "center",
        /** Used to align text horizontally on right side of node/connector*/
        Right: "right"
    };
    /**
* Enum for LabelEditMode of text in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.LabelEditMode = {
        /** Used to set label edit mode as edit*/
        Edit: "edit",
        /** Used to set label edit mode as view*/
        View: "view"
    };
    /**
    * Enum for Vertical Alignment of text in diagram	 
    * @enum {string}
    * @global 
    */
    ej.datavisualization.Diagram.VerticalAlignment = {
        /** Used to align text Vertically on left side of node/connector*/
        Top: "top",
        /** Used to align text Vertically on center of node/connector*/
        Center: "center",
        /** Used to align text Vertically on bottom of node/connector*/
        Bottom: "bottom"
    };
    /**
* Enum for TextDecorations in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.TextDecorations = {
        /** Used to set text decoration of the label as Underline*/
        Underline: "underline",
        /** Used to set text decoration of the label as Overline*/
        Overline: "overline",
        /** Used to set text decoration of the label as LineThrough*/
        LineThrough: "line-through",
        /** Used to set text decoration of the label as None*/
        None: "none"
    };
    /**
* Enum for the NodeConstraints in diagram	 
* @enum {NodeConstraints}
* @global 
*/
    ej.datavisualization.Diagram.NodeConstraints = {
        /**Disable all node Constraints */
        None: 1 << 0,
        /**Enables node to be selected*/
        Select: 1 << 1,
        /**Enables node to be Deleted*/
        Delete: 1 << 2,
        /**Enables node to be Resized */
        Resize: 1 << 3,
        /**Enables node to be Dragged*/
        Drag: 1 << 4,
        /**Enables node to be Rotated*/
        Rotate: 1 << 5,
        /**Enables node to be connected*/
        Connect: 1 << 6,
        /**Enables all node constraints*/
        Default: 1 << 1 | 1 << 2 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6
    };
    /**
* Enum for ConnectorConstraints in diagram	 
* @enum {ConnectorConstraints}
* @global 
*/
    ej.datavisualization.Diagram.ConnectorConstraints = {
        /**Disable all connector Constraints */
        None: 1 << 0,
        /**Enables connector to be selected*/
        Select: 1 << 1,
        /**Enables connector to be Deleted*/
        Delete: 1 << 2,
        /**Enables connector to be Dragged*/
        Drag: 1 << 3,
        /**Enables connectors source end to be selected*/
        DragSourceEnd: 1 << 4,
        /**Enables connectors target end to be selected*/
        DragTargetEnd: 1 << 5,
        /**Enables control point and end point of every segment in a connector for editing*/
        DragSegmentThumb: 1 << 6,
        /**Enables all constraints*/
        Default: 1 << 1 | 1 << 2 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6
    };
    /**
* Enum for PortConstraints in diagram	 
* @enum {PortConstraints}
* @global 
*/
    ej.datavisualization.Diagram.PortConstraints = {
        /**Disable all constraints*/
        None: 1 << 0,
        /**Enables connections with connector*/
        Connect: 1 << 1
    };
    /**
* Enum for specify the SelectorConstraints in diagram	 
* @enum {SelectorConstraints}
* @global 
*/
    ej.datavisualization.Diagram.SelectorConstraints = {
        /** Disables all constraints*/
        None: 1 << 0,
        /** Enables the rotation handle when select node*/
        Rotator: 1 << 1,
        /**Enables the resize when select node*/
        Resizer: 1 << 2,
        /** Enables the user handles when select node*/
        UserHandles: 1 << 3,
        /** Enables all the constraints*/
        All: 1 << 1 | 1 << 2 | 1 << 3
    };
    /**
* Enum for Position in diagram	 
* @enum {String}
* @global 
*/
    ej.datavisualization.Diagram.UserHandlePositions = {
        /**Used to set position as TopLeft*/
        TopLeft: "topleft",
        /**Used to set position as TopCenter*/
        TopCenter: "topcenter",
        /**Used to set position as TopRight*/
        TopRight: "topright",
        /**Used to set position as MiddleLeft*/
        MiddleLeft: "middleleft",
        /**Used to set position as  MiddleRight*/
        MiddleRight: "middleright",
        /**Used to set position as BottomLeft*/
        BottomLeft: "bottomleft",
        /**Used to set position as BottomCenter*/
        BottomCenter: "bottomcenter",
        /**Used to set position as BottomRight*/
        BottomRight: "bottomright"
    };
    /**
* Enum for SnapConstraints in diagram	 
* @enum {SnapConstraints}
* @global 
*/
    ej.datavisualization.Diagram.SnapConstraints = {
        /**Enables node to be snapped to horizontal gridlines*/
        None: 0,
        /**Enables node to be snapped to vertical gridlines*/
        SnapToHorizontalLines: 1,
        /**Enables node to be snapped to horizontal gridlines*/
        SnapToVerticalLines: 2,
        /**Enables node to be snapped to gridlines*/
        SnapToLines: 1 | 2,
        /**Enable horizontal lines*/
        ShowHorizontalLines: 4,
        /**Enable vertical lines*/
        ShowVerticalLines: 8,
        /**Enable both horizontal and vertical lines*/
        ShowLines: 4 | 8,
        /**Enable all the constraints*/
        All: 1 | 2 | 4 | 8
    };
    /**
* Enum for PageOrientations in diagram	 
* @enum {String}
* @global 
*/
    ej.datavisualization.Diagram.PageOrientations = {
        /** Used to set orientation as Landscape*/
        Landscape: "landscape",
        /** Used to set orientation as portrait*/
        Portrait: "portrait"
    };
    
   /**
   * Enum for LayoutOrientations in diagram	
   * @enum {String}
   * @global 
   */
    ej.datavisualization.Diagram.LayoutOrientations = {
        /** Used to set LayoutOrientation from top to bottom */
        TopToBottom: "toptobottom",
        /** Used to set LayoutOrientation from bottom to top */
        BottomToTop: "bottomtotop",
        /** Used to set LayoutOrientation from left to right */
        LeftToRight: "lefttoright",
        /** Used to set LayoutOrientation from right to left */
        RightToLeft: "righttoleft"
    };
    //#endregion

    //#region Palette
    ej.datavisualization.Diagram.PaletteDefaults = {
        /** specifies the name of the palette
     * @default ""
     * @type {String}
     * @example
     * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
      var palette = [{name: "Basic Shapes"}];
     *  $("#symbolpalette").ejSymbolPalette({palettes:palette});
     * &lt;/script&gt
     * @memberof ejSymbolpalette
     * @instance
     */
        name: "",
        /** Enable or disable the expand property of palette
      * @default false
      * @type {Boolean}
      * @example
      * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
       var palette = [{expanded: true}];
      *  $("#symbolpalette").ejSymbolPalette({palettes:palette});
      * &lt;/script&gt
      * @memberof ejSymbolpalette
      * @instance
      */
        expanded: false,
        subControlId: null,
        /** Collection of items in plaette
    * @default []
    * @type {Array}
    * @example
    * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
     var palette = [{ items:[{ name: "Triangle"},{ name: "Ellipse"}]}];
    *  $("#symbolpalette").ejSymbolPalette({palettes:palette});
    * &lt;/script&gt
    * @memberof ejSymbolpalette
    * @instance
    */
        items: []
    };
    ej.datavisualization.Diagram.Palette = function (options) {
        if (options.items)
            for (var i = 0; i < options.items.length; i++) {
                if (options.items[i].line)
                    options.items[i] = ej.datavisualization.Diagram.Connector(options.items[i]);
                else if (options.items[i].isGroup)
                    options.items[i] = ej.datavisualization.Diagram.Group(options.items[i]);
                else
                    options.items[i] = ej.datavisualization.Diagram.Node(options.items[i]);
            }
        return $.extend(true, {}, ej.datavisualization.Diagram.PaletteDefaults, options);
    };
    //#endregion

    //#region Shapes
    /**
* Enum for various shapes of node in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.Shapes = {
        /**Used to specify node Shape as Rectangle*/
        Rectangle: "rectangle",
        /**Used to specify node Shape as Ellipse*/
        Ellipse: "ellipse",
        /**Used to specify node Shape as Image*/
        Image: "image",
        /**Used to specify node Shape as Text*/
        Text: "text",
        /**Used to specify node Shape as Path*/
        Path: "path",
        /**Used to specify node Shape as Polygon*/
        Polygon: "polygon",
        /**Used to specify node Shape as Html*/
        Html: "html",
        /**Used to specify node Shape as Native*/
        Native: "native"
    };


    ej.datavisualization.Diagram.ShapeDefaults = {
        /** The type of node See {@link Shapes}
         
         * @default ej.datavisualization.Diagram.Shapes.Rectangle
         * @type {enum}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var node=[];
         * node={[shape:{type:"rectangle"}]};
         * $("#diagramcontent").ejDiagram({nodes:node});
         * &lt;/script&gt
        * @alias ejDiagram#nodes->shape->type
         * @memberof ejDiagram
         * @instance
         */
        type: ej.datavisualization.Diagram.Shapes.Rectangle,
        /** Defines the shape of the corner
         * @default 0
         * @type {Integer}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var node=[];
         * node={[shape:{type:"rectangle",cornerRadius:2}]};
         * $("#diagramcontent").ejDiagram({nodes:node});
         * &lt;/script&gt
       * @alias ejDiagram#nodes->shape->cornerRadius
         * @memberof ejDiagram
         * @instance
         */
        cornerRadius: 0,
        /** The src location for the image node
      * @default ""
      * @type {String}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node={[shape:{type:"image",src:"Syncfusion.png"}]};
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
     * @alias ejDiagram#nodes->shape->src
      * @memberof ejDiagram
      * @instance
      */
        src: "",
        /** Set the geometry that specifies the shapes to be drawn
       * @default ""
       * @type {String}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var node=[];
       * node={[shape:{type:"path",pathData:"M 269.711,29.3333C 269.711,44.061 257.772,56 243.044,56L 158.058,56C 143.33z"}]};
       * $("#diagramcontent").ejDiagram({nodes:node});
       * &lt;/script&gt
     * @alias ejDiagram#nodes->shape->pathData
       * @memberof ejDiagram
       * @instance
       */
        pathData: "",
        /**This is used to display text
      * @default ""
      * @type {Integer}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * var textBlock = ej.datavisualization.Diagram.TextBlockDefaults;
      * textBlock.text = "TextNode";
      * node={[shape: { type: "text", textBlock: textBlock }]};
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
     * @alias ejDiagram#nodes->shape->textBlock
      * @memberof ejDiagram
      * @instance
      */
        textBlock: null,
        /** Points to define X and Y coordinates for the polygon
       * @default []
       * @type {Array}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var node=[];
       * node={[shape: { type: "polygon", points:[{ x: 0, y: 12.5 }, { x: 0, y: 50 }, { x: 50, y: 50 }, { x: 50, y: 0 }, { x: 12.5, y: 0 }, { x: 0, y: 12.5 }]}]};
       * $("#diagramcontent").ejDiagram({nodes:node});
       * &lt;/script&gt
    * @alias ejDiagram#nodes->shape->points
       * @memberof ejDiagram
       * @instance
       */
        points: [],
        /** Content of the html element is to be updated
   * @default ""
   * @type {String}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node={[shape: { type: "html", html:"Html Node"}]};
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
 * @alias ejDiagram#nodes->shape->html
   * @memberof ejDiagram
   * @instance
   */
        html: "",
        /** Content for the native node to be updated
     * @default null
     * @type {Object}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * var node=[];
     * var g = document.getElementById("CompensationInterruptingGateWay");
     * node={[shape: { type: "native", content:g}]};
     * $("#diagramcontent").ejDiagram({nodes:node});
     * &lt;/script&gt
     * @alias ejDiagram#nodes->shape->content
     * @memberof ejDiagram
     * @instance
     */
        content: null
    };
    ej.datavisualization.Diagram.Shape = function (options) {
        if (options && options.textBlock) {
            options.textBlock = ej.datavisualization.Diagram.TextBlock(options.textBlock);
        }
        return $.extend(true, {}, ej.datavisualization.Diagram.ShapeDefaults, options);
    };
    //#endregion

    //#region Lines
    /**
* Enum for various lines of connector in diagram	 
* @enum {string}
* @global 
*/
    ej.datavisualization.Diagram.Lines = {
        /** Used to specify the lines as Straight*/
        Straight: "straight",
        /** Used to specify the lines as Orthogonal*/
        Orthogonal: "orthogonal",
        /** Used to specify the lines as Bezier*/
        Bezier: "bezier"
    };
    
   
    ej.datavisualization.Diagram.LineDefaults = {
        /**Tyoe of the connector See {@link Lines}         
         * @default ej.datavisualization.Diagram.Lines.Straight
         * @type {enum}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var link=[];
         * link={[line:{type:"straight"}]};
         * $("#diagramcontent").ejDiagram({connectors:link});
         * &lt;/script&gt
         * @alias  ejDiagram#connectors->line->type
         * @memberof ejDiagram
         * @instance
         */
        type: ej.datavisualization.Diagram.Lines.Straight,
        /**Start point of the connector
      * @default Diagram.Point()
      * @type {Point}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var connectors = [];
      * var line = { type: "orthogonal",startPoint: { x: 10, y: 10 }};
      * connectors=[{line: line}];
      * $("#diagramcontent").ejDiagram({connectors:connectors});
      * &lt;/script&gt
      * @alias  ejDiagram#connectors->line->startPoint
      * @memberof ejDiagram
      * @instance
      */
        startPoint: ej.datavisualization.Diagram.Point(),
        /** End point of the connector
    * @default Diagram.Point()
    * @type {Point}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var connectors = [];
    * var line = { type: "orthogonal",endPoint: { x: 0, y: 0 }};
    * connectors=[{line: line}];
    * $("#diagramcontent").ejDiagram({connectors:connectors});
    * &lt;/script&gt
    * @alias  ejDiagram#connectors->line->endPoint
    * @memberof ejDiagram
    * @instance
    */
        endPoint: ej.datavisualization.Diagram.Point(),
        /** Contains both start and end points of the connector
       * @default Diagram.Point()
       * @type {Point}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var connectors = [];
       * var point= {[ startPoint: { x: 10, y: 10 },endPoint: { x: 0, y: 0 }]};
       * connectors=[{line: point}];
       * $("#diagramcontent").ejDiagram({connectors:connectors});
       * &lt;/script&gt
       * @alias  ejDiagram#connectors->line->points
       * @memberof ejDiagram
       * @instance
       */
        points: [],
        /** Describes the control point1 of bezier connector
       * @default null
       * @type {Point}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var connectors = [];
       * var point= {[ startPoint: { x: 10, y: 10 },point1: {x: 20, y: 10 },endPoint: { x: 40, y: 40 }]};
       * connectors=[{line: point}];
       * $("#diagramcontent").ejDiagram({connectors:connectors});
       * &lt;/script&gt
       * @alias ejDiagram#connectors->line->point1
       * @memberof ejDiagram
       * @instance
       */
        point1: null,
        /** Describes the control point2 of bezier connector
       * @default null
       * @type {Point}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var connectors = [];
       * var point= {[ startPoint: { x: 10, y: 10 },point2: {x: 20, y: 10 },endPoint: { x: 40, y: 40 }]};
       * connectors=[{line: point}];
       * $("#diagramcontent").ejDiagram({connectors:connectors});
       * &lt;/script&gt
       * @alias ejDiagram#connectors->line->point2
       * @memberof ejDiagram
       * @instance
       */
        point2: null,
        _point1: ej.datavisualization.Diagram.Point(),
        _point2: ej.datavisualization.Diagram.Point()
    };
    ej.datavisualization.Diagram.Line = function (options) {
        var line = $.extend(true, {}, ej.datavisualization.Diagram.LineDefaults, options);
        var points = [];
        points.push(line.startPoint);
        if (line.type === ej.datavisualization.Diagram.Lines.Orthogonal) {
            ej.datavisualization.Diagram.Util._addOrthogonalPoints(points, line.startPoint, line.endPoint);
        }
        points.push(line.endPoint);
        line["points"] = points;
        if (line.type === ej.datavisualization.Diagram.Lines.Bezier) {
            ej.datavisualization.Diagram.Util._updateBezierPoints(line);
        }
        return line;
    };
    //#endregion


    //#region Margin
    /** This clears area around the label in diagram 
    * @alias ejDiagram.Label#margin
    */

    ej.datavisualization.Diagram.MarginDefaults = {
        /**		
                  * This allows to set the top margin for the label
                  * @default 0
                  * @type {Number}
                  * @example 
                  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                  * &lt;script&gt;
                  * var node = [];
                  *node={[labels: [{"margin": new ej.datavisualization.Diagram.Margin({ "top": 30})}]};
                  *$("#diagramContent").ejDiagram({nodes:node}); 
                  * &lt;/script&gt
                  * @alias  ejDiagram.Label#margin->top
                   * @memberof ejDiagram.Label
                  * @instance
                  */
        top: 0,
        /**		
                 * This allows to set the left margin for the label
                 * @default 0
                 * @type {Number}
                 * @example 
                 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                 * &lt;script&gt;
                 * var node = [];
                 *node={[labels: [{"margin": new ej.datavisualization.Diagram.Margin({ "left": 30})}]};
                 *$("#diagramContent").ejDiagram({nodes:node}); 
                 * &lt;/script&gt
                 * @alias  ejDiagram.Label#margin->left
                  * @memberof ejDiagram.Label
                 * @instance
                 */
        left: 0,
        /**		
                 * This allows to set the right margin for the label
                 * @default 0
                 * @type {Number}
                 * @example 
                 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                 * &lt;script&gt;
                 * var node = [];
                 *node={[labels: [{"margin": new ej.datavisualization.Diagram.Margin({ "right": 30})}]};
                 *$("#diagramContent").ejDiagram({nodes:node}); 
                 * &lt;/script&gt
                 * @alias  ejDiagram.Label#margin->right
                  * @memberof ejDiagram.Label
                 * @instance
                 */
        right: 0,
        /**		
                * This allows to set the bottom margin for the label 
                * @default 0
                * @type {Number}
                * @example 
                * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                * &lt;script&gt;
                * var node = [];
                *node={[labels: [{"margin": new ej.datavisualization.Diagram.Margin({ "bottom": 30})}]};
                *$("#diagramContent").ejDiagram({nodes:node}); 
                * &lt;/script&gt
                * @alias  ejDiagram.Label#margin->bottom
                 * @memberof ejDiagram.Label
                * @instance
                */
        bottom: 0
    };
    ej.datavisualization.Diagram.Margin = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.MarginDefaults, options);
    };
    //#endregion

    //#region Path Util
    ej.datavisualization.Diagram.Path = function () {
        this._path = "";
    };
    ej.datavisualization.Diagram.Path.prototype = {
        moveTo: function (x, y) {
            this._path += "M" + x + "," + y; return this;
        },
        lineTo: function (x, y) {
            this._path += "L" + x + "," + y; return this;
        },
        cubicBezierTo: function (points, isSmooth) {
            if (isSmooth)
                this._path += "S";
            else
                this._path += "C";
            this._addPoints(points);
            return this;
        },
        quadraticBezierTo: function (points, isSmooth) {
            if (isSmooth)
                this._path += "T";
            else
                this._path += "Q";
            this._addPoints(points);
            return this;
        },
        ellipticalArcTo: function (rx, ry, xAngle, arcFlag, sweepFlag, x, y) {
            this._path += "A" + rx + "," + ry + " " + xAngle + " " + arcFlag + "," + sweepFlag + " " + x + "," + y;
            return this;
        },
        close: function () {
            this._path += "Z"; return this;
        },
        toString: function () {
            return this._path;
        },
        _addPoints: function (points) {
            var point;
            for (var i = 0; i < points.length; i++) {
                point = points[i];
                this._path += point.x + ", " + point.y;
                if (i !== (points.length - 1))
                    this._path += " ";
            }
        }
    };
    //#endregion

    ej.datavisualization.Diagram.DecoratorDefaults = {
       
        /** The shape of decorator in connector See {@link DecoratorShapes}
     
        * @default ej.datavisualization.Diagram.DecoratorShapes.Arrow
        * @type {enum}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var link=[];
        * link={[targetDecorator:{shape:"arrow"}]};
        * $("#diagramcontent").ejDiagram({connectors:link});
        * &lt;/script&gt
        * @alias ejDiagram#connectors->sourceDecorator->shape
    
        * @memberof ejDiagram
        * @instance
        */
       
        shape: ej.datavisualization.Diagram.DecoratorShapes.Arrow,
        /** This allows to set the width of the decorator in connector
   * @default 8
   * @type {Number}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var link=[];
   * link={[targetDecorator:{width:10}]};
   * $("#diagramcontent").ejDiagram({connectors:link});
   * &lt;/script&gt
     * @alias ejDiagram#connectors->sourceDecorator->width
     
   * @memberof ejDiagram
   * @instance
   */
        width: 8,
        /** This allows to set the height of the decorator in connector
         * @default 8
         * @type {Number}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var link=[];
         * link={[targetDecorator:{height:10}]};
         * $("#diagramcontent").ejDiagram({connectors:link});
         * &lt;/script&gt
           * @alias ejDiagram#connectors->sourceDecorator->height
      
      * @memberof ejDiagram
         * @instance
         */
        height: 8,
        /** Sets the border color of the decorator
    * @default "black"
    * @type {String}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var link=[];
    * link={[targetDecorator:{borderColor: "green"}]};
    * $("#diagramcontent").ejDiagram({connectors:link});
    * &lt;/script&gt
      * @alias ejDiagram#connectors->sourceDecorator->borderColor
      
     * @memberof ejDiagram
    * @instance
    */
        borderColor: "black",
        /** The color which sets inside the decorator 
   * @default "black"
   * @type {String}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var link=[];
   * link={[targetDecorator:{fillColor: "green"}]};
   * $("#diagramcontent").ejDiagram({connectors:link});
   * &lt;/script&gt
     * @alias ejDiagram#connectors->sourceDecorator->fillColor
     
  * @memberof ejDiagram
   * @instance
   */
        fillColor: "black",
        /** Path data to draw custom shape for decorator
   * @default ""
   * @type {String}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var link=[];
   * link={[targetDecorator:{pathData: "M 269.711,29.3333C 269.711,44.061 257.772,56 243.044,56z"}]};
   * $("#diagramcontent").ejDiagram({connectors:link});
   * &lt;/script&gt
   * @alias ejDiagram#connectors->sourceDecorator->pathData

   * @memberof ejDiagram
   * @instance
   */
        pathData: ""
    };
 
    ej.datavisualization.Diagram.Decorator = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.DecoratorDefaults, options);
    };
    //#endregion


    ej.datavisualization.Diagram.TextBlockDefaults = {
        /** Allow the label to be read only
     * @default false
     * @type {Boolean}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * var node=[];
     * node=[{labels:{"readOnly": false}}];
     * $("#diagramcontent").ejDiagram({nodes:node});
     * &lt;/script&gt
      * @alias ejDiagram#nodes->labels->readOnly
      
* @memberof ejDiagram
     * @instance
     */
        readOnly: false,
        /** To displays the bold font style for label
      * @default false
      * @type {Boolean}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{"bold": false}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->bold
      
* @memberof ejDiagram
      * @instance
      */
        bold: false,
        /** To displays the italic font style for label
    * @default false
    * @type {Boolean}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var node=[];
    * node=[{labels:{"italic": false}}];
    * $("#diagramcontent").ejDiagram({nodes:node});
    * &lt;/script&gt
     * @alias ejDiagram#nodes->labels->italic
     
* @memberof ejDiagram
    * @instance
    */
        italic: false,
        /** Set text for the label
   * @default ""
   * @type {String}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node=[{labels:{"text": "Label"}}];
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
    * @alias ejDiagram#nodes->labels->text
     
* @memberof ejDiagram
   * @instance
   */
        text: "",
        /**Thi allows to specifies the decoration addeed to text see{@link TextDecorations}
    
      * @default TextDecorations.None
      * @type {Enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{textDecoration: ej.datavisualization.Diagram.TextDecorations.Underline}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->textDecoration
      
* @memberof ejDiagram
      * @instance
      */
        textDecoration: ej.datavisualization.Diagram.TextDecorations.None,
        /** To sets the size of the font of the label
   * @default 12
   * @type {Integer}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node=[{labels:{"fontSize": 12}}];
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
    * @alias ejDiagram#nodes->labels->fontSize
    

* @memberof ejDiagram
   * @instance
   */
        fontSize: 12,
        /** This allows to set font for label
 * @default "arial"
 * @type {String}
 * @example
 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
 * &lt;script&gt;
 * var node=[];
 * node=[{labels:{"fontFamily": "Arial"}}];
 * $("#diagramcontent").ejDiagram({nodes:node});
 * &lt;/script&gt
  * @alias ejDiagram#nodes->labels->fontFamily
  
* @memberof ejDiagram
 * @instance
 */
        fontFamily: "Arial",
        /** Used to set the text color
* @default "black"
* @type {String}
* @example
* &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
* &lt;script&gt;
* var node=[];
* node=[{labels:{"fontColor": "black"}}];
* $("#diagramcontent").ejDiagram({nodes:node});
* &lt;/script&gt
 * @alias ejDiagram#nodes->labels->fontColor
 
* @memberof ejDiagram
* @instance
*/
        fontColor: "black",
        /** Set offset to align label poistion
* @default Point(0.5, 0.5)
* @type {Point}
* @example
* &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
* &lt;script&gt;
* var node=[];
* node=[{labels:{offset: ej.datavisualization.Diagram.Point(0.5, 0.5)}}];
* $("#diagramcontent").ejDiagram({nodes:node});
* &lt;/script&gt
 * @alias ejDiagram#nodes->labels->offset
 
* @memberof ejDiagram
* @instance
*/
        offset: ej.datavisualization.Diagram.Point(0.5, 0.5),
        /** Alignment of text in an element see{@link TextAlign}
   
      * @default TextAlign.Center
      * @type {Enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{textAlign: ej.datavisualization.Diagram.TextAlign.Center}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->textAlign
       
     * @memberof ejDiagram
      * @instance
      */
        textAlign: ej.datavisualization.Diagram.TextAlign.Center,
        /** Horizontal alignment of text in an element see{@link HorizontalAlignment}
   
      * @default HorizontalAlignment.Center
      * @type {Enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{horizontalAlignment: ej.datavisualization.Diagram.HorizontalAlignment.Center}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->horizontalAlignment
      
    * @memberof ejDiagram
      * @instance
      */
        horizontalAlignment: ej.datavisualization.Diagram.HorizontalAlignment.Center,
        /** Vertical alignment of text in an element see{@link VerticalAlignment}
      
      * @default VerticalAlignment.Center
      * @type {Enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{verticalAlignment: ej.datavisualization.Diagram.VerticalAlignment.Center}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->verticalAlignment
    
   * @memberof ejDiagram
      * @instance
      */
        verticalAlignment: ej.datavisualization.Diagram.VerticalAlignment.Center,
        /** This enables or disables the line breaking rules for text
    * @default true
    * @type {Boolean}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var node=[];
    * node=[{labels:{wrapText: true}}];
    * $("#diagramcontent").ejDiagram({nodes:node});
    * &lt;/script&gt
     * @alias ejDiagram#nodes->labels->wrapText
    
* @memberof ejDiagram
* @instance
    */
        wrapText: true,
        /** margin of the label 
      * @default ej.datavisualization.Diagram.Margin()
      * @type {Object}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{"margin": ej.datavisualization.Diagram.Margin()}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->margin
       
     * @memberof ejDiagram
      * @instance
      */
        margin: ej.datavisualization.Diagram.Margin(),
        /** To set the label edit mode see{@link LabelEditMode}       
      * @default LabelEditMode.Edit
      * @type {Enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{mode: ej.datavisualization.Diagram.LabelEditMode.Edit}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->mode
       
     * @memberof ejDiagram
      * @instance
      */
        mode: ej.datavisualization.Diagram.LabelEditMode.Edit,
        /** To set the width of the label
     * @default 50
     * @type {Interger}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * var node=[];
     * node=[{labels:{width: 50}}];
     * $("#diagramcontent").ejDiagram({nodes:node});
     * &lt;/script&gt
      * @alias ejDiagram#nodes->labels->width
     
     * @memberof ejDiagram
     * @instance
     */
        width: 50
    };
    ej.datavisualization.Diagram.TextBlock = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.TextBlockDefaults, options);
    };
    ///**The label properties for node/Connector
    //* @alias ejDiagram#node->labels*/
    ej.datavisualization.Diagram.LabelDefaults = $.extend(true, {}, ej.datavisualization.Diagram.TextBlockDefaults, {
        /** Name of the label 
      * @default ""
      * @type {String}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{name:"Label"}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->name
        
  * @memberof ejDiagram
      * @instance
      */
        name: "",
        /**Enables or disables the visibility of the label 
      * @default true
      * @type {Boolean}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{visible: true}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->visible
     
    * @memberof ejDiagram
      * @instance
      */
        visible: true,
        /**The color of the border for the text
      * @default "transparent"
      * @type {String}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{borderColor: "transparent"}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->borderColor
        
      * @memberof ejDiagram
      * @instance
      */
        borderColor: "transparent",
        /**Sets the border width of the label 
      * @default 0
      * @type {Number}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{borderWidth: 4}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->borderWidth
         
      * @memberof ejDiagram
      * @instance
      */
        borderWidth: 0,
        /**The color which is filled inside the text 
      * @default "transparent"
      * @type {String}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node=[{labels:{fillColor: "green"}}];
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->labels->fillColor
       
      * @memberof ejDiagram
      * @instance
      */
        fillColor: "transparent"
    });
    ej.datavisualization.Diagram.Label = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.LabelDefaults, options);
    };
    //#endregion

    //#region Port


//    /**
//* @namespace ej
//* @class ejDiagram.Port 
//* @classdesc Port is a specific point on node to make a static connection with node
//* @example 
//* &lt;div id="diagram"&gt;&lt;/div&gt;<br>
//* &lt;script&gt;
//* //Create Diagram
//$("#diagram").ejDiagram();
//* &lt;/script&gt
//*/
    ej.datavisualization.Diagram.PortDefaults = {
        /** The name of port to be specified
           * @default ""
           * @type {String}
           * @example
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           * var node=[];
           * node={ports:[{ name: "port"}]};
           * $("#diagramcontent").ejDiagram({nodes:node});
           * &lt;/script&gt

		    * @alias ejDiagram#nodes->ports->name;
           * @memberof ejDiagram 
           * @instance
           */
        name: "",
        /** Enables or disables the visibility of port See {@link PortVisibility}
      
      * @default PortVisibility.Default
      * @type {enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node={ports:[{visibility: ej.datavisualization.Diagram.PortVisibility.Default}]};
      * $("#diagramcontent").ejDiagram({nodes:port});
      * &lt;/script&gt 
        * @alias ejDiagram#nodes->ports->visibility
           * @memberof ejDiagram 
      * @instance
      */
        visibility: ej.datavisualization.Diagram.PortVisibility.Default,
        /** Enables or disables the behavior of port See {@link PortConstraints}
      
      * @default PortConstraints.Connect
      * @type {enum}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var node=[];
      * node={ports:[{constraints: ej.datavisualization.Diagram.PortConstraints.Connect}]};
      * $("#diagramcontent").ejDiagram({nodes:node});
      * &lt;/script&gt
        * @alias ejDiagram#nodes->ports->constraints
          * @memberof ejDiagram 
      * @instance
      */
        constraints: ej.datavisualization.Diagram.PortConstraints.Connect,
        /**Size of the port
   * @default 8
   * @type {Number}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node={ports:[{size: 10}]};
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
     * @alias ejDiagram#nodes->ports->size
          * @memberof ejDiagram 
   * @instance
   */
        size: 8,
        /** Offset value to align the label position
    * @default Point(0, 0)
    * @type {Point}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var node=[];
    * node={ports:[{{ x: 0, y: 0.5 }}]};
    * $("#diagramcontent").ejDiagram({nodes:node});
    * &lt;/script&gt
      * @alias ejDiagram#nodes->ports->offset
           * @memberof ejDiagram 
    * @instance
    */
        offset: ej.datavisualization.Diagram.Point(0, 0),
        /** Sets the border color of the port
    * @default "#1a1a1a"
    * @type {String}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var node=[];
    * node={ports:[{borderColor:"green"}]};
    * $("#diagramcontent").ejDiagram({nodes:node});
    * &lt;/script&gt
       * @alias ejDiagram#nodes->ports->borderColor
          * @memberof ejDiagram 
    * @instance
    */
        borderColor: "#1a1a1a",
        /** Sets the border width of the port
    * @default 1
    * @type {Number}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var node=[];
    * node={ports:[{borderWidth: 1}]};
    * $("#diagramcontent").ejDiagram({nodes:node});
    * &lt;/script&gt
      * @alias ejDiagram#nodes->ports->borderWidth
            * @memberof ejDiagram 
    * @instance
    */
        borderWidth: 1,
        /** The color to be filled inside the port 
     * @default "white"
     * @type {String}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * var node=[];
     * node={ports:[{fillColor:"green"}]};
     * $("#diagramcontent").ejDiagram({nodes:node});
     * &lt;/script&gt
      * @alias ejDiagram#nodes->ports->fillColor
           * @memberof ejDiagram 
     * @instance
     */
        fillColor: "white",
        /** Shape of the port to be updated See {@link PortShapes}

   * @default PortShapes.Square
   * @type {enum}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node={ports:[{shape: ej.datavisualization.Diagram.PortShapes.Square}]};
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
     * @alias ejDiagram#nodes->ports->shape
            * @memberof ejDiagram
   * @instance
   */
        shape: ej.datavisualization.Diagram.PortShapes.Square,
        /**Path data to draw the custom port 
   * @default ""
   * @type {String}
   * @example
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
   * var node=[];
   * node={ports:[{pathData:""}]};
   * $("#diagramcontent").ejDiagram({nodes:node});
   * &lt;/script&gt
    * @alias ejDiagram#nodes->ports->pathData
          * @memberof ejDiagram 
   * @instance
   */
        pathData: ""
    };
    ej.datavisualization.Diagram.Port = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.PortDefaults, options);
    };
    //#endregion
    // /**
    //* @namespace ej
    //* @class Gradient 
    //* @classdesc The diagram control provides 2D surface to visualize the data as shapes, lines, text and images. It can be configured to DOM element such as DIV.
    //* @example 
    //* &lt;div id="diagram"&gt;&lt;/div&gt;<br>
    //* &lt;script&gt;
    //* //Create Diagram
    //$("#diagram").ejDiagram();
    //* &lt;/script&gt

    // */
    /**Specifies the gradient of the Node.
           * @type {object} 
              * @memberof ejDiagram
             * @alias ejDiagram#nodes->gradient->Stop
             * @instance
           */

    //#region Gradient
    ej.datavisualization.Diagram.StopDefaults = {
        /**The color for applied gradient region 
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
          * gradient.type = "linear;
          * gradient.x1 = 0;
          * gradient.x2 = 50;
          * gradient.y1 = 0;
          * gradient.y2 = 50;
          * var stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "white";
          * stop.offset = 0;
          * gradient.stops.push(stop);
          * stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "darkCyan";
          * stop.offset = 100;
          * gradient.stops.push(stop);
          * gradient.stops.push(stop);
          * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
        * @alias ejDiagram#nodes->gradient->Stop->color
          * @memberof ejDiagram
          * @instance
          */
        color: "",
        /**To set desired offset to apply color to the node region
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
          * gradient.type = "linear;
          * gradient.x1 = 0;
          * gradient.x2 = 50;
          * gradient.y1 = 0;
          * gradient.y2 = 50;
          * var stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "white";
          * stop.offset = 0;
          * gradient.stops.push(stop);
          * stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "darkCyan";
          * stop.offset = 100;
          * gradient.stops.push(stop);
          * gradient.stops.push(stop);
          * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->gradient->Stop->offset
          * @memberof ejDiagram
          * @instance
          */
        offset: 0,
        /**Decribes the transparency level for the region
          * @default 1
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
          * gradient.type = "linear;
          * gradient.x1 = 0;
          * gradient.x2 = 50;
          * gradient.y1 = 0;
          * gradient.y2 = 50;
          * var stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "white";
          * stop.opacity = 0.8;
          * stop.offset = 0;
          * gradient.stops.push(stop);
          * stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "darkCyan";
          * stop.offset = 100;
          * gradient.stops.push(stop);
          * gradient.stops.push(stop);
          * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
        * @alias ejDiagram#nodes->gradient->Stop->opacity
          * @memberof ejDiagram
          * @instance
          */
        opacity: 1
    };
    ej.datavisualization.Diagram.Stop = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.StopDefaults, options);
    };

    /**Paints an area with a linear gradient. 
           * @type {object}
            
              * @alias ejDiagram#nodes->gradient->LinearGradient
             
           */
    ej.datavisualization.Diagram.LinearGradientDefaults = {
        type: "linear",
        /**The starting X-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
        * gradient.type = "linear;
        * gradient.x1 = 10;
        * gradient.x2 = 50;
        * gradient.y1 = 0;
        * gradient.y2 = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
          * @alias ejDiagram#nodes->gradient->LinearGradient->x1
        * @memberof ejDiagram
        * @instance
        */
        x1: 0,
        /**The ending X-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
        * gradient.type = "linear;
        * gradient.x1 = 10;
        * gradient.x2 = 50;
        * gradient.y1 = 20;
        * gradient.y2 = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
          * @alias ejDiagram#nodes->gradient->LinearGradient->x2
        * @memberof ejDiagram
        * @instance
        */
        x2: 0,
        /**The starting Y-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
        * gradient.type = "linear;
        * gradient.x1 = 10;
        * gradient.x2 = 50;
        * gradient.y1 = 0;
        * gradient.y2 = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
           * @alias ejDiagram#nodes->gradient->LinearGradient->y1
        * @memberof ejDiagram
        * @instance
        */
        y1: 0,
        /**The ending Y-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
        * gradient.type = "linear;
        * gradient.x1 = 10;
        * gradient.x2 = 50;
        * gradient.y1 = 0;
        * gradient.y2 = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
          * @alias ejDiagram#nodes->gradient->LinearGradient->y2
        * @memberof ejDiagram
        * @instance
        */
        y2: 0,
        /**The stop region for the gradient
        * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var gradient = ej.datavisualization.Diagram.LinearGradientDefaults();
          * gradient.type = "linear;
          * gradient.x1 = 10;
          * gradient.x2 = 50;
          * gradient.y1 = 20;
          * gradient.y2 = 50;
          * var stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "white";
          * stop.opacity = 0.8;
          * stop.offset = 0;
          * gradient.stops.push(stop);
          * stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "darkCyan";
          * stop.offset = 100;
          * gradient.stops.push(stop);
          * gradient.stops.push(stop);
          * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->gradient->LinearGradient->stops
          * @memberof ejDiagram
          * @instance
        */
        stops: []
    };
    ej.datavisualization.Diagram.LinearGradient = function (options) {
        for (var i = 0; i < options.stops.length; i++) {
            options.stops[i] = ej.datavisualization.Diagram.Stop(options.stops[i]);
        }
        return $.extend(true, {}, ej.datavisualization.Diagram.LinearGradientDefaults, options);
    };
    /**Paints an area with a radial gradient. A focal point defines the beginning of the gradient, and a circle defines the end point of the gradient. 
           * @type {object}
             
                 * @alias ejDiagram#nodes->gradient->RadialGradient
          
           */
    ej.datavisualization.Diagram.RadialGradientDefaults = {
        type: "radial",
        /**The starting X-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.RadialGradientDefaults();
        * gradient.type = "linear;
        * gradient.cx = 20;
        * gradient.cy = 50;
        * gradient.fx = 20;
        * gradient.fy = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
        * @alias ejDiagram#nodes->gradient->RadialGradient->cx
        * @memberof ejDiagram
        * @instance
        */
        cx: 0,
        /**The ending X-Axis for the region
       * @default 0
       * @type {Int}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var gradient = ej.datavisualization.Diagram.RadialGradientDefaults();
       * gradient.type = "linear;
       * gradient.cx = 20;
       * gradient.cy = 50;
       * gradient.fx = 20;
       * gradient.fy = 50;
       * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
       * $("#diagramcontent").ejDiagram({nodes:nodes});
       * &lt;/script&gt
    * @alias ejDiagram#nodes->gradient->RadialGradient->cy
       * @memberof ejDiagram
       * @instance
       */
        cy: 0,
        /**The starting X-Axis for the region
        * @default 0
        * @type {Int}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var gradient = ej.datavisualization.Diagram.RadialGradientDefaults();
        * gradient.type = "linear;
        * gradient.cx = 20;
        * gradient.cy = 50;
        * gradient.fx = 20;
        * gradient.fy = 50;
        * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
        * $("#diagramcontent").ejDiagram({nodes:nodes});
        * &lt;/script&gt
      * @alias ejDiagram#nodes->gradient->RadialGradient->fx
        * @memberof ejDiagram
        * @instance
        */
        fx: 0,
        /**The ending Y-Axis for the region
       * @default 0
       * @type {Int}
       * @example
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * var gradient = ej.datavisualization.Diagram.RadialGradientDefaults();
       * gradient.type = "linear;
       * gradient.cx = 20;
       * gradient.cy = 50;
       * gradient.fx = 20;
       * gradient.fy = 50;
       * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
       * $("#diagramcontent").ejDiagram({nodes:nodes});
       * &lt;/script&gt
    * @alias ejDiagram#nodes->gradient->RadialGradient->fy
       * @memberof ejDiagram
       * @instance
       */
        fy: 0,
        /**The stop region for the gradient
        * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var gradient = ej.datavisualization.Diagram.RadialGradientDefaults();
          * gradient.type = "linear;
          * gradient.x1 = 10;
          * gradient.x2 = 50;
          * gradient.y1 = 20;
          * gradient.y2 = 50;
          * var stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "white";
          * stop.opacity = 0.8;
          * stop.offset = 0;
          * gradient.stops.push(stop);
          * stop = ej.datavisualization.Diagram.Stop();
          * stop.color = "darkCyan";
          * stop.offset = 100;
          * gradient.stops.push(stop);
          * gradient.stops.push(stop);
          * var nodes = [{name:"Node1",width: 100,height: 100,gradient : gradient}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->gradient->RadialGradient->stops
          * @memberof ejDiagram
          * @instance
        */
        stops: []
    };
    ej.datavisualization.Diagram.RadialGradient = function (options) {
        for (var i = 0; i < options.stops.length; i++) {
            options.stops[i] = ej.datavisualization.Diagram.Stop(options.stops[i]);
        }
        return $.extend(true, {}, ej.datavisualization.Diagram.RadialGradientDefaults, options);
    };


    //#region Node
    ej.datavisualization.Diagram.NodeBaseDefaults = {
        /** To set the name of node
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{name:"Node1"}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->name
          * @memberof ejDiagram
          * @instance
          */
        name: "",
        /** To sets the width of the node
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{width: 100}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
            * @alias ejDiagram#nodes->width
          * @memberof ejDiagram
          * @instance
          */
        width: 0,
        /** To sets the height of the node
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{height: 100}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->height
          * @memberof ejDiagram
          * @instance
          */
        height: 0,
        /** Align nodes position along X-axis
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{offsetX: 100}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->offsetX
          * @memberof ejDiagram
          * @instance
          */
        offsetX: 0,
        /** Align nodes position along y axis
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{offsetY: 100}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->offsetY
          * @memberof ejDiagram
          * @instance
          */
        offsetY: 0,
        /** To set the visibility of the node
          * @default true
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{visible: true}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->visible
          * @memberof ejDiagram
          * @instance
          */
        visible: true,
        /** Zorder of the node
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{zOrder: 1}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->zOrder
          * @memberof ejDiagram
          * @instance
          */
        zOrder: 0,
        /**The arrangements of node in layout
          * @default false
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{visible: true}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->excludeFromLayout
          * @memberof ejDiagram
          * @instance
          */
        excludeFromLayout: false,
        /** To enables or disables the default behaviour of the node see{@link NodeConstraints}
      
          * @default NodeConstraints.Default
          * @type {Constraints}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{Constraints: ej.datavisualization.Diagram.NodeConstraints.Select}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->constraints
          * @memberof ejDiagram
          * @instance
          */
        constraints: ej.datavisualization.Diagram.NodeConstraints.Default,
        parent: "",
        /** Collection labels of node
          * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var label = [];
          * label = { "text": "Node1", "fontColor": "Red"};
          * nodes=[{labels:label}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->labels
          * @memberof ejDiagram
          * @instance
          */
        labels: [],
        /**To add port to the node
          * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var port: [{ offset: { x: 0, y: 0.5 }, name: "aport" }]
          * nodes=[{ports:port}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->ports
          * @memberof ejDiagram
          * @instance
          */
        ports: [],
        /**The connectors which comes to the Node.
          * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [{ name: "connector1", sourceNode: "Node1", targetNode: "Node2"}];
          * nodes=[{inEdges:connectors}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->inEdges
          * @memberof ejDiagram
          * @instance
          */
        inEdges: [],
        /** The connectors which leave from the Node.
          * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [{ name: "connector1", sourceNode: "Node1", targetNode: "Node2"}];
          * nodes=[{outEdges:connectors}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->outEdges
          * @memberof ejDiagram
          * @instance
          */
        outEdges: [],
        /** To set the rotation angle of the node
          * @default 0
          * @type {Number}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{rotateAngle: 120}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->rotateAngle
          * @memberof ejDiagram
          * @instance
          */
        rotateAngle: 0,
        /** To set the pivot point of the node
          * @default Points(0.5,0.5)
          * @type {Point}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{pivot: ej.datavisualization.Diagram.Point(0.8, 0.8)}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->pivot
          * @memberof ejDiagram
          * @instance
          */
        pivot: ej.datavisualization.Diagram.Point(0.5, 0.5),
        /** To provide/save extra information about Node
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var addInfo = {Name1:"Node1",Name2:"Name2"}
          * nodes=[{addInfo: addInfo}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
          * @alias ejDiagram#nodes->addInfo
          * @memberof ejDiagram
          * @instance
          */
        addInfo: {}
    };
    ej.datavisualization.Diagram.NodeBase = function (options) {
        var i;
        if (options.labels)
            for (i = 0; i < options.labels.length; i++) {
                options.labels[i] = ej.datavisualization.Diagram.Label(options.labels[i]);
            }
        if (options.ports)
            for (i = 0; i < options.ports.length; i++) {
                options.ports[i] = ej.datavisualization.Diagram.Port(options.ports[i]);
            }
        return $.extend(true, {}, ej.datavisualization.Diagram.NodeBaseDefaults, options);
    };

    ej.datavisualization.Diagram.NodeDefaults = {
        /** The color to be filled inside the node
          * @default "White"
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{fillColor: "white"}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->fillColor
          * @memberof ejDiagram
          * @instance
          */
        fillColor: "white",
        /** Sets the border color of the node
      * @default "black"
      * @type {String}
      * @example
      * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * var nodes = [];
      * nodes=[{borderColor: "black"}];
      * $("#diagramcontent").ejDiagram({nodes:nodes});
      * &lt;/script&gt
       * @alias ejDiagram#nodes->borderColor
      * @memberof ejDiagram
      * @instance
      */
        borderColor: "black",
        /** Sets the border width of the node
     * @default 1
     * @type {Number}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * var nodes = [];
     * nodes=[{borderWidth: 3}];
     * $("#diagramcontent").ejDiagram({nodes:nodes});
     * &lt;/script&gt
      * @alias ejDiagram#nodes->borderWidth
     * @memberof ejDiagram
     * @instance
     */
        borderWidth: 1,
        /** The dotted line for the node
    * @default ""
    * @type {String}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var nodes = [];
    * nodes=[{borderDashArray: "2 2"}];
    * $("#diagramcontent").ejDiagram({nodes:nodes});
    * &lt;/script&gt
     * @alias ejDiagram#nodes->borderDashArray
    * @memberof ejDiagram
    * @instance
    */
        borderDashArray: "",
        /**Defines the transparency of the node
  * @default 1
  * @type {Number}
  * @example
  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
  * &lt;script&gt;
  * var nodes = [];
  * nodes=[{opacity: 2}];
  * $("#diagramcontent").ejDiagram({nodes:nodes});
  * &lt;/script&gt
   * @alias ejDiagram#nodes->opacity
  * @memberof ejDiagram
  * @instance
  */
        opacity: 1,
        /** Smooth transition from one color to another color in node   
         * @alias ejDiagram#nodes->gradient
 * @memberof ejDiagram
 * @instance
 */
        gradient: null,
        /** The shape of the node see{@link Shapes}
    
    * @default Diagram.Shape()
    * @type {Enum}
    * @example
    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * var nodes = [];
    * nodes=[shape:{type: "rectangle"}];
    * $("#diagramcontent").ejDiagram({nodes:nodes});
    * &lt;/script&gt
     * @alias ejDiagram#nodes->shape
    * @memberof ejDiagram
    * @instance
    */
        shape: ej.datavisualization.Diagram.Shape()
    };
    ej.datavisualization.Diagram.Node = function (options) {
        if (options.gradient) {
            if (options.gradient.type === "linear") {
                options.gradient = ej.datavisualization.Diagram.LinearGradient(options.gradient);
            }
            else if (options.gradient.type === "radial") {
                options.gradient = ej.datavisualization.Diagram.RadialGradient(options.gradient);
            }
        }
        if (options.shape) {
            options.shape = ej.datavisualization.Diagram.Shape(options.shape);
        }
        return $.extend(true, {}, ej.datavisualization.Diagram.NodeDefaults, ej.datavisualization.Diagram.NodeBase(options));
    };
    //#endregion

    //#region Connector
    ej.datavisualization.Diagram.ConnectorDefaults = {
        /**Name of the connector
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{name:"Connector1"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
           * @alias ejDiagram#connectors->name
          * @memberof ejDiagram
          * @instance
          */
        name: "",
        /** Enables or disables the visibility of connector
          * @default true
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{visible: true}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->visible
          * @memberof ejDiagram
          * @instance
          */
        visible: true,
        /** Dotted lines for connector
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{lineDashArray:"4 4"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->lineDashArray
          * @memberof ejDiagram
          * @instance
          */
        lineDashArray: "",
        /** To set targetDecorator for connector
          * @default null
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * var targetDecorator = { shape: "arrow", borderColor: "#606060", width: "10", height: "10" };
          * connectors=[{targetDecorator:targetDecorator}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->targetDecorator
          * @memberof ejDiagram
          * @instance
          */
        targetDecorator:  /** @lends ejdiagram# */
            {
                /** The shape of decorator in connector See {@link DecoratorShapes}
     
        * @default ej.datavisualization.Diagram.DecoratorShapes.Arrow
        * @type {enum}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var link=[];
        * link={[targetDecorator:{shape:"arrow"}]};
        * $("#diagramcontent").ejDiagram({connectors:link});
        * &lt;/script&gt
        * @alias ejDiagram#connectors->targetDecorator->shape
    
        * @memberof ejDiagram
        * @instance
        */

                shape: ej.datavisualization.Diagram.DecoratorShapes.Arrow,
                /** This allows to set the width of the decorator in connector
            * @default 8
            * @type {Number}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{width:10}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
             * @alias ejDiagram#connectors->targetDecorator->width
             
            * @memberof ejDiagram
            * @instance
            */
                width: 8,
                /** This allows to set the height of the decorator in connector
                 * @default 8
                 * @type {Number}
                 * @example
                 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                 * &lt;script&gt;
                 * var link=[];
                 * link={[targetDecorator:{height:10}]};
                 * $("#diagramcontent").ejDiagram({connectors:link});
                 * &lt;/script&gt
                   * @alias ejDiagram#connectors->targetDecorator->height
              
              * @memberof ejDiagram
                 * @instance
                 */
                height: 8,
                /** Sets the border color of the decorator
            * @default "black"
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{borderColor: "green"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
              * @alias ejDiagram#connectors->targetDecorator->borderColor
              
             * @memberof ejDiagram
            * @instance
            */
                borderColor: "black",
                /** The color which sets inside the decorator 
            * @default "black"
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{fillColor: "green"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
             * @alias ejDiagram#connectors->targetDecorator->fillColor
             
            * @memberof ejDiagram
            * @instance
            */
                fillColor: "black",
                /** Path data to draw custom shape for decorator
            * @default ""
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{pathData: "M 269.711,29.3333C 269.711,44.061 257.772,56 243.044,56z"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
            * @alias ejDiagram#connectors->targetDecorator->pathData
            
            * @memberof ejDiagram
            * @instance
            */
                pathData: ""
            },
        /** To set sourceDecorator for connector
         * @default null
         * @type {String}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var connectors = [];
         * var targetDecorator = { shape: "arrow", borderColor: "#606060", width: "10", height: "10" };
         * connectors=[{targetDecorator:targetDecorator}];
         * $("#diagramcontent").ejDiagram({connectors:connectors});
         * &lt;/script&gt
             * @alias ejDiagram#connectors->sourceDecorator
         * @memberof ejDiagram
         * @instance
         */

        sourceDecorator:
            /** @lends ejdiagram# */
            {
                /** The shape of decorator in connector See {@link DecoratorShapes}
     
        * @default ej.datavisualization.Diagram.DecoratorShapes.Arrow
        * @type {enum}
        * @example
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * var link=[];
        * link={[targetDecorator:{shape:"arrow"}]};
        * $("#diagramcontent").ejDiagram({connectors:link});
        * &lt;/script&gt
        * @alias ejDiagram#connectors->sourceDecorator->shape
    
        * @memberof ejDiagram
        * @instance
        */
       
                shape: ej.datavisualization.Diagram.DecoratorShapes.Arrow,
                /** This allows to set the width of the decorator in connector
            * @default 8
            * @type {Number}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{width:10}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
             * @alias ejDiagram#connectors->sourceDecorator->width
             
            * @memberof ejDiagram
            * @instance
            */
                width: 8,
                /** This allows to set the height of the decorator in connector
                 * @default 8
                 * @type {Number}
                 * @example
                 * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                 * &lt;script&gt;
                 * var link=[];
                 * link={[targetDecorator:{height:10}]};
                 * $("#diagramcontent").ejDiagram({connectors:link});
                 * &lt;/script&gt
                   * @alias ejDiagram#connectors->sourceDecorator->height
              
              * @memberof ejDiagram
                 * @instance
                 */
                height: 8,
                /** Sets the border color of the decorator
            * @default "black"
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{borderColor: "green"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
              * @alias ejDiagram#connectors->sourceDecorator->borderColor
              
             * @memberof ejDiagram
            * @instance
            */
                borderColor: "black",
                /** The color which sets inside the decorator 
            * @default "black"
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{fillColor: "green"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
             * @alias ejDiagram#connectors->sourceDecorator->fillColor
             
            * @memberof ejDiagram
            * @instance
            */
                fillColor: "black",
                /** Path data to draw custom shape for decorator
            * @default ""
            * @type {String}
            * @example
            * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var link=[];
            * link={[targetDecorator:{pathData: "M 269.711,29.3333C 269.711,44.061 257.772,56 243.044,56z"}]};
            * $("#diagramcontent").ejDiagram({connectors:link});
            * &lt;/script&gt
            * @alias ejDiagram#connectors->sourceDecorator->pathData
            
            * @memberof ejDiagram
            * @instance
            */
                pathData: ""
            },
        /** To set line type and its start and end point
          * @default Lines.Straight
          * @type {Line}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * var line = { type: "orthogonal",startPoint: { x: 0, y: 0 }, endPoint: { x: 40, y: 40 }};
          * connectors=[{line: line}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->line
          * @memberof ejDiagram
          * @instance
          */
        line: ej.datavisualization.Diagram.Line({ startPoint: ej.datavisualization.Diagram.Point(), endPoint: ej.datavisualization.Diagram.Point() }),
        /**Sets the color of the connector
          * @default black
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{lineColor:"blue"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->lineColor
          * @memberof ejDiagram
          * @instance
          */
        lineColor: "black",
        /**Sets the width of the line
          * @default 1
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{lineWidth:4}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->lineWidth
          * @memberof ejDiagram
          * @instance
          */
        lineWidth: 1,
        /** Enables or disables the behaviour of connector see{@link ConnectorConstraints}
          * @default ConnectorConstraints.Default
          * @type {Constraints}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{Constraints: ej.datavisualization.Diagram.ConnectorConstraints.Select}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->constraints
          * @memberof ejDiagram
          * @instance
          */
        constraints: ej.datavisualization.Diagram.ConnectorConstraints.Default,
        /**The transparency of the connector
          * @default 1
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * connectors=[{opacity:0.6}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->opacity
          * @memberof ejDiagram
          * @instance
          */
        opacity: 1,
        parent: "",

        /**The labels property of connectors
          
          * @default ""
          * @type {Array}
          * @example
          * Refer nodes label for label properties details <br>
          
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var label = [];
          * label = { "text": "Connector1", "fontColor": "Red"};
          * connectors=[{labels:label}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->labels
          * @memberof ejDiagram
          * @instance
          */
        labels: [],
        /** Zorder of the connector
          * @default 0
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors= [];
          * connectors=[{connectors: 1}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->zOrder
          * @memberof ejDiagram
          * @instance
          */
        zOrder: 0,
        /** The padding added to the line to detect line during interaction
          * @default 10
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors= [];
          * connectors=[{lineHitPadding: 30}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->lineHitPadding
          * @memberof ejDiagram
          * @instance
          */
        lineHitPadding: 10,
        /**To provide/save extra information about Node
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var connectors = [];
          * var addInfo = {Name1:"Connector1",Connector2:"Connector3"}
          * connectors=[{addInfo: addInfo}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->addInfo
          * @memberof ejDiagram
          * @instance
          */
        addInfo: {},
        /** The target node of the connector
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes =[];
          * var connectors = [];
          * nodes = {name: "openBrowses", width: 175, height: 60};
          * connectors=[{targetNode: "openBrowses"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->targetNode
          * @memberof ejDiagram
          * @instance
          */
        targetNode: null,
        /** The targetPort of the connector
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var ports = [];
          * var connectors = [];
          * nodes = {name: "openBrowses", width: 175, height: 60};
          * ports = { offset: { x: 0, y: 0.5 }, name: "aport" };
          * connectors=[{targetPort: "aport"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->targetPort
          * @memberof ejDiagram
          * @instance
          */
        targetPort: null,
        /** The sourceNode of the connector
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var connectors = [];
          * nodes = {name: "openBrowses", width: 175, height: 60};
          * connectors=[{sourceNode: "openBrowses"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->sourceNode
          * @memberof ejDiagram
          * @instance
          */
        sourceNode: null,
        /** The sourcePort of the connector
          * @default null
          * @type {Object}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var ports = [];
          * var connectors = [];
          * nodes = {name: "openBrowses", width: 175, height: 60};
          * ports = { offset: { x: 0, y: 0.5 }, name: "bport" };
          * connectors=[{sourcePort: "bport"}];
          * $("#diagramcontent").ejDiagram({connectors:connectors});
          * &lt;/script&gt
              * @alias ejDiagram#connectors->sourcePort
          * @memberof ejDiagram
          * @instance
          */
        sourcePort: null
    };
    ej.datavisualization.Diagram.Connector = function (options) {
        options.targetDecorator = ej.datavisualization.Diagram.Decorator(options.targetDecorator || {});
        options.sourceDecorator = ej.datavisualization.Diagram.Decorator(options.sourceDecorator || { shape: ej.datavisualization.Diagram.DecoratorShapes.None });
        if (options.line) {
            options.line = ej.datavisualization.Diagram.Line(options.line);
        }
        if (options.labels)
            for (var i = 0; i < options.labels.length; i++) {
                options.labels[i] = ej.datavisualization.Diagram.Label(options.labels[i]);
            }
        return $.extend(true, {}, ej.datavisualization.Diagram.ConnectorDefaults, options);
    };
    //#endregion

   // /**
   //* @namespace ej
   //* @class ejDiagram.Group    
   //* @classdesc Group is a container of Nodes and Connectors as a single entity
   //* @example 
   //* &lt;div id="diagram"&gt;&lt;/div&gt;<br>
   //* &lt;script&gt;
   //* //Create Diagram
   //$("#diagram").ejDiagram();
   //* &lt;/script&gt
   //*/
    //#region Group
    ej.datavisualization.Diagram.GroupDefaults = {
        /** To set node as group
          * @default true
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * nodes=[{name:"GroupNode",isGroup:true}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->isGroup
          * @memberof ejDiagram
          * @instance
          */
        isGroup: true,
        /** Collection of children in group node
          * @default ""
          * @type {Array}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var children = ["Node1","Node2"];
          * nodes=[{name:"GroupNode",isGroup:true,children:children}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->children
          * @memberof ejDiagram
          * @instance
          */
        children: [],
        /**This is used to set whether we can ungroup the group or not
          * @default true
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var nodes = [];
          * var children = ["Node1","Node2"];
          * nodes=[{name:"GroupNode",isGroup:true,children:children,canUngroup:false}];
          * $("#diagramcontent").ejDiagram({nodes:nodes});
          * &lt;/script&gt
           * @alias ejDiagram#nodes->canUngroup
          * @memberof ejDiagram
          * @instance
          */
        canUngroup: true
    };
    ej.datavisualization.Diagram.Group = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.GroupDefaults, ej.datavisualization.Diagram.NodeBase(options));
    };
    //#endregion

    //#region ZoomCommand
    ej.datavisualization.Diagram.ZoomCommand = {
        ///** ZoomIn operation assigns the value to ,which operation is to be performed
        //  * @default 1
        //  * @type {Int}
        //  * @example
        //  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        //  * &lt;script&gt;
        //  * var zoom = ZoomCommand.ZoomIn;
        //  * &lt;/script&gt
        //  * @memberof ejDiagram
        //  * @instance
        //  */
        ZoomIn: 1,
        ///** ZoomOut operation assigns the value to ,which operation is to be performed
        // * @default 2
        // * @type {Int}
        // * @example
        // * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        // * &lt;script&gt;
        // * var zoom = ZoomCommand.ZoomOut;
        // * &lt;/script&gt
        // * @memberof ejDiagram
        // * @instance
        // */
        ZoomOut: 2
    };
    ej.datavisualization.Diagram.Zoom = function (options) {
        return $.extend(true, {}, { zoomFactor: 0.2, focusPoint: null, zoomCommand: ej.datavisualization.Diagram.ZoomCommand.ZoomIn }, options);
    };
    //#endregion

  //  /**
  //* @namespace ej
  //* @class  ejDiagram.UserHandle    
  //* @classdesc Some frequently used commands can be added around the selector though user handles.
  //* @example 
  //* &lt;div id="diagram"&gt;&lt;/div&gt;<br>
  //* &lt;script&gt;
  //* //Create Diagram
  //$("#diagram").ejDiagram();
  //* &lt;/script&gt
  //*/
    //#region UserHandle
    ej.datavisualization.Diagram.UserHandleDefaults = {
        /** The name of the user handles
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.name = "Clone";
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        name: "",
        /** To customize the userhandles shape using path data
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.pathData = "M4.6350084,4.8909971 L4.6350084,9.3649971 9.5480137,9.3649971 9.5480137,4.8909971 z M3.0000062,2.8189973 L11.184016,2.8189973 11.184016,10.999997 3.0000062,10.999997 z M0,0 L7.3649998,0 7.3649998,1.4020001 1.4029988,1.4020001 1.4029988,8.0660002 0,8.0660002 0,1.4020001 0,0.70300276 z";
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        pathData: "",
        /** The border color of user handles
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.borderColor = "red";
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        borderColor: "",
        /**The background color of user handle
          * @default #2382c3
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.backgroundColor = "red";
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        backgroundColor: "#2382c3",
        /** The Position of user handles to be updated See {@link Position}
          * @name Position
          * @default ej.datavisualization.Diagram.UserHandlePositions.BottomCenter
          * @type {enum}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.position = ej.datavisualization.Diagram.UserHandlePositions.BottomLeft;
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        position: ej.datavisualization.Diagram.UserHandlePositions.BottomCenter,
        /** Customize the color of user handles
          * @default white
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.pathColor = "red";
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        pathColor: "white",
        /**The tool to be used as a user handle
          * @default ""
          * @type {String}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.tool = new CloneTool(cloneHandle.name);
          * function CloneTool(name) { base.call(this, name);this.singleAction = true;} //Properties can be modified
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        tool: "",
        /**The size of the tool
          * @default 20
          * @type {Int}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.size = 30;
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        size: 20,
        /**Enables or disables the visibility of the user handle
          * @default true
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.visibility = false;
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        visible: true,
        /** The functionality to enables or disables the multiple selection
          * @default false
          * @type {Boolean}
          * @example
          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * var userHandles = ej.datavisualization.Diagram.UserHandle();
          * userHandles.enableMultiSelection = false;
          * $("#diagramcontent").ejDiagram({userHandles:userHandles});
          * &lt;/script&gt
          * @memberof ejDiagram.UserHandle 
          * @instance
          */
        enableMultiSelection: false
    };
    ej.datavisualization.Diagram.UserHandle = function (options) {
        return $.extend(true, {}, ej.datavisualization.Diagram.UserHandleDefaults, options);
    };
    //#endregion

})(jQuery, Syncfusion);

;

(function ($, ej) {
    "use strict";

    //#region SVG
    var Svg = (function () {
        function Svg(attr) {
            this.xmlns = "http://www.w3.org/2000/svg";
            this.document = document.createElementNS(this.xmlns, "svg");
            this.id = attr.id;
            if (attr) {
                ej.datavisualization.Diagram.Util.attr(this.document, attr);
            }
            return this;
        }
        Svg.prototype.element = function (attr, tag) {
            var element;
            if (attr && attr.id) {
                element = this.document.getElementById(attr.id);
            }
            if (!element) {
                element = document.createElementNS(this.xmlns, tag);
            }
            if (attr)
                ej.datavisualization.Diagram.Util.attr(element, attr);
            return element;
        };
        Svg.prototype.g = function (attr) {
            return this.element(attr, "g");
        };
        Svg.prototype.defs = function (attr) {
            return this.element(attr, "defs");
        };
        Svg.prototype.image = function (attr) {
            return this.element(attr, "image");
        };
        Svg.prototype.path = function (attr) {
            return this.element(attr, "path");
        };
        Svg.prototype.text = function (attr) {
            return this.element(attr, "text");
        };
        Svg.prototype.textPath = function (attr) {
            return this.element(attr, "textPath");
        };
        Svg.prototype.tspan = function (attr) {
            return this.element(attr, "tspan");
        };
        Svg.prototype.rect = function (attr) {
            return this.element(attr, "rect");
        };
        Svg.prototype.ellipse = function (attr) {
            return this.element(attr, "ellipse");
        };
        Svg.prototype.circle = function (attr) {
            return this.element(attr, "circle");
        };
        Svg.prototype.line = function (attr) {
            return this.element(attr, "line");
        };
        Svg.prototype.polyline = function (attr) {
            return this.element(attr, "polyline");
        };
        Svg.prototype.polygon = function (attr) {
            return this.element(attr, "polygon");
        };
        Svg.prototype.foreignObject = function (attr) {
            return this.element(attr, "foreignObject");
        };
        Svg.prototype.linearGradient = function (attr) {
            return this.element(attr, "linearGradient");
        };
        Svg.prototype.radialGradient = function (attr) {
            return this.element(attr, "radialGradient");
        };
        Svg.prototype.stop = function (attr) {
            return this.element(attr, "stop");
        };
        Svg.prototype.pattern = function (attr) {
            return this.element(attr, "pattern");
        };
        Svg.prototype.appendChild = function (element) {
            this.document.appendChild(element);
        };
        Svg.prototype.removeChild = function (element, parent) {
            if (parent) {
                parent.removeChild(element);
            } else {
                this.document.removeChild(element);
            }
        };
        Svg.prototype.getElementById = function (id) {
            return this.document.getElementById(id);
        };
        Svg.prototype.getElementsByClassName = function (name) {
            return this.document.getElementsByClassName(name);
        };
        Svg.prototype.getElementsByTagName = function (name) {
            return this.document.getElementsByTagName(name);
        };
        Svg.prototype.pathBounds = function (data) {
            var attributes = { d: data };
            var path = this.path(attributes);
            this.document.appendChild(path);
            var bounds = path.getBBox();
            this.document.removeChild(path);
            return bounds;
        };
        Svg.prototype.textBounds = function (text, attr, textElement) {
            var bounds = null;
            if (text && attr) {
                var svgText = this.text(attr);
                svgText.appendChild(document.createTextNode(text));
                this.document.appendChild(svgText);
                bounds = svgText.getBBox();
                this.document.removeChild(svgText);
            }
            else if (textElement) {
                this.document.appendChild(textElement);
                bounds = textElement.getBBox();
                this.document.removeChild(textElement);
            }
            return bounds;
        };
        Svg.prototype.absolutePath = function (path) {
            var x0, y0, x1, y1, x2, y2, segs = path.pathSegList;
            for (var x = 0, y = 0, i = 0, length = segs.numberOfItems; i < length; ++i) {
                var seg = segs.getItem(i), char = seg.pathSegTypeAsLetter;
                if (/[MLHVCSQTA]/.test(char)) {
                    if ('x' in seg) x = seg.x;
                    if ('y' in seg) y = seg.y;
                } else {
                    if ('x1' in seg) x1 = x + seg.x1;
                    if ('x2' in seg) x2 = x + seg.x2;
                    if ('y1' in seg) y1 = y + seg.y1;
                    if ('y2' in seg) y2 = y + seg.y2;
                    if ('x' in seg) x += seg.x;
                    if ('y' in seg) y += seg.y;
                    switch (char) {
                        case 'm': segs.replaceItem(path.createSVGPathSegMovetoAbs(x, y), i); break;
                        case 'l': segs.replaceItem(path.createSVGPathSegLinetoAbs(x, y), i); break;
                        case 'h': segs.replaceItem(path.createSVGPathSegLinetoHorizontalAbs(x), i); break;
                        case 'v': segs.replaceItem(path.createSVGPathSegLinetoVerticalAbs(y), i); break;
                        case 'c': segs.replaceItem(path.createSVGPathSegCurvetoCubicAbs(x, y, x1, y1, x2, y2), i); break;
                        case 's': segs.replaceItem(path.createSVGPathSegCurvetoCubicSmoothAbs(x, y, x2, y2), i); break;
                        case 'q': segs.replaceItem(path.createSVGPathSegCurvetoQuadraticAbs(x, y, x1, y1), i); break;
                        case 't': segs.replaceItem(path.createSVGPathSegCurvetoQuadraticSmoothAbs(x, y), i); break;
                        case 'a': segs.replaceItem(path.createSVGPathSegArcAbs(x, y, seg.r1, seg.r2, seg.angle, seg.largeArcFlag, seg.sweepFlag), i); break;
                        case 'z': case 'Z': x = x0; y = y0; break;
                    }
                }
                if (char === 'M' || char === 'm') x0 = x, y0 = y;
            }
            return path;
        };
        return Svg;
    })();

    ej.datavisualization.Diagram.Svg = Svg;
    //#endregion

    //#region SVG Renderer
    ej.datavisualization.Diagram.SvgContext = {
        _renderDocument: function (view, diagram) {
            if (window.SVGSVGElement) {
                var attr = {
                    id: view.canvas.id + "_svg",
                    version: "1.1",
                    xlink: "http://www.w3.org/1999/xlink",
                    "style": "position:absolute",
                };

                var svg = new ej.datavisualization.Diagram.Svg(attr);

                view.svg = svg;
                if (diagram) {
                    diagram._createScroller(diagram._canvas);
                    diagram._svg = svg;
                    view.canvas.appendChild(svg.document);
                    diagram._view = this._renderView(view.canvas, view.svg);
                    diagram._page = this._renderPage(view.canvas, view.svg, diagram._view);
                    diagram._htmlLayer = this._renderHtmlLayer(view.canvas);
                    this._renderBackground(view.canvas, view.svg, diagram._page, diagram.model);
                    diagram._pageBackgroundLayer = this._renderBackgroundLayer(view.canvas, view.svg, diagram._page);
                    this._renderGrid(view.canvas, view.svg, diagram._page, diagram);
                    diagram._diagramLayer = view.diagramLayer = this._renderDiagramLayer(view.canvas, view.svg, diagram._page);
                    diagram._adornerLayer = this._renderAdornerLayer(view.canvas, view.svg, diagram._page);
                }
                else {


                }
            }
        },

        _renderView: function (canvas, svg) {
            var attr = { id: canvas.id + "_view" };
            var view = svg.g(attr);
            svg.appendChild(view);
            return view;
        },

        _renderHtmlLayer: function (canvas) {
            var div = document.createElement("div");
            var attr = { "id": canvas.id + "_htmlLayer", "class": "htmlLayer" };
            ej.datavisualization.Diagram.Util.attr(div, attr);
            var htmlLayer = div;
            div.style.pointerEvents = "none";
            canvas.appendChild(htmlLayer);
            return htmlLayer;
        },

        _renderPage: function (canvas, svg, parent) {
            var attr = { "id": canvas.id + "_page", "class": "page" };
            var page = svg.g(attr);
            parent.appendChild(page);
            return page;
        },

        _renderDiagramLayer: function (canvas, svg, parent) {
            var attr = { "id": canvas.id + "_diagramLayer", "class": "DiagramLayer" };
            var diagramLayer = svg.g(attr);
            parent.appendChild(diagramLayer);
            return diagramLayer;
        },

        _renderAdornerLayer: function (canvas, svg, parent) {
            var attr = { "id": canvas.id + "_adornerLayer", "class": "AdornerLayer" };
            var adornerLayer = svg.g(attr);
            parent.appendChild(adornerLayer);
            return adornerLayer;
        },

        _renderBackgroundLayer: function (canvas, svg, parent) {
            var attr = {
                "id": canvas.id + "_pageBackground",
                "class": "PageBackgroundLayer"
            };
            var pageBackgroundLayer = svg.g(attr);
            parent.appendChild(pageBackgroundLayer);
            return pageBackgroundLayer;
        },

        _renderBackground: function (canvas, svg, parent, model) {
            svg.document.style.msTouchAction = "none";
            svg.document.style.display = "block";
            svg.document.style.backgroundColor = "white";
            var attr = { id: canvas.id + "_backgroundLayer" };
            var g = svg.g(attr);
            attr = { "id": canvas.id + "_background", "x": "0", "y": "0", "width": "100%", "height": "100%", "preserveAspectRatio": "none", "pointer-events": "none" };
            var image = svg.image(attr);
            if (model.backgroundImage) {
                image.setAttributeNS("http://www.w3.org/1999/xlink", "xlink:href", model.backgroundImage);
                if (!svg.getElementById(canvas.id + "_background")) {
                    g.appendChild(image);
                }
            }
            else {
                if (svg.getElementById(image.id)) {
                    g.removeChild(svg.getElementById(image.id));
                }
            }
            if (!svg.getElementById(g.id))
                parent.appendChild(g);

        },

        _renderGrid: function (canvas, svg, parent, diagram) {
            var defs = svg.defs({ "id": canvas.id + "patterndefinition" });
            var g;
            svg.appendChild(defs);
            if (diagram.model.snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.ShowHorizontalLines ||
                diagram.model.snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.ShowVerticalLines) {
                var grid = document.getElementById(canvas.id + "_grid");
                var rect = document.getElementById(canvas.id + "pattern_gridline");
                var pattern = document.getElementById(canvas.id + "pattern_grid");
                if (pattern)
                    defs.removeChild(pattern);
                var attr = { id: canvas.id + "_grid", "pointer-events": "none" };
                g = svg.g(attr);
                var height = 0;
                if (diagram.model.snapSettings.horizontalGridLines.linesInterval) {
                    diagram.model.snapSettings.horizontalGridLines.linesInterval.forEach(function (entry) {
                        height += entry;
                    });
                }
                var width = 0;
                if (diagram.model.snapSettings.verticalGridLines.linesInterval) {
                    diagram.model.snapSettings.verticalGridLines.linesInterval.forEach(function (entry) {
                        width += entry;
                    });
                }
                var scale = diagram.model.zoomFactor;
                attr = { id: canvas.id + "pattern_grid", x: 0, y: 0, width: width * scale, height: height * scale, patternUnits: "userSpaceOnUse" };
                var pattern = svg.pattern(attr);
                //pattern.setAttribute("patternUnits", "userSpaceOnUse");
                scale = this._scaleSnapInterval(diagram.model, scale);
                this._renderHorizontalGridlines(scale, pattern, width, diagram.model, svg);
                this._renderVerticalGridlines(scale, pattern, height, diagram.model, svg);
                defs.appendChild(pattern);
                var rect = svg.rect({ id: canvas.id + "pattern_gridline", "x": 0, "y": 0, "width": "100%", "height": "100%", "fill": "url(#" + canvas.id + "pattern_grid)" });
                g.appendChild(rect);
                if (!grid)
                    parent.appendChild(g);
            }
            else {
                g = document.getElementById(canvas.id + "_grid");
                if (g) {
                    var grid = document.getElementById(canvas.id + "pattern_gridline");
                    if (grid)
                        g.removeChild(grid);
                }
            }
        },
        _updateGrid: function (hoffset, voffset, scale, diagram) {
            var grid = document.getElementById(diagram._canvas.id + "pattern_gridline");
            var i;
            if (grid) {
                var pattern = document.getElementById(diagram._canvas.id + "pattern_grid");
                var width = 0;
                if (diagram.model.snapSettings.horizontalGridLines.linesInterval) {
                    for (i = 0; i < diagram.model.snapSettings.horizontalGridLines.linesInterval.length; i++) {
                        width += diagram.model.snapSettings.horizontalGridLines.linesInterval[i];
                    }
                }
                var height = 0;
                if (diagram.model.snapSettings.verticalGridLines.linesInterval) {
                    for (i = 0; i < diagram.model.snapSettings.verticalGridLines.linesInterval.length; i++) {
                        height += diagram.model.snapSettings.verticalGridLines.linesInterval[i];
                    }
                }

                scale = this._scaleSnapInterval(diagram.model, scale);
                var svg = diagram._svg;
                var defs = svg.defs({ "id": diagram._canvas.id + "patterndefinition" });
                if (pattern)
                    defs.removeChild(pattern);
                var attr = { id: diagram._canvas.id + "pattern_grid", x: 0, y: 0, width: width * scale, height: height * scale, patternUnits: "userSpaceOnUse" };
                pattern = diagram._svg.pattern(attr);
                this._renderHorizontalGridlines(scale, pattern, width, diagram.model, diagram._svg);
                this._renderVerticalGridlines(scale, pattern, height, diagram.model, diagram._svg);
                defs.appendChild(pattern);
            }
        },
        _scaleSnapInterval: function (model, scale) {
            if (scale >= 2) {
                while (scale >= 2) {
                    scale /= 2;
                }
            }
            else if (scale <= 0.5) {
                while (scale <= 0.5) {
                    scale *= 2;
                }
            }
            var i;
            if (scale !== 1) {
                model.snapSettings.horizontalGridLines._snapinterval = [];
                for (i = 0; i < model.snapSettings.horizontalGridLines.snapInterval.length; i++) {
                    model.snapSettings.horizontalGridLines._snapinterval[i] =
                        model.snapSettings.horizontalGridLines.snapInterval[i] * scale;
                }
                model.snapSettings.verticalGridLines._snapinterval = [];
                for (i = 0; i < model.snapSettings.verticalGridLines.snapInterval.length; i++) {
                    model.snapSettings.verticalGridLines._snapinterval[i] =
                        model.snapSettings.verticalGridLines.snapInterval[i] * scale;
                }
            }
            return scale;
        },

        _renderHorizontalGridlines: function (scale, pattern, height, model, svg) {
            var snapSettings = model.snapSettings;
            if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.ShowHorizontalLines) {
                var space = 0;
                var cnt = 0;
                for (var i = 0; i < snapSettings.horizontalGridLines.linesInterval.length; i = i + 2) {
                    var thickness = snapSettings.horizontalGridLines.linesInterval[i];
                    var line = svg.line({
                        "x1": space * scale, "y1": 0, "x2": space * scale, "y2": height * scale, "stroke": snapSettings.horizontalGridLines.lineColor,
                        "stroke-width": thickness
                    });
                    //svg.appendChild(line);
                    space += snapSettings.horizontalGridLines.linesInterval[i + 1] + thickness;
                    pattern.appendChild(line);
                    cnt++;
                }
            }
        },

        _renderVerticalGridlines: function (scale, pattern, width, model, svg) {
            var snapSettings = model.snapSettings;
            if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.ShowVerticalLines) {
                var space = 0;
                var cnt = 0;
                for (var i = 0; i < snapSettings.verticalGridLines.linesInterval.length; i = i + 2) {
                    var thickness = model.snapSettings.verticalGridLines.linesInterval[i];
                    var line = svg.line({
                        "x1": 0, "y1": space * scale, "x2": width * scale, "y2": space * scale, "stroke": snapSettings.verticalGridLines.lineColor,
                        "stroke-width": thickness, "stroke-dasharray": snapSettings.verticalGridLines.lineDashArray
                    });
                    space += snapSettings.verticalGridLines.linesInterval[i + 1] + thickness;
                    pattern.appendChild(line);
                    cnt++;
                }
            }
        },
        //#region Transformation
        transformView: function (diagram, hOffset, vOffset) {
            var view = diagram._view;
            var attr = {
                "transform": "translate(" + hOffset + "," + vOffset + ")"
            };
            ej.datavisualization.Diagram.Util.attr(view, attr);
            if (ej.browserInfo().name === "msie") {
                if (diagram._htmlLayer && diagram._htmlLayer.children.length > 0) {
                    diagram._htmlLayer.style.left = hOffset + "px";
                    diagram._htmlLayer.style.top = vOffset + "px";
                    diagram._htmlLayer.style.position = "absolute";
                }
            }
        },
        scaleContent: function (diagram, scale) {
            var diagramLayer = diagram._diagramLayer;
            ej.datavisualization.Diagram.Util.attr(diagramLayer, { "transform": "scale(" + scale + ")" });
            if (ej.browserInfo().name === "msie") {
                if (diagram._htmlLayer && diagram._htmlLayer.children.length > 0) {
                    diagram._htmlLayer.style.transform = "scale(" + scale + ")";
                }
            }
            if (diagram.selectionList.length > 0)
                this.updateSelector(diagram.selectionList[0], diagram._svg, scale, diagram, diagram.model.selectorConstraints);
            if (diagram.selectionList[0]) {
                if ((diagram.model.userHandles && diagram.model.userHandles.length > 0)) {
                    var isMultipleSelection = false;
                    if (diagram.selectionList[0].isPseudoGroup)
                        isMultipleSelection = true;
                    if (diagram.model.selectorConstraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                        ej.datavisualization.Diagram.SvgContext.updateUserHandles(diagram.model.userHandles, diagram.selectionList[0], diagram._svg, isMultipleSelection, false, scale);
                }
            }
        },
        setSize: function (svg, width, height) {
            ej.datavisualization.Diagram.Util.attr(svg.document, { width: width + "px", height: height + "px" });
        },
        //#endregion

        _findIndex: function (diagram, node) {
            var lastNode, newIndex = 1, index, elements;
            if (node.parent)
                elements = $("#" + node.parent.name).find(">.node,>.connector,>.group");
            else
                elements = $("#DiagramContent_canvas_svg").find(">.node,>.connector,>.group");
            if (node.name != "helper") {
                lastNode = elements[elements.length - 1];
                if (lastNode && lastNode.id == "helper")
                    lastNode = elements[elements.length - 2];
                if (lastNode) {
                    index = 0;
                    if (lastNode.className.animVal == "ej-d-node" || lastNode.className.animVal == "ej-d-group") {
                        newIndex = index + 1;
                    }
                    else if (lastNode.className.animVal == "ej-d-connector") {
                        newIndex = index + 1;
                    }
                }
            }
            return newIndex;
        },
        //#region Render Node

        //#region render
        renderNode: function (node, svg, parent) {
            var g;
            // if (node.visible) 
            {
                var name = node.name;
                var visible = node.visible ? "visible" : "hidden";
                var x = node.offsetX - node.width * node.pivot.x;
                var y = node.offsetY - node.height * node.pivot.y;
                g = svg.g({
                    "id": name, "class": "ej-d-node", "transform": "rotate(" + node.rotateAngle + "," + node.offsetX + "," + node.offsetY +
                        "),translate(" + x + "," + y + ")", "visibility": visible
                });
                if (parent) {
                    parent.appendChild(g);
                }
                else {
                    svg.appendChild(g);
                }
                this._renderNode(node, svg, g);
            }
            return g;
        },

        _renderNode: function (node, svg, g) {

            this._renderShape(node, svg, g);
            this._renderLabels(node, svg, g);
            this._renderPorts(node, svg, g);
        },

        renderGroup: function (group, svg, parent, nameTable) {
            var g;
            var visible = group.visible ? "visible" : "hidden";
            //if (group.visible) 
            {
                g = svg.g({ "id": group.name, "class": "ej-d-group", "visibility": visible });
                if (parent) {
                    parent.appendChild(g);
                }
                else {
                    svg.appendChild(g);
                }
                var children = group.children;
                for (var i = 0, len = children.length; i < len; i++) {
                    var child = nameTable[children[i]];
                    if (child.isGroup)
                        this.renderGroup(child, svg, g, nameTable);
                    else if (child.line)
                        this.renderConnector(child, svg, g);
                    else
                        this.renderNode(child, svg, g);
                }
                this._renderLabels(group, svg, g);
                this._renderPorts(group, svg, g);
            }
            return g;
        },

        _renderGradient: function (name, gradient, svg) {
            var fill;
            var id;
            if (gradient.type === "linear") {
                id = this._renderLinearGradient(name, gradient, svg);
                fill = "url(#" + id + ")";
            }
            else if (gradient.type === "radial") {
                id = this._renderRadialGradient(name, gradient, svg);
                fill = "url(#" + id + ")";
            }
            return fill;
        },

        _renderLinearGradient: function (name, gradient, svg) {
            var defs = svg.getElementsByTagName("defs")[0];
            if (defs) {
                var attr = { "id": name + "_gradient", "x1": gradient.x1 + "%", "y1": gradient.y1 + "%", "x2": gradient.x2 + "%", "y2": gradient.y2 + "%" };
                var linear = svg.linearGradient(attr);
                this._renderStops(gradient, svg, linear);
                defs.appendChild(linear);
                return linear.id;
            }
            return null;
        },

        _renderRadialGradient: function (name, gradient, svg) {
            var defs = svg.getElementsByTagName("defs")[0];
            if (defs) {
                var attr = {
                    "id": name + "_gradient", "cx": gradient.cx + "%", "cy": gradient.cy + "%",
                    "fx": gradient.fx + "%", "fy": gradient.fy + "%", "r": gradient.r + "%"
                };
                var radial = svg.radialGradient(attr);
                this._renderStops(gradient, svg, radial);
                defs.appendChild(radial);
                return radial.id;
            }
            return null;
        },

        _renderStops: function (gradient, svg, element) {
            if (svg.getElementById(element.getAttribute("id")) === element) {
                while (element.firstChild) {
                    element.removeChild(element.firstChild);
                }
            }
            var stops = gradient.stops;
            var stop;
            for (var i = 0, len = stops.length; i < len; i++) {
                stop = stops[i];
                element.appendChild(svg.stop({ "offset": stop.offset + "%", "stop-color": stop.color, "stop-opacity": stop.opacity }));
            }
        },

        _renderShape: function (node, svg, g) {
            switch (node.shape.type) {
                case "rectangle":
                    this._renderRect(node, svg, g);
                    break;
                case "ellipse":
                    this._renderEllipse(node, svg, g);
                    break;
                case "image":
                    this._renderImage(node, svg, g);
                    break;
                case "path":
                    this._renderPath(node, svg, g);
                    break;
                case "polygon":
                    this._renderPolygon(node, svg, g);
                    break;
                case "text":
                    this._renderTextElement(node, svg, g);
                    break;
                case "html":
                    this._renderHtmlElement(node, svg, g);
                    break;
                case "native":
                    this._rendercontent(node, svg, g);
                    break;
            }
        },

        _rendercontent: function (node, svg, g) {
            if (node.shape.content) {
                if (typeof (node.shape.content) == 'string') {
                    var content = document.getElementById(node.shape.content);
                    node.shape.content = content.cloneNode(true);
                }
                if (node.shape.content instanceof SVGElement) {
                    node.shape.content = node.shape.content.cloneNode(true);
                }
                node.shape.content.setAttribute("preserveAspectRatio", "none");
                g.appendChild(node.shape.content);
                var bounds = node.shape.content.getBBox();
                var delwidth = bounds.width ? node.width / bounds.width : 1;
                var delheight = bounds.height ? node.height / bounds.height : 1;
                node.shape.content.setAttribute("transform", "scale(" + delwidth + "," + delheight + ")");
                node.shape.content.setAttribute("id", node.name + "_shape");
            }
        },

        _fill: function (node, svg) {
            var fill;
            if (node.gradient) {
                fill = this._renderGradient(node.name, node.gradient, svg);
            }
            if (!fill) {
                fill = node.fillColor;
            }
            return fill;
        },

        _renderRect: function (node, svg, g) {
            var fill = this._fill(node, svg);
            var attr = {
                "id": node.name + "_shape", "rx": node.shape.cornerRadius, "ry": node.shape.cornerRadius,
                "width": node.width, "height": node.height, "fill": fill, "stroke": node.borderColor,
                "stroke-width": node.borderWidth, "opacity": node.opacity, "stroke-dasharray": node.borderDashArray
            };
            g.appendChild(svg.rect(attr));
        },

        _renderEllipse: function (node, svg, g) {
            var fill = this._fill(node, svg);
            var attr = {
                "id": node.name + "_shape", "rx": node.width / 2, "ry": node.height / 2,
                "cx": node.width / 2, "cy": node.height / 2,
                "fill": fill, "stroke": node.borderColor, "stroke-width": node.borderWidth,
                "opacity": node.opacity, "stroke-dasharray": node.borderDashArray

            };
            g.appendChild(svg.ellipse(attr));
        },

        _renderImage: function (node, svg, g) {
            var backRect = this._renderBackgroundRect(node, svg);
            g.appendChild(backRect);
            var attr = {
                "id": node.name + "_shape", "width": node.width, "height": node.height,
                "opacity": node.opacity, "preserveAspectRatio": "none"
            };
            var shape = svg.image(attr);
            shape.setAttributeNS("http://www.w3.org/1999/xlink", "xlink:href", node.shape.src);
            g.appendChild(shape);
        },

        _renderPolygon: function (node, svg, g) {
            var fill = this._fill(node, svg);
            ej.datavisualization.Diagram.Geometry.updatePolygonPoints(node);
            var points = this._convertToSVGPoints(node.shape.points);
            var attr = {
                "id": node.name + "_shape", "fill": fill, "stroke": node.borderColor,
                "stroke-width": node.borderWidth, "opacity": node.opacity,
                "stroke-dasharray": node.borderDashArray, "points": points
            };
            g.appendChild(svg.polygon(attr));
        },

        _renderPath: function (node, svg, g) {
            var fill = this._fill(node, svg);
            var d = ej.datavisualization.Diagram.Geometry.updatePath(0, 0, node.width, node.height, node.shape.pathData, svg);
            var attr = {
                "id": node.name + "_shape", "width": node.width,
                "height": node.height, "d": d, "opacity": node.opacity,
                "stroke-dasharray": node.borderDashArray, "stroke": node.borderColor,
                "stroke-width": node.borderWidth, "fill": fill

            };
            g.appendChild(svg.path(attr));
        },

        _renderHtmlElement: function (node, svg, g) {
            var backRect = this._renderBackgroundRect(node, svg);
            g.appendChild(backRect);
            if (node.shape.html) {
                var x = node.offsetX - node.width * node.pivot.x;
                var y = node.offsetY - node.height * node.pivot.y;
                var div = document.createElement("div");
                var style = "width:" + node.width + "px;height:" + node.height + "px;padding:1px; opacity:" + node.opacity + ";left:" + x + "px; top:" + y + "px; ";
                if (ej.browserInfo().name === "msie")
                    style += "display: block; position: absolute; border:0px;";
                var attr = { "id": node.name + "_html", "class": "foreignObject", "style": style };
                ej.datavisualization.Diagram.Util.attr(div, attr);
                if (node.shape.html instanceof HTMLElement) {
                    div.appendChild(node.shape.html);
                }
                else
                    div.innerHTML = node.shape.html.toString();
                if (ej.browserInfo().name === "msie") {
                    var parentdiv = document.createElement("div");
                    var attr1 = { "id": node.name + "_parentdiv", "class": "ej-d-node" };
                    ej.datavisualization.Diagram.Util.attr(parentdiv, attr1);
                    parentdiv.appendChild(div);
                    var htmlLayer = svg.document.parentNode.getElementsByClassName("htmlLayer")[0];
                    if (htmlLayer)
                        htmlLayer.appendChild(parentdiv);
                    else
                        svg.document.parentNode.appendChild(div);
                }
                else {
                    attr = { "id": node.name + "_shape", "width": node.width, "height": node.height, "style": "pointer-events:none" };
                    var shape = svg.foreignObject(attr);
                    shape.appendChild(div);
                    g.appendChild(shape);
                }
            }
        },

        _initializeGuidelines: function (svg, attr, parent) {
            var g = svg.g(attr);
            parent.appendChild(g);
            return g;
        },

        _renderSideAlignmentLines: function (start, end, g, svg, scale) {
            var line = svg.line({
                "x1": start.x * scale, "y1": start.y * scale,
                "x2": end.x * scale, "y2": end.y * scale, "stroke": "#07EDE1", "stroke-width": 1
            });
            g.appendChild(line);
        },

        _renderCenterAlignmentLines: function (start, end, g, svg, scale) {
            var line = svg.line({
                "x1": start.x * scale, "y1": start.y * scale,
                "x2": end.x * scale, "y2": end.y * scale, "stroke": "#07EDE1", "stroke-width": 1,
            });
            g.appendChild(line);
        },

        _renderSpacingLines: function (start, end, g, svg, scale) {
            var d, d1;
            var div1 = svg.g({});
            if (start.x == end.x) {
                d = "M" + (start.x * scale - 5) + " " + (start.y * scale + 5) + " L" + start.x * scale + " " + start.y * scale + " L" + (start.x * scale + 5) + " " + (start.y * scale + 5) + "z";
                d1 = "M" + (end.x * scale - 5) + " " + (end.y * scale - 5) + " L" + end.x * scale + " " + end.y * scale + " L" + (end.x * scale + 5) + " " + (end.y * scale - 5) + "z";
                div1.appendChild(svg.line({ "x1": start.x * scale - 8, "x2": start.x * scale + 8, "y1": start.y * scale - 1, "y2": start.y * scale - 1, "stroke": "#07EDE1", "stroke-width": 1 }));
                div1.appendChild(svg.line({ "x1": end.x * scale - 8, "x2": end.x * scale + 8, "y1": end.y * scale + 1, "y2": end.y * scale + 1, "stroke": "#07EDE1", "stroke-width": 1 }));
            }
            else {
                d = "M" + (start.x * scale + 5) + " " + (start.y * scale + 5) + " L" + start.x * scale + " " + start.y * scale + " L" + (start.x * scale + 5) + " " + (start.y * scale - 5) + "z";
                d1 = "M" + (end.x * scale - 5) + " " + (end.y * scale - 5) + " L" + end.x * scale + " " + end.y * scale + " L" + (end.x * scale - 5) + " " + (end.y * scale + 5) + "z";
                div1.appendChild(svg.line({ "x1": start.x * scale - 1, "x2": start.x * scale - 1, "y1": start.y * scale - 8, "y2": start.y * scale + 8, "stroke": "#07EDE1", "stroke-width": 1 }));
                div1.appendChild(svg.line({ "x1": end.x * scale + 1, "x2": end.x * scale + 1, "y1": end.y * scale - 8, "y2": end.y * scale + 8, "stroke": "#07EDE1", "stroke-width": 1 }));
            }
            div1.appendChild(svg.path({ "d": d, "fill": "#07EDE1" }));
            var line = svg.line({
                "x1": start.x * scale, "y1": start.y * scale,
                "x2": end.x * scale, "y2": end.y * scale, "stroke": "#07EDE1", "stroke-width": 0.6, "fill": "#07EDE1"
            });
            div1.appendChild(line);
            div1.appendChild(svg.path({ "d": d1, "fill": "#07EDE1" }));
            g.appendChild(div1);
        },

        _removeGuidelines: function (parent, g) {
            if (g != null) {
                parent.removeChild(g);
            }
        },

        //#endregion

        //#region update
        update: function (data, diagram) {
            if (data.isGroup)
                this.updateGroup(data, svg, diagram);
            else if (data.line)
                this.updateConnector(data, svg, diagram);
            else
                this.updateNode(data, svg, diagram);
        },

        updateGroup: function (group, svg, diagram) {
            var children = group.children;
            var visible = group.visible ? "visible" : "hidden";
            svg.g({ "id": group.name, "visibility": visible });
            for (var i = 0, len = children.length; i < len; i++) {
                var child = diagram.nameTable[children[i]];
                if (child.isGroup)
                    this.updateGroup(child, svg, diagram);
                else if (child.line)
                    this.updateConnector(child, svg, diagram);
                else
                    this.updateNode(child, svg, diagram);
            }
            this._updateAssociatedConnector(group, svg, diagram);
            this._updateLabels(group, svg);
            this._updatePorts(group, svg);
        },

        updateLabelStyle: function (node, label, svg) {
            var attr = {};
            if (node && svg && label) {
                if (label.bold)
                    attr["font-weight"] = "bold";
                else
                    attr["font-weight"] = "";

                if (label.italic)
                    attr["font-style"] = "italic";
                else
                    attr["font-style"] = "";

                if (label.textDecoration)
                    attr["text-decoration"] = label.textDecoration;
                attr["font-family"] = label.fontFamily;
                attr["font-size"] = label.fontSize;
                attr["fill"] = label.fontColor;
            }
            ej.datavisualization.Diagram.Util.attr(svg.getElementById(node.name + "_" + label.name), attr);
        },

        _updateNodeStyle: function (node, svg) {
            if (node && svg) {
                var attr = {};
                attr["fill"] = node.fillColor;
                attr["stroke"] = node.borderColor;
                attr["stroke-width"] = node.borderWidth;
                attr["stroke-dasharray"] = node.borderDashArray;
                if (node.gradient)
                    attr["fill"] = this._renderGradient(node.name, node.gradient, svg);
                var type = node.shape.type == "text" ? "_backRect" : "_shape";
                if (ej.browserInfo().name === "msie" && node.shape && node.shape.type == "html") {
                    //ej.datavisualization.Diagram.Util.attr(svg.getElementById(node.name + "_html"), attr);
                }
                else
                    ej.datavisualization.Diagram.Util.attr(svg.getElementById(node.name + type), attr);
            }
        },

        _updateConnectorStyle: function (connector, svg) {
            if (connector && svg) {
                var attr = {};
                attr["stroke"] = connector.lineColor;
                attr["stroke-width"] = connector.lineWidth;
                attr["stroke-dasharray"] = connector.lineDashArray;
                ej.datavisualization.Diagram.Util.attr(svg.getElementById(connector.name).firstChild, attr);
            }
        },

        updateTargetDecoratorStyle: function (connector, svg) {
            if (svg) {
                var attr = {};
                attr["stroke"] = connector.targetDecorator.borderColor;
                attr["fill"] = connector.targetDecorator.fillColor;
                ej.datavisualization.Diagram.Util.attr(svg.getElementById(connector.name + "_targetDecorator"), attr);
            }
        },

        updateSourceDecoratorStyle: function (connector, svg) {
            if (svg) {
                var attr = {};
                attr["stroke"] = connector.sourceDecorator.borderColor;
                attr["fill"] = connector.sourceDecorator.fillColor;
                ej.datavisualization.Diagram.Util.attr(svg.getElementById(connector.name + "_sourceDecorator"), attr);
            }
        },

        updateNode: function (node, svg, diagram) {
            var g, bounds;
            if (node.shape.type === "html" && ej.browserInfo().name === "msie") {
                g = document.getElementById(node.name + "_html").getBoundingClientRect();
                bounds = { x: g.left, y: g.top, width: g.width, height: g.height };
            }
            else {
                g = svg.getElementById(node.name + "_shape");
                bounds = g.getBBox();
            }
            this._updateNode(node, svg);
            this._updateNodeStyle(node, svg);
            this._updateAssociatedConnector(node, svg, diagram);
            if (!diagram.activeTool.inAction || diagram.activeTool.name !== "move" && diagram.activeTool.name !== "rotate") {
                this._updateLabels(node, svg);
                if (bounds.width != node.width || bounds.height != node.height) {
                    this._updatePorts(node, svg);
                }
            }
        },

        updateTextBlock: function (node, label, svg) {
            var attr = {};
            var label = node.shape.textBlock;
            node.shape.textBlock = label;
            if (node && svg && label) {
                if (label.bold)
                    attr["font-weight"] = "bold";
                else
                    attr["font-weight"] = "";

                if (label.italic)
                    attr["font-style"] = "italic";
                else
                    attr["font-style"] = "";

                if (label.textDecoration)
                    attr["text-decoration"] = label.textDecoration;
                attr["font-family"] = label.fontFamily;
                attr["font-size"] = label.fontSize;
                attr["fill"] = label.fontColor;
            }
            ej.datavisualization.Diagram.Util.attr(svg.getElementById(node.name + "_shape"), attr);
            this._updateTextElement(node, svg);
        },

        _updateAssociatedConnector: function (node, svg, diagram) {
            var i, len;
            for (i = 0, len = node.inEdges.length; i < len; i++) {
                this.updateConnector(diagram.nameTable[node.inEdges[i]], svg, diagram);
            }
            for (i = 0, len = node.outEdges.length; i < len; i++) {
                this.updateConnector(diagram.nameTable[node.outEdges[i]], svg, diagram);
            }
        },

        _updateNode: function (node, svg) {
            var x = node.offsetX - node.width * node.pivot.x;
            var y = node.offsetY - node.height * node.pivot.y;
            var angle = node.rotateAngle;
            var pt = ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY);
            var visible = node.visible ? "visible" : "hidden";
            var attr = ({
                "id": node.name, "transform": "rotate(" + angle + "," + pt.x + "," + pt.y + "),translate(" + x + "," + y + ")",
                "visibility": visible
            });
            svg.g(attr);
            switch (node.shape.type) {
                case "rectangle":
                    svg.rect({
                        "id": node.name + "_shape", "width": node.width, "height": node.height,
                    });
                    break;
                case "ellipse":
                    svg.ellipse({
                        "id": node.name + "_shape", "rx": node.width / 2, "ry": node.height / 2,
                        "cx": node.width / 2, "cy": node.height / 2
                    });
                    break;
                case "image":
                    this._updateBackgroundRect(node, svg);
                    svg.image({
                        "id": node.name + "_shape", "width": node.width, "height": node.height,
                    });
                    break;
                case "path":

                    var d = ej.datavisualization.Diagram.Geometry.updatePath(0, 0, node.width, node.height, node.shape.pathData, svg);

                    svg.path({
                        "id": node.name + "_shape", "d": d,
                    });
                    break;
                case "polygon":
                    this._updatePolygon(node, svg);
                    break;
                case "text":
                    this._updateTextElement(node, svg);
                    break;
                case "html":
                    this._updateHtmlElement(node, svg);
                    break;
                case "native":
                    var bounds = node.shape.content.getBBox();
                    var delwidth = bounds.width ? node.width / bounds.width : 1;
                    var delheight = bounds.height ? node.height / bounds.height : 1;
                    svg.g({
                        "id": node.name + "_shape", "width": node.width, "height": node.height,
                        "transform": "scale(" + delwidth + "," + delheight + ")"
                    });

                    break;
            }
        },

        _updateHtmlElement: function (node, svg) {
            this._updateBackgroundRect(node, svg);
            var div;
            if (ej.browserInfo().name === "msie") {
                var x = node.offsetX - node.width * node.pivot.x;
                var y = node.offsetY - node.height * node.pivot.y;
                div = document.getElementById(node.name + "_html");
                div.style.left = x + "px";
                div.style.top = y + "px";
                div.style.transform = "rotate(" + node.rotateAngle + "deg)";
            }
            else {
                div = svg.getElementById(node.name + "_shape");
                svg.foreignObject({
                    "id": node.name, "width": node.width, "height": node.height
                });
            }
            div.style.width = node.width.toString() + "px";
            div.style.height = node.height.toString() + "px";
        },

        _updatePolygon: function (node, svg) {
            ej.datavisualization.Diagram.Geometry.updatePolygonPoints(node);
            svg.polygon({
                "id": node.name + "_shape", "points": this._convertToSVGPoints(node.shape.points)
            });
        },

        _convertToSVGPoints: function (points) {
            var pts = "";
            for (var i = 0, len = points.length; i < len; i++) {
                pts += points[i].x + "," + points[i].y + " ";
            }
            return pts.trim();
        },

        _renderTextElement: function (node, svg, g) {
            var textElement = node.shape.textBlock;
            if (textElement) {
                var backRect = this._renderBackgroundRect(node, svg);
                g.appendChild(backRect);
                var attr = {
                    "id": node.name + "_shape", "class": "ej-d-label", "font-family": textElement.fontFamily,
                    "font-size": textElement.fontSize, "fill": textElement.fontColor,
                    "text-decoration": textElement.textDecoration, "opacity": node.opacity,
                    "alignment-baseline": "middle"
                };
                if (textElement.bold)
                    attr["font-weight"] = "bold";
                if (textElement.italic)
                    attr["font-style"] = "italic";
                var text = svg.text(attr);
                text.appendChild(document.createTextNode(textElement.text));
                g.appendChild(text);
                var bounds = ej.datavisualization.Diagram.Util.bounds(node);
                this._wrapText(node, bounds, text, node.shape.textBlock, svg);
                this._alignTextOnLabel(node, bounds, text, node.shape.textBlock, svg);
            }
        },

        _updateTextElement: function (node, svg) {
            this._updateBackgroundRect(node, svg);
            var text = svg.getElementById(node.name + "_shape");
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            this._wrapText(node, bounds, text, node.shape.textBlock, svg);
            this._alignTextOnLabel(node, bounds, text, node.shape.textBlock, svg);
        },

        _renderBackgroundRect: function (node, svg) {
            var fill = this._fill(node, svg);
            var attr = {
                "id": node.name + "_backRect", "class": "backrect", "x": 0, "y": 0,
                "width": node.width, "height": node.height, "fill": fill,
                "stroke": node.borderColor, "stroke-width": node.borderWidth, "opacity": node.opacity,
                "stroke-dasharray": node.borderDashArray
            };
            return svg.rect(attr);
        },

        _updateBackgroundRect: function (node, svg) {
            var attr = {
                "id": node.name + "_backRect", "x": 0, "y": 0,
                "width": node.width, "height": node.height,
            };
            svg.rect(attr);
        },
        //#endregion

        setNodeShape: function (node, svg, parent) {
            var g;
            if (parent) {
                var parentg = svg.getElementById(parent.name);
                g = $(parentg).find("#" + node.name)[0];
            }
            else {
                g = svg.getElementById(node.name);
            }
            $(g).empty();
            this._renderNode(node, svg, g);
        },

        setLine: function (connector, svg, parent) {
            var g;
            if (parent) {
                var parentg = svg.getElementById(parent.name);
                g = $(parentg).find("#" + connector.name)[0];
            }
            else {
                g = svg.getElementById(connector.name);
            }
            $(g).empty();

            this.renderConnector(connector, svg, g);
        },

        addNodeLabel: function (node, label, svg, parent) {
            var g;
            if (parent) {
                var parentg = svg.getElementById(parent.name);
                g = $(parentg).find("#" + node.name)[0];
            }
            else {
                g = svg.getElementById(node.name);
            }
            this._renderLabel(node, label, svg, g);
        },
        //#endregion

        //#region Render Connector
        renderConnector: function (connector, svg, parent) {
            var g;
            var line;
            var visible = connector.visible ? "visible" : "hidden";
            //if (connector.visible) 
            {
                g = svg.g({ "id": connector.name, "class": "ej-d-connector", "visibility": visible });
                if (parent) {
                    if (parent.id !== g.id) {
                        parent.appendChild(g);
                    }
                }
                else {
                    svg.appendChild(g);
                }
                var attr = {
                    "id": connector.name + "_line", "fill": "none", "stroke": connector.lineColor,
                    "stroke-width": connector.lineWidth, "stroke-dasharray": connector.lineDashArray, "opacity": connector.opacity
                };
                if (connector.line.type != "bezier") {
                    var points = this._clipDecorators(connector);
                    attr["points"] = this._convertToSVGPoints(points);
                    line = svg.polyline(attr);
                    g.appendChild(line);
                    attr = { "id": attr.id + "_hitTest", "stroke-width": connector.lineHitPadding, "points": attr.points, "pointer-events": "stroke", "visibility": "hidden" };
                    line = svg.polyline(attr);
                    g.appendChild(line);
                }
                else {
                    var conn = connector.line;
                    var d = "M" + conn.startPoint.x + " " + conn.startPoint.y + " C" + conn._point1.x + " " + conn._point1.y + " " + conn._point2.x + " " + conn._point2.y + " " + conn.endPoint.x + " " + conn.endPoint.y;
                    attr = {
                        "id": connector.name + "_line",
                        "d": d, "fill": "none", "stroke": connector.lineColor,
                        "stroke-width": connector.lineWidth, "stroke-dasharray": connector.lineDashArray, "opacity": connector.opacity
                    };
                    line = svg.path(attr);
                    g.appendChild(line);
                    attr = { "id": attr.id + "_hitTest", "stroke-width": connector.lineHitPadding, "d": d, "pointer-events": "stroke", "visibility": "hidden" };
                    line = svg.path(attr);
                    g.appendChild(line);
                }

                this._renderLabels(connector, svg, g);
                this._renderDecorators(connector, svg, g);
            }
            return g;
        },

        _clipDecorators: function (connector) {
            var start, end;
            var points = $.extend(true, [], connector.line.points);
            if (connector.targetDecorator && connector.targetDecorator.shape !== ej.datavisualization.Diagram.DecoratorShapes.None) {
                start = points[points.length - 1];
                end = points[points.length - 2];
                var len = ej.datavisualization.Diagram.Geometry.distance(start, end);
                len = (len == 0) ? 1 : len;
                var width = connector.targetDecorator.width;
                var newPoint = ej.datavisualization.Diagram.Point();
                newPoint.x = start.x + width * (end.x - start.x) / len;
                newPoint.y = start.y + width * (end.y - start.y) / len;
                points[points.length - 1] = newPoint;
            }
            if (connector.sourceDecorator && connector.sourceDecorator.shape !== ej.datavisualization.Diagram.DecoratorShapes.None) {
                start = points[0];
                end = points[1];
                var len = ej.datavisualization.Diagram.Geometry.distance(start, end);
                len = (len == 0) ? 1 : len;
                var width = connector.sourceDecorator.width;
                var newPoint = ej.datavisualization.Diagram.Point();
                newPoint.x = start.x + width * (end.x - start.x) / len;
                newPoint.y = start.y + width * (end.y - start.y) / len;
                points[0] = newPoint;
            }
            return points;
        },

        _updateConnector: function (connector, svg) {
            if (connector.line.type != "bezier") {
                var points = this._clipDecorators(connector);
                svg.polyline({ "id": connector.name + "_line", "points": this._convertToSVGPoints(points) });
                svg.polyline({ "id": connector.name + "_line_hitTest", "points": this._convertToSVGPoints(points) });
            }
            else {
                var conn = connector.line;
                var d = "M" + conn.startPoint.x + " " + conn.startPoint.y + " C" + conn._point1.x + " " + conn._point1.y + " " + conn._point2.x + " " + conn._point2.y + " " + conn.endPoint.x + " " + conn.endPoint.y;
                svg.path({ "id": connector.name + "_line", "d": d });
                svg.path({ "id": connector.name + "_line_hitTest", "d": d });
            }
            this._updateConnectorStyle(connector, svg);
        },

        updateConnector: function (connector, svg, diagram) {
            //var svg = diagram._svg;
            var visible = connector.visible ? "visible" : "hidden";
            svg.g({ "id": connector.name, "visibility": visible });
            this._updateConnector(connector, svg);
            this._updateLabels(connector, svg);
            this._updateDecorators(connector, svg);
        },

        renderDecorators: function (connector, svg) {
            var g = svg.getElementById(connector.name);
            this._renderDecorators(connector, svg, g);
        },
        clearDecorators: function (connector, svg) {
            this._updateConnector(connector, svg);
            var g = svg.getElementById(connector.name);
            var dec = svg.getElementById(connector.name + "_targetDecorator");
            if (dec)
                svg.removeChild(dec, g);
            dec = svg.getElementById(connector.name + "_sourceDecorator");
            if (dec)
                svg.removeChild(dec, g);
        },
        //#endregion

        //#region Render Decorator
        _renderDecorators: function (connector, svg, g) {
            var startPoint;
            var endPoint;
            if (connector.targetDecorator && connector.targetDecorator.shape) {
                startPoint = connector.line.points[connector.line.points.length - 2];
                endPoint = connector.line.endPoint;
                if (connector.line.type == "bezier") {
                    startPoint = connector.line._point2;
                }
                this._renderDecorator(connector.name + "_targetDecorator", endPoint,
                    startPoint, connector.targetDecorator, svg, g);
            }
            if (connector.sourceDecorator && connector.sourceDecorator.shape) {
                startPoint = connector.line.startPoint;
                endPoint = connector.line.points[1];
                if (connector.line.type == "bezier") {
                    endPoint = connector.line._point1;
                }
                this._renderDecorator(connector.name + "_sourceDecorator", startPoint,
                    endPoint, connector.sourceDecorator, svg, g);
            }
        },

        _renderDecorator: function (name, point1, point2, decorator, svg, g) {
            var shape;
            var attr;
            var d;
            var size = ej.datavisualization.Diagram.Size(decorator.width, decorator.height);
            switch (decorator.shape) {
                case "arrow":
                    d = this._constructArrow(point1, size);
                    attr = { "id": name, "class": "decorator", "d": d, "fill": decorator.fillColor, "stroke": decorator.borderColor };
                    shape = svg.path(attr);
                    break;
                case "openarrow":
                    d = this._constructArrow(point1, size, true);
                    attr = { "id": name, "class": "decorator", "d": d, "fill": "transparent", "stroke": decorator.borderColor };
                    shape = svg.path(attr);
                    break;
                case "circle":
                    var rx = size.width / 2;
                    var ry = size.height / 2;
                    attr = {
                        "id": name, "class": "decorator", "rx": rx, "ry": ry, "cx": (point1.x + size.width / 2), "cy": (point1.y),
                        "fill": decorator.fillColor, "stroke": decorator.borderColor
                    };
                    shape = svg.ellipse(attr);
                    break;
                case "diamond":
                    d = this._constructDiamond(point1, size, svg);
                    attr = {
                        "id": name, "class": "decorator", "x": point1.x, "y": point1.y, "width": size.width,
                        "height": size.height, "d": d, "fill": decorator.fillColor, "stroke": decorator.borderColor
                    };
                    shape = svg.path(attr);
                    break;
                case "path":
                    d = ej.datavisualization.Diagram.Geometry.updatePath(point1.x, point1.y - size.height / 2, size.width, size.height, decorator.pathData, svg);
                    attr = {
                        "id": name, "class": "decorator", "x": point1.x, "y": point1.y, "width": size.width,
                        "height": size.height, "d": d, "fill": decorator.fillColor, "stroke": decorator.borderColor
                    };
                    shape = svg.path(attr);
                    break;
            }
            //apply translate matrix and rotate matrix here
            if (shape) {
                shape.setAttribute("transform", "rotate(" + ej.datavisualization.Diagram.Geometry.findAngle(point1, point2) + " " + point1.x + " " + point1.y + ")");
                g.appendChild(shape);
            }
        },

        _updateDecorators: function (connector, svg) {
            var startPoint;
            var endPoint;
            if (connector.targetDecorator && connector.targetDecorator.shape !== ej.datavisualization.Diagram.DecoratorShapes.None) {
                startPoint = connector.line.points[connector.line.points.length - 2];
                endPoint = connector.line.endPoint;
                if (connector.line.type == "bezier") {
                    startPoint = connector.line._point2;
                }
                this._updateDecorator(connector.name + "_targetDecorator", endPoint, startPoint, connector.targetDecorator, svg);
            }
            if (connector.sourceDecorator && connector.sourceDecorator.shape !== ej.datavisualization.Diagram.DecoratorShapes.None) {
                startPoint = connector.line.startPoint;
                endPoint = connector.line.points[1];
                if (connector.line.type == "bezier") {
                    endPoint = connector.line._point1;
                }
                this._updateDecorator(connector.name + "_sourceDecorator", startPoint, endPoint, connector.sourceDecorator, svg);
            }
        },

        _updateDecorator: function (name, point1, point2, decorator, svg) {
            var shape;
            var attr;
            var d;
            var size = ej.datavisualization.Diagram.Size(decorator.width, decorator.height);
            switch (decorator.shape) {
                case "arrow":
                    d = this._constructArrow(point1, size);
                    attr = { "id": name, "d": d };
                    shape = svg.path(attr);
                    break;
                case "openarrow":
                    d = this._constructArrow(point1, size, true);
                    attr = { "id": name, "d": d };
                    shape = svg.path(attr);
                    break;
                case "circle":
                    var rx = size.width / 2;
                    var ry = size.height / 2;
                    attr = { "id": name, "rx": rx, "ry": ry, "cx": (point1.x + size.width / 2), "cy": (point1.y) };
                    shape = svg.ellipse(attr);
                    break;
                case "diamond":
                    d = this._constructDiamond(point1, size, svg);
                    attr = { "id": name, "x": point1.x, "y": point1.y, "width": size.width, "height": size.height, "d": d };
                    shape = svg.path(attr);
                    break;
                case "path":
                    d = ej.datavisualization.Diagram.Geometry.updatePath(point1.x, point1.y - size.height / 2, size.width, size.height, decorator.pathData, svg);
                    attr = {
                        "id": name, "x": point1.x, "y": point1.y, "width": size.width, "height": size.height, "d": d
                    };
                    shape = svg.path(attr);
                    break;
            }
            //apply translate matrix and rotate matrix here
            if (shape)
                shape.setAttribute("transform", "rotate(" + ej.datavisualization.Diagram.Geometry.findAngle(point1, point2) + " " + point1.x + " " + point1.y + ")");
        },

        _constructArrow: function (point, size, isOpen) {
            var path = new ej.datavisualization.Diagram.Path();
            path.moveTo(point.x + size.width, point.y + size.height / 2);
            path.lineTo(point.x, point.y);
            path.lineTo(point.x + size.width, point.y - size.height / 2);
            if (!isOpen) {
                path.close();
            }
            return path.toString();
        },

        _constructDiamond: function (point, size, svg) {
            var path = new ej.datavisualization.Diagram.Path();
            path.moveTo(point.x + size.width, point.y);
            path.lineTo(point.x + size.width / 2, point.y + size.height / 2);
            path.lineTo(point.x, point.y);
            path.lineTo(point.x + size.width / 2, point.y - size.height / 2);
            path.lineTo(point.x + size.width, point.y);
            var d = path.toString();
            return d;
        },
        //#endregion

        //#region Render Label
        _renderLabels: function (node, svg, g) {
            var labels = node.labels;
            for (var i = 0, len = labels.length; i < len; ++i) {
                this._renderLabel(node, labels[i], svg, g);
            }
        },

        _renderLabelBackground: function (label, node, text, svg) {
            var bounds;
            if (ej.browserInfo().name === "mozilla")
                bounds = text.getBoundingClientRect();
            else
                bounds = text.getBBox();
            var attr = {
                "id": node.name + "_" + label.name + "_lblbg",
                "width": bounds.width, "height": bounds.height, "fill": label.fillColor,
                "stroke": label.borderColor, "stroke-width": label.borderWidth, "transform": "translate(" + 0 + "," + 0 + ")"
            };
            return svg.rect(attr);
        },

        _renderLabel: function (node, label, svg, g) {
            var attr = {
                "id": node.name + "_" + label.name, "class": "ej-d-label", "font-family": label.fontFamily,
                "font-size": label.fontSize, "fill": label.fontColor, "text-decoration": label.textDecoration,
                "dominant-baseline": "middle", "pointer-events": "none"
            };
            if (label.bold)
                attr["font-weight"] = "bold";
            if (label.italic)
                attr["font-style"] = "italic";
            var text = svg.text(attr);
            text.textContent = label.text;
            g.appendChild(text);
            var bg = this._renderLabelBackground(label, node, text, svg);
            g.insertBefore(bg, text);
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            this._wrapText(node, bounds, text, label, svg);
            this._alignTextOnLabel(node, bounds, text, label, svg);
        },

        _updateLabels: function (node, svg) {
            var labels = node.labels;
            for (var i = 0, len = labels.length; i < len; ++i) {
                var label = labels[i];
                var text = svg.getElementById(node.name + "_" + label.name);
                text.setAttribute("fill", label.fontColor);
                var bounds = ej.datavisualization.Diagram.Util.bounds(node);
                this._wrapText(node, bounds, text, label, svg);
                this._alignTextOnLabel(node, bounds, text, label, svg);
            }
        },

        updateLabel: function (node, label, svg) {
            var text = svg.getElementById(node.name + "_" + label.name);
            text.setAttribute("fill", label.fontColor);
            text.textContent = label.text;
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            this._wrapText(node, bounds, text, label, svg);
            this._alignTextOnLabel(node, bounds, text, label, svg);
        },

        _alignTextOnLabel: function (node, nodeBounds, text, label, svg) {
            var bounds = text.getBBox();
            var offset = ej.datavisualization.Diagram.Util._getLabelPosition(label, nodeBounds);
            var point = { x: 0, y: 0 };
            var y = 0;

            if (label.verticalAlignment == ej.datavisualization.Diagram.VerticalAlignment.Top)
                y = label.margin.top + offset.y;
            else if (label.verticalAlignment == ej.datavisualization.Diagram.VerticalAlignment.Center)
                y = offset.y - bounds.height / 2;
            else
                y = offset.y - bounds.height - label.margin.bottom;
            point.y = y;

            switch (label.horizontalAlignment) {
                case ej.datavisualization.Diagram.HorizontalAlignment.Left:
                    switch (label.textAlign) {
                        case ej.datavisualization.Diagram.TextAlign.Left:
                            point.x = offset.x + label.margin.left;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Center:
                            point.x = offset.x + bounds.width / 2 + label.margin.left;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Right:
                            point.x = offset.x + bounds.width + label.margin.left;
                            break;
                    }
                    break;
                case ej.datavisualization.Diagram.HorizontalAlignment.Center:
                    switch (label.textAlign) {
                        case ej.datavisualization.Diagram.TextAlign.Left:
                            point.x = offset.x - bounds.width / 2;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Center:
                            point.x = offset.x;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Right:
                            point.x = offset.x + bounds.width / 2;
                            break;
                    }
                    break;
                case ej.datavisualization.Diagram.HorizontalAlignment.Right:
                    switch (label.textAlign) {
                        case ej.datavisualization.Diagram.TextAlign.Left:
                            point.x = offset.x - bounds.width - label.margin.right;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Center:
                            point.x = offset.x - bounds.width / 2 - label.margin.right;
                            break;
                        case ej.datavisualization.Diagram.TextAlign.Right:
                            point.x = offset.x - label.margin.right;
                            break;
                    }
                    break;
            }
            if (node.line || node.isGroup) {
                point.x = point.x + nodeBounds.x;
                point.y = point.y + nodeBounds.y;
            }
            text.setAttribute("transform", "translate(" + point.x + "," + point.y + ")");
            //Updates the label background
            var background = svg.getElementById(node.name + "_" + label.name + "_lblbg");
            if (background) {
                var x = point.x + bounds.x;
                y = point.y;
                if (ej.browserInfo().name === "mozilla")
                    y = point.y + label.fontSize / 2;
                var attr = {
                    "width": bounds.width, "height": bounds.height, "transform": "translate(" + x + "," + y + ")", "fill": label.fillColor,
                    "stroke": label.borderColor, "stroke-width": label.borderWidth
                };
                ej.datavisualization.Diagram.Util.attr(background, attr);
            }
        },

        _wrapText: function (node, textBBox, text, label, svg) {
            var str = label.text; var attr = null;
            while (text.hasChildNodes()) {
                text.removeChild(text.lastChild);
            }
            var bbWidth, bbHeight;
            if (node.line) {
                bbWidth = textBBox.width;
                bbHeight = textBBox.height;
            }
            else {
                bbWidth = textBBox.width - label.margin.left - label.margin.right;
                bbHeight = textBBox.height - label.margin.top - label.margin.bottom;
            }
            bbWidth = bbWidth < label.width ? label.width : bbWidth;
            var eachLine = str.split('\n');
            var x, y, tspan, j, string = "", posX, posY, childNodes, bounds, i;
            childNodes = svg.getElementById(text.id).childNodes;
            for (j = 0; j < eachLine.length; j++) {
                tspan = svg.tspan();
                tspan.style.fontSize = label.fontSize;
                text.appendChild(tspan);
                for (i = 0; i < eachLine[j].length; i++) {
                    bounds = childNodes[childNodes.length - 1].getComputedTextLength();
                    if (label.wrapText) {
                        if (bounds >= (bbWidth - label.fontSize)) {
                            tspan.textContent += eachLine[j][i];
                            posX = -bounds;
                            if (!(i == eachLine[j].length - 1)) {
                                tspan = svg.tspan();
                                text.appendChild(tspan);
                            }
                        }
                        else {
                            tspan.textContent += eachLine[j][i];
                        }
                    }
                    else {
                        tspan.textContent += eachLine[j][i];
                    }
                }
            }
            this._wrapTextAlign(text, childNodes, label.fontSize, label.textAlign);
        },

        _wrapTextAlign: function (text, childNodes, height, textAlign) {
            for (var i = 0; i < childNodes.length; i++) {
                var x = childNodes[i].getComputedTextLength();
                switch (textAlign) {
                    case "left":
                        x = 0;
                        break;
                    case "center":
                        x = -x / 2;
                        break;
                    case "right":
                        x = -x;
                        break;
                }
                var attr = { "x": Number(x), "dy": height };
                var tspan = childNodes[i];
                ej.datavisualization.Diagram.Util.attr(tspan, attr);
            }
        },
        //#endregion

        //#region Render Port
        _renderPorts: function (node, svg, g) {
            var ports = node.ports;
            var port;
            for (var i = 0, len = ports.length; i < len; ++i) {
                port = ports[i];
                var shape = this._renderPort(node, port, svg);
                g.appendChild(shape);
                if (port.visibility & ej.datavisualization.Diagram.PortVisibility.Hidden || port.visibility & ej.datavisualization.Diagram.PortVisibility.Hover || port.visibility & ej.datavisualization.Diagram.PortVisibility.Connect) {
                    shape.setAttribute("visibility", "hidden");
                }
            }
        },

        _renderPort: function (node, port, svg) {
            var shape;
            var attr;
            var size = ej.datavisualization.Diagram.Size(port.size, port.size);
            var point = ej.datavisualization.Diagram.Util._getPortPosition(port, ej.datavisualization.Diagram.Util.bounds(node, true), true);
            switch (port.shape) {
                case "x":
                    var d = this._constructX(point, port.size);
                    attr = {
                        "id": node.name + "_" + port.name, "class": "ej-d-port", "fill": port.fillColor,
                        "stroke": port.borderColor, "stroke-width": port.borderWidth, "d": d
                    };
                    shape = svg.path(attr);
                    break;
                case "circle":
                    var rx = size.width / 2;
                    var ry = size.height / 2;
                    attr = {
                        "id": node.name + "_" + port.name, "class": "ej-d-port", "rx": rx, "ry": ry,
                        "cx": point.x, "cy": point.y, "fill": port.fillColor, "stroke": port.borderColor,
                        "stroke-width": port.borderWidth
                    };
                    shape = svg.ellipse(attr);
                    break;
                case "square":
                    attr = {
                        "id": node.name + "_" + port.name, "class": "ej-d-port", "x": point.x - port.size / 2,
                        "y": point.y - port.size / 2, "width": size.width, "height": size.height,
                        "fill": port.fillColor, "stroke": port.borderColor, "stroke-width": port.borderWidth
                    };
                    shape = svg.rect(attr);
                    break;
            }
            return shape;
        },
        _insertPort: function (node, port, svg) {
            var g;
            g = document.getElementById(node.name);
            var portshape = ej.datavisualization.Diagram.SvgContext._renderPort(node, port, svg);
            g.appendChild(portshape);
            if (port.visibility & ej.datavisualization.Diagram.PortVisibility.Hidden || port.visibility & ej.datavisualization.Diagram.PortVisibility.Hover || port.visibility & ej.datavisualization.Diagram.PortVisibility.Connect) {
              portshape.setAttribute("visibility", "hidden");
            }

        },
        _updatePort: function (node, port, svg) {
            var size = ej.datavisualization.Diagram.Size(port.size, port.size);
            var point = ej.datavisualization.Diagram.Util._getPortPosition(port, ej.datavisualization.Diagram.Util.bounds(node, true), true);
            var id = node.name + "_" + port.name;
            switch (port.shape) {
                case "x":
                    var d = this._constructX(point, port.size);
                    svg.path({ "id": id, "d": d });
                    break;
                case "circle":
                    var rx = size.width / 2;
                    var ry = size.height / 2;
                    svg.ellipse({ "id": id, "rx": rx, "ry": ry, "cx": point.x, "cy": point.y });
                    break;
                case "square":
                    svg.rect({ "id": id, "x": point.x - port.size / 2, "y": point.y - port.size / 2 });
                    break;
            }
        },

        _updatePorts: function (node, svg) {
            var ports = node.ports;
            for (var i = 0, len = ports.length; i < len; ++i) {
                var port = ports[i];
                this._updatePort(node, port, svg);
            }
        },

        _constructX: function (point, size) {
            var path = new ej.datavisualization.Diagram.Path();
            path.moveTo((point.x - size / 2), (point.y - size / 2));
            path.lineTo((point.x + size / 2), (point.y + size / 2));
            path.moveTo((point.x + size / 2), (point.y - size / 2));
            path.lineTo((point.x - size / 2), (point.y + size / 2));
            return path.toString();
        },

        _drawPortHighlighter: function (port, node, svg, parent, scale) {
            var shape, size, point, x, y, transform;
            var bounds;
            var fill = "#8CC63F";
            var border = "#1A1A1A";
            var borderWidth = 0.5;
            if (!port) {
                bounds = ej.datavisualization.Diagram.Util.bounds(node, true);
                size = ej.datavisualization.Diagram.Size(bounds.width, bounds.height);
                point = ej.datavisualization.Diagram.Point(bounds.x, bounds.y);
                x = point.x * scale;
                y = point.y * scale;
                border = fill;
                fill = "transparent";
                borderWidth = 2;
                var center = ej.datavisualization.Diagram.Point(node.offsetX - node.width * node.pivot.x + node.width / 2, node.offsetY - node.height * node.pivot.y + node.height / 2);
                transform = "rotate(" + node.rotateAngle + "," + center.x * scale + "," + center.y * scale + ")";
            }
            else {
                size = ej.datavisualization.Diagram.Size(port.size * 2, port.size * 2);
                point = ej.datavisualization.Diagram.Util._getPortPosition(port, ej.datavisualization.Diagram.Util.bounds(node, true));
                var matrix = ej.Matrix.identity();
                ej.Matrix.rotate(matrix, node.rotateAngle, node.offsetX, node.offsetY);
                point = ej.Matrix.transform(matrix, point);
                x = (point.x - port.size) * scale;
                y = (point.y - port.size) * scale;
                transform = "rotate(" + 0 + "," + (x + size.width / 2) + "," + (y + size.height / 2) + ")";
            }
            var attr = {
                "id": "portHighlighter", "class": "ej-d-port", "x": x,
                "y": y, "width": size.width * scale, "height": size.height * scale,
                "fill": fill, "stroke": border, "stroke-width": borderWidth, "pointer-events": "none", "transform": transform
            };
            shape = svg.rect(attr);
            parent.appendChild(shape);
            return shape;
        },

        _removePortHighlighter: function (svg, parent) {
            var highlighter = svg.getElementById("portHighlighter");
            if (highlighter) {
                svg.removeChild(highlighter, parent);
            }
        },
        //#endregion

        //#region Render Selector

        renderSelector: function (shape, svg, parent, scale, constraints) {
            if (shape.line) {
                var g = svg.g({
                    "id": svg.document.id + "handle_g", "class": "handle"
                });
                parent.appendChild(g);
                this._renderEndPointHandle(shape, svg, scale);
            }
            else {
                var g = svg.g({
                    "id": svg.document.id + "handle_g", "class": "handle",
                    "transform": "translate(" + (shape.offsetX - shape.width / 2) * scale + "," + (shape.offsetY - shape.height / 2) * scale + "),rotate(" + shape.rotateAngle + "," + (shape.width / 2) * scale + "," + (shape.height / 2) * scale + ")"
                });
                parent.appendChild(g);
                this._renderResizeHandle(shape, svg, scale, constraints);
            }
        },

        _renderResizeHandle: function (node, svg, scale, constraints) {

            var rotate = ej.datavisualization.Diagram.Point(node.width / 2, -20 / scale);
            if (constraints & ej.datavisualization.Diagram.SelectorConstraints.Rotator) {
                this._renderPivotLine(node, svg, scale);
                this._renderRotateThumb("rotate", node, rotate.x, rotate.y, scale, svg);
            }
            if (constraints & ej.datavisualization.Diagram.SelectorConstraints.Resizer) {
                this._renderResizeBorder("resizeBorder", node, svg, scale);
                this._renderResizeCorner("nw-resize", node, 0, 0, svg);
                this._renderResizeCorner("n-resize", node, (node.width / 2) * scale, 0, svg);
                this._renderResizeCorner("ne-resize", node, node.width * scale, 0, svg);
                this._renderResizeCorner("w-resize", node, 0, (node.height / 2) * scale, svg);
                this._renderResizeCorner("e-resize", node, node.width * scale, (node.height / 2) * scale, svg);
                this._renderResizeCorner("sw-resize", node, 0, node.height * scale, svg);
                this._renderResizeCorner("s-resize", node, (node.width / 2) * scale, node.height * scale, svg);
                this._renderResizeCorner("se-resize", node, node.width * scale, node.height * scale, svg);
            }
        },

        renderUserHandles: function (handles, shape, svg, isMultipleSelection, scale, parent) {
            for (var handleIndex = 0; handleIndex < handles.length; handleIndex++) {
                if ((isMultipleSelection && handles[handleIndex].enableMultiSelection) || !isMultipleSelection) {
                    if (handles[handleIndex].visible)
                        this._renderUserHandle(handles[handleIndex], shape, svg, scale, parent);
                }
            }
        },

        _renderUserHandle: function (handle, node, svg, scale, parent) {
            var g = svg.g({ "id": svg.document.id + "userHandle_g", "class": "userHandle" });
            parent.appendChild(g);
            var position = this._getHandlePosition(handle, node, scale);
            var d = ej.datavisualization.Diagram.Geometry.updatePath(position.x * scale - handle.size / 4, position.y * scale - handle.size / 4, (handle.size / 2), (handle.size / 2), handle.pathData, svg);
            var shape = this._getHandleShape(handle, position.x * scale, position.y * scale);
            var icon = this._getHandleIcon(handle, d, position.x, position.y);
            g.appendChild(svg.circle(shape));
            g.appendChild(svg.path(icon));
        },

        _getHandleIcon: function (handle, d) {
            var icon = {
                "id": handle.name + "_icon", "class": "userHandle-icon", "d": d, "fill": handle.pathColor
            };
            return icon;
        },

        _getHandlePosition: function (handle, node, scale) {
            var positionPoints = ej.datavisualization.Diagram.Point();
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            var position = handle.position;
            var distance = 10;
            var matrix = ej.Matrix.identity();
            if (node.rotateAngle)
                ej.Matrix.rotate(matrix, node.rotateAngle);
            var point = new ej.datavisualization.Diagram.Point();
            switch (position) {
                case "topleft":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(distance + (handle.size / 2), distance + (handle.size / 2)));
                    positionPoints.x = bounds.topLeft.x - (point.x / scale);
                    positionPoints.y = bounds.topLeft.y - (point.y / scale);
                    break;
                case "topcenter":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(0, distance + (handle.size / 2)));
                    positionPoints.x = bounds.topCenter.x - (point.x / scale);
                    positionPoints.y = bounds.topCenter.y - point.y / scale;
                    break;
                case "topright":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(distance + (handle.size / 2), (distance / 2) - (handle.size)));
                    positionPoints.x = bounds.topRight.x + (point.x / scale);
                    positionPoints.y = bounds.topRight.y + (point.y / scale);
                    break;
                case "middleleft":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(-(distance + (handle.size / 2)), 0));
                    positionPoints.x = bounds.middleLeft.x + (point.x / scale);
                    positionPoints.y = bounds.middleLeft.y + (point.y / scale);
                    break;
                case "middleright":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(distance + (handle.size / 2), 0));
                    positionPoints.x = bounds.middleRight.x + (point.x / scale);
                    positionPoints.y = bounds.middleRight.y + (point.y / scale);
                    break;
                case "bottomleft":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(-(distance + (handle.size / 2)), distance + (handle.size / 2)));
                    positionPoints.x = bounds.bottomLeft.x + (point.x / scale);
                    positionPoints.y = bounds.bottomLeft.y + (point.y / scale);
                    break;
                case "bottomcenter":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(0, ((distance / 2) - (handle.size))));
                    positionPoints.x = bounds.bottomCenter.x - (point.x / scale);
                    positionPoints.y = bounds.bottomCenter.y - (point.y / scale);
                    break;
                case "bottomright":
                    point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(distance + (handle.size / 2), distance + (handle.size / 2)));
                    positionPoints.x = bounds.bottomRight.x + (point.x / scale);
                    positionPoints.y = bounds.bottomRight.y + (point.y / scale);
                    break;
            }
            return positionPoints;
        },

        _getHandleShape: function (handle, cx, cy) {
            var shape = {
                "id": handle.name + "_shape", "class": "userHandle", "cx": cx, "cy": cy, "r": handle.size / 2, "fill": handle.backgroundColor,
                "stroke": handle.borderColor, "stroke-width": handle.borderWidth, "title": handle.name
            };
            return shape;
        },

        _updateHandleShape: function (handle, cx, cy, svg) {
            var attr = { "id": handle.name + "_shape", "cx": cx, "cy": cy };
            svg.circle(attr);
        },

        _updateHanleIcon: function (handle, d, svg) {
            var attr = { "id": handle.name + "_icon", "d": d };
            svg.path(attr);
        },

        _getHanleIcon: function (handle, d, cx, cy) {
            var icon = {
                "id": handle.name, "d": d, "stroke": handle.borderColor,
                "stroke-width": handle.borderWidth, "fill": handle.fillColor
            };
            return icon;
        },

        renderPivotPoint: function (node, scale, svg) {
            if (!svg.getElementById("pivot")) {
                ej.datavisualization.Diagram.SvgContext._renderResizeCorner("pivot", node,
                      node.offsetX * scale, node.offsetY * scale, svg);
                this._updatePivotLine(node, svg, scale);
            }

        },

        _renderPivotLine: function (node, svg, scale) {
            var rotateThumb = ej.datavisualization.Diagram.Point(node.width / 2, -20 / scale);
            var pivot = ej.datavisualization.Diagram.Point(node.width / 2, 0);
            var handle = svg.getElementById(svg.document.id + "handle_g");
            var line = svg.line({
                "id": "pivotLine", "x1": rotateThumb.x * scale, "y1": rotateThumb.y * scale, "x2": pivot.x * scale, "y2": pivot.y * scale,
                "stroke": "black", "stroke-width": 1, "stroke-dasharray": "2,3", "fill": "none"
            });
            handle.appendChild(line);
        },

        _renderResizeBorder: function (id, node, svg, scale) {
            var handle = svg.getElementById(svg.document.id + "handle_g");
            var rect = svg.rect({
                "id": id, "width": node.width * scale, "height": node.height * scale, "stroke": "#097F7F", "stroke-width": 0.6, "stroke-dasharray": "6,3", "fill": "none"
            });
            handle.appendChild(rect);
        },

        _renderResizeCorner: function (corner, node, cx, cy, svg) {
            var handle = svg.getElementById(svg.document.id + "handle_g");
            var fill = "white";
            if (!(ej.datavisualization.Diagram.Util.canResize(node)))
                fill = "darkgray";
            var attr = { "id": corner, "fill": fill, "stroke": "black", "stroke-width": 1, "cx": cx, "cy": cy, "r": 7 };
            handle.appendChild(svg.circle(attr));
            attr = { "id": corner + "_transparent", "class": corner, "fill": "transparent", "cx": cx, "cy": cy, "r": 10 };
            handle.appendChild(svg.circle(attr));
        },

        _renderRotateThumb: function (corner, node, cx, cy, scale, svg) {
            var handle = svg.getElementById(svg.document.id + "handle_g");
            var d = "M 16.856 10.239 L 18 3.438 l -2.189 0.817 c -0.974 -1.694 -2.482 -2.995 -4.326 -3.696 C 9.375 -0.245 7.071" +
                "-0.18 5.01 0.744 C 2.942 1.668 1.365 3.342 0.558 5.453 c -0.803 2.115 -0.738 4.414 0.185 6.478 c 0.925 2.064 " +
            "2.6 3.645 4.714 4.45 c 0.969 0.371 1.993 0.554 3.013 0.554 c 1.345 0 2.685 -0.317 3.897 -0.948 l -1.016 -1.962 c -1.584 0.822" +
            "-3.445 0.929 -5.114 0.293 c -1.56 -0.596 -2.793 -1.762 -3.479 -3.289 C 2.078 9.502 2.031 7.803 2.622 6.244 C 3.216 4.68 4.387" +
            " 3.443 5.914 2.761 C 7.437 2.079 9.137 2.03 10.7 2.626 c 1.246 0.475 2.271 1.328 2.986 2.424 L 11.54 5.851 L 16.856 10.239 Z";
            var fill = "#231f20";
            if (!(ej.datavisualization.Diagram.Util.canRotate(node)))
                fill = "darkgray";
            var width = 20;
            var height = 20;
            var dist = 20;
            var attr = {
                "id": "rotatehandle", "class": corner, "fill": fill, "stroke": "black", "stroke-width": 0.5, "width": width, "height": height, "d": d,
                "transform": "translate(" + (cx * scale - width / 2) + "," + (cy * scale - height) + ")"
            };
            var path = svg.path(attr);
            var circle = svg.circle({
                "id": "rotate", "class": corner, "fill": "transparent", "stroke": "none", "cx": width / 2, "cy": height / 2, "r": 13,
                "transform": "translate(" + (cx * scale - width / 2) + "," + (cy * scale - height) + ")"
            });
            handle.appendChild(path);
            handle.appendChild(circle);
        },

        _renderEndPointHandle: function (connector, svg, scale) {

            if (connector.line.type == "bezier") {
                var line = connector.line;
                var enabled = ej.datavisualization.Diagram.Util.canDragSegmentThumbs(connector);
                this._renderBezierLine("bezierline1", connector.line.startPoint, connector.line._point1, scale, svg);
                this._renderBezierLine("bezierline2", connector.line.endPoint, connector.line._point2, scale, svg);
                this._renderEndPointCorner("bezierpoint1", line._point1.x * scale, line._point1.y * scale, false, svg, enabled);
                this._renderEndPointCorner("bezierpoint2", line._point2.x * scale, line._point2.y * scale, false, svg, enabled);
            }
            var points = connector.line.points;
            this._renderEndPointCorner("targetEndPoint", points[points.length - 1].x * scale, points[points.length - 1].y * scale, ej.datavisualization.Diagram.Util.isTargetConnected(connector), svg,
                ej.datavisualization.Diagram.Util.canDragTargetEnd(connector));
            this._renderEndPointCorner("sourceEndPoint", points[0].x * scale, points[0].y * scale, ej.datavisualization.Diagram.Util.isSourceConnected(connector), svg,
                ej.datavisualization.Diagram.Util.canDragSourceEnd(connector));

        },

        _renderEndPointCorner: function (corner, x, y, isConnected, svg, isenabled) {
            var handle = svg.getElementById(svg.document.id + "handle_g");
            var fill = isConnected ? "#8CC63F" : "white";
            if (!isenabled) fill = "darkgray";
            var attr = { "id": corner, "class": corner, "fill": fill, "stroke": "black", "stroke-width": 2, "cx": x, "cy": y, "r": 7 };
            handle.appendChild(svg.circle(attr));
        },

        _renderBezierLine: function (id, start, end, scale, svg) {
            var line = svg.line({
                "id": id, "x1": start.x * scale, "y1": start.y * scale, "x2": end.x * scale, "y2": end.y * scale,
                "stroke": "black", "stroke-width": 1, "stroke-dasharray": "3,3", "fill": "none"
            });
            var handle = svg.getElementById(svg.document.id + "handle_g");
            handle.appendChild(line);
        },
        _renderControlPointCorner: function (corner, point, index, svg) {
            var g = svg.g({ "class": corner });
            svg.getElementById(svg.document.id + "handle_g").appendChild(g);
            var attr = {
                "id": corner + "_" + index, "fill": "white", "stroke": "black", "stroke-width": 2,
                "cx": point.x, "cy": point.y, "r": 5
            };
            g.appendChild(svg.circle(attr));
        },

        _removePivotPoint: function (node, svg, scale) {
            var parent = svg.getElementById(svg.document.id + "handle_g");
            if (parent != null && svg.getElementById("pivot")) {
                parent.removeChild(svg.getElementById("pivot"));
                this._updatePivotLine(node, svg, scale);
            }
        },

        updateSelector: function (shape, svg, scale, diagram, constraints) {
            if (shape.line) {
                this._updateEndPointHandle(shape, svg, scale);
                if (constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                    this.updateUserHandles(diagram.model.userHandles, shape, svg, false, false, scale);
            } else {
                var g = svg.g({
                    "id": svg.document.id + "handle_g",
                    "transform": "translate(" + (shape.offsetX - shape.width / 2) * scale + "," + (shape.offsetY - shape.height / 2) * scale + "),rotate(" + shape.rotateAngle + "," + (shape.width / 2) * scale + "," + (shape.height / 2) * scale + ")"
                });
                //if ((diagram.activeTool.name != "move" && diagram.activeTool.name != "rotate") || shape.line || shape.isGroup || shape.isPseudoGroup)
                this._updateResizeHandle(shape, svg, scale, constraints);
                if (diagram.model.userHandles && diagram.model.userHandles.length > 0) {
                    var isMultipleSelection = false;
                    if (diagram.selectionList[0] && diagram.selectionList[0].name == "multipleSelection")
                        isMultipleSelection = true;
                    if (constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                        this.updateUserHandles(diagram.model.userHandles, shape, svg, isMultipleSelection, false, scale);
                }
            }
        },

        _updateResizeHandle: function (node, svg, scale, constraints) {
            var corner = node._corners;
            var rotate = ej.datavisualization.Diagram.Point(node.width / 2, -20 / scale);
            if (constraints & ej.datavisualization.Diagram.SelectorConstraints.Rotator) {
                this._updateRotateHandle("rotate", rotate.x, rotate.y, scale, svg, node);
                this._updatePivotLine(node, svg, scale);
            }
            //this._updateResizeCorner("pivot", node.offsetX * scale, node.offsetY * scale, svg);
            if (constraints & ej.datavisualization.Diagram.SelectorConstraints.Resizer) {
                this._updateResizeCorner("nw-resize", 0, 0, svg);
                this._updateResizeCorner("n-resize", (node.width / 2) * scale, 0, svg);
                this._updateResizeCorner("ne-resize", node.width * scale, 0, svg);
                this._updateResizeCorner("w-resize", 0, (node.height / 2) * scale, svg);
                this._updateResizeCorner("e-resize", node.width * scale, (node.height / 2) * scale, svg);
                this._updateResizeCorner("sw-resize", 0, node.height * scale, svg);
                this._updateResizeCorner("s-resize", (node.width / 2) * scale, node.height * scale, svg);
                this._updateResizeCorner("se-resize", node.width * scale, node.height * scale, svg);
                this._updateResizeBorder("resizeBorder", node, svg, scale);
            }
        },

        _updateRotateHandle: function (thumb, cx, cy, scale, svg, node) {
            var width = 20;
            var height = 20;
            var dist = 20;
            var attr = {
                "id": "rotatehandle",
                "transform": "translate(" + (cx * scale - width / 2) + "," + (cy * scale - height) + ")"
            };
            svg.path(attr);
            svg.circle({
                "id": "rotate",
                "transform": "translate(" + (cx * scale - width / 2) + "," + (cy * scale - height) + ")"
            });
        },

        _updatePivotLine: function (node, svg, scale) {
            var rotateThumb = ej.datavisualization.Diagram.Point(node.width / 2, -20 / scale);
            var pivot = ej.datavisualization.Diagram.Point(node.width / 2, 0);
            var line = svg.line({
                "id": "pivotLine", "x1": rotateThumb.x * scale, "y1": rotateThumb.y * scale, "x2": pivot.x * scale, "y2": pivot.y * scale
            });
        },

        _updateResizeBorder: function (id, node, svg, scale) {
            svg.rect({
                "id": id, "width": node.width * scale, "height": node.height * scale,
            });
        },

        _updateResizeCorner: function (corner, cx, cy, svg) {
            var attr = { "id": corner, "cx": cx, "cy": cy };
            svg.circle(attr);
            var attr = { "id": corner + "_transparent", "cx": cx, "cy": cy };
            svg.circle(attr);
        },

        _updateEndPointHandle: function (connector, svg, scale) {

            var points = connector.line.points;

            this._updateEndPointCorner("targetEndPoint", points[points.length - 1].x * scale, points[points.length - 1].y * scale, ej.datavisualization.Diagram.Util.isTargetConnected(connector), svg,
                ej.datavisualization.Diagram.Util.canDragTargetEnd(connector));
            this._updateEndPointCorner("sourceEndPoint", points[0].x * scale, points[0].y * scale, ej.datavisualization.Diagram.Util.isSourceConnected(connector), svg,
                ej.datavisualization.Diagram.Util.canDragSourceEnd(connector));
            if (connector.line.type == "bezier") {
                var line = connector.line;
                var enabled = ej.datavisualization.Diagram.Util.canDragSegmentThumbs(connector);
                this._updateEndPointCorner("bezierpoint1", line._point1.x * scale, line._point1.y * scale, false, svg, enabled);
                this._updateEndPointCorner("bezierpoint2", line._point2.x * scale, line._point2.y * scale, false, svg, enabled);
                this._updateBezierLine("bezierline1", connector.line.startPoint, connector.line._point1, scale, svg);
                this._updateBezierLine("bezierline2", connector.line.endPoint, connector.line._point2, scale, svg);
            }
            //if (points.length > 2) {
            //    for (var i = 1, len = points.length; i < len - 1; ++i) {
            //        this._updateControlPointCorner("controlPoint", points[i], i, svg);
            //    }
            //}
        },

        _updateEndPointCorner: function (corner, x, y, isConnected, svg, isenabled) {
            var fill = isConnected ? "#8CC63F" : "white";
            if (!isenabled) fill = "darkgray";
            var attr = { "id": corner, "fill": fill, "cx": x, "cy": y };
            svg.circle(attr);
        },
        _updateBezierLine: function (id, start, end, scale, svg) {
            var line = svg.line({
                "id": id, "x1": start.x * scale, "y1": start.y * scale, "x2": end.x * scale, "y2": end.y * scale
            });
        },
        _updateControlPointCorner: function (corner, point, index, svg) {
            svg.circle({ "id": corner + "_" + index, "cx": point.x, "cy": point.y });
        },

        updateUserHandles: function (handles, node, svg, isMultipleSelection, isDragging, scale) {
            if (handles && handles.length > 0) {
                for (var handleIndex = 0; handleIndex < handles.length; handleIndex++) {
                    if ((isMultipleSelection && handles[handleIndex].enableMultiSelection) || !isMultipleSelection)
                        this._updateHandle(handles[handleIndex], node, svg, isDragging, scale);
                }
            }
        },

        _updateHandle: function (handle, node, svg, isDragging, scale) {
            var position = this._getHandlePosition(handle, node, scale);
            if (!isDragging && handle.visible) {
                var d = ej.datavisualization.Diagram.Geometry.updatePath((position.x * scale) - (handle.size) / 4, (position.y * scale) - (handle.size) / 4, (handle.size / 2), (handle.size / 2), handle.pathData, svg);
                this._updateHandleShape(handle, position.x * scale, position.y * scale, svg);
                this._updateHanleIcon(handle, d, svg);
                if (svg.getElementById(handle.name + "_shape") && handle.visible) {
                    svg.getElementById(handle.name + "_shape").style.display = "block";
                    svg.getElementById(handle.name + "_icon").style.display = "block";
                }
            }
            else {
                if (svg.getElementById(handle.name + "_shape")) {
                    svg.getElementById(handle.name + "_shape").style.display = "none";
                    svg.getElementById(handle.name + "_icon").style.display = "none";
                }
            }
        },

        clearSelector: function (svg, parent) {
            var handle = svg.getElementById(svg.document.id + "handle_g");
            if (handle)
                parent.removeChild(handle);
            handle = svg.getElementById(svg.document.id + "userHandle_g");
            if (handle)
                parent.removeChild(handle);
        },

        _initializePageBreaks: function (svg, attr, g) {
            var g1 = svg.g(attr);
            g.appendChild(g1);
            return g1;
        },

        _renderVPageBreakLine: function (start, end, svg, g) {
            var line = svg.line({
                "x1": start.x, "y1": start.y,
                "x2": end.x, "y2": end.y,
                "style": "stroke:#aaaaaa;stroke-width:1;stroke-dasharray:10,10 "
            });
            g.appendChild(line);
        },

        _renderPageSettingsRect: function (start, end, svg, g, _stroke, _fill, _strokewidth) {
            var rect = svg.rect({
                "id": "pageback",
                "x": start.x, "y": start.y, "width": end.x, "height": end.y,
                "style": "fill:" + _fill + ";stroke:" + _stroke + ";stroke-width:" + _strokewidth + ""
            });
            g.appendChild(rect);
        },

        _updatePageBakground: function (start, end) {
            var rect = document.getElementById("pageback");
            var attr = {
                "x": start.x, "y": start.y, "width": end.x, "height": end.y
            };
            if (rect)
                ej.datavisualization.Diagram.Util.attr(rect, attr);
        },

        _renderHPageBreakLine: function (start, end, svg, g) {
            var line = svg.line({
                "x1": start.x, "y1": start.y,
                "x2": end.x, "y2": end.y,
                "style": "stroke:#aaaaaa;stroke-width:1;stroke-dasharray:10,10 "
            });
            g.appendChild(line);
        },

        _removePageBreaks: function (svg, g, layer) {
            if (g != null) {
                if (layer != null) {
                    layer.removeChild(g);
                }
            }
        },
        removeChild: function (element, view) {
            view.diagramLayer.removeChild(view.svg.document.getElementById(element.name));
        }
        //#endregion
    };
    //#endregion

    //#region Common Renderer
    ej.datavisualization.Diagram.DiagramContext = {
        updateViewPort: function (diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                if (view.context == ej.datavisualization.Diagram.SvgContext && view.type == "mainview") {
                    ej.datavisualization.Diagram.ScrollUtil._updateScroller(diagram);
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
            });
        },
        renderNode: function (node, diagram, parent) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.renderNode(node, panel, parent || view.diagramLayer);
            });
        },

        renderPort: function ( node, port,diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context._insertPort(node, port, panel);
            });
        },
        renderConnector: function (connector, diagram, parent) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.renderConnector(connector, panel, parent || view.diagramLayer);
            });
        },

        renderGroup: function (group, diagram, parent) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.renderGroup(group, panel, parent || view.diagramLayer, diagram.nameTable);
            });
        },
        update: function (data, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                if (data.isGroup)
                    view.context.updateGroup(data, panel, diagram);
                else if (data.line)
                    view.context.updateConnector(data, panel, diagram);
                else
                    view.context.updateNode(data, panel, diagram);
            });
        },

        addNodeLabel: function (shape, label, parent, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.addNodeLabel(shape, label, panel, parent);

            });
        },

        updateLabel: function (node, label, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateLabel(node, label, panel);
            });
        },

        setNodeShape: function (node, diagram, parent) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.setNodeShape(node, panel, parent);
            });
        },

        setLine: function (connector, diagram, parent) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.setLine(connector, panel, parent);
            });
        },

        renderDecorators: function (connector, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.renderDecorators(connector, panel);
            });
        },

        clearDecorators: function (connector, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.clearDecorators(connector, panel);
            });
        },

        updateTargetDecoratorStyle: function (node, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateTargetDecoratorStyle(node, panel);
            });
        },

        updateSourceDecoratorStyle: function (node, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateSourceDecoratorStyle(node, panel);
            });
        },

        updateNodeStyle: function (node, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateNodeStyle(node, panel);
            });
        },

        updateLabelStyle: function (node, label, diagram) {
            diagram._views.forEach(function (viewid) {
                var view = diagram._views[viewid];
                var panel = view.svg || view.canvas;
                view.context.updateLabelStyle(node, label, panel);
            });
        },

        updateConnectorStyle: function (connector, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateConnectorStyle(connector, panel);
            });
        },

        updateTextBlock: function (node, label, diagram) {
            var view, panel;
            diagram._views.forEach(function (viewid) {
                view = diagram._views[viewid];
                panel = view.svg || view.canvas;
                view.context.updateTextBlock(node, label, panel);
            });

        }
    };
    //#endregion
})(jQuery, Syncfusion);;
/// <reference path="ej.diagramcommon.js" />
/// <reference path="ej.diagramsvg.js" />
/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
* @namespace ej
* @class ejSymbolPalette
* @requires jQuery.js
* @requires ej.common.all
* @requires ej.widgets.all
* @requires jquery.easing.js
* @requires jquery.globalize.js
* @requires jsrender.js
* @requires jquery.validate.js
* @requires jquery.validate.unobtrusive.js
* @classdesc defined values to render symbolpalette
* @example 
* &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
* &lt;script&gt;
* //Create symbolpalette
$("#symbolpalette").ejSymbolPalette();
* &lt;/script&gt
*/
    "use strict";
    //#region SymbolPalette widget
    ej.widget("ejSymbolPalette", "ej.datavisualization.SymbolPalette", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        nameTable: {},

        //#region Initialization
        defaults: {
            /**The width of the palette 
          * @default 250
          * @type {Number}
          * @example
          * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
          * &lt;script&gt;
          * $("#symbolpalette").ejSymbolPalette({width:300});
          * &lt;/script&gt
          * @memberof ejSymbolPalette
          * @instance
          */
            width: 250,
            /**The height of the palette 
        * @default 400
        * @type {Number}
        * @example
        * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#symbolpalette").ejSymbolPalette({height:500});
        * &lt;/script&gt
        * @memberof ejSymbolPalette
        * @instance
        */
            height: 400,
            /**Width of the palette item
        * @default 50
        * @type {Number}
        * @example
        * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#symbolpalette").ejSymbolPalette({paletteItemWidth: 50});
        * &lt;/script&gt
        * @memberof ejSymbolPalette
        * @instance
        */
            paletteItemWidth: 50,
            /**Height of the items in palette
        * @default 50
        * @type {Number}
        * @example
        * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#symbolpalette").ejSymbolPalette({paletteItemHeight: 50});
        * &lt;/script&gt
        * @memberof ejSymbolPalette
        * @instance
        */
            paletteItemHeight: 50,
            /**Preview width of the palette items
        * @default 100
        * @type {Number}
        * @example
        * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#symbolpalette").ejSymbolPalette({previewWidth: 100});
        * &lt;/script&gt
        * @memberof ejSymbolPalette
        * @instance
        */
            previewWidth: 100,
            /**Preview height of the palette items
       * @default 100
       * @type {Number}
       * @example
       * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * $("#symbolpalette").ejSymbolPalette({previewHeight: 100});
       * &lt;/script&gt
       * @memberof ejSymbolPalette
       * @instance
       */
            previewHeight: 100,
            /**The preview offset for the palette items
     * @default (102, 102)
     * @type {Object}
     * @example
     * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * $("#symbolpalette").ejSymbolPalette({previewOffset: {x: 102, y: 102 }});
     * &lt;/script&gt
     * @memberof ejSymbolPalette
     * @instance
     */
            previewOffset: { x: 102, y: 102 },
            /**The diagramId of the palette 
      * @default null
      * @type {}
      * @example
      * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * $("#symbolpalette").ejSymbolPalette({diagramId: "diagram"});
      * &lt;/script&gt
      * @memberof ejSymbolPalette
      * @instance
      */
            diagramId: null,
            /**Height of the palette header
      * @default 30
      * @type {Number}
      * @example
      * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * $("#symbolpalette").ejSymbolPalette({headerHeight: 30});
      * &lt;/script&gt
      * @memberof ejSymbolPalette
      * @instance
      */
            headerHeight: 30,
            /** The selectedPaletteName of the symbol palette
      * @default 0
      * @type {Number}
      * @example
      * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * $("#symbolpalette").ejSymbolPalette({selectedPaletteName: "paletteName"});
      * &lt;/script&gt
      * @memberof ejSymbolPalette
      * @instance
      */
            selectedPaletteName: 0,
            /** Used to change the style of the node 
         * @default "e-symbolpalette"
         * @type {String}
         * @example
         * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#symbolpalette").ejSymbolPalette({cssClass: "e-symbolpalette"});
         * &lt;/script&gt
         * @memberof ejSymbolPalette
         * @instance
         */
            cssClass: "e-datavisualization-symbolpalette",
            /** Enable or disable the palette item text 
       * @default true
       * @type {Boolean}
       * @example
       * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * $("#symbolpalette").ejSymbolPalette({showPaletteItemText: true});
       * &lt;/script&gt
       * @memberof ejSymbolPalette
       * @instance
       */
            showPaletteItemText: true,
            /** Enable or disable the Drag function of items in the palette 
       * @default true
       * @type {Boolean}
       * @example
       * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       * $("#symbolpalette").ejSymbolPalette({allowDrag: true});
       * &lt;/script&gt
       * @memberof ejSymbolPalette
       * @instance
       */
            allowDrag: true,
            /** Collection of palette items 
        * @default null
        * @type {Array}
        * @example
        * &lt;div id="symbolpalette"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#symbolpalette").ejSymbolPalette({palettes: palette});
        * &lt;/script&gt
        * @memberof ejSymbolPalette
        * @instance
        */
            palettes: []
        },

        dataTypes: {
            paletteItemWidth: "number",
            paletteItemHeight: "number",
            previewWidth: "number",
            previewHeight: "number",
            headerHeight: "number",
            showPaletteItemText: "boolean",
            allowDrag: "boolean",
            palettes: "array"
        },

        _canvas: null,

        _init: function () {
            this.selectedItem = null;
            this.activePalette = null;
            this._selectedElement = null;
            this._renderSymbolPalette();
            this._wireEvents();
            this.updateScrollerViewport();
        },

        _setModel: function (options) {
            for (var option in options) {
                switch (option) {
                    case "width":
                        this._setWidth(options[option]);
                        break;
                    case "height":
                        this._setHeight(options[option]);
                        break;
                    case "paletteItemWidth":
                        this.model.paletteItemWidth = options[option];
                        this._redrawContent();
                        break;
                    case "paletteItemHeight":
                        this.model.paletteItemHeight = options[option];
                        this._redrawContent();
                        break;
                    case "headerHeight":
                        this._setHeaderHeight(options[option]);
                        break;
                    case "cssClass":
                        this._setCssClass(options[option]);
                        break;
                    case "showPaletteItemText":
                        this._showItemText(options[option]);
                        break;
                }
            }
        },

        _destroy: function () {
            this.element.empty().removeClass(this.model.cssClass);
        },
        //#endregion

        //#region Rendering
        _renderSymbolPalette: function () {
            this._canvas = document.createElement("div");
            this._canvas.setAttribute("class", "e-scanvas");
            this._canvas.setAttribute("id", this.element[0].id + "_canvas");

            this.element[0].setAttribute("style", "height:" + this.model.height + "; width:" + this.model.width + ";");
            this.element.append(this._canvas);
            this.element.ejScroller({ width: this._setViewPortWidth(), height: this._setViewPortHeight() });
            var palettes = this.model.palettes;
            if (palettes) {
                for (var i = 0, len = palettes.length; i < len; i++) {
                    palettes[i] = ej.datavisualization.Diagram.Palette(palettes[i]);
                    this._renderPalette(palettes[i]);
                }
            }
        },

        _setViewPortWidth: function () {
            this.element[0].setAttribute("style", "width:" + this.model.width + ";");
            var w = this.element.width();
            var left = this.element[0].offsetLeft;
            return Math.abs(w - left);
        },

        _setViewPortHeight: function () {
            this.element[0].setAttribute("style", "height:" + this.model.height + ";");
            var h = this.element.height();
            var top = this.element[0].offsetTop;
            return Math.abs(h - top);
        },
        _renderPalette: function (palette) {
            this._renderHeader(palette);
            this._renderContent(palette);
            this._collapse(palette);
        },

        _renderHeader: function (palette) {
            var header = document.createElement("div");
            var attr = { "id": palette.name + "_header", "class": "e-header", "style": "height:" + this.model.headerHeight + "px;" };
            ej.datavisualization.Diagram.Util.attr(header, attr);
            this._renderHeaderArrow(header, palette.expanded, palette.name);
            this._renderHeaderText(header, palette.name);
            this._addExpandedClass(header, palette.expanded);
            if (this.model.selectedPaletteName === palette.name) {
                $(header).addClass("selected");
                this.activePalette = palette;
            }
            this._canvas.appendChild(header);
        },

        _renderHeaderText: function (header, text) {
            var span = document.createElement("span");
            span.setAttribute("class", "e-header-text");
            span.innerHTML = text;
            header.appendChild(span);
        },

        _renderHeaderArrow: function (header, expanded, index) {
            var arrow = document.createElement("span");
            arrow.setAttribute("class", "e-header-arrow e-icon");
            arrow.setAttribute("style", "top:" + (this.model.headerHeight - 16) / 2 + "px;");
            this._addExpandedClass(arrow, expanded);
            if (this.model.selectedPaletteName === name)
                $(arrow).addClass("selected");
            header.appendChild(arrow);
        },

        _renderContent: function (palette) {
            var content = document.createElement("div");
            content.setAttribute("id", palette.name + "_content");
            content.setAttribute("class", "e-scontent");
            if ((this.model.palettes.length - 1) === this.model.palettes.indexOf(palette))
                content.setAttribute("style", "border-bottom-width: 0px;");
            this._canvas.appendChild(content);
            var paletteItems = palette.items;
            if (paletteItems && paletteItems.length > 0) {
                for (var i = 0, len = paletteItems.length; i < len; i++) {
                    if (paletteItems[i].parent)
                        this.nameTable[paletteItems[i].name] = paletteItems[i];
                    else
                        this._renderItem(paletteItems[i], content);
                }
            }
        },

        _renderItem: function (paletteItem, content) {
            var svg = this._renderItemContainer(paletteItem.name, content);
            if (paletteItem.line)
                this._renderConnector(paletteItem, svg);
            else if (!paletteItem.isGroup)
                this._renderNode(paletteItem, svg);
            else
                this._renderGroup(paletteItem, svg);
        },

        _renderItemContainer: function (id, content, isDrag) {
            var container = document.createElement("div");
            var attr = { "id": id + "_paletteItem", "draggable": "true", "height": this.model.paletteItemHeight + "px", "width": this.model.paletteItemWidth + "px", "class": "e-paletteItem", "style": "-ms-touch-action: none;touch-action: none;" };
            ej.datavisualization.Diagram.Util.attr(container, attr);
            content.appendChild(container);
            var paletteId = this.element[0].id;
            var context = this;
            if (!isDrag) {
                $(container).ejDraggable({
                    clone: true,
                    cursorAt: { top: context.model.previewOffset.y, left: context.model.previewOffset.x },
                    helper: function (event) {
                        var paletteItemWidth, paletteItemHeight;
                        paletteItemWidth = context.model.paletteItemWidth;
                        paletteItemHeight = context.model.paletteItemHeight;
                        context.model.paletteItemWidth = context.model.previewWidth;
                        context.model.paletteItemHeight = context.model.previewHeight;
                        var svg = context._renderItemContainer(context.selectedItem.name + "_clone", document.body, true);
                        svg.document.setAttribute("drag", "true");
                        var item = $.extend(true, {}, context.selectedItem);
                        if (context.selectedItem.line) {
                            var bounds = ej.datavisualization.Diagram.Util.bounds(item);
                            var delWidth = (context.model.previewWidth - 10) / bounds.width;
                            var delHeight = (context.model.previewHeight - 10) / bounds.height;
                            var diagram = $("#" + context.model.diagramId).ejDiagram("instance");
                            diagram._scale(context.selectedItem, delWidth, delHeight, bounds.topLeft, diagram.nameTable);
                            context._renderConnector(context.selectedItem, svg);
                        }
                        else {
                            item.width = context.model.previewWidth - 10;
                            item.height = context.model.previewHeight - 10;
                            item.offsetX = item.width / 2 + 5;
                            item.offsetY = item.height / 2 + 5;
                            if (!item.isGroup)
                                context._renderNode(item, svg);
                            else {
                                context._renderGroup(item, svg);

                            }
                        }
                        var helper = document.getElementById(context.selectedItem.name + "_clone_paletteItem");
                        $(helper).addClass("dragClone");
                        context.model.paletteItemWidth = paletteItemWidth;
                        context.model.paletteItemHeight = paletteItemHeight;
                        return $(helper);
                    },
                    drag: function () {
                        var proxy = this;
                        var element = $(".dragClone")[0];
                        if (element) {
                            element.setAttribute("paletteId", paletteId);
                        }
                    },
                    dragStop: function (event, ui) {
                        $(".dragClone").remove();
                    }
                });
            }
            return this._renderAnchor(container, id);
        },

        _renderAnchor: function (container, id) {
            var anchor = document.createElement("div");
            var attr = { "id": id + "_anchor", "height": this.model.paletteItemHeight + "px", "width": this.model.paletteItemWidth + "px", "class": "e-anchor" };
            ej.datavisualization.Diagram.Util.attr(anchor, attr);
            container.appendChild(anchor);
            var svg = this._renderSvg(anchor, id);
            this._renderText(anchor, id);
            return svg;
        },

        _renderSvg: function (anchor, id) {
            var wrapper = document.createElement("div");
            var attr = {
                "id": id + "_svgWrapper", "width": this.model.paletteItemWidth + "px;",
                "height": +this.model.paletteItemHeight + "px;", "class": "e-svg-container"
            };
            ej.datavisualization.Diagram.Util.attr(wrapper, attr);
            attr = {
                "id": id + "_svg", "width": this.model.paletteItemWidth, "height": this.model.paletteItemHeight,
                "version": "1.1", "xlink": "http://www.w3.org/1999/xlink"
            };
            var svg = new ej.datavisualization.Diagram.Svg(attr);
            wrapper.appendChild(svg.document);
            anchor.appendChild(wrapper);
            return svg;
        },

        _renderText: function (anchor, text) {
            var div = document.createElement("div");
            div.setAttribute("class", "e-text-container");
            div.setAttribute("style", "width:" + this.model.paletteItemWidth + "px;");
            var span = document.createElement("span");
            span.setAttribute("class", "e-paletteItemText");
            span.innerHTML = text;
            div.appendChild(span);
            if (!this.model.showPaletteItemText)
                div.style.display = "none";
            anchor.appendChild(div);
        },

        _renderNode: function (node, svg) {
            var group = ej.datavisualization.Diagram.SvgContext.renderNode(node, svg);
            var isDrag = false;
            if (svg.document.getAttribute("drag") != null) {
                isDrag = true;
            }
            this._transformItem(group, node.width, node.height, node, isDrag);
        },

        _renderGroup: function (node, svg) {
            var childBounds = ej.datavisualization.Diagram.Util._getChildrenBounds(node, this.nameTable);
            node.width = childBounds.width;
            node.height = childBounds.height;
            var group = ej.datavisualization.Diagram.SvgContext.renderGroup(node, svg, null, this.nameTable);
            var isDrag = false;
            if (svg.document.getAttribute("drag") != null) {
                isDrag = true;
            }
            this._transformItem(group, node.width, node.height, node, isDrag);

        },
        _renderConnector: function (connector, svg) {
            var group = ej.datavisualization.Diagram.SvgContext.renderConnector(connector, svg);
            var bounds = ej.datavisualization.Diagram.Geometry.rect(connector.line.points);
            var isDrag = false;
            if (svg.document.getAttribute("drag") != null) {
                isDrag = true;
            }
            this._transformItem(group, bounds.width, bounds.height, null, isDrag);
        },

        //#endregion

        //#region Events
        _wireEvents: function () {
            this._on(this.element, ej.eventType.click, ".e-header", this._headerClick);
            this._on(this.element, ej.eventType.mouseDown, ".e-header", this._headerMouseDown);
            this._on(this.element, "mouseover", ".e-header", this._headerMouseOver);
            this._on(this.element, "mouseout", ".e-header", this._headerMouseOut);
            this._on(this.element, ej.eventType.mouseDown, ".e-paletteItem", this._itemMouseDown);
            this._on(this.element, "mouseover", ".e-paletteItem", this._itemMouseOver);
            this._on(this.element, "mouseout", ".e-paletteItem", this._itemMouseOut);
            this._on(this.element, ej.eventType.click, ".e-anchor", this._itemClick);
        },

        _headerClick: function (evt) {
            var proxy = this;
            $(evt.currentTarget).next(".e-scontent").slideToggle(200, function () {
                proxy._refresh();
            });
            this._updateHeaderState(evt.currentTarget);
            var palette = this._getActivePalette(evt.currentTarget.id);
            if (palette && palette !== this.activePalette)
                this.activePalette = palette;


        },

        _headerMouseDown: function (evt) {
            evt.preventDefault();
            evt.stopPropagation();
        },

        _headerMouseOver: function (evt) {
            $(evt.currentTarget).addClass("hover");
            $(evt.currentTarget).find(".e-header-arrow").addClass("hover");
        },

        _headerMouseOut: function (evt) {
            $(evt.currentTarget).removeClass("hover");
            $(evt.currentTarget).find(".e-header-arrow").removeClass("hover");
        },

        _itemMouseDown: function (evt) {
            if (this.model.diagramId) {
                var diagram = $("#" + this.model.diagramId).ejDiagram("instance");
                if (diagram.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                    diagram.activeTool._showAllPorts(true);
                    diagram.deactivateTool();
                }
            }
            if (!this.model.allowDrag) {
                evt.preventDefault();
                evt.stopPropagation();
            }
            if (this._selectedElement) {
                if (this._selectedElement !== evt.currentTarget) {
                    $(this._selectedElement).removeClass("selected");
                    this._selectedElement = evt.currentTarget;
                }
            }
            else
                this._selectedElement = evt.currentTarget;
            if (!($(evt.currentTarget).hasClass("selected")))
                $(evt.currentTarget).addClass("selected");

            var palette = this._getActivePalette(evt.currentTarget.parentElement.id);
            if (palette && palette !== this.activePalette) {
                this._clearHeaderSelection();
                this._updateHeaderSelection($(evt.currentTarget.parentElement).prev());
                this.activePalette = palette;
            }

            if (this.activePalette && this._selectedElement) {
                var name = this._selectedElement.id.slice(0, this._selectedElement.id.lastIndexOf('_'));
                var items = this.activePalette.items;
                for (var i = 0, len = items.length; i < len; i++) {
                    var item = items[i];
                    if (item.name === name)
                        this.selectedItem = item;
                }
            }
        },

        _itemMouseOver: function (evt) {
            $(evt.currentTarget).addClass("hover");
        },

        _itemMouseOut: function (evt) {
            $(evt.currentTarget).removeClass("hover");
        },

        _itemDraStart: function (evt) {
            var dataTransfer = evt.originalEvent.dataTransfer;
            dataTransfer.setData("Text", this.element[0].id);
            dataTransfer.effectAllowed = "copy";
        },

        _itemClick: function (evt) {
            if (this.model.diagramId) {
                if (evt.type === "click" || (evt.type === "touchend" && !$(".dragClone")[0])) {
                    var diagram = $("#" + this.model.diagramId).ejDiagram("instance");
                    var item = $.extend(true, {}, this.selectedItem);
                    item.name += ej.datavisualization.Diagram.Util.randomId();
                    if (item.isGroup) {
                        for (var j = 0; j < item.children.length; j++) {
                            var newObj = $.extend(true, {}, this.nameTable[item.children[j]]);
                            newObj.parent = item.name;
                            newObj.name = item.name + newObj.name;
                            item.children[j] = newObj.name;
                            diagram.nameTable[newObj.name] = newObj;
                            diagram.model.nodes.push(newObj);
                            ej.datavisualization.Diagram.SpatialUtil._updateQuad(diagram, diagram._spatialSearch, newObj);
                        }
                        item.height = item.width = 0;
                        diagram._updateChildBounds(item, diagram.nameTable);
                    }
                    diagram.add(item);
                }
            }
        },

        _collectionChanged: function (args) {
            if (args.changeType == "insert") {
                this._renderPalette(args.element);
            }
            else if (args.changeType == "remove") {
                var palette = args.element;
                if (palette != null) {
                    var paletteHeader = document.getElementById(palette.name + "_header");
                    if (paletteHeader)
                        paletteHeader.parentNode.removeChild(paletteHeader);
                    var paletteContent = document.getElementById(palette.name + "_content");
                    if (paletteContent)
                        paletteContent.parentNode.removeChild(paletteContent);
                }
            }
        },
        //#endregion

        //#region Public methods

        addPaletteItem: function (paletteName, item) {
            var content, palette;
            for (var i = 0; i < this.model.palettes.length; i++) {
                palette = this.model.palettes[i];
                if (palette.name === paletteName) {
                    palette.items.push(item);
                    content = document.getElementById(paletteName + "_content");
                    this._renderItem(item, content);
                }
            }
        },

        removePaletteItem: function (paletteName, item) {
            var content, palette;
            for (var i = 0; i < this.model.palettes.length; i++) {
                palette = this.model.palettes[i];
                if (palette.name === paletteName) {
                    ej.datavisualization.Diagram.Util.removeItem(palette.items, item);
                    content = document.getElementById(paletteName + "_content");
                    content.removeChild(content.getElementsByClassName("e-paletteItem e-draggable e-js").item(item.name + "_paletteItem"));
                    this.selectedItem = null;
                }
            }
        },

        addPalette: function (palette) {
            this.model.palettes.push(palette);
            this._renderPalette(palette);
        },

        removePalette: function (paletteName) {
            var paletteHeader, paletteContent, palette;
            for (var i = 0; i < this.model.palettes.length; i++) {
                palette = this.model.palettes[i];
                if (palette.name === paletteName) {
                    ej.datavisualization.Diagram.Util.removeItem(this.model.palettes, palette);
                    paletteHeader = document.getElementById(palette.name + "_header");
                    if (paletteHeader)
                        paletteHeader.parentNode.removeChild(paletteHeader);
                    paletteContent = document.getElementById(palette.name + "_content");
                    if (paletteContent)
                        paletteContent.parentNode.removeChild(paletteContent);
                }
            }
        },
        setWidth: function (value) {
            this.model.width = value;
            this._setWidth(value);
        },

        setHeight: function (value) {
            this.model.height = value;
            this._setHeight(value);
        },

        setPaletteItemWidth: function (value) {
            this.model.paletteItemWidth = value;
            this._redrawContent();
        },

        setPaletteItemHeight: function (value) {
            this.model.paletteItemHeight = value;
            this._redrawContent();
        },

        setHeaderHeight: function (value) {
            this.model.headerHeight = value;
            this._setHeaderHeight(value);
        },

        setCssClass: function (value) {
            this._setCssClass(value);
            this.model.cssClass = value;
        },

        showPaletteItemText: function (value) {
            this._showItemText(value);
            this.model.showPaletteItemText = value;
        },

        searchPalette: function (palette, key) {
            var paletteCollection = new ej.datavisualization.Diagram.Collection();
            var paletteItems = null;
            if (key != "") {
                palette = this._getSearchPaletteItems(key);
                paletteCollection.add(palette);
            }
            return paletteCollection;
        },
        //#endregion

        //#region Helper methods
        _getSearchPaletteItems: function (key) {
            var palette = new ej.datavisualization.Diagram.Palette();
            var palettes = this.model.palettes, i, j;
            for (i = 0; i < palettes.length; i++) {
                if ((((palettes[i].name).toLocaleLowerCase()).search(key.toLocaleLowerCase())) >= 0) {
                    for (j = 0; j < palettes[i].items.length; j++) {
                        this.element.find("#" + palettes[i].items[j].name + "_paletteItem")[0].style.display = "block";
                    }
                }
                else {
                    for (j = 0; j < palettes[i].items.length; j++) {
                        if ((((palettes[i].items[j].name).toLocaleLowerCase()).search(key.toLocaleLowerCase())) >= 0) {
                            this.element.find("#" + palettes[i].items[j].name + "_paletteItem")[0].style.display = "block";
                        }
                        else
                            this.element.find("#" + palettes[i].items[j].name + "_paletteItem")[0].style.display = "none";
                    }
                }
            }
            return palette;
        },

        _addExpandedClass: function (element, expanded) {
            if (expanded)
                $(element).addClass("expanded");
            else
                $(element).addClass("collapsed");
        },

        _collapse: function (palette) {
            if (!palette.expanded)
                $(document.getElementById(palette.name + "_header")).next(".e-scontent").slideToggle(10);

        },

        _transformItem: function (group, width, height, node, isDrag) {
            if (!isDrag) {
                var scale = this._getScaleFactor(width, height);
                var translate = this._getTranslateFactor(width, height);
                var transform = "";
                //translate
                transform += "translate(" + translate + "," + translate + ")";
                //scale
                transform += "scale(" + scale + "," + scale + ")";
                group.setAttribute("transform", transform);
            }
            if (node && ej.browserInfo().name === "msie") {
                if (!node.isGroup && node.shape.type === "html") {
                    var htmlDiv = document.getElementById(node.name + "_html");
                    htmlDiv.setAttribute("style", "zoom:" + scale + ";");
                }
            }
        },

        _getScaleFactor: function (width, height) {
            var fx = (30 * this.model.paletteItemWidth) / 100;
            var fy = (30 * this.model.paletteItemHeight) / 100;
            var sx = (this.model.paletteItemWidth - fx) / width;
            var sy = (this.model.paletteItemHeight - fy) / height;
            sx = sx > 1 ? 1 : sx;
            sy = sy > 1 ? 1 : sy;
            return Math.min(sx, sy);
        },

        _getTranslateFactor: function (width, height) {
            var x = (15 / 100) * this.model.paletteItemWidth;
            var y = (15 / 100) * this.model.paletteItemHeight;
            return Math.min(x, y);
        },

        _setWidth: function (val) {
            this.element.css("width", val);
        },

        _setHeight: function (val) {
            this.element.css("height", val);
        },

        _setHeaderHeight: function (val) {
            this.element.find(".e-header").css("height", val);
            this.element.find(".e-header-arrow").css("top", (val - 16) / 2);
        },

        _setCssClass: function (val) {
            this.element.removeClass(this.model.cssClass).addClass(val);
        },

        _showItemText: function (val) {
            if (val !== this.model.showPaletteItemText)
                if (val) {
                    this.element.find(".e-text-container").show();
                }
                else
                    this.element.find(".e-text-container").hide();
        },

        _redrawContent: function () {
            var contents = this.element.find(".e-scontent");
            for (var i = 0, len = contents.length; i < len; ++i) {
                var content = contents[i];
                $(content).empty();
                var palette = this.model.palettes[i];
                var paletteItems = palette.items;
                if (paletteItems && paletteItems.length > 0) {
                    for (var count = 0, l = paletteItems.length; count < l; count++) {
                        this._renderItem(paletteItems[count], content);
                    }
                }
            }
        },

        _getActivePalette: function (elementId) {
            var name = elementId.slice(0, elementId.lastIndexOf('_'));
            var palettes = this.model.palettes;
            for (var i = 0, len = palettes.length; i < len; i++) {
                var palette = palettes[i];
                if (palette.name === name && palette !== this.activePalette)
                    return palette;
            }
            return null;
        },

        _updateHeaderState: function (target) {
            this._clearHeaderSelection();
            this._updateExpandState(target);
            this._updateHeaderSelection(target);
        },

        _updateExpandState: function (target) {
            if (($(target).hasClass("expanded"))) {
                $(target).removeClass("expanded").addClass("collapsed");
                $(target).find(".e-header-arrow").removeClass("expanded").addClass("collapsed");
            }
            else {
                $(target).removeClass("collapsed").addClass("expanded");
                $(target).find(".e-header-arrow").removeClass("collapsed").addClass("expanded");
            }
        },

        _updateHeaderSelection: function (target) {
            if (!($(target).hasClass("selected"))) {
                $(target).addClass("selected");
                $(target).find(".e-header-arrow").addClass("selected");
            }
        },

        _clearHeaderSelection: function () {
            this.element.find(".e-header").removeClass("selected");
            this.element.find(".e-header-arrow").removeClass("selected");
        },

        _addItem: function (palette, item) {
            var content = document.getElementById(palette.name + "_content");
            this._renderItem(item, content);
        },

        _removeItem: function (palette, item) {
            var content = document.getElementById(palette.name + "_content");
            content.removeChild(document.getElementById(item.name + "_paletteItem"));
            if (item === this._selectedElement)
                this._selectedElement = null;
        },

        updateScrollerViewport: function () {
            var scroller = this.element.ejScroller("instance");
            scroller.model.touchScroll = false;
            scroller.model.width = this._setViewPortWidth();
            scroller.model.height = this._setViewPortHeight();
            this._refresh();
        },

        _refresh: function () {
            this.element.ejScroller("refresh");
        },

        //#endregion
    });
    //#endregion

})(jQuery, Syncfusion);;


(function ($, ej) {
    "use strict";
    //#region Extends
    ej.datavisualization.Diagram.extend = function (d, b) {
        for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
        function __() { this.constructor = d; }
        __.prototype = b.prototype;
        d.prototype = new __();
    }
    //#endregion

    //#region Tool
    var Tool = (function () {
        function Tool(name, diagram) {
            this.name = name;
            this.diagram = diagram;
            this.helper = null;
            this.inAction = false;
            this.selectedObject = null;
            this.startPoint = ej.datavisualization.Diagram.Point(0, 0);
            this.currentPoint = ej.datavisualization.Diagram.Point(0, 0);
            this.previousPoint = ej.datavisualization.Diagram.Point(0, 0);
            this.cursor = "default";
            this._currentPossibleConnection = null;
            this._previousPossibleConnection = null;
            this._possibleConnectionPort = null;
            this.singleAction = false;
            this.svgHelper = null;
            this.single = null;
            this._centralPoint = ej.datavisualization.Diagram.Point(0, 0);
            this._enableAutoNode = null;
            this._prevTool = null;
        }
        Tool.prototype.abort = function (evt) {
            this._endAction();
            ej.datavisualization.Diagram.SvgContext.updateSelector(this.diagram.selectionList[0], this.diagram._svg, this.diagram.model.zoomFactor, this.diagram, this.diagram.model.selectorConstraints);
            this.diagram._removeTooltip();
        };
        Tool.prototype.keydown = function (evt) {
            var keycode = evt.keyCode ? evt.keyCode : evt.which;
            if (keycode === 27 && this.inAction) {
                this.abort();
            }
            else if (!this.inAction && keycode == 27) {
                this.diagram._clearSelection();
            }
        };
        Tool.prototype._findNodeUnderMouse = function (evt, skip) {
            var obj;
            var parents = $(evt.target).parents("g");
            if (parents.length > 3) {
                var parent;
                var type;
                //check selection exists already
                var selections = this.diagram.selectionList;
                if (selections.length > 0) {
                    var count = parents.length - 3;
                    if (count > 1 && parents[count - 1].getAttribute("class") == "ej-d-group" && !selections[0].isPseudoGroup) {
                        var id = (parents[count - 1]).getAttribute("id");
                        if (id !== (this.diagram._svg.document.id + "handle_g")) {
                            var i;
                            var child;
                            var group = this._findObj(parents[count - 1]);
                            if (skip) {
                                obj = group;
                                if (selections[0].isPseudoGroup || this.diagram._selectionContains(group)) {
                                    obj = selections[0];
                                }
                                else {
                                    for (i = count - 2; i >= 0; i--) {
                                        if (group.isGroup) {
                                            child = this._findObj(parents[i], group);
                                            if (this.diagram._selectionContains(child)) {
                                                obj = selections[0];
                                                break;
                                            }
                                            else if (this.diagram._findChildren(group, selections[0].name)) {
                                                obj = child;
                                            }
                                        }
                                        group = child;
                                    }
                                }
                            }
                            else {
                                if (this.diagram._selectionContains(group) || this.diagram._findChildren(group, selections[0].name)) {
                                    for (i = count - 2; i >= 0; i--) {
                                        //if (group.getAttribute("class") == "group") 
                                        {
                                            child = this._findObj(parents[i], group);
                                            if (this.diagram._selectionContains(child)) {
                                                if (!child.isGroup) {
                                                    obj = group;
                                                    break;
                                                }
                                            }
                                            else {
                                                obj = child;
                                                break;
                                            }
                                        }
                                    }
                                }
                                else {

                                    obj = group;
                                }
                            }
                        }
                    }
                    else if (selections[0].isPseudoGroup) {
                        //if (skip) {
                        //    obj = selections[0];
                        //}
                        //else
                        {
                            obj = this._findObj(parents[count - 1], selections[0]);
                            if (!obj) {
                                obj = this._findObj(parents[parents.length - 4]);
                            }
                        }
                    }
                    else {
                        obj = this._findObj(parents[parents.length - 4]);
                    }
                }
                else {
                    obj = this._findObj(parents[parents.length - 4]);
                }
            }
            return obj;
        };
        Tool.prototype._processCtrlKey = function (evt) {
            var obj;
            if (this.diagram.selectionList.length > 0) {
                var selectionList = this.diagram.selectionList;
                var isMultipleSelection;
                if (selectionList[0].isPseudoGroup) {
                    isMultipleSelection = true;
                    obj = this._findNodeUnderMouse(evt);
                }
                else {
                    obj = this._findNodeUnderMouse(evt, true);
                }
                if (obj && !this.diagram._selectionContains(obj)) {
                    if (isMultipleSelection) {
                        var mulSelection = selectionList[0];
                        if (!this.diagram._findChildren(mulSelection, obj.name)) {
                            mulSelection.children.push(obj.name);
                            //obj.parent = "multipleSelection";
                            ej.datavisualization.Diagram.Util._updateGroupBounds(mulSelection, this.diagram.nameTable);
                            this.selectedObject = selectionList[0];
                            ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectedObject, this.diagram._svg, this.diagram.model.zoomFactor, this.diagram, this.diagram.model.selectorConstraints);
                            //if (this.diagram._hasSelection()) {
                            //    this.diagram._clearSelection();
                            //}
                            //this.diagram._addSelection(this.selectedObject);
                        }
                        else {
                            ej.datavisualization.Diagram.Util.removeItem(mulSelection.children, obj.name);
                            if (mulSelection.children.length == 1) {
                                var node = this.diagram.nameTable[mulSelection.children[0]];
                                this.selectedObject = node;
                                ej.datavisualization.Diagram.Util._updateGroupBounds(mulSelection, this.diagram.nameTable);
                                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectedObject, this.diagram._svg, this.diagram.model.zoomFactor, this.diagram, this.diagram.model.selectorConstraints);
                            }
                            else {
                                this.selectedObject = selectionList[0];
                                ej.datavisualization.Diagram.Util._updateGroupBounds(mulSelection, this.diagram.nameTable);
                                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectedObject, this.diagram._svg, this.diagram.model.zoomFactor, this.diagram, this.diagram.model.selectorConstraints);
                            }
                        }
                    }
                    else {
                        var selectionList = this.diagram.selectionList[0];
                        if (this.diagram._hasSelection()) {
                            this.diagram._clearSelection();
                        }
                        var pseudoGroup = ej.datavisualization.Diagram.Group({ isPseudoGroup: true, "name": "multipleSelection" });
                        pseudoGroup.children.push(selectionList.name);
                        //this.diagram.selectionList[0].parent = "multipleSelection";
                        pseudoGroup.children.push(obj.name);
                        //obj.parent = "multipleSelection";
                        this.diagram.model.nodes.push(pseudoGroup);
                        this.diagram.nameTable[pseudoGroup.name] = pseudoGroup;
                        ej.datavisualization.Diagram.Util._updateGroupBounds(pseudoGroup, this.diagram.nameTable);
                        this.selectedObject = pseudoGroup;
                        this.diagram._addSelection(this.selectedObject);
                    }
                }
                else {
                    this.selectedObject = obj;
                }
            }
            else {
                obj = this._findNodeUnderMouse(evt);
                this.selectedObject = obj;
            }
            return obj;
        };
        Tool.prototype._findObj = function (element, group) {
            var obj;
            var id = element.getAttribute("id");
            if (group) {
                obj = this.diagram._findChildren(group, id);
            }
            else {
                var type = element.getAttribute("class");
                if (type) {
                    if (type === "ej-d-node" || type === "ej-d-group") {
                        obj = this.diagram._findNode(id);
                    }
                    else if (type === "ej-d-connector") {
                        obj = this.diagram._findConnector(id);
                    }
                }
            }
            return obj;
        };
        Tool.prototype.mousedown = function (evt) {
            this.startPoint = this.mousePosition(evt);
            this.previousPoint = this.startPoint;
        };

        Tool.prototype.mousemove = function (evt) {
            this.currentPoint = this.mousePosition(evt);
        };
        Tool.prototype.mouseup = function (evt) {
            this._endAction();
            if (this.singleAction) {
                this.diagram.activateTool("select");
            }
        };
        Tool.prototype.mousePosition = function (evt) {
            return this.diagram._mousePosition(evt);
        };
        Tool.prototype.updateCursor = function (cursor) {
            this.diagram._currentCursor = cursor;
            this.diagram._updateCursor();
        };
        Tool.prototype.nearestGridPoint = function (point) {
            var snapPt = ej.datavisualization.Diagram.Point();
            if (this.diagram.model.snap & ej.datavisualization.Diagram.Snap.Grid) {
                var magnification = this.diagram.model.magnification / 100;
                var hSpacing = this.diagram.model.grid.horizontalSpacing * magnification;
                var vSpacing = this.diagram.model.grid.verticalSpacing * magnification;
                var width = point.x % hSpacing;
                var height = point.y % vSpacing;
                if (width >= (hSpacing / 2)) {
                    snapPt.x = point.x + hSpacing - width;
                }
                else {
                    snapPt.x = point.x - width;
                }
                if (height >= (vSpacing / 2)) {
                    snapPt.y = point.y + vSpacing - height;
                }
                else {
                    snapPt.y = point.y - height;
                }
            }
            return snapPt;
        };
        Tool.prototype.snap = function (point) {
            var snapSettings = this.diagram.model.snapSettings;
            var zoomFactor = this.diagram.model.zoomFactor;
            if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToVerticalLines)
                point.x = ej.datavisualization.Diagram.SnapUtil._round(point.x, snapSettings.verticalGridLines.snapInterval, zoomFactor);
            if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToHorizontalLines)
                point.y = ej.datavisualization.Diagram.SnapUtil._round(point.y, snapSettings.horizontalGridLines.snapInterval, zoomFactor);
            return point;

        };
        Tool.prototype._endAction = function () {
            this.inAction = false;

            if (this.svgHelper) {
                var helper = this.helper;
                var search = this.diagram._spatialSearch;
                if (!helper.isGroup) {
                    ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(search, search.quadTable[helper.name], helper);
                }
                else {
                    var length = this.helper.children.length - 1;
                    for (var i = length; i >= 0; i--) {
                        ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(search, search.quadTable[helper.children[i].name], helper.children[i]);
                    }
                }
            }
            if (this.helper) {
                if (this.svgHelper)
                    this.diagram._svg.removeChild(this.svgHelper, this.diagram._diagramLayer);
                if (this.helper.gradient) {
                    var defs = this.diagram._svg.getElementsByTagName("defs")[0];
                    defs.removeChild(this.diagram._svg.getElementById(this.helper.name + "_gradient"));
                }
            }
            if (this._previousPossibleConnection) {
                this._previousPossibleConnection = null;
                ej.datavisualization.Diagram.SvgContext._removePortHighlighter(this.diagram._svg, this.diagram._adornerLayer);
            }
            this._currentPossibleConnection = null;
            this._possibleConnectionPort = null;
            this.helper = null;
            this.svgHelper = null;
            this.selectedObject = null;
            this.startPoint = ej.datavisualization.Diagram.Point(0, 0);
            this.currentPoint = ej.datavisualization.Diagram.Point(0, 0);
            this.previousPoint = ej.datavisualization.Diagram.Point(0, 0);
        };
        Tool.prototype._isResizeCorner = function (type) {
            var isResizeCorner = false;
            switch (type) {
                case "n-resize":
                case "e-resize":
                case "w-resize":
                case "s-resize":
                case "ne-resize":
                case "nw-resize":
                case "se-resize":
                case "sw-resize":
                case "targetEndPoint":
                case "sourceEndPoint":
                    isResizeCorner = true;
                    break;
            }
            return isResizeCorner;
        };
        Tool.prototype._initHelper = function () {
            if (this.selectedObject) {
                this.helper = $.extend(true, {}, this.selectedObject);
                this._updateHelperName(this.helper);
            }
        };
        Tool.prototype._updateHelperName = function (helper, child) {
            if (child) {
                helper.name += "helper";
            }
            else
                helper.name = "helper";
            helper.opacity = 0.5;
            var labels = helper.labels;
            for (var i = 0, len = labels.length; i < len; ++i) {
                labels[i].name += "helper";
            }
            if (helper.ports) {
                var ports = helper.ports;
                for (i = 0, len = ports.length; i < len; ++i) {
                    ports[i].name += "helper";
                }
            }
            if (helper.isGroup) {
                var children = helper.children;
                for (i = 0, len = children.length; i < len; i++) {
                    this._updateHelperName(children[i], true);
                }
            }
        };
        Tool.prototype._raiseEvent = function (type, args) {
            this.diagram._trigger(type, args);
            return args;
        };
        Tool.prototype._findPort = function (pt, node) {
            var port = this.diagram._findPortAtPoint(pt, node);
            if (!port && node.isGroup) {
                var childPort;
                for (var j = 0; j < node.children.length; j++) {
                    var child = this.diagram.nameTable[node.children[j]];
                    if (child && !child.line) {
                        childPort = this._findPort(pt, child);
                        if (childPort && !child.isGroup) {
                            this._currentPossibleConnection = child;
                            port = childPort;
                        }
                        else if (childPort) {
                            return childPort;
                        }
                    }
                }
            }
            return port;
        };
        Tool.prototype._checkConnectionPossible = function (evt) {
            var port = null;
            var pt = ej.datavisualization.Diagram.Point(this.currentPoint.x, this.currentPoint.y);
            var node = this.diagram._findNodeUnderMouse(evt);
            if (node && !(node.line)) {
                if (!(node.isPseudoGroup)) {
                    this._showPorts(node);
                    this._currentPossibleConnection = node;
                    if (this._previousPossibleConnection == null || this._previousPossibleConnection.name !== this._currentPossibleConnection.name) {
                        this._previousPossibleConnection = this._currentPossibleConnection;
                    }
                }
            }
            else if (this.diagram.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                this._showPorts();
                this._currentPossibleConnection = null;
                this._possibleConnectionPort = null;
            }
            else  {

                var epoint = ej.datavisualization.Diagram.Point(0, 0);
                if (this._endPoint == "targetEndPoint") {
                    epoint.x = (this.selectedObject.line.endPoint.x) - 25;
                    epoint.y = (this.selectedObject.line.endPoint.y) - 25;
                }
                else if (this._endPoint == "sourceEndPoint") {

                    epoint.x = (this.selectedObject.line.startPoint.x) - 25;
                    epoint.y = (this.selectedObject.line.startPoint.y) - 25;
                }
                var bounds = ej.datavisualization.Diagram.Rectangle(epoint.x, epoint.y, 50, 50);
                var quads = ej.datavisualization.Diagram.SpatialUtil.findQuads(this.diagram._spatialSearch, bounds);
                for (var i = 0; i < quads.length; i++) {
                    var quad = quads[i];
                    if (quad.objects.length > 0) {
                        for (var j = 0; j < quad.objects.length; j++) {
                            var nd = quad.objects[j];
                            var nodebounds = ej.datavisualization.Diagram.Util.bounds(nd);
                            if (ej.datavisualization.Diagram.Geometry.intersectsRect(bounds, nodebounds)) {
                                if (!nd.line) {
                                    this._showPort(nd);
                                }
                            }
                            else {
                                if (!nd.line) {
                                    this._showPort(nd, true);
                                }
                            }
                        }
                    }
                }

                this._currentPossibleConnection = null;
                this._possibleConnectionPort = null;
            }
            
            if (this._currentPossibleConnection) {
                port = this._findPort(pt, this._currentPossibleConnection);
                if ((port && ej.datavisualization.Diagram.Util.canConnect(port, true)) || ej.datavisualization.Diagram.Util.canConnect(this._currentPossibleConnection)) {
                    ej.datavisualization.Diagram.SvgContext._drawPortHighlighter(port, this._currentPossibleConnection, this.diagram._svg, this.diagram._adornerLayer,
                        this.diagram.model.zoomFactor);
                }
                else {
                    ej.datavisualization.Diagram.SvgContext._removePortHighlighter(this.diagram._svg, this.diagram._adornerLayer);
                }
                this._possibleConnectionPort = port;
                if (port && ej.datavisualization.Diagram.Util.canConnect(port, true)) {
                    var connectionNode = this._currentPossibleConnection;
                    var point = ej.datavisualization.Diagram.Util._getPortPosition(this._possibleConnectionPort, ej.datavisualization.Diagram.Util.bounds(connectionNode, true));
                    var matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, connectionNode.rotateAngle, connectionNode.offsetX, connectionNode.offsetY);
                    point = ej.Matrix.transform(matrix, point);
                    this.currentPoint = point;
                }
            }
            else {
                if (this._previousPossibleConnection) {
                    this._previousPossibleConnection = null;
                    ej.datavisualization.Diagram.SvgContext._removePortHighlighter(this.diagram._svg, this.diagram._adornerLayer);
                    this._possibleConnectionPort = null;
                }
            }

        };
        Tool.prototype._showPorts = function (node) {
            if (node) {
                if (this._currentPossibleConnection && this._currentPossibleConnection.name !== node.name) {
                    this._showPort(this._currentPossibleConnection, true);
                }
                this._showPort(node);
            }
            else {
                if (this._currentPossibleConnection != null) {
                    this._showPort(this._currentPossibleConnection, true);
                }
            }
        };
        Tool.prototype._showPort = function (node, hide) {
            var ports;
            var port;
            var portShape;
            var i;
            var len;
            if (hide) {
                ports = node.ports;
                for (i = 0, len = ports.length; i < len; ++i) {
                    port = ports[i];
                    if (port.visibility & ej.datavisualization.Diagram.PortVisibility.Hover || port.visibility & ej.datavisualization.Diagram.PortVisibility.Connect) {
                        portShape = this.diagram._svg.getElementById(node.name + "_" + port.name);
                        portShape.setAttribute("visibility", "hidden");
                    }
                }
            }
            else {
                ports = node.ports;
                for (i = 0, len = ports.length; i < len; ++i) {
                    port = ports[i];
                    if (port.visibility & ej.datavisualization.Diagram.PortVisibility.Hover || port.visibility & ej.datavisualization.Diagram.PortVisibility.Connect) {
                        portShape = this.diagram._svg.getElementById(node.name + "_" + port.name);
                        portShape.setAttribute("visibility", "visible");
                    }
                }
            }
        };
        Tool.prototype._showAllPorts = function (hide) {
            var i;
            var len;
            var nodes = this.diagram.model.nodes;
            if (hide) {
                for (i = 0, len = nodes.length; i < len; i++) {
                    this._showPort(nodes[i], hide);
                }
            }
            else {
                for (i = 0, len = nodes.length; i < len; ++i) {
                    this._showPort(nodes[i]);
                }
            }
        };
        Tool.prototype._disconnect = function (connector) {
            var args;
            var node = this.diagram.nameTable[connector.targetNode];
            var port = null;
            if (node) {
                port = ej.datavisualization.Diagram.Util.findPortByName(node, connector.targetPort);
                args = this._raiseEvent("connectionChange", { element: connector, connection: node, port: port, cancel: false });
                if (!args.cancel) {
                    ej.datavisualization.Diagram.Util.removeItem(node.inEdges, connector.name);
                    connector.targetNode = null;
                    connector.targetPort = null;
                }
            }
            node = this.diagram.nameTable[connector.sourceNode];
            if (node) {
                port = ej.datavisualization.Diagram.Util.findPortByName(node, connector.sourcePort);
                args = this._raiseEvent("connectionChange", { element: connector, connection: node, port: port, cancel: false });
                if (!args.cancel) {
                    ej.datavisualization.Diagram.Util.removeItem(node.outEdges, connector.name);
                    connector.sourceNode = null;
                    connector.sourcePort = null;
                }
            }
        };
        return Tool;
    })();

    ej.datavisualization.Diagram.Tool = Tool;
    //#endregion

    //#region SelectTool
    var SelectTool = (function (base) {
        ej.datavisualization.Diagram.extend(SelectTool, base);
        function SelectTool(diagram) {
            base.call(this, "select", diagram);
            this.cursor = "default";
            this._svgHelper = null;
        }
        SelectTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            var node = this._findNodeUnderMouse(evt);
            if (node) {
                this.selectedObject = node;
            }
        };
        SelectTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            if (!ej.datavisualization.Diagram.Geometry.isEmptyPoint(this.startPoint)) {
                if (!this.inAction && (this.startPoint.x != this.currentPoint.x || this.startPoint.y != this.currentPoint.y)) {
                    this.inAction = true;
                    this._initHelper();
                }
                this._updateHelper();
            }
        };
        SelectTool.prototype.mouseup = function (evt) {
            if (this.inAction) {
                this.currentPoint = this.mousePosition(evt);
                var width = Math.abs(this.startPoint.x - this.currentPoint.x);
                var height = Math.abs(this.startPoint.y - this.currentPoint.y);
                var x = (this.startPoint.x > this.currentPoint.x) ? this.currentPoint.x : this.startPoint.x;
                var y = (this.startPoint.y > this.currentPoint.y) ? this.currentPoint.y : this.startPoint.y;
                var rect = ej.datavisualization.Diagram.Rectangle(x, y, width, height);
                if (width !== 0 || height !== 0) {
                    var i;
                    var len;
                    var bounds;
                    var collection = [];
                    var nodes = this.diagram.model.nodes;
                    for (i = 0, len = nodes.length; i < len; i++) {
                        var node = nodes[i];
                        bounds = ej.datavisualization.Diagram.Util.bounds(node);
                        bounds = ej.datavisualization.Diagram.Geometry.rect([bounds.topLeft, bounds.topRight, bounds.bottomRight, bounds.bottomLeft]);
                        if (ej.datavisualization.Diagram.Util.canSelect(node)) {
                            if (ej.datavisualization.Diagram.Geometry.containsRect(rect, bounds)) {
                                if (node.parent === "")
                                    collection.push(node);
                            }
                            else if (node.isGroup) {
                                this._checkGroupChildren(collection, node, rect);
                            }
                        }
                    }
                    var connectors = this.diagram.model.connectors;
                    for (i = 0, len = connectors.length; i < len; i++) {
                        var connector = connectors[i];
                        bounds = ej.datavisualization.Diagram.Util.bounds(connector);
                        bounds = ej.datavisualization.Diagram.Geometry.rect([bounds.topLeft, bounds.topRight, bounds.bottomRight, bounds.bottomLeft]);
                        if (ej.datavisualization.Diagram.Util.canSelect(connector) && ej.datavisualization.Diagram.Geometry.containsRect(rect, bounds)) {
                            if (connector.parent === "")
                                collection.push(connector);
                        }
                    }
                    if (this.diagram._hasSelection()) {
                        this.diagram._clearSelection();
                    }
                    if (collection.length > 0) {
                        var children = collection;
                        var selection;
                        if (children.length > 1) {
                            var pseudoGroup = ej.datavisualization.Diagram.Group({ isPseudoGroup: true, "name": "multipleSelection" });
                            for (i = 0, len = children.length; i < len; i++) {
                                //children[i].parent = "multipleSelection";
                                pseudoGroup.children.push(children[i].name);
                            }
                            this.diagram.model.nodes.push(pseudoGroup);
                            this.diagram.nameTable[pseudoGroup.name] = pseudoGroup;
                            selection = pseudoGroup;
                        }
                        else {
                            selection = collection[0];
                        }
                        if (selection.isGroup)
                            ej.datavisualization.Diagram.Util._updateGroupBounds(selection, this.diagram.nameTable);
                        this.diagram._addSelection(selection);
                    }
                }
                else {
                    if (this.diagram._hasSelection() && !this.diagram._isDropped) {
                        this.diagram._clearSelection();
                    }
                }
            }
            else {

                if (this.selectedObject || this.diagram._hasSelection()) {

                    if (evt.ctrlKey || evt.shiftKey) {
                        this._processCtrlKey(evt);
                    }
                    else if (this.diagram._hasSelection())
                        this.diagram._clearSelection();
                    this.diagram._addSelection(this.selectedObject);
                }
                else if (this.diagram._hasSelection() && !this.diagram._isDropped) {
                    this.diagram._clearSelection();
                }
            }
            this.diagram._isDropped = false;
            base.prototype.mouseup.call(this, evt);
        };
        SelectTool.prototype._endAction = function () {
            if (this._svgHelper) {
                this.diagram._adornerLayer.removeChild(this._svgHelper);
                this.selectedObject = null;
                this._svgHelper = null;
            }
            base.prototype._endAction.apply(this);
        };
        SelectTool.prototype._initHelper = function () {
            if (!this._svgHelper) {
                var g = this.diagram._svg.g();
                this.diagram._adornerLayer.appendChild(g);
                var scale = this.diagram.model.zoomFactor;
                var selectionRect = this.diagram._svg.rect({
                    "id": "helper", "x": this.startPoint.x * scale, "y": this.startPoint.y * scale,
                    "fill": "transparent", "stroke": "gray", "stroke-dasharray": "2 2", "shape-rendering": "crispEdges"
                });
                g.appendChild(selectionRect);
                g.setAttribute("pointer-events", "none");
                this._svgHelper = g;
            }
        };
        SelectTool.prototype._updateHelper = function () {
            var helper = this.diagram._svg.getElementById("helper");
            var width = Math.abs(this.startPoint.x - this.currentPoint.x);
            var height = Math.abs(this.startPoint.y - this.currentPoint.y);
            var scale = this.diagram.model.zoomFactor;
            var x = ((this.startPoint.x > this.currentPoint.x) ? this.currentPoint.x : this.startPoint.x) * scale;
            var y = ((this.startPoint.y > this.currentPoint.y) ? this.currentPoint.y : this.startPoint.y) * scale;

            if (helper) {
                this.diagram._svg.rect({
                    "id": helper.id, "x": x,
                    "y": y, "width": width * scale, "height": height * scale
                });
            }
        };
        SelectTool.prototype._checkGroupChildren = function (collection, group, bounds) {
            var child, childBounds;
            for (var i = 0; i < group.children.length; i++) {
                child = group.children[i];
                childBounds = ej.datavisualization.Diagram.Util.bounds(child);
                if (ej.datavisualization.Diagram.Geometry.containsRect(bounds, childBounds)) {
                    collection.push(child);
                }
                else if (child.isGroup) {
                    this._checkGroupChildren(collection, child, bounds);
                }
            }
        }
        return SelectTool;
    })(Tool);

    ej.datavisualization.Diagram.SelectTool = SelectTool;
    //#endregion

    //#region MoveTool
    var MoveTool = (function (base) {
        ej.datavisualization.Diagram.extend(MoveTool, base);
        function MoveTool(diagram) {
            base.call(this, "move", diagram);
            this.cursor = "move";
            this._isMouseDown = false;
            this.diffx = 0;
            this.diffy = 0;
            this.undoObject = [];
        }
        MoveTool.prototype.mousedown = function (evt) {
            ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
            this.diffx = 0;
            this.diffy = 0;
            base.prototype.mousedown.call(this, evt);
            this._isMouseDown = true;
            this.updateCursor(this.cursor);
        };
        MoveTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
            if (this._isMouseDown && !this.inAction && (this.startPoint.x != this.currentPoint.x || this.startPoint.y != this.currentPoint.y)) {
                if (!this.selectedObject) {
                    var selectedObject;
                    if (this.diagram.selectionList.length > 0) {
                        selectedObject = this._findNodeUnderMouse(evt, true);
                    }
                    else {
                        selectedObject = this._findNodeUnderMouse(evt);
                    }
                    if (selectedObject) {
                        if (this.diagram.selectionList[0] && this.diagram.selectionList[0].isPseudoGroup) {
                            if (!(this.diagram._findChildren(this.diagram.selectionList[0], selectedObject.name))) {
                                this.selectedObject = selectedObject;
                                this.diagram._clearSelection();
                            }
                            else this.selectedObject = this.diagram.selectionList[0];
                        }
                        else {
                            if (this.diagram.selectionList[0] != selectedObject) {
                                this.diagram._clearSelection();

                                this.selectedObject = this.diagram.nameTable[selectedObject.name];

                            } else {
                                this.selectedObject = this.diagram.nameTable[this.diagram.selectionList[0].name];
                            }
                        }
                        //this.undoObject = ej.datavisualization.Diagram.Util.clone(this.selectedObject);

                        var data;
                        var childTable = {};
                        if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                            childTable = this.diagram._getChildTable(this.selectedObject, childTable);
                        var temp = { "childTable": childTable, "node": this.selectedObject };
                        data = $.extend(true, {}, temp);
                        this.undoObject = jQuery.extend(true, {}, data);
                    }
                }
            }
            if (this.selectedObject && ej.datavisualization.Diagram.Util.canSelect(this.selectedObject)) {
                if (!this.inAction) {
                    //ej.datavisualization.Diagram.SvgContext._removePivotPoint(this.selectedObject, this.diagram._svg, this.diagram.model.zoomFactor);
                    this.inAction = true;
                    this.updateCursor("move");
                    this._updateSelection();
                }
                this._updateXY(this.selectedObject, this.previousPoint, this.currentPoint);
                if (this.selectedObject.line) {
                    var connector = this.selectedObject;
                    if (ej.datavisualization.Diagram.Util.isTargetConnected(connector) || ej.datavisualization.Diagram.Util.isSourceConnected(connector)) {
                        this._disconnect(connector);
                    }
                }
                if (this.selectedObject.isPseudoGroup) {
                    var child;
                    for (var i = 0, len = this.selectedObject.children.length; i < len; i++) {
                        child = this.diagram.nameTable[this.selectedObject.children[i]];
                        ej.datavisualization.Diagram.DiagramContext.update(child, this.diagram);
                    }
                }
                else {
                    if (this.selectedObject.parent) {
                        ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[this.selectedObject.parent], this.diagram.nameTable);
                    }
                    ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
                }

                this.diagram._renderTooltip(this.selectedObject);
                this._updateSelection();
                this.diagram._updateSelectionHandle(true);
            }
            this.previousPoint = this.currentPoint;
        };
        MoveTool.prototype.mouseup = function (evt) {
            this._isMouseDown = false;
            ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
            var clickedObject;
            if (this.inAction) {
                this.inAction = false;
                this._updateXY(this.selectedObject, this.previousPoint, this.currentPoint);
                this._updateObject();

                var data;
                var childTable = {};
                if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                    childTable = this.diagram._getChildTable(this.selectedObject, childTable);
                var temp = { "childTable": childTable, "node": this.selectedObject };
                data = $.extend(true, {}, temp);


                var entry = { type: "positionchanged", undoObject: this.undoObject, redoObject: jQuery.extend(true, {}, data), isMultipleNode: this.selectedObject.isGroup ? true : false };
                this.diagram.addHistoryEntry(entry);
                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.MoveHandleCmd(this.undoObject, ej.datavisualization.Diagram.Util.clone(this.selectedObject), this.selectedObject.isPseudoGroup ? true : false));
                //this.diagram.historyManager.addHistoryEntry(entry);
                this.diagram._updateSelectionHandle();
                clickedObject = this.selectedObject;
            }
            else {
                if (!this.selectedObject) {
                    if (evt.which == 3) {
                        if (this.diagram.selectionList && !(this.diagram.selectionList[0].isPseudoGroup)) {
                            if (this.diagram.selectionList.length > 0) {
                                this.selectedObject = this._findNodeUnderMouse(evt, true);
                                clickedObject = this.selectedObject;
                            } else {
                                this.selectedObject = this._findNodeUnderMouse(evt);
                                clickedObject = this.selectedObject;
                            }
                            if (this.selectedObject && !this.diagram._selectionContains(this.selectedObject))
                                this.diagram._clearSelection();
                        }
                    }
                    else {
                        if (evt.ctrlKey || evt.shiftKey) {
                            clickedObject = this._processCtrlKey(evt);
                        }
                        else {
                            this.selectedObject = this._findNodeUnderMouse(evt);
                            clickedObject = this.selectedObject;
                        }
                        if (this.selectedObject && !this.diagram._selectionContains(this.selectedObject))
                            this.diagram._clearSelection();
                    }
                }
                else {
                    clickedObject = this._findNodeUnderMouse(evt);
                }
            }
            if (this.selectedObject) {
                this._updateSelection();
            }
            this.diagram._removeTooltip();
            this.diagram._endEdit();
            //raise click event
            if (clickedObject) {
                this._raiseEvent("click", { element: clickedObject });
            }
            base.prototype.mouseup.call(this, evt);
        };
        MoveTool.prototype._updateObject = function () {
            if (this.selectedObject.isPseudoGroup) {
                var child;
                for (var i = 0, len = this.selectedObject.children.length; i < len; i++) {
                    child = this.diagram.nameTable[this.selectedObject.children[i]];
                    ej.datavisualization.Diagram.DiagramContext.update(child, this.diagram);
                }
            }
            else
                ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
        };
        MoveTool.prototype._endAction = function () {
            base.prototype._endAction.apply(this);
            this._isMouseDown = false;
            this._mouseOffset = ej.datavisualization.Diagram.Size(0, 0);
        };

        MoveTool.prototype._renderHelper = function () {
            if (!this.svgHelper) {
                if (this.helper.line)
                    ej.datavisualization.Diagram.DiagramContext.renderConnector(this.helper, this.diagram);
                else if (this.helper.isGroup)
                    ej.datavisualization.Diagram.DiagramContext.renderGroup(this.helper, this.diagram);
                else
                    ej.datavisualization.Diagram.DiagramContext.renderNode(this.helper, this.diagram);
                this.svgHelper = document.getElementById(this.helper.name);
                this.svgHelper.setAttribute("pointer-events", "none");
            }
        };
        MoveTool.prototype._updateHelper = function () {
            this._updateXY(this.helper, this.previousPoint, this.currentPoint);
            ej.datavisualization.Diagram.DiagramContext.update(this.helper, this.diagram);
        };
        MoveTool.prototype._updateXY = function (shape, startPoint, endPoint) {
            var towardsLeft = endPoint.x < startPoint.x;
            var towardsTop = endPoint.y < startPoint.y;
            var difx = this.diffx + (endPoint.x - startPoint.x);
            var dify = this.diffy + (endPoint.y - startPoint.y);
            var offset;
            if ((this.diagram.model.snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToHorizontalLines) ||
                (this.diagram.model.snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToVerticalLines) || this.diagram.model.snapSettings.enableSnapToObject)
                offset = ej.datavisualization.Diagram.SnapUtil._snapPoint(this.diagram, this.selectedObject, towardsLeft, towardsTop, ej.datavisualization.Diagram.Point(difx, dify),
                    endPoint, startPoint);

            if (!offset)
                offset = ej.datavisualization.Diagram.Point(difx, dify);

            this.diffx = difx - offset.x;
            this.diffy = dify - offset.y;
            if (!ej.datavisualization.Diagram.Geometry.isEmptyPoint(offset)) {
                var args = this._raiseEvent("drag", { element: this.selectedObject, offset: offset, cancel: false });
                if (!args.cancel) {
                    this.diagram._translate(shape, offset.x, offset.y, this.diagram.nameTable);
                    this._updateParent(shape);
                    if (shape.isGroup) {
                        ej.datavisualization.Diagram.Util._updateGroupBounds(shape, this.diagram.nameTable);
                    }
                }
            }
        };
        MoveTool.prototype._updateParent = function (shape) {
            var child;
            if (shape.isPseudoGroup) {
                for (var i = 0; i < shape.children.length; i++) {
                    child = this.diagram.nameTable[shape.children[i]];
                    if (child && child.parent) {
                        ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[child.parent], this.diagram.nameTable);
                        ej.datavisualization.Diagram.DiagramContext.update(this.diagram.nameTable[child.parent], this.diagram);
                        this.diagram._updateAssociatedConnectorEnds(this.diagram.nameTable[child.parent], this.diagram.nameTable);
                    }
                }
            } else {
                if (shape && shape.parent) {
                    ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[shape.parent], this.diagram.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(this.diagram.nameTable[shape.parent], this.diagram);
                    this.diagram._updateAssociatedConnectorEnds(this.diagram.nameTable[shape.parent], this.diagram.nameTable);
                }
            }
        };
        MoveTool.prototype._updateSelection = function () {
            if (!this.diagram._selectionContains(this.selectedObject)) {
                this.diagram._addSelection(this.selectedObject);
            }
        };
        return MoveTool;
    })(Tool);

    ej.datavisualization.Diagram.MoveTool = MoveTool;
    //#endregion

    //#region ResizeTool
    var ResizeTool = (function (base) {
        ej.datavisualization.Diagram.extend(ResizeTool, base);
        function ResizeTool(diagram) {
            base.call(this, "resize", diagram);
            this.cursor = "default";//update resize cursor during action i.e in action
            this._resizeDirection = null;
            this._mouseOffset = ej.datavisualization.Diagram.Size(0, 0);
            this.diffx = 0;
            this.diffy = 0;
            this.undoObject = null;
        }
        ResizeTool.prototype.mousedown = function (evt) {
            ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
            base.prototype.mousedown.call(this, evt);
            this.selectedObject = this.diagram.nameTable[this.diagram.selectionList[0].name];

            var data;
            var childTable = {};
            if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                childTable = this.diagram._getChildTable(this.selectedObject, childTable);
            var temp = { "childTable": childTable, "node": this.selectedObject };
            data = $.extend(true, {}, temp);
            this.undoObject = jQuery.extend(true, {}, data);


            //this.undoObject = ej.datavisualization.Diagram.Util.clone(this.selectedObject);
            this._resizeDirection = evt.target.getAttribute("class");
            this.diffx = 0;
            this.diffy = 0;
        };
        ResizeTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
            if (this.selectedObject) {
                if (!this.inAction) {
                    ej.datavisualization.Diagram.SvgContext._removePivotPoint(this.selectedObject, this.diagram._svg, this.diagram.model.zoomFactor);
                    this.inAction = true;
                }
                this._updateSize(this.selectedObject, this.previousPoint, this.currentPoint);
                ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
                this.diagram._renderTooltip(this.selectedObject);
                this.diagram._updateSelectionHandle(true);
            }

            this.previousPoint = this.currentPoint;
        };
        ResizeTool.prototype.mouseup = function (evt) {
            if (this.inAction) {
                ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this.diagram);
                this.inAction = false;
                this._updateSize(this.selectedObject, this.previousPoint, this.currentPoint);
                if (this.selectedObject.parent) {
                    ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[this.selectedObject.parent], this.diagram.nameTable);
                }
                ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
                this.diagram._updateSelectionHandle();

                var data;
                var childTable = {};
                if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                    childTable = this.diagram._getChildTable(this.selectedObject, childTable);
                var temp = { "childTable": childTable, "node": this.selectedObject };
                data = $.extend(true, {}, temp);


                var entry = { type: "sizechanged", undoObject: this.undoObject, redoObject: jQuery.extend(true, {}, data), isMultipleNode: this.selectedObject.isGroup ? true : false };
                this.diagram.addHistoryEntry(entry);

                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.ResizeHandleCmd(this.undoObject, ej.datavisualization.Diagram.Util.clone(this.selectedObject), this.selectedObject.isPseudoGroup ? true: false));
                //this.diagram.historyManager.addHistoryEntry(entry);
                this.diagram._removeTooltip();
            }
            base.prototype.mouseup.call(this, evt);
        };
        ResizeTool.prototype._updateSize = function (shape, startPoint, endPoint, x1, y1) {
            var matrix = ej.Matrix.identity();
            ej.Matrix.rotate(matrix, -shape.rotateAngle);
            var horizontalsnap = { snapped: false, offset: 0, left: false, right: false };
            var verticalsnap = { snapped: false, offset: 0, top: false, bottom: false };
            var difx = (x1 ? x1 : (endPoint.x - startPoint.x)) + this.diffx;
            var dify = (y1 ? y1 : (endPoint.y - startPoint.y)) + this.diffy;
            var dely = dify;
            var delx = difx;
            this.diffx = 0;
            this.diffy = 0;
            var pivot = ej.datavisualization.Diagram.Point(0, 0);
            var trans = ej.Matrix.identity();
            var pt = shape.pivot;
            var x = shape.offsetX;
            var y = shape.offsetY;
            ej.Matrix.rotate(trans, shape.rotateAngle, x, y);
            var w = shape.width;
            var h = shape.height;
            x = x - w * pt.x;
            y = y - h * pt.y;
            switch (this._resizeDirection) {
                case "n-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x + w / 2, y + h));
                    var deltaWidth = 1;
                    dify = this._snapTop(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaHeight = (shape.height - dify) / shape.height;
                    break;
                case "e-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x, y + h / 2));
                    difx = this._snapRight(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width + difx) / shape.width;
                    var deltaHeight = 1;
                    break;
                case "w-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x + w, y + h / 2));
                    difx = this._snapLeft(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width - difx) / shape.width;
                    var deltaHeight = 1;
                    break;
                case "s-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x + w / 2, y));
                    var deltaWidth = 1;
                    dify = this._snapBottom(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaHeight = (shape.height + dify) / shape.height;
                    break;
                case "ne-resize":
                    dify = this._snapTop(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x, y + h));
                    difx = this._snapRight(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width + difx) / shape.width;
                    var deltaHeight = (shape.height - dify) / shape.height;
                    break;
                case "nw-resize":
                    dify = this._snapTop(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x + w, y + h));
                    difx = this._snapLeft(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width - difx) / shape.width;
                    var deltaHeight = (shape.height - dify) / shape.height;
                    break;
                case "se-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x, y));
                    dify = this._snapBottom(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    difx = this._snapRight(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width + difx) / shape.width;
                    var deltaHeight = (shape.height + dify) / shape.height;
                    break;
                case "sw-resize":
                    pivot = ej.Matrix.transform(trans, ej.datavisualization.Diagram.Point(x + w, y));
                    dify = this._snapBottom(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    difx = this._snapLeft(horizontalsnap, verticalsnap, delx, dely, shape, endPoint == startPoint);
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(difx, dify)); difx = diff.x; dify = diff.y;
                    var deltaWidth = (shape.width - difx) / shape.width;
                    var deltaHeight = (shape.height + dify) / shape.height;
                    break;
            }

            var size = ej.datavisualization.Diagram.Size();
            size.width = deltaWidth;
            size.height = deltaHeight;
            if (!ej.datavisualization.Diagram.Geometry.isEmptySize(size)) {
                this.diagram._scale(shape, deltaWidth, deltaHeight, pivot, this.diagram.nameTable);
                var args = this._raiseEvent("sizeChange", { element: this.selectedObject, offset: size, cancel: false });
                if (args.cancel) {
                    this.diagram._scale(shape, 1 / deltaWidth, 1 / deltaHeight, pivot, this.diagram.nameTable);
                }
                if (shape.isGroup) {
                    ej.datavisualization.Diagram.Util._updateGroupBounds(shape, this.diagram.nameTable);
                }
            }
        };
        ResizeTool.prototype._snapTop = function (horizontalsnap, verticalsnap, delx, dely, shape, ended) {
            var dify = dely;
            verticalsnap.top = true;
            var snapSettings = this.diagram.model.snapSettings;
            var zoomFactor = this.diagram.model.zoomFactor;
            if (snapSettings.enableSnapToObject)
                ej.datavisualization.Diagram.SnapUtil._snapSize(this.diagram, horizontalsnap, verticalsnap, delx, dely, this.selectedObject, ended);
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            if (!verticalsnap.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToHorizontalLines) {
                    var actualTop = bounds.top + dely;
                    var roundedTop = ej.datavisualization.Diagram.SnapUtil._round(actualTop, snapSettings.horizontalGridLines.snapInterval, zoomFactor);
                    dify = roundedTop - bounds.top;
                    this.diffy = actualTop - roundedTop;
                }
            }
            else {
                this.diffy = dify - verticalsnap.offset;
                dify = verticalsnap.offset;
            }
            return dify;
        };
        ResizeTool.prototype._snapBottom = function (horizontalsnap, verticalsnap, delx, dely, shape, ended) {
            var dify = dely;
            verticalsnap.bottom = true;
            var snapSettings = this.diagram.model.snapSettings;
            var zoomFactor = this.diagram.model.zoomFactor;
            if (snapSettings.enableSnapToObject)
                ej.datavisualization.Diagram.SnapUtil._snapSize(this.diagram, horizontalsnap, verticalsnap, delx, dely, this.selectedObject, ended);;
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            if (!verticalsnap.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToHorizontalLines) {
                    var actualBottom = bounds.bottom + dely;
                    var roundedBottom = ej.datavisualization.Diagram.SnapUtil._round(actualBottom, snapSettings.horizontalGridLines.snapInterval, zoomFactor);
                    dify = roundedBottom - bounds.bottom;
                    this.diffy = actualBottom - roundedBottom;
                }
            }
            else {
                this.diffy = dify - verticalsnap.offset;
                dify = verticalsnap.offset;
            }
            return dify;
        };
        ResizeTool.prototype._snapLeft = function (horizontalsnap, verticalsnap, delx, dely, shape, ended) {
            var difx = delx;
            horizontalsnap.left = true;
            var snapSettings = this.diagram.model.snapSettings;
            var zoomFactor = this.diagram.model.zoomFactor;
            if (snapSettings.enableSnapToObject)
                ej.datavisualization.Diagram.SnapUtil._snapSize(this.diagram, horizontalsnap, verticalsnap, delx, dely, this.selectedObject, ended);;
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            if (!horizontalsnap.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToVerticalLines) {
                    var actualLeft = bounds.left + delx;
                    var roundedLeft = ej.datavisualization.Diagram.SnapUtil._round(actualLeft, snapSettings.verticalGridLines.snapInterval, zoomFactor);
                    difx = roundedLeft - bounds.left;
                    this.diffx = actualLeft - roundedLeft;
                }
            }
            else {
                this.diffx = difx - horizontalsnap.offset;
                difx = horizontalsnap.offset;
            }
            return difx;
        };
        ResizeTool.prototype._snapRight = function (horizontalsnap, verticalsnap, delx, dely, shape, ended) {
            var difx = delx;
            horizontalsnap.right = true;
            var snapSettings = this.diagram.model.snapSettings;
            var zoomFactor = this.diagram.model.zoomFactor;
            if (snapSettings.enableSnapToObject)
                ej.datavisualization.Diagram.SnapUtil._snapSize(this.diagram, horizontalsnap, verticalsnap, delx, dely, this.selectedObject, ended);;
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            if (!horizontalsnap.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToVerticalLines) {
                    var actualRight = bounds.right + delx;
                    var roundedRight = ej.datavisualization.Diagram.SnapUtil._round(actualRight, snapSettings.verticalGridLines.snapInterval, zoomFactor);
                    difx = roundedRight - bounds.right;
                    this.diffx = actualRight - roundedRight;
                }
            }
            else {
                this.diffx = difx - horizontalsnap.offset;
                difx = horizontalsnap.offset;
            }
            return difx;
        };
        return ResizeTool;
    })(Tool);

    ej.datavisualization.Diagram.ResizeTool = ResizeTool;
    //#endregion

    //#region EndPointTool
    var EndPointTool = (function (base) {
        ej.datavisualization.Diagram.extend(EndPointTool, base);
        function EndPointTool(diagram) {
            base.call(this, "endPoint", diagram);
            this.cursor = "move";
            this._endPoint = null;
            this._undoObject = null;
        }
        EndPointTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            this.selectedObject = this.diagram.nameTable[this.diagram.selectionList[0].name];
            this.undoObject = this._getClonedObject(this.selectedObject);
            this._endPoint = evt.target.getAttribute("class");
        };
        EndPointTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            if (this.selectedObject) {
                if (!this.inAction && (this.startPoint.x != this.currentPoint.x || this.startPoint.y != this.currentPoint.y)) {
                    this.inAction = true;
                    $(this.diagram._svg.getElementById(this.selectedObject.name)).attr("pointer-events", "none");
                    $(this.diagram._svg.getElementById(this.selectedObject.name + "_line_hitTest")).attr("pointer-events", "none");
                    $("#" + this.diagram._svg.document.id + "handle_g").attr("pointer-events", "none");
                    //this._initHelper();
                    //this._renderHelper();
                    this.undoObject = this._getClonedObject(this.selectedObject);
                }
                else {
                    //this._updateHelper();
                    if (this._endPoint == "targetEndPoint" || this._endPoint == "sourceEndPoint")
                        this._checkConnectionPossible(evt);
                    this._updatePoints(this.selectedObject);
                    this._disconnect(this.selectedObject);
                    this._updateConnection(this.selectedObject);
                    ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
                    this.diagram._updateSelectionHandle(true);
                }
            }
            this.previousPoint = this.currentPoint;
        };
        EndPointTool.prototype.mouseup = function (evt) {
            if (this.inAction) {
                this.inAction = false;
                this._updatePoints(this.selectedObject);
                this._disconnect(this.selectedObject);
                var args;
                if (this._currentPossibleConnection && !this.inAction) {
                    this._updateConnection(this.selectedObject);
                }
                else {
                    if (this.selectedObject.sourceNode || this.selectedObject.targetNode) {
                        this._updateConnection(this.selectedObject);
                    }
                }
                ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);

                var entry = { type: "endpointchanged", undoObject: this.undoObject, redoObject: this._getClonedObject(this.selectedObject), isMultipleNode: this.selectedObject.isGroup ? true : false };
                this.diagram.addHistoryEntry(entry);

                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.EndPointHandleCmd(this._undoObject, this._getClonedObject(this.selectedObject)));
                //this.diagram.historyManager.addHistoryEntry(entry);
                if (this.selectedObject.parent)
                    ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[this.selectedObject.parent], this.diagram.nameTable);
                this.diagram._updateSelectionHandle();
            }
            if (this.selectedObject) {
                $(this.diagram._svg.getElementById(this.selectedObject.name)).removeAttr("pointer-events");
                $(this.diagram._svg.getElementById(this.selectedObject.name + "_line_hitTest")).attr("pointer-events", "stroke");
            }
            $("#" + this.diagram._svg.document.id + "handle_g").removeAttr("pointer-events");
            base.prototype.mouseup.call(this, evt);
        };
        EndPointTool.prototype._getClonedObject = function (connector) {
            var clonedObject = $.extend(true, {}, connector);
            clonedObject.targetNode = connector.targetNode;
            clonedObject.sourceNode = connector.sourceNode;
            clonedObject.targetPort = connector.targetPort;
            clonedObject.sourcePort = connector.sourcePort;
            return clonedObject;
        };
        EndPointTool.prototype._updateConnection = function (connector) {
            var args;
            if (this._currentPossibleConnection) {
                if (this._endPoint == "targetEndPoint") {
                    if (this._possibleConnectionPort && ej.datavisualization.Diagram.Util.canConnect(this._possibleConnectionPort, true)) {
                        args = this._raiseEvent("connectionChange", { element: this.selectedObject, endPoint: this._endPoint, connection: this._currentPossibleConnection, port: this._possibleConnectionPort, cancel: false });
                        if (!args.cancel) {
                            connector.targetNode = this._currentPossibleConnection.name;
                            connector.targetPort = this._possibleConnectionPort.name;
                            this._currentPossibleConnection.inEdges.push(connector.name);
                        }
                    }
                    else if (ej.datavisualization.Diagram.Util.canConnect(this._currentPossibleConnection)) {
                        args = this._raiseEvent("connectionChange", { element: this.selectedObject, endPoint: this._endPoint, connection: this._currentPossibleConnection, port: this._possibleConnectionPort, cancel: false });
                        if (!args.cancel) {
                            connector.targetNode = this._currentPossibleConnection.name;
                            this._currentPossibleConnection.inEdges.push(connector.name);
                        }
                    }
                }
                else {
                    if (this._possibleConnectionPort && ej.datavisualization.Diagram.Util.canConnect(this._possibleConnectionPort, true)) {
                        args = this._raiseEvent("connectionChange", { element: this.selectedObject, endPoint: this._endPoint, connection: this._currentPossibleConnection, port: this._possibleConnectionPort, cancel: false });
                        if (!args.cancel) {
                            connector.sourceNode = this._currentPossibleConnection.name;
                            connector.sourcePort = this._possibleConnectionPort.name;
                            this._currentPossibleConnection.outEdges.push(connector.name);
                        }
                    }
                    else if (ej.datavisualization.Diagram.Util.canConnect(this._currentPossibleConnection)) {
                        args = this._raiseEvent("connectionChange", { element: this.selectedObject, endPoint: this._endPoint, connection: this._currentPossibleConnection, port: this._possibleConnectionPort, cancel: false });
                        if (!args.cancel) {
                            connector.sourceNode = this._currentPossibleConnection.name;
                            this._currentPossibleConnection.outEdges.push(connector.name);
                        }
                    }
                }
            }
            this.diagram._dock(connector, this.diagram.nameTable);
        };
        EndPointTool.prototype._disconnect = function (connector) {
            var args;
            var node = this.diagram.nameTable[connector.targetNode];
            var port = null;
            if (this._endPoint == "targetEndPoint" && node) {
                port = ej.datavisualization.Diagram.Util.findPortByName(node, connector.targetPort);
                args = this._raiseEvent("connectionChange", { element: connector, endPoint: this._endPoint, connection: node, port: port, cancel: false });
                if (!args.cancel) {
                    ej.datavisualization.Diagram.Util.removeItem(node.inEdges, connector.name);
                    connector.targetNode = null;
                    connector.targetPort = null;
                }

            }
            node = this.diagram.nameTable[connector.sourceNode];
            if ((this._endPoint == "sourceEndPoint") && node) {
                port = ej.datavisualization.Diagram.Util.findPortByName(node, connector.sourcePort);
                args = this._raiseEvent("connectionChange", { element: connector, endPoint: this._endPoint, connection: node, port: port, cancel: false });
                if (!args.cancel) {
                    ej.datavisualization.Diagram.Util.removeItem(node.outEdges, connector.name);
                    connector.sourceNode = null;
                    connector.sourcePort = null;
                }
            }
        };
        EndPointTool.prototype._initHelper = function () {
            base.prototype._initHelper.call(this);
            this.helper.targetNode = this.selectedObject.targetNode;
            this.helper.targetPort = this.selectedObject.targetPort;
            this.helper.sourceNode = this.selectedObject.sourceNode;
            this.helper.sourcePort = this.selectedObject.sourcePort;
        };
        EndPointTool.prototype._endAction = function () {
            this._showPorts();
            var possibleConnection;
            if (this._currentPossibleConnection && !this._possibleConnectionPort) {
                possibleConnection = this._currentPossibleConnection;
            }
            base.prototype._endAction.apply(this);
            if (this._endPoint) {
                this._endPoint = null;
                if (possibleConnection) {
                    this.diagram._checkToolToActivate(possibleConnection, this.currentPoint);
                    this.diagram._updateCursor();
                }
            }
        };
        EndPointTool.prototype._renderHelper = function () {
            if (!this.svgHelper) {
                this.svgHelper = ej.datavisualization.Diagram.DiagramContext.renderConnector(this.helper, this.diagram);
                this.svgHelper = document.getElementById(this.helper.name);
                this.svgHelper.setAttribute("pointer-events", "none");
            }
        };
        EndPointTool.prototype._updateHelper = function () {

        };
        EndPointTool.prototype._updatePoints = function (connector) {
            var isTarget = (this._endPoint == "targetEndPoint") ? true : false;
            var isSource = (this._endPoint == "sourceEndPoint") ? true : false;
            var endPoint;
            if (this._endPoint) {
                switch (this._endPoint) {
                    case "targetEndPoint":
                        endPoint = connector.line.endPoint;
                        break;
                    case "sourceEndPoint":
                        endPoint = connector.line.startPoint;
                        break;
                    case "bezierpoint1":
                        endPoint = connector.line._point1;
                        break;
                    case "bezierpoint2":
                        endPoint = connector.line._point2;
                        break;
                }

                var ptCur = this.currentPoint;
                if (this._possibleConnectionPort == null) {
                    ptCur = this.snap(ptCur);
                }
                var offset = ej.datavisualization.Diagram.Point(endPoint.x - ptCur.x, endPoint.y - ptCur.y);
                if (!ej.datavisualization.Diagram.Geometry.isEmptyPoint(offset)) {
                    var cancel = false;
                    var args;
                    var type = null;

                    if (isTarget) {
                        type = "target";
                    }
                    else if (isSource) {
                        type = "source";
                    }
                    args = this._raiseEvent("drag", { end: type, element: this.selectedObject, cancel: false });
                    cancel = args.cancel;

                    if (!cancel) {
                        if (isTarget || isSource)
                            this.diagram._setEndPoint(connector, ej.datavisualization.Diagram.Point(ptCur.x, ptCur.y), isTarget);
                        else
                            ej.datavisualization.Diagram.Util._setBezierPoint(connector, ej.datavisualization.Diagram.Point(ptCur.x, ptCur.y), this._endPoint);
                    }
                }
            }
        };
        return EndPointTool;
    })(Tool);

    ej.datavisualization.Diagram.EndPointTool = EndPointTool;
    //#endregion

    //#region LineTool
    var LineTool = (function (base) {
        ej.datavisualization.Diagram.extend(LineTool, base);
        function LineTool(name, diagram) {
            base.call(this, name, diagram);
            this.cursor = "crosshair";
            this._isMouseDown = false;
            this._targetPossibleConnection = null;
            this._sourcePossibleConnection = null;
            this._targetPort = null;
            this._sourcePort = null;
        }
        LineTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            this._isMouseDown = true;
            if (this.diagram._hasSelection()) {
                this.diagram._clearSelection();
            }
            if (this._currentPossibleConnection) {
                this._sourcePossibleConnection = this._currentPossibleConnection;
                this._sourcePort = this._possibleConnectionPort;
            }
        };
        LineTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            this._checkConnectionPossible(evt);
            if (this._isMouseDown) {
                if (!this.inAction) {
                    this.inAction = true;
                    this._initHelper();
                    this._renderHelper();
                }
                else {
                    this._targetPossibleConnection = this._currentPossibleConnection;
                    this._targetPort = this._possibleConnectionPort;
                    this._updateHelper();
                }
            }
            this.previousPoint = this.currentPoint;
        };
        LineTool.prototype.mouseup = function (evt) {
            this._isMouseDown = false;
            if (this.inAction) {
                this.inAction = false;
                var ptStart = this._getStartPoint();
                var ptEnd = this._getCurrentPoint();
                var distance = ej.datavisualization.Diagram.Geometry.distance(ptStart, ptEnd);
                if (distance > 0) {
                    var connector = this.createConnector(ptStart, ptEnd);
                    connector.name = "connector" + ej.datavisualization.Diagram.Util.randomId();
                    var args;
                    if (this._sourcePossibleConnection) {
                        if (this._sourcePort && ej.datavisualization.Diagram.Util.canConnect(this._sourcePort, true)) {
                            args = this._raiseEvent("connectionChange", { element: connector, connection: this._sourcePossibleConnection, port: this._sourcePort, cancel: false });
                            if (!args.cancel) {
                                connector.sourceNode = this._sourcePossibleConnection.name;
                                connector.sourcePort = this._sourcePort.name;
                                ej.datavisualization.Diagram.Util.removeItem(this._sourcePossibleConnection.outEdges, this.helper.name);
                            }
                        }
                        else if (ej.datavisualization.Diagram.Util.canConnect(this._sourcePossibleConnection)) {
                            args = this._raiseEvent("connectionChange", { element: connector, connection: this._sourcePossibleConnection, port: this._sourcePort, cancel: false });
                            if (!args.cancel) {
                                connector.sourceNode = this._sourcePossibleConnection.name;
                                ej.datavisualization.Diagram.Util.removeItem(this._sourcePossibleConnection.outEdges, this.helper.name);
                            }
                        }
                    }
                    if (this._targetPossibleConnection) {
                        if (this._targetPort && ej.datavisualization.Diagram.Util.canConnect(this._targetPort, true)) {
                            args = this._raiseEvent("connectionChange", { element: connector, connection: this._targetPossibleConnection, port: this._targetPort, cancel: false });
                            if (!args.cancel) {
                                connector.targetNode = this._targetPossibleConnection.name;
                                connector.targetPort = this._targetPort.name;
                                ej.datavisualization.Diagram.Util.removeItem(this._targetPossibleConnection.inEdges, this.helper.name);
                            }
                        }
                        else if (ej.datavisualization.Diagram.Util.canConnect(this._targetPossibleConnection)) {
                            args = this._raiseEvent("connectionChange", { element: connector, connection: this._targetPossibleConnection, port: this._targetPort, cancel: false });
                            if (!args.cancel) {
                                connector.targetNode = this._targetPossibleConnection.name;
                                ej.datavisualization.Diagram.Util.removeItem(this._targetPossibleConnection.inEdges, this.helper.name);
                            }
                        }

                    }
                    this.diagram.add(connector);
                }
            }
            if (this.singleAction)
                this.diagram.deactivateTool();
            if (this._prevTool)
                this._prevTool.inAction = false;
            this._showPorts();
            base.prototype.mouseup.call(this, evt);
        };

        LineTool.prototype._getStartPoint = function () {
            var ptStart;
            if (this._sourcePossibleConnection && this._sourcePort) {
                ptStart = ej.datavisualization.Diagram.Util._getPortPosition(this._sourcePort, ej.datavisualization.Diagram.Util.bounds(this._sourcePossibleConnection));
            }
            else {
                ptStart = this.snap(this.startPoint);
            }
            return ptStart;
        };
        LineTool.prototype._getCurrentPoint = function () {
            var ptCur;
            if (this._targetPossibleConnection && this._targetPort) {
                ptCur = ej.datavisualization.Diagram.Util._getPortPosition(this._targetPort, ej.datavisualization.Diagram.Util.bounds(this._targetPossibleConnection));
            }
            else {
                ptCur = this.snap(this.currentPoint);
            }
            return ptCur;
        };
        LineTool.prototype._initHelper = function () {
            this.helper = this.createConnector(ej.datavisualization.Diagram.Point(0, 0), ej.datavisualization.Diagram.Point(0, 0));
            this.helper.name = "helper";
        };
        LineTool.prototype.createConnector = function (startPoint, endPoint) {
            return null;
        };
        LineTool.prototype._renderHelper = function () {
            if (!this.svgHelper) {
                this.svgHelper = ej.datavisualization.Diagram.DiagramContext.renderConnector(this.helper, this.diagram);
                this.svgHelper = document.getElementById(this.helper.name);
                this.svgHelper.setAttribute("pointer-events", "none");
                $(this.diagram._svg.getElementById(this.svgHelper.id)).attr("pointer-events", "none");
                $(this.diagram._svg.getElementById(this.svgHelper.id + "_line_hitTest")).attr("pointer-events", "none");
            }
        };
        LineTool.prototype._updateHelper = function () {
            var points = [];
            var ptStart = this._getStartPoint();
            var ptEnd = this._getCurrentPoint();
            points.push(ptStart);
            points.push(ptEnd);
            this.diagram._setEndPoint(this.helper, ptStart, false);
            this.diagram._setEndPoint(this.helper, ptEnd, true);
            this._disconnect(this.helper);
            if (this._sourcePossibleConnection) {
                if (this._sourcePort && ej.datavisualization.Diagram.Util.canConnect(this._sourcePort, true)) {
                    this.helper.sourceNode = this._sourcePossibleConnection.name;
                    this.helper.sourcePort = this._sourcePort.name;
                    this._sourcePossibleConnection.outEdges.push(this.helper.name);
                }
                else if (ej.datavisualization.Diagram.Util.canConnect(this._sourcePossibleConnection)) {
                    this.helper.sourceNode = this._sourcePossibleConnection.name;
                    this._sourcePossibleConnection.outEdges.push(this.helper.name);
                }
            }
            if (this._targetPossibleConnection) {
                if (this._targetPort && ej.datavisualization.Diagram.Util.canConnect(this._targetPort, true)) {
                    this.helper.targetNode = this._targetPossibleConnection.name;
                    this.helper.targetPort = this._targetPort.name;
                    this._targetPossibleConnection.inEdges.push(this.helper.name);
                }
                else if (ej.datavisualization.Diagram.Util.canConnect(this._targetPossibleConnection)) {
                    this.helper.targetNode = this._targetPossibleConnection.name;
                    this._targetPossibleConnection.inEdges.push(this.helper.name);
                }
            }
            this.diagram._dock(this.helper, this.diagram.nameTable);

            ej.datavisualization.Diagram.DiagramContext.update(this.helper, this.diagram);
        };
        LineTool.prototype._endAction = function () {
            base.prototype._endAction.apply(this);
            this._targetPossibleConnection = null;
            this._sourcePossibleConnection = null;
            this._targetPort = null;
            this._sourcePort = null;
            this._isMouseDown = false;
        };
        LineTool.prototype._showPorts = function (node) {
        };
        LineTool.prototype._showAllPorts = function (hide) {
            base.prototype._showAllPorts.call(this, hide);
        };
        return LineTool;
    })(Tool);

    ej.datavisualization.Diagram.LineTool = LineTool;
    //#endregion

    //#region StraightLineTool
    var StraightLineTool = (function (base) {
        ej.datavisualization.Diagram.extend(StraightLineTool, base);
        function StraightLineTool(diagram) {
            base.call(this, "straightLine", diagram);
        }
        StraightLineTool.prototype.createConnector = function (startPoint, endPoint) {
            var connector = ej.datavisualization.Diagram.Connector({ "line": { "type": "straight", "startPoint": startPoint, "endPoint": endPoint } });
            return connector;
        };
        return StraightLineTool;
    })(LineTool);

    ej.datavisualization.Diagram.StraightLineTool = StraightLineTool;
    //#endregion

    //#region OrthogonalLineTool
    var OrthogonalLineTool = (function (base) {
        ej.datavisualization.Diagram.extend(OrthogonalLineTool, base);
        function OrthogonalLineTool(diagram) {
            base.call(this, "orthogonalLine", diagram);
        }
        OrthogonalLineTool.prototype.createConnector = function (startPoint, endPoint) {
            var connector = ej.datavisualization.Diagram.Connector({ "line": { "type": "orthogonal", "startPoint": startPoint, "endPoint": endPoint } });
            return connector;
        };
        return OrthogonalLineTool;
    })(LineTool);

    ej.datavisualization.Diagram.OrthogonalLineTool = OrthogonalLineTool;
    //#endregion

    //#region RotateTool
    var RotateTool = (function (base) {
        ej.datavisualization.Diagram.extend(RotateTool, base);
        function RotateTool(diagram) {
            base.call(this, "rotatetool", diagram);
            this._mouseOffset = ej.datavisualization.Diagram.Size(0, 0);
            this.undoObject = null;
        }
        RotateTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            this.selectedObject = this.diagram.selectionList[0];
            //this.undoObject = ej.datavisualization.Diagram.Util.clone(this.selectedObject);

            var data;
            var childTable = {};
            if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                childTable = this.diagram._getChildTable(this.selectedObject, childTable);
            var temp = { "childTable": childTable, "node": this.selectedObject };
            data = $.extend(true, {}, temp);
            this.undoObject = jQuery.extend(true, {}, data);

            var scale = this.diagram.model.zoomFactor;
            //ej.datavisualization.Diagram.SvgContext.renderPivotPoint(this.selectedObject, this.diagram.model.zoomFactor, this.diagram._svg);

        };
        RotateTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);

            if (this.selectedObject) {
                if (!this.inAction) {
                    this.inAction = true;
                }
                else {
                    this._rotate(this.selectedObject);
                    if (this.selectedObject.parent) {
                        ej.datavisualization.Diagram.Util._updateGroupBounds(this.diagram.nameTable[this.selectedObject.parent], this.diagram.nameTable);
                    }
                    ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);
                    this.diagram._updateSelectionHandle(true);
                    this.diagram._renderTooltip(this.selectedObject);
                }
            }
            this.previousPoint = this.currentPoint;
        };
        RotateTool.prototype._rotate = function (node) {
            var cancel = false;
            var args;

            args = this._raiseEvent("rotationChange", { element: node, cancel: false });
            cancel = args.cancel;

            if (!cancel) {
                var pt = ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY);
                var crntpoint = this.currentPoint;
                var angle = ej.datavisualization.Diagram.Geometry.findAngle(ej.datavisualization.Diagram.Point(pt.x, pt.y), crntpoint) + 90;
                angle = ej.datavisualization.Diagram.SnapUtil._snapAngle(this.diagram, angle);
                this.diagram._rotate(node, angle - node.rotateAngle, this.diagram.nameTable);
            }
        };
        RotateTool.prototype.mouseup = function (evt) {
            if (this.inAction) {
                this.inAction = false;
                this._rotate(this.selectedObject);
                ej.datavisualization.Diagram.DiagramContext.update(this.selectedObject, this.diagram);

                var data;
                var childTable = {};
                if (this.selectedObject.isGroup || this.selectedObject.isPseudoGroup)
                    childTable = this.diagram._getChildTable(this.selectedObject, childTable);
                var temp = { "childTable": childTable, "node": this.selectedObject };
                data = $.extend(true, {}, temp);
                var entry = { type: "rotationchanged", undoObject: this.undoObject, redoObject: jQuery.extend(true, {}, data), isMultipleNode: this.selectedObject.isGroup ? true : false };
                this.diagram.addHistoryEntry(entry);

                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.RotationHandleCmd(this.undoObject, ej.datavisualization.Diagram.Util.clone(this.selectedObject), this.selectedObject.isPseudoGroup ? true : false));
                //this.diagram.historyManager.addHistoryEntry(entry);
                this.diagram._updateSelectionHandle();
                this.diagram._removeTooltip();
            }
            //this.diagram._removeTooltip();
            base.prototype.mouseup.call(this, evt);
        };
        return RotateTool;
    })(Tool);

    ej.datavisualization.Diagram.RotateTool = RotateTool;
    //#endregion 

    //#region PivotTool
    var PivotTool = (function (base) {
        ej.datavisualization.Diagram.extend(PivotTool, base);
        function PivotTool(diagram) {
            base.call(this, "PivotTool", diagram);
            this._mouseOffset = ej.datavisualization.Diagram.Size(0, 0);
        }
        PivotTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            this.selectedObject = this.diagram.selectionList[0];
        };
        PivotTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);

            if (this.selectedObject) {
                if (!this.inAction) {
                    this.inAction = true;
                }
                else {
                    var delx = this.currentPoint.x - this.previousPoint.x;
                    var dely = this.currentPoint.y - this.previousPoint.y;
                    var matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, -this.selectedObject.rotateAngle);
                    var delta = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(delx, dely));
                    var difx = (this.selectedObject.width * this.selectedObject.pivot.x + delta.x) / this.selectedObject.width;
                    var dify = (this.selectedObject.height * this.selectedObject.pivot.y + delta.y) / this.selectedObject.height;
                    this.selectedObject.pivot.x = difx;
                    this.selectedObject.pivot.y = dify;
                    this.selectedObject.offsetX += delx;
                    this.selectedObject.offsetY += dely;
                    this.diagram._updateSelectionHandle();
                }
            }
            this.previousPoint = this.currentPoint;
        };
        PivotTool.prototype._rotate = function (node) {
            var pt = ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY);
            var crntpoint = this.currentPoint;
            var angle = this.FindAngle(pt, crntpoint);
            this.diagram._rotate(node, angle - node.rotateAngle, pt, this.diagram.nameTable);
        };
        PivotTool.prototype.mouseup = function (evt) {
            if (this.inAction) {
                this.inAction = false;
                this.diagram._updateSelectionHandle();
            }
            base.prototype.mouseup.call(this, evt);
        };
        return PivotTool;
    })(Tool);
    ej.datavisualization.Diagram.PivotTool = PivotTool;
    //#endregion

    //#region PanTool
    var PanTool = (function (base) {
        ej.datavisualization.Diagram.extend(PanTool, base);
        function PanTool(diagram) {
            base.call(this, "panTool", diagram);
            this.diagram = diagram;
            this._isMouseDown = false;
            this.cursor = "pointer";
        }
        PanTool.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            if (this.diagram.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                var svgDocument = this.diagram._svg.document;
                var pt = this.diagram._svg.document.createSVGPoint();
                pt.x = evt.clientX; pt.y = evt.clientY;
                var mousept = pt.matrixTransform(this.diagram._svg.document.getScreenCTM().inverse());
                svgDocument.lastMouseX = mousept.x;
                svgDocument.lastMouseY = mousept.y;
                this._isMouseDown = true;
                return false;
            }
        };
        PanTool.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            if (this.diagram.activeTool instanceof ej.datavisualization.Diagram.PanTool && this._isMouseDown) {
                this.inAction = true;
                var svgDocument = this.diagram._svg.document;
                var pt = this.diagram._svg.document.createSVGPoint();
                pt.x = evt.clientX; pt.y = evt.clientY;
                var mousept = pt.matrixTransform(this.diagram._svg.document.getScreenCTM().inverse());
                var ex = mousept.x;
                var ey = mousept.y;
                var nx, ny;

                nx = ((ex - svgDocument.lastMouseX));
                ny = ((ey - svgDocument.lastMouseY));
                if (!(document.getElementById(this.diagram.element[0].id).getElementsByClassName('e-hhandle').length > 0))
                    nx = 0;
                if (!(document.getElementById(this.diagram.element[0].id).getElementsByClassName('e-vhandle').length > 0))
                    ny = 0;
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this.diagram, 1, nx, ny, ej.datavisualization.Diagram.Point(ex, ey));
                svgDocument.lastMouseX = ex;
                svgDocument.lastMouseY = ey;
                return false;
            }
        };
        PanTool.prototype.mouseup = function (evt) {
            if (this.diagram.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                this.inAction = false;
                document.onmousemove = null;
                document.onmouseup = null;
                this._isMouseDown = false;
            }
            base.prototype.mouseup.call(this, evt);
        };
        return PanTool;
    })(Tool);
    ej.datavisualization.Diagram.PanTool = PanTool;
    //#endregion

    //#region RectangleToolBase
    var RectangleToolBase = (function (base) {
        ej.datavisualization.Diagram.extend(RectangleToolBase, base);
        function RectangleToolBase(name, diagram) {
            base.call(this, name, diagram);
            this.cursor = "crosshair";
        }
        RectangleToolBase.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            this.selectedObject = this.createNode();
        };
        RectangleToolBase.prototype.createNode = function () {
        };
        RectangleToolBase.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            if (this.selectedObject) {
                if (!this.inAction) {
                    this.inAction = true;
                    this._initHelper();
                    this._renderHelper();
                    this._calcOffset();
                }
                else {
                    this._updateHelper();
                }
            }
        };
        RectangleToolBase.prototype.mouseup = function (evt) {
            if (this.inAction) {
                this.inAction = false;
                if (this.diagram.model.snapSettings.snapConstraints.snapToLines) {
                    this._calcOffset();
                }
                this._updateSize(this.selectedObject, this.startPoint, this.currentPoint);
                this.diagram.add(this.selectedObject);
                this.diagram._clearSelection();
                this.diagram._addSelection(this.selectedObject);
            }
            this.diagram._toolToActivate = "selectTool";
            this.diagram._drawingTool = false;
            base.prototype.mouseup.call(this, evt);
        };
        RectangleToolBase.prototype._calcOffset = function () {
            var scale = this.diagram.model.magnification / 100;
            var bounds = ej.datavisualization.Diagram.Util.bounds(this.helper);
            var location = bounds.topLeft;
            location = ej.datavisualization.Diagram.Point(bounds.x + bounds.width, bounds.y + bounds.height);
            var x = location.x * scale;
            var y = location.y * scale;
            var xy = ej.datavisualization.Diagram.Point(x, y);
            var snapxy = this.snap(ej.datavisualization.Diagram.Point(x, y));
            this._mouseOffset = ej.datavisualization.Diagram.Size(xy.x - snapxy.x, xy.y - snapxy.y);
        };
        RectangleToolBase.prototype.getBoundingRect = function (startPoint, currentPoint) {
            var width = Math.abs(this.startPoint.x - this.currentPoint.x);
            var height = Math.abs(this.startPoint.y - this.currentPoint.y);
            var diff = ej.datavisualization.Diagram.Size(width, height);
            if (this.diagram.model.snapSettings.snapConstraints.snapToVerticalLines) {
                if (this._mouseOffset.width != 0) {
                    diff.width -= this._mouseOffset.width;
                    this._mouseOffset.width = 0;
                }
            }
            if (this.diagram.model.snapSettings.snapConstraints.snapToHorizontalLines) {
                if (this._mouseOffset.height != 0) {
                    diff.height -= this._mouseOffset.height;
                    this._mouseOffset.height = 0;
                }
            }
            var x = (this.startPoint.x > this.currentPoint.x) ? this.currentPoint.x : this.startPoint.x;
            var y = (this.startPoint.y > this.currentPoint.y) ? this.currentPoint.y : this.startPoint.y;
            return { size: diff, offset: ej.datavisualization.Diagram.Point(x, y) };
        };
        RectangleToolBase.prototype._renderHelper = function () {
            if (!this.svgHelper) {
                this.svgHelper = ej.datavisualization.Diagram.DiagramContext.renderNode(this.helper, this.diagram);
                this.svgHelper = document.getElementById(this.helper.name);
                this.svgHelper.setAttribute("pointer-events", "none");
            }
        };
        RectangleToolBase.prototype._updateHelper = function () {
            this._updateSize(this.helper, this.startPoint, this.currentPoint);
            ej.datavisualization.Diagram.DiagramContext.update(this.helper, this.diagram);
        };
        RectangleToolBase.prototype._updateSize = function (shape, startPoint, currentPoint) {
            var rect = this.getBoundingRect(startPoint, currentPoint);
            var size = rect.size;
            var offset = rect.offset;
            if (!ej.datavisualization.Diagram.Geometry.isEmptySize(size)) {
                shape.offsetX = offset.x + size.width / 2;
                shape.offsetY = offset.y + size.height / 2;
                shape.width = size.width;
                shape.height = size.height;
            }
        };
        return RectangleToolBase;
    })(ej.datavisualization.Diagram.Tool);
    ej.datavisualization.Diagram.RectangleToolBase = RectangleToolBase;
    //#endregion

    //#region PolygonToolBase
    var PolygonToolBase = (function (base) {
        ej.datavisualization.Diagram.extend(PolygonToolBase, base);
        function PolygonToolBase(name, diagram) {
            base.call(this, name, diagram);
            this.cursor = "crosshair";
        }
        PolygonToolBase.prototype.createNode = function () {

        };
        PolygonToolBase.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
        };
        PolygonToolBase.prototype.mousemove = function (evt) {

            base.prototype.mousemove.call(this, evt);
            if (this.selectedObject) {
                if (!this.inAction) {
                    this.inAction = true;
                    this._initHelper();
                    this._renderHelper();
                    this._calcOffset();
                }
                else {
                    this._updateHelper(this.snap(this.currentPoint));
                }
            }
        };
        PolygonToolBase.prototype.mouseup = function (evt) {
            if (!this.selectedObject) {
                if (this.startPoint) {
                    this.selectedObject = this.createNode();
                    var sp = this.snap(this.startPoint);
                    var ep = this.snap(this.currentPoint);
                    this.selectedObject.shape.points.push(ej.datavisualization.Diagram.Point(sp.x, sp.y));
                    this.selectedObject.shape.points.push(ej.datavisualization.Diagram.Point(ep.x, ep.y));
                }
            }
            else if (this.inAction) {
                this.helper.shape.points.push(ej.datavisualization.Diagram.Point(this.currentPoint.x, this.currentPoint.y));
            }
        };
        PolygonToolBase.prototype._calcOffset = function () {
            var scale = this.diagram.model.magnification / 100;
            var bounds = ej.datavisualization.Diagram.Util.bounds(this.helper);
            var location = bounds.topLeft;
            location = ej.datavisualization.Diagram.Point(bounds.x + bounds.width, bounds.y + bounds.height);
            var x = location.x * scale;
            var y = location.y * scale;
            var xy = ej.datavisualization.Diagram.Point(x, y);
            var snapxy = this.snap(ej.datavisualization.Diagram.Point(x, y));
            this._mouseOffset = ej.datavisualization.Diagram.Size(xy.x - snapxy.x, xy.y - snapxy.y);
        };
        PolygonToolBase.prototype._renderHelper = function () {
            if (!this.svgHelper) {

                var rect = ej.datavisualization.Diagram.Geometry.rect(this.helper.shape.points);
                this.helper.offsetX = rect.x + rect.width / 2;
                this.helper.offsetY = rect.y + rect.height / 2;
                this.helper.width = rect.width;
                this.helper.height = rect.height;
                this.svgHelper = ej.datavisualization.Diagram.DiagramContext.renderNode(this.helper, this.diagram);
                this.svgHelper = document.getElementById(this.helper.name);
                this.svgHelper.setAttribute("pointer-events", "none");
            }
        };
        PolygonToolBase.prototype.doubleclick = function (currentPoint) {
            if (this.selectedObject) {

                ej.datavisualization.Diagram.Util.removeItem(this.helper.shape.points, this.helper.shape.points[this.helper.shape.points.length - 2]);
                ej.datavisualization.Diagram.Util.removeItem(this.helper.shape.points, this.helper.shape.points[this.helper.shape.points.length - 1]);
                this.selectedObject.shape.points = this.helper.shape.points;
                var rect = ej.datavisualization.Diagram.Geometry.rect(this.helper.shape.points);
                this.selectedObject.offsetX = rect.x + rect.width / 2;
                this.selectedObject.offsetY = rect.y + rect.height / 2;
                this.selectedObject.width = rect.width;
                this.selectedObject.height = rect.height;
                this.diagram.model.nodes.push(this.selectedObject);
                this.diagram.nameTable[this.selectedObject.name] = this.selectedObject;
                ej.datavisualization.Diagram.DiagramContext.renderNode(this.selectedObject, this.diagram);

                this.diagram._clearSelection();
                this.diagram._addSelection(this.selectedObject);
            }
            if (this._svgHelper) {
                this.diagram._svg.removeChild(this._svgHelper);
                this._svgHelper = null;
            }
            this._endAction();
            this.diagram._drawingTool = false;
            this.diagram._toolToActivate = "selectTool";
            this._mouseOffset = ej.datavisualization.Diagram.Size(0, 0);
        };
        PolygonToolBase.prototype._updateHelper = function (currentPoint) {
            this.helper.shape.points[this.helper.shape.points.length - 1] = ej.datavisualization.Diagram.Point(currentPoint.x, currentPoint.y);
            var rect = ej.datavisualization.Diagram.Geometry.rect(this.helper.shape.points);
            this.helper.offsetX = rect.x + rect.width / 2;
            this.helper.offsetY = rect.y + rect.height / 2;
            this.helper.width = rect.width;
            this.helper.height = rect.height;
            ej.datavisualization.Diagram.DiagramContext.update(this.helper, this.diagram);
        };
        return PolygonToolBase;
    })(ej.datavisualization.Diagram.Tool);
    ej.datavisualization.Diagram.PolygonToolBase = PolygonToolBase;
    //#endregion

    //#region TextToolBase
    var TextToolBase = (function (base) {
        ej.datavisualization.Diagram.extend(TextToolBase, base);
        function TextToolBase(name, diagram) {
            base.call(this, name, diagram);
            this.boundingRect = ej.datavisualization.Diagram.Rectangle();
            this.activeLabel = null;
            this.cursor = "crosshair";
        }
        TextToolBase.prototype.mousedown = function (evt) {
            base.prototype.mousedown.call(this, evt);
            if (this.diagram._isEditing) {
                this.diagram._endEdit();
            }
        };
        TextToolBase.prototype.createNode = function (rect) {

        };
        TextToolBase.prototype.mousemove = function (evt) {
            base.prototype.mousemove.call(this, evt);
            if (!this.selectedObject && !ej.datavisualization.Diagram.Geometry.isEmptyPoint(this.startPoint) && !this.diagram._isEditing) {
                if (!this.inAction) {
                    this.inAction = true;
                    this._initHelper();
                }
                else {
                    this._updateHelper();
                }
            }
        };
        TextToolBase.prototype.mouseup = function (evt) {
            this.activeLabel = null;
            var minHeight = 12;
            if (this.inAction) {
                var rect = this.getBoundingRect(this.startPoint, this.currentPoint);
                this._endAction();
                if (ej.browserInfo().name === "chrome" && (rect.width === 0 || rect.height === 0)) {
                    rect.width = 90;
                    rect.height = minHeight;
                }
                this.selectedObject = this.createNode(rect.x + (rect.width / 2), (rect.y + (rect.height / 2)), rect.width, rect.height);
                this.diagram._startEdit(this.selectedObject);
            }
            else {
                var node = this._findNodeUnderMouse(evt);
                if (node != null) {
                    this.selectedObject = node;
                    this.diagram._startEdit(this.selectedObject);
                }
                else {
                    var rect = ej.datavisualization.Diagram.Rectangle(this.currentPoint.x - (90 / 2), this.currentPoint.y - (minHeight / 2), 90, minHeight);
                    this._endAction();
                    this.selectedObject = this.createNode(rect.x + (rect.width / 2), rect.y + (rect.height / 2), rect.width, minHeight);
                    this.diagram._startEdit(this.selectedObject);
                }
            }
        };
        TextToolBase.prototype.getBoundingRect = function (startPoint, currentPoint) {
            var width = Math.abs(this.startPoint.x - this.currentPoint.x);
            var height = Math.abs(this.startPoint.y - this.currentPoint.y);
            var x = (this.startPoint.x > this.currentPoint.x) ? this.currentPoint.x : this.startPoint.x;
            var y = (this.startPoint.y > this.currentPoint.y) ? this.currentPoint.y : this.startPoint.y;
            return { x: x, y: y, width: width, height: height };
        };
        TextToolBase.prototype._initHelper = function () {
            if (!this._svgHelper) {
                var g = this.diagram._svg.g();
                this.diagram._adornerLayer.appendChild(g);
                var scale = this.diagram.model.zoomFactor;
                var selectionRect = this.diagram._svg.rect({ "id": "helper", "x": this.startPoint.x * scale, "y": this.startPoint.y * scale, "fill": "transparent", "stroke": "gray", "stroke-dasharray": "2 2", "shape-rendering": "crispEdges" });
                g.appendChild(selectionRect);
                g.setAttribute("pointer-events", "none");
                this._svgHelper = g;
            }
        };
        TextToolBase.prototype._updateHelper = function () {
            var helper = this.diagram._svg.getElementById("helper");
            var width = Math.abs(this.startPoint.x - this.currentPoint.x);
            var height = Math.abs(this.startPoint.y - this.currentPoint.y);
            var scale = this.diagram.model.zoomFactor;
            var x = ((this.startPoint.x > this.currentPoint.x) ? this.currentPoint.x : this.startPoint.x) * scale;
            var y = ((this.startPoint.y > this.currentPoint.y) ? this.currentPoint.y : this.startPoint.y) * scale;
            if (helper) {
                this.diagram._svg.rect({ "id": helper.id, "x": x, "y": y, "width": width * scale, "height": height * scale });
            }
        };
        TextToolBase.prototype._endAction = function () {
            if (this._svgHelper) {
                this.diagram._adornerLayer.removeChild(this._svgHelper);
                this._svgHelper = null;
            }
            base.prototype._endAction.apply(this);
        };
        TextToolBase.prototype._findNodeUnderMouse = function (evt, skip) {
            var obj;
            var textElement = $(evt.target).parents("text")[0];
            if (textElement != null) {
                if (textElement.getAttribute("class") == "ej-d-label") {
                    var parentNode = $(textElement).parents("g")[0];
                    obj = this._findObj(parentNode);
                    if (obj.shape.type != "text") {
                        var label = textElement.id.split('_');
                        this.activeLabel = obj.labels.find(label[1]);
                    }
                }
            }
            else {
                var parents = $(evt.target).parents("g");
                if (parents.length > 3) {
                    var element = parents[parents.length - 4];
                    var id = element.getAttribute("id");
                    var type = element.getAttribute("class");
                    if (type) {
                        if (type === "ej-d-node" || type === "ej-d-group") {
                            obj = this.diagram._findNode(id);
                            var curlabel = this.diagram._findLabelAtPoint(this.currentPoint, obj);
                            this.activeLabel = curlabel;
                        }
                        else if (type === "ej-d-connector") {
                            obj = this.diagram._findConnector(id);
                            var curlabel = this.diagram._findLabelAtPoint(this.currentPoint, obj);
                            this.activeLabel = curlabel;
                        }
                    }
                }
            }
            return obj;
        };
        TextToolBase.prototype.getLabelUnderMouse = function () {
            return this.activeLabel;
        };
        return TextToolBase;
    })(ej.datavisualization.Diagram.Tool);
    ej.datavisualization.Diagram.TextToolBase = TextToolBase;
    //#endregion

    //#region RectangleTool
    var RectangleTool = (function (base) {
        ej.datavisualization.Diagram.extend(RectangleTool, base);
        function RectangleTool(diagram) {
            base.call(this, "rectangleTool", diagram);
        }
        RectangleTool.prototype.createNode = function () {
            var node = ej.datavisualization.Diagram.Node({ name: "rectangle" + ej.datavisualization.Diagram.Util.randomId() });
            node.offsetX = 0;
            node.offsetY = 0;
            node.width = 0;
            node.height = 0;
            return node;
        };
        return RectangleTool;
    })(ej.datavisualization.Diagram.RectangleToolBase);
    ej.datavisualization.Diagram.RectangleTool = function (diagram) {
        return new RectangleTool(diagram);
    };
    //#endregion

    //#region EllipseTool
    var EllipseTool = (function (base) {
        ej.datavisualization.Diagram.extend(EllipseTool, base);
        function EllipseTool(diagram) {
            base.call(this, "ellipseTool", diagram);
        }
        EllipseTool.prototype.createNode = function () {
            var node = ej.datavisualization.Diagram.Node({ name: "ellipse" + ej.datavisualization.Diagram.Util.randomId() });
            node.shape.type = ej.datavisualization.Diagram.Shapes.Ellipse;
            node.fillColor = "white";
            node.offsetX = 0;
            node.offsetY = 0;
            node.width = 0;
            node.height = 0;

            return node;
        };
        return EllipseTool;
    })(ej.datavisualization.Diagram.RectangleToolBase);
    ej.datavisualization.Diagram.EllipseTool = function (diagram) {
        return new EllipseTool(diagram);
    };
    //#endregion

    //#region RoundRectTool
    var RoundRectTool = (function (base) {
        ej.datavisualization.Diagram.extend(RoundRectTool, base);
        function RoundRectTool(diagram) {
            base.call(this, "roundRectTool", diagram);
        }
        RoundRectTool.prototype.createNode = function () {
            var node = ej.datavisualization.Diagram.Node({ name: "roundrect" + ej.datavisualization.Diagram.Util.randomId() });
            node.shape.type = ej.datavisualization.Diagram.Shapes.Rectangle;
            node.shape.cornerRadius = 15;
            node.offsetX = 0;
            node.offsetY = 0;
            node.width = 0;
            node.height = 0;

            return node;
        };
        return RoundRectTool;
    })(ej.datavisualization.Diagram.RectangleToolBase);
    ej.datavisualization.Diagram.RoundRectTool = function (diagram) {
        return new RoundRectTool(diagram);
    };
    //#endregion

    //#region TextTool
    var TextTool = (function (base) {
        ej.datavisualization.Diagram.extend(TextTool, base);
        function TextTool(diagram) {
            base.call(this, "textTool", diagram);
        }
        TextTool.prototype.createNode = function (x, y, width, height) {
            var node = ej.datavisualization.Diagram.Node({ name: "text" + ej.datavisualization.Diagram.Util.randomId() });
            node.shape.type = ej.datavisualization.Diagram.Shapes.Text;
            node.shape.textBlock = ej.datavisualization.Diagram.TextBlock();
            node.offsetX = x;
            node.offsetY = y;
            node.width = width;
            node.height = height;
            node.borderColor = "transparent";
            node.fillColor = "transparent";
            return node;
        };
        return TextTool;
    })(ej.datavisualization.Diagram.TextToolBase);
    ej.datavisualization.Diagram.TextTool = function (diagram) {
        return new TextTool(diagram);
    };
    //#endregion

    //#region PolygonTool
    var PolygonTool = (function (base) {
        ej.datavisualization.Diagram.extend(PolygonTool, base);
        function PolygonTool(diagram) {
            base.call(this, "polygonTool", diagram);
        }
        PolygonTool.prototype.createNode = function () {
            var node = ej.datavisualization.Diagram.Node({ name: "polygon" + ej.datavisualization.Diagram.Util.randomId() });
            node.shape.type = ej.datavisualization.Diagram.Shapes.Polygon;
            node.offsetX = 0;
            node.offsetY = 0;
            node.width = 0;
            node.height = 0;
            return node;
        };
        return PolygonTool;
    })(ej.datavisualization.Diagram.PolygonToolBase);
    ej.datavisualization.Diagram.PolygonTool = function (diagram) {
        return new PolygonTool(diagram);
    };;
    //#endregion

    //#region ImageTool
    var ImageTool = (function (base) {
        ej.datavisualization.Diagram.extend(ImageTool, base);
        function ImageTool(saveUrl, removeUrl, uploadfileUrl, autoOpenUpload, diagram) {
            base.call(this, "imageTool", diagram);
            this.saveUrl = saveUrl;
            this.removeUrl = removeUrl;
            this.uploadfileUrl = uploadfileUrl;
            this.autoOpenUpload = autoOpenUpload;
            this.bounds = ej.datavisualization.Diagram.Rectangle(0, 0, 0, 0);
            this.cursor = "crosshair";
        }
        ImageTool.prototype.createNode = function (imageUrl) {
            var node = ej.datavisualization.Diagram.Node();
            node.name = "image" + ej.datavisualization.Diagram.Util.randomId();
            node.shape = ej.datavisualization.Diagram.Shapes.Image(imageUrl);
            node.borderDashArray = "5,5";
            node.offsetX = 0;
            node.offsetY = 0;
            node.width = 0;
            node.height = 0;

            return node;
        };
        ImageTool.prototype.mouseup = function (evt) {
            if (this.inAction)
                this.bounds = this.getBoundingRect(this.snap(this.startPoint), this.snap(this.currentPoint));
            this._renderDialogControl();
            this.diagram._toolToActivate = "selectTool";
            this.diagram._drawingTool = false;
            this._endAction();
        };
        ImageTool.prototype._showPopup = function () {
            this._renderDialogControl();
            this.diagram._toolToActivate = "selectTool";
            this.diagram._drawingTool = false;
            this._endAction();
        };
        ImageTool.prototype._renderDialogControl = function () {
            var dialogDiv = document.createElement("div");
            var attr = {
                "id": "basicDialog",
                "title": "Insert Image",
                "style": "display:none"
            };
            ej.datavisualization.Diagram.Util.attr(dialogDiv, attr);
            document.body.appendChild(dialogDiv);
            var uploadDiv = document.createElement("div");
            attr = {
                "id": "UploadDefault",
                "style": "padding-Left:15px; float:left"
            };
            ej.datavisualization.Diagram.Util.attr(uploadDiv, attr);
            var table = document.createElement("table");
            var tr = document.createElement("tr");
            var td = document.createElement("td");
            attr = {
                "align": "left",
                "style": "padding-Top:10px"
            }
            ej.datavisualization.Diagram.Util.attr(td, attr);
            var childDiv = document.createElement("div");
            childDiv.style.cssFloat = "left";
            var rdoComputer = document.createElement("input");
            attr = {
                "type": "radio",
                "name": "uploadOption",
                "id": "rdoComputer",
                "checked": "true"
            };
            ej.datavisualization.Diagram.Util.attr(rdoComputer, attr);
            rdoComputer.onchange = $.proxy(this._rdoChanged, this);
            childDiv.appendChild(rdoComputer);
            var label = document.createElement("label");
            label.innerHTML = "My Computer";
            label.className = "dialogLabel";
            attr = {
                "style": "font-weight:normal; padding-left:5px; vertical-align: top;"
            }
            ej.datavisualization.Diagram.Util.attr(label, attr);
            label.onclick = $.proxy(this._labelClick, this);
            childDiv.appendChild(label);
            td.style.paddingBottom = "5px";
            td.appendChild(childDiv);
            td.appendChild(uploadDiv);
            var label = document.createElement("label");
            attr = {
                "id": "lblComputerUrl",
                "style": "font-weight:normal;padding-left:10px; vertical-align: top;color:red;"
            };
            ej.datavisualization.Diagram.Util.attr(label, attr);
            td.appendChild(label);
            tr.appendChild(td);
            table.appendChild(tr);
            tr = document.createElement("tr");
            td = document.createElement("td");
            var rdoWebUrl = document.createElement("input");
            attr = {
                "id": "rdoWebUrl",
                "type": "radio",
                "name": "uploadOption"
            };
            ej.datavisualization.Diagram.Util.attr(rdoWebUrl, attr);
            rdoWebUrl.onchange = $.proxy(this._rdoChanged, this);
            td.appendChild(rdoWebUrl);
            var label = document.createElement("label");
            label.innerHTML = "Web URL";
            label.className = "dialogLabel";
            attr = {
                "style": "font-weight:normal; padding-left:5px; vertical-align: top;"
            };
            ej.datavisualization.Diagram.Util.attr(label, attr);
            label.onclick = $.proxy(this._labelClick, this);
            td.appendChild(label);
            var label = document.createElement("label");
            attr = {
                "id": "lblWebUrl",
                "style": "font-weight:normal;padding-left:25px; vertical-align: top;color:red;"
            };
            ej.datavisualization.Diagram.Util.attr(label, attr);
            td.appendChild(label);
            tr.appendChild(td);
            table.appendChild(tr);
            tr = document.createElement("tr");
            td = document.createElement("td");
            attr = {
                "style": "padding-Top:5px;padding-Bottom:15px"
            };
            ej.datavisualization.Diagram.Util.attr(td, attr);
            var txtImageUrl = document.createElement("input");
            attr = {
                "id": "txtImageUrl",
                "type": "text",
                "placeholder": "Image URL",
                "style": "width:460px;height:20px"
            };
            ej.datavisualization.Diagram.Util.attr(txtImageUrl, attr);
            txtImageUrl.onfocus = $.proxy(this._textFocus, this);
            txtImageUrl.onfocusout = $.proxy(this._textFocusOut, this);
            td.appendChild(txtImageUrl);
            tr.appendChild(td);
            table.appendChild(tr);
            tr = document.createElement("tr");
            td = document.createElement("td");
            var btnOk = document.createElement("input");
            attr = {
                "value": "Ok",
                "type": "button",
                "id": "btnOk",
                "style": "width : 100px; height: 30px; margin-Right: 5px; border: 1px solid #F7952E; color : white; font-Family:Segoe UI;font-weight:bold"
            };
            ej.datavisualization.Diagram.Util.attr(btnOk, attr);
            btnOk.onclick = $.proxy(this._uploadClick, this);
            td.appendChild(btnOk);
            var btnCancel = document.createElement("input");
            attr = {
                "value": "Cancel",
                "type": "button",
                "id": "btnCancel",
                "style": "width : 100px; height: 30px; border: 1px solid #DFDFDE; font-Family:Segoe UI;font-weight:bold"
            };
            ej.datavisualization.Diagram.Util.attr(btnCancel, attr);
            btnCancel.onclick = $.proxy(this._closeDialog, this);
            td.appendChild(btnCancel);
            attr = {
                "align": "right"
            };
            ej.datavisualization.Diagram.Util.attr(td, attr);
            tr.appendChild(td);
            table.appendChild(tr);
            dialogDiv.appendChild(table);
            $("#UploadDefault").ejUploadbox({
                saveUrl: this.saveUrl,
                removeUrl: this.removeUrl,
                complete: $.proxy(this.fileuploadComplete, this)
            });
            $("#basicDialog").ejDialog({ height: 230, width: 500, modal: true });
            $("#basicDialog").ejDialog("open");
        };
        ImageTool.prototype.fileuploadComplete = function (e, ui) {
            var fileName = this.uploadfileUrl + "/" + e.files.name;
            this._renderImageNode(fileName);
            this._closeDialog();
        };
        ImageTool.prototype._uploadClick = function () {
            var imageUrl = document.getElementById("txtImageUrl").value;
            if (/^(http:\/\/www\.|https:\/\/www\.)[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(:[0-9]{1,5})?(\/.*)?$/.test(imageUrl)) {
                this._renderImageNode(imageUrl);
                this._closeDialog();
            }
            else {
                if (document.getElementById("rdoComputer").checked === true) {
                    var lblComputerUrl = document.getElementById("lblComputerUrl");
                    var lblWebUrl = document.getElementById("lblWebUrl");
                    lblComputerUrl.innerHTML = "Browse any image to insert";
                    lblWebUrl.innerHTML = "";
                }
                else {
                    var lblComputerUrl = document.getElementById("lblComputerUrl");
                    var lblWebUrl = document.getElementById("lblWebUrl");
                    lblComputerUrl.innerHTML = "";
                    lblWebUrl.innerHTML = "Invalid Url";
                    document.getElementById("txtImageUrl").focus();
                }
            }
        };
        ImageTool.prototype._rdoChanged = function () {
            var lblComputerUrl = document.getElementById("lblComputerUrl");
            var lblWebUrl = document.getElementById("lblWebUrl");
            lblComputerUrl.innerHTML = "";
            lblWebUrl.innerHTML = "";
        };
        ImageTool.prototype._closeDialog = function () {
            $("#basicDialog").ejDialog("close");
            var dialog = document.getElementById("basicDialog");
            dialog.parentNode.removeChild(dialog);
        };
        ImageTool.prototype._labelClick = function (evt) {
            if (evt.target.innerHTML == "My Computer") {
                var radio = document.getElementById("rdoComputer");
                radio.checked = true;
            }
            else {
                var radio = document.getElementById("rdoWebUrl");
                radio.checked = true;
            }
            this._rdoChanged();
        };
        ImageTool.prototype._textFocus = function (evt) {
            var radio = document.getElementById("rdoWebUrl");
            radio.checked = true;
        };
        ImageTool.prototype._renderImageNode = function (fileName) {
            var node = this.createNode(fileName);
            if (this.bounds.size.width != undefined && !ej.datavisualization.Diagram.Geometry.isEmptySize(this.bounds.size)) {
                node.offsetX = this.bounds.offset.x + this.bounds.size.width / 2;
                node.offsetY = this.bounds.offset.y + this.bounds.size.height / 2;
                node.width = this.bounds.size.width;
                node.height = this.bounds.size.height;
            }
            else {
                node.offsetX = 150;
                node.offsetY = 150;
                node.width = 100;
                node.height = 100;
            }
            node.borderDashArray = "";

            this.diagram.model.nodes.push(node);
            ej.datavisualization.Diagram.DiagramContext.renderNode(node, this.diagram);

            this.diagram._clearSelection();
            this.diagram._addSelection(node);
        };
        return ImageTool;
    })(ej.datavisualization.Diagram.RectangleToolBase);
    ej.datavisualization.Diagram.ImageTool = function (saveUrl, removeUrl, uploadfileUrl, autoOpenUpload, diagram) {
        return new ImageTool(saveUrl, removeUrl, uploadfileUrl, autoOpenUpload, diagram);
    };;
    //#endregion

})(jQuery, Syncfusion);;

(function ($, ej) {
    "use strict";
    //#region layout
    ej.datavisualization.Diagram.LayoutTypes = { None: "none", HierarchicalTree: "hierarchicaltree" };
    ej.datavisualization.Diagram.GraphNode = function (node) {
        return { visited: false, children: [], parents: [], distance: 0, node: node, added: false };
    };
    ej.datavisualization.Diagram.Layout = {
        doLayout: function (diagram) {
            if (diagram.model.layout.type === "hierarchicaltree") {
                ej.datavisualization.Diagram.HierarchicalLayout.doLayout(diagram);
            }
        },
    };
    ej.datavisualization.Diagram.HierarchicalLayout = {
        doLayout: function (diagram) {
            var model = diagram.model;
            var layout = {
                passedNodes: [], passedNodesList: [], graph: null, firstRankOrdered: [], fictitiousNodes: [],
                biggestDimensions: [], fX: 0, fY: 0, yBorder: 0, xBorder: 0, visitedNodes: 0, fixedNode: null, diagram: diagram
            };
            layout = $.extend(true, {}, layout, model.layout);
            layout.visitedNodes = 0;
            var fixedPosition = null;
            var fixedNode;
            if (model.nodes.length > 0) {
                while (model.nodes.length > layout.visitedNodes) {
                    this._getNodesToPosition(layout, model.nodes);
                    if (!layout.graph)
                        continue;
                    if (layout.fixedNode) {
                        fixedNode = diagram.nameTable[layout.fixedNode];
                        if (fixedNode) {
                            fixedPosition = ej.datavisualization.Diagram.Point(fixedNode.offsetX, fixedNode.offsetY);
                            layout.fixedNode = fixedNode;
                        }
                    }
                    if (layout.graph) {
                        this._makeLayout(layout, layout.graph);
                    }
                    this._updateOrientation(layout);
                    this._arrangeNodesToLeftMost(layout, fixedPosition);
                }
                var connections = model.connectors;
                for (var i = 0; i < connections.length; i++) {
                    diagram._dock(connections[i], diagram.nameTable);
                }
                if (diagram._pageBackgroundLayer) {
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
            }
        },
        _getNodesToPosition: function (layout, nodes) {
            var node;
            for (var i = 0; i < nodes.length; i++) {
                node = nodes[i];
                if (layout.passedNodes[node.name] == null && !node.excludeFromLayout) {
                    this._selectNodes(layout, node);
                    break;
                }
                else if (node.excludeFromLayout)
                    layout.visitedNodes++;
            }
        },
        _selectNodes: function (layout, node) {
            if (node != null) {
                if (this._addNodeInCollection(layout, node)) {
                    if (this._isConnectedToAnotherNode(layout, node)) {
                        // create the graph and set as Selected
                        layout.graph = { improvePerformance: false, graphNodes: [], typeOrdered: [] };
                        // fill graph
                        this._selectConnectedNodes(layout, node);
                        var typeOrdered = this._setTypeOrdered(layout);
                        layout.graph.typeOrdered = typeOrdered;
                    }
                }
            }
        },
        _addNodeInCollection: function (layout, node) {
            var success = false;
            if (node) {
                if (layout.passedNodes[node.name] == null) {
                    layout.passedNodes[node.name] = node;
                    layout.passedNodesList.push(node);
                    layout.visitedNodes++;
                }
                // Check for node visible
                if (node.visible)
                    success = true;
            }
            return success;
        },
        _isConnectedToAnotherNode: function (layout, node) {
            var bFoundConnectedNode = false;
            if (node.inEdges && node.inEdges.length > 0)
                bFoundConnectedNode = this._searchEdgeCollection(layout, node.inEdges, "fromNode");
            if (!bFoundConnectedNode && node.outEdges && node.outEdges.length > 0)
                bFoundConnectedNode = this._searchEdgeCollection(layout, node.outEdges, "toNode");
            return bFoundConnectedNode;
        },
        _searchEdgeCollection: function (layout, edges, connectionDirection) {
            var foundConnectedNode = false;
            var diagram = layout.diagram;
            var edge;
            var fromNode, toNode;
            for (var i = 0; i < edges.length; i++) {
                edge = diagram._findNode(edges[i]);
                if (!this._addNodeInCollection(layout, edge))
                    continue;
                fromNode = diagram._findNode(edge.sourceNode);
                toNode = diagram._findNode(edge.targetNode);
                if ((connectionDirection == "fromNode" && fromNode != null && !fromNode.excludeFromLayout)
                        || (connectionDirection == "toNode" && toNode != null && !toNode.excludeFromLayout)) {
                    foundConnectedNode = true;
                    break;
                }
            }
            return foundConnectedNode;
        },
        _selectConnectedNodes: function (layout, node) {
            var graph = layout.graph;
            var graphNode;
            if (graph) {
                if (node && this._addNodeInCollection(layout, node)) {
                    var nodeName = node.name;
                    if (graph.graphNodes[nodeName] == null) {
                        graphNode = this._addGraphNode(layout, node);
                        this._getConnectedRelatives(layout, graphNode);
                        this._exploreRelative(layout, node);
                    }
                    else {
                        graphNode = graph.graphNodes[nodeName];
                        if (graphNode.added) {
                            graphNode.added = false;
                            this._getConnectedRelatives(layout, graphNode);
                            this._exploreRelative(layout, node);
                        }
                    }
                }
            }
        },
        _addGraphNode: function (layout, node) {
            var graph = layout.graph;
            var graphNode = ej.datavisualization.Diagram.GraphNode(node);
            if (graph != null) {
                graph.graphNodes[node.name] = graphNode;
            }
            return graphNode;
        },
        _getConnectedRelatives: function (layout, graphNode) {
            this._getConnectedParents(layout, graphNode);
            this._getConnectedChildren(layout, graphNode);
        },
        _getConnectedParents: function (layout, graphNode) {
            var graph = layout.graph;
            var edge, gNode, sourceNode;
            var diagram = layout.diagram;
            if (graph) {
                var node = graphNode.node;
                for (var i = 0; i < node.inEdges.length; i++) {
                    edge = diagram._findNode(node.inEdges[i]);
                    sourceNode = diagram._findNode(edge.sourceNode);
                    if (sourceNode && !sourceNode.excludeFromLayout && sourceNode.visible) {
                        if (graph.graphNodes[sourceNode.name] == null) {
                            gNode = this._addGraphNode(layout, sourceNode);
                            gNode.added = true;
                        }
                        else {
                            gNode = graph.graphNodes[sourceNode.name];
                        }
                        // set Reference to child node
                        this._setNode(gNode.children, graphNode);
                        // add new node as parent to child node
                        if (this._findNode(graphNode.parents, gNode.node.name) < 0)
                            graphNode.parents.push(gNode);
                    }
                }
            }
        },
        _getConnectedChildren: function (layout, graphNode) {
            var graph = layout.graph;
            var edge, targetNode, gNode;
            var diagram = layout.diagram;
            if (graph != null) {
                var node = graphNode.node;
                for (var i = 0; i < node.outEdges.length; i++) {
                    edge = diagram._findNode(node.outEdges[i]);
                    targetNode = diagram._findNode(edge.targetNode);
                    if (targetNode && !targetNode.excludeFromLayout && targetNode.visible) {
                        if (graph.graphNodes[targetNode.name] == null) {
                            gNode = this._addGraphNode(layout, targetNode);
                            gNode.added = true;
                        }
                        else {
                            gNode = graph.graphNodes[targetNode.name];
                        }
                        // set Reference to parent node
                        this._setNode(gNode.parents, graphNode);
                        // add new node as child to parent node
                        if (this._findNode(graphNode.children, gNode.node.name) < 0)
                            graphNode.children.push(gNode);
                    }
                }
            }
        },
        _findNode: function (list, name) {
            var index = -1;
            var node;
            if (list != null && name != "") {
                for (var i = 0, nLength = list.length; i < nLength; i++) {
                    node = list[i].node;
                    if (node && node.name == name) {
                        index = i;
                        break;
                    }
                }
            }
            return index;
        },
        _setNode: function (list, graphNode) {
            var i = this._findNode(list, graphNode.node.name);
            if (i >= 0 && i < list.length) {
                list[i] = graphNode;
            }
            else {
                list.push(graphNode);
            }
        },
        _exploreRelative: function (layout, node) {
            this._exploreRelatives(layout, node, "parents");
            this._exploreRelatives(layout, node, "children");
        },
        _exploreRelatives: function (layout, node, relation) {
            var edges, edge;
            var fromNode, toNode;
            var diagram = layout.diagram;
            if (relation == "parents") {
                edges = node.inEdges;
            }
            if (relation == "children") {
                edges = node.outEdges;
            }
            if (edges) {
                for (var i = 0; i < edges.length; i++) {
                    edge = diagram._findNode(edges[i]);
                    if (this._addNodeInCollection(layout, edge)) {
                        fromNode = diagram._findNode(edge.sourceNode);
                        toNode = diagram._findNode(edge.targetNode);
                        if (relation == "parents" && fromNode != null && !fromNode.excludeFromLayout) {
                            this._selectConnectedNodes(layout, fromNode);
                        } else if (relation == "children" && toNode != null && !toNode.excludeFromLayout) {
                            this._selectConnectedNodes(layout, toNode);
                        }
                    }
                }
            }
        },
        _setTypeOrdered: function (layout) {
            var graphNodes = layout.graph.graphNodes;
            var gNode;
            var noneDirected = true;
            // search for node without parents.
            for (var name in graphNodes) {
                gNode = graphNodes[name];
                if (gNode && gNode.parents) {
                    if (gNode.parents.length == 0)
                        noneDirected = false;
                    if (gNode.parents.length > 1) {
                        if (!noneDirected)
                            break;
                    }
                }
            }
            // 1 - sort nodes by y positions
            this._rankGraphNodeInitialization(layout);
            if (layout.firstRankOrdered.length > 0) {
                // 2 -  add fictitious nodes
                this._addFictitiousNodes(layout);
                // 3 - optimize graph. Remove intercetion.
                if (!layout.graph.improvePerformance) {
                    this._optimizeGraph(layout);
                }
                // 4 Sort relatives to rank order
                // SortRelatives();
                // 6 - check for dimetions
                this._checkRankDimensions(layout);
            }
            return layout.firstRankOrdered;
        },
        _rankGraphNodeInitialization: function (layout) {
            var topNode = this._getGraphFirstTopNode(layout);
            this._rankGraphNodes(layout, topNode, 0);
            // remove emptyLevels
            var lstEmpty = [];
            var i, list;
            for (i = 0; i < layout.firstRankOrdered.length; i++) {
                list = layout.firstRankOrdered[i];
                if (list.length == 0)
                    lstEmpty.push(list);
            }
            for (i = 0; i < lstEmpty.length; i++) {
                list = lstEmpty[i];
                ej.datavisualization.Diagram.Util.removeItem(layout.firstRankOrdered, list);
            }
        },
        _getGraphFirstTopNode: function (layout) {
            var gNode;
            var graphNodes = layout.graph.graphNodes;
            for (var name in graphNodes) {
                gNode = graphNodes[name];
                if (gNode.parents && gNode.parents.length == 0) {
                    return gNode;
                }
            }
            return null;
        },
        _rankGraphNodes: function (layout, graphNode, rank) {
            if (graphNode) {
                var nodeRank = this._getGraphNodeRank(layout, graphNode);
                // if node is exist in rank list
                if (nodeRank >= 0) {
                    // if him level right then return current rank
                    if (this._checkRankPosition(layout, graphNode, nodeRank)
                            || rank === nodeRank) {
                        return rank;
                    }
                    // else remove this node from his rankLevel list
                    var lstRank = layout.firstRankOrdered[nodeRank];
                    ej.datavisualization.Diagram.Util.removeItem(lstRank, graphNode);
                }
                // add and get current node rank
                rank = this._addNodeInTypeOrederd(layout, graphNode, rank);
                var i;
                for (i = 0; i < graphNode.children.length; i++) {
                    var gnChild = graphNode.children[i];
                    this._rankGraphNodes(layout, gnChild, rank + 1);
                }
                if (!layout.graph.improvePerformance) {
                    for (i = 0; i < graphNode.parents.length; i++) {
                        var gnParent = graphNode.parents[i];
                        this._rankGraphNodes(layout, gnParent, rank - 1);
                    }
                }
            }
            return rank;
        },
        _getGraphNodeRank: function (layout, graphNode) {
            var rank = -1;
            var success = false;
            var firstRank, nextRank;
            for (var i = 0; i < layout.firstRankOrdered.length; i++) {
                firstRank = layout.firstRankOrdered[i];
                if (success)
                    break;
                for (var j = 0; j < firstRank.length; j++) {
                    nextRank = firstRank[j];
                    if (nextRank.node.name == graphNode.node.name) {
                        rank = layout.firstRankOrdered.indexOf(firstRank);
                        success = true;
                        break;
                    }
                }
            }
            return rank;
        },
        _checkRankPosition: function (layout, graphNode, nodeRank) {
            var rank;
            var correctPosition = true;
            var maxParentIndex = Number.MIN_VALUE;
            var parentRank, childRank, i;
            var minChildrenIndex = Number.MAX_VALUE;
            var parent, child;
            for (i = 0; i < graphNode.parents.length; i++) {
                parent = graphNode.parents[i];
                parentRank = this._getGraphNodeRank(layout, parent);
                if (parentRank < 0)
                    parentRank = 0;
                maxParentIndex = Math.max(maxParentIndex, parentRank);
            }
            for (i = 0; i < graphNode.children.length; i++) {
                child = graphNode.children[i];
                childRank = this._getGraphNodeRank(layout, child);
                minChildrenIndex = Math.min(minChildrenIndex, childRank);
            }
            if (maxParentIndex != Number.MIN_VALUE) {
                rank = maxParentIndex + 1;
                correctPosition = (nodeRank >= rank);
            }
            else if (minChildrenIndex != Number.MAX_VALUE && minChildrenIndex != 0) {
                rank = minChildrenIndex - 1;
                correctPosition = (nodeRank == rank);
            }
            return correctPosition;
        },
        _addNodeInTypeOrederd: function (layout, graphNode, rank) {
            var length = layout.firstRankOrdered.length;
            while (rank < 0) {
                layout.firstRankOrdered.splice(0, 0, []);
                rank++;
            }
            while (rank >= length) {
                layout.firstRankOrdered.push([]);
                length++;
            }
            var lstRank = layout.firstRankOrdered[rank];
            lstRank.push(graphNode);
            return rank;
        },
        _addFictitiousNodes: function (layout) {
            var parentsRank, childrenRank, graphNode, child, children;
            var parent, parentIndex, childIndex;
            var randOrdered = layout.firstRankOrdered;
            for (var level = 0, len = randOrdered.length - 1; level < len; level++) {
                parentsRank = randOrdered[level];
                childrenRank = randOrdered[level + 1];
                for (var index = 0; index < parentsRank.length; index++) {
                    parent = parentsRank[index];
                    children = parent.children;
                    for (var i = 0, nLength = children.length; i < nLength; i++) {
                        child = children[i];
                        // if child rank don't contains node child then add fictition node
                        if (childrenRank.indexOf(child) == -1) {
                            graphNode = ej.datavisualization.Diagram.GraphNode(null);
                            childIndex = parent.children.indexOf(child);
                            parentIndex = child.parents.indexOf(parent);
                            // parent change Reference to child
                            parent.children[childIndex] = graphNode;
                            // child change reference to parent
                            child.parents[parentIndex] = graphNode;
                            // Ficted node set new  parent and child
                            graphNode.parents.push(parent);
                            graphNode.children.push(child);
                            childrenRank.push(graphNode);
                            // add node to storage list
                            layout.fictitiousNodes.push(graphNode);
                        }
                    }
                }
            }
        },
        _optimizeGraph: function (layout) {
            var beforeIterceptionCount = this._getInterceptionCount(layout);
            var alwaysIterceptionCount = this._getAlwaysInterceptionCount(layout);
            var orderedClone = this._getListOrderedClone(layout);
            // optimize by sort nodes in list
            if (alwaysIterceptionCount < beforeIterceptionCount) {
                this._sortRankNodes(layout);
            }
            this._optimizeTopRank(layout);
            var interceptions = this._getInterception(layout);
            var afterIterceptionCount = interceptions.length;
            if (afterIterceptionCount < beforeIterceptionCount) {
                orderedClone = this._getListOrderedClone(layout);
                beforeIterceptionCount = afterIterceptionCount;
            }
            if (alwaysIterceptionCount < beforeIterceptionCount) {
                this._removeInterceptions(interceptions);
            }
            // get current interceptions
            afterIterceptionCount = this._getInterceptionCount(layout);
            // if interception increase then roll back last ordered
            if (afterIterceptionCount > beforeIterceptionCount)
                layout.firstRankOrdered = orderedClone;
        },
        _getInterceptionCount: function (layout) {
            return this._getInterception(layout).length;
        },
        _getInterception: function (layout) {
            var interceptions = [];
            var parents;
            var children;
            var curIndex = -1, index = -1, parentIndex = -1;
            var leftChild, rightChild;
            var rightParent, leftParent;
            var interception, success = true;
            for (var i = 0, nLength = layout.firstRankOrdered.length - 1; i < nLength; i++) {
                parents = layout.firstRankOrdered[i];
                children = layout.firstRankOrdered[i + 1];
                for (var leftChildIndex = 0; leftChildIndex < children.length; leftChildIndex++) {
                    leftChild = children[leftChildIndex];
                    curIndex = children.indexOf(leftChild);
                    for (var rightParentIndex = 0; rightParentIndex < leftChild.parents.length; rightParentIndex++) {
                        rightParent = leftChild.parents[rightParentIndex];
                        index = parents.indexOf(rightParent);
                        for (var rightChildIndex = 0; rightChildIndex < children.length; rightChildIndex++) {
                            rightChild = children[rightChildIndex];
                            if (leftChild == rightChild || curIndex >= children.indexOf(rightChild))
                                continue;
                            for (var leftParentIndex = 0; leftParentIndex < rightChild.parents.length; leftParentIndex++) {
                                leftParent = rightChild.parents[leftParentIndex];
                                parentIndex = parents.indexOf(leftParent);
                                if (parentIndex >= 0 && index >= 0 && parentIndex < index) {
                                    for (var interceptionIndex = 0; interceptionIndex < interceptions.length; interceptionIndex++) {
                                        interception = interceptions[interceptionIndex];
                                        if ((interception.leftParent == leftParent && interception.rightParent == rightParent
                                                && interception.leftChild == leftChild && interception.rightChild == rightChild)
                                                || (interception.leftParent == rightParent && interception.rightParent == leftParent
                                                && interception.leftChild == rightChild && interception.rightChild == leftChild)) {
                                            success = false;
                                            break;
                                        }
                                    }
                                    if (success)
                                        interceptions.push(this._interception(leftParent, rightChild, rightParent, leftChild));
                                }
                            }
                        }
                    }
                }
            }
            return interceptions;
        },
        _interception: function (leftParent, rightChild, rightParent, leftChild) {
            var interception = { leftChild: leftChild, leftParent: leftParent, rightChild: rightChild, rightParent: rightParent, canFixed: false };
            var success = this._xCrossCondition(interception);
            if (!success)
                success = !this._parentParentCondition(interception);
            interception.canFixed = !success;
            return interception;
        },
        _xCrossCondition: function (interception) {
            var lparents = interception.leftChild.parents;
            var rparents = interception.rightChild.parents;

            return (lparents.indexOf(interception.leftParent) != -1 && rparents.indexOf(interception.rightParent) != -1);
        },
        _parentParentCondition: function (interception) {
            var bSuccess = false;
            if (interception.leftParent.parents.length == 1 && interception.rightParent.parents.length == 1) {
                bSuccess = (interception.leftParent.parents[0] == interception.rightParent.parents[0]);
            }
            return bSuccess;
        },
        _getAlwaysInterceptionCount: function (layout) {
            var crossCount = 0;
            var xCrossCount = 0;
            var crossedNodes = [];
            var parents = [], children = [];
            var parentsRank, childrenRank;
            var parent, rightParent, leftParent;
            var child, leftChild, rightChild;
            var i, length;
            for (var n = 0, len = layout.firstRankOrdered.length - 1; n < len; n++) {
                parentsRank = layout.firstRankOrdered[n];
                childrenRank = layout.firstRankOrdered[n + 1];
                for (i = 0, length = parentsRank.length; i < length; i++) {
                    parent = parentsRank[i];
                    parents.push(parent);
                    for (var lCIndex = 0; lCIndex < parent.children.length; lCIndex++) {
                        leftChild = parent.children[lCIndex];
                        if (childrenRank.indexOf(leftChild) == -1)
                            continue;
                        for (var rPIndex = 0; rPIndex < leftChild.parents.length; rPIndex++) {
                            rightParent = leftChild.parents[rPIndex];
                            if (rightParent != parent && parents.indexOf(rightParent) == -1) {
                                for (var rCIndex = 0; rCIndex < rightParent.children.length; rCIndex++) {
                                    rightChild = rightParent.children[rCIndex];
                                    if (childrenRank.indexOf(rightChild) == -1)
                                        continue;
                                    if (rightChild != leftChild) {
                                        for (var lPIndex = 0; lPIndex < rightChild.parents.length; lPIndex++) {
                                            leftParent = rightChild.parents[lPIndex];
                                            if (leftParent == parent) {
                                                xCrossCount++;
                                                crossedNodes.push(leftParent);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                for (i = 0, length = childrenRank.length; i < length; i++) {
                    child = childrenRank[i];
                    for (var index = 0; index < child.parents.length; index++) {
                        parent = child.parents[index];
                        if (crossedNodes.indexOf(parent) != -1) {
                            ej.datavisualization.Diagram.Util.clear(children);
                            break;
                        }
                        var nCount = parent.children.length;
                        if (nCount > 1)
                            children.push(nCount);
                    }
                    if (children.length > 2) {
                        var counts = children;
                        for (var k = 0, count = counts.length - 2; k < count; k++)
                            crossCount += counts[k] - 1;
                    }
                    children = [];
                }
            }
            crossCount += xCrossCount / 2;
            return crossCount;
        },
        _getListOrderedClone: function (layout) {
            var clone = [], list;
            for (var i = 0; i < layout.firstRankOrdered.length; i++) {
                list = layout.firstRankOrdered[i];
                clone.push($.extend({}, $.extend(list)[0]));
            }
            return clone;
        },
        _sortRankNodes: function (layout) {
            var parentsRank, childrenRank;
            for (var i = 0, nLength = layout.firstRankOrdered.length - 1; i < nLength; i++) {
                parentsRank = layout.firstRankOrdered[i];
                childrenRank = layout.firstRankOrdered[i + 1];
                if (i == 0) {
                    layout.firstRankOrdered[i + 1] = this._sortChildrenRankNodes(parentsRank, childrenRank);
                    childrenRank = layout.firstRankOrdered[i + 1];
                    layout.firstRankOrdered[i] = this.sortParentRankNodes(parentsRank, childrenRank);
                    parentsRank = layout.firstRankOrdered[i];
                    this._optimizeTopRank(layout);
                }
                layout.firstRankOrdered[i + 1] = this._sortChildrenRankNodes(parentsRank, childrenRank);
            }
        },
        _sortChildrenRankNodes: function (lstParentsRankList, lstChildrenRankList) {
            var arrChildrenRankList = lstChildrenRankList;
            var nLength = arrChildrenRankList.length;
            var arrChildCount = [];
            var arrPosition = [];
            var i, gnChild;
            for (i = 0; i < nLength; i++) {
                gnChild = lstChildrenRankList[i];
                arrChildCount[i] = gnChild.parents.length;
            }
            Array.sort(arrChildCount, arrChildrenRankList);
            var dIndex, dParentIndex, dMoveNode, dPalceNode;
            var nParentCount, nChildrenCount;
            for (i = 0; i < nLength; i++) {
                gnChild = arrChildrenRankList[i];
                nParentCount = lstParentsRankList.length;
                nChildrenCount = lstChildrenRankList.length;
                if (nChildrenCount > 0 && nParentCount > 0) {
                    dParentIndex = this._getCentralNode(gnChild.parents, lstParentsRankList);
                    dIndex = this._getParentIndexInChildList(dParentIndex, nChildrenCount, nParentCount);
                    dMoveNode = this._compareChilds(gnChild, lstParentsRankList);
                    dPalceNode = this._compareChilds(arrChildrenRankList[dIndex], lstParentsRankList);
                    // move left or right by remove interceptions
                    if (dMoveNode > 0 && dPalceNode < 0)
                        dIndex++;
                    arrPosition[i] = dIndex;
                }
            }
            Array.sort(arrPosition, arrChildrenRankList);
            // return lstNewRankList;
            return new Array(arrChildrenRankList);
        },
        _optimizeTopRank: function (layout) {
            if (layout.firstRankOrdered.length > 0) {
                var lstRank = layout.firstRankOrdered[0];
                var lstRankCheck = lstRank;
                var gnNode, gnChild, centerIndex;
                for (var i = 0; i < lstRankCheck.length; i++) {
                    gnNode = lstRankCheck[i];
                    if (gnNode.parents.length == 0 && gnNode.children.length == 1) {
                        gnChild = gnNode.children[0];
                        // place node in center of children parents
                        centerIndex = this._getCentralNode(gnChild.parents, lstRank);
                        this._moveNode(lstRank, gnNode, centerIndex);
                    }
                }
            }
        },
        _moveNode: function (list, gnNode, nIndex) {
            var nCurIndex = list.indexOf(gnNode);
            if (nCurIndex != nIndex) {
                if (nIndex > nCurIndex)
                    nIndex--;
                if (nIndex >= 0) {
                    ej.datavisualization.Diagram.Util.removeItem(list, gnNode);
                    list.splice(nIndex, 0, gnNode);
                }
                else if (nIndex == list.Count) {
                    list.push(gnNode);
                }
            }
        },
        _getCentralNode: function (lstRealtive, lstRankList) {
            var dToReturn = 0;
            var dIndex = 0;
            var gnNode, index;
            for (var gnNodeindex = 0; gnNodeindex < lstRealtive.length; gnNodeindex++) {
                gnNode = lstRealtive[gnNodeindex];
                index = lstRankList.indexOf(gnNode);
                if (index >= 0) {
                    dIndex += index + 0.5;
                }
            }
            if (lstRealtive.length > 0) {
                dToReturn = dIndex / lstRealtive.length;
            }
            return dToReturn;
        },
        _checkRankDimensions: function (layout) {
            var lstRank, nodeToCompare;
            for (var nRankCounter = 0; nRankCounter < layout.firstRankOrdered.length; nRankCounter++) {
                lstRank = layout.firstRankOrdered[nRankCounter];
                for (var nCounter = 0; nCounter < lstRank.length; nCounter++) {
                    nodeToCompare = lstRank[nCounter];
                    this._checkDimensions(layout, nodeToCompare.node, nRankCounter);
                }
            }
        },
        _checkDimensions: function (layout, nodeToCompare, nRank) {
            var nLength = layout.biggestDimensions.length;
            var szRankBiggestDimension;
            if (nLength > nRank && nRank >= 0) {
                szRankBiggestDimension = layout.biggestDimensions[nRank];
                if (this._isCurrentNodeDimensionBigger(szRankBiggestDimension, nodeToCompare, "width"))
                    this._update(szRankBiggestDimension, nodeToCompare, "width");
                if (this._isCurrentNodeDimensionBigger(szRankBiggestDimension, nodeToCompare, "height"))
                    this._update(szRankBiggestDimension, nodeToCompare, "height");
            }
            else {
                while (nRank >= nLength) {
                    layout.biggestDimensions.push(ej.datavisualization.Diagram.Size());
                    nLength++;
                }
                while (nRank < 0) {
                    layout.biggestDimensions.splice(0, 0, ej.datavisualization.Diagram.Size());
                    nRank++;
                }
                szRankBiggestDimension = ej.datavisualization.Diagram.Size();
                szRankBiggestDimension.width = nodeToCompare.width;
                szRankBiggestDimension.height = nodeToCompare.height;
            }
            layout.biggestDimensions[nRank] = szRankBiggestDimension;
        },
        _isCurrentNodeDimensionBigger: function (szRankBiggestDimension, boundsNode, dimension) {
            var bIsCurrentNodeDimensionBigger = false;
            switch (dimension) {
                case "width":
                    if (boundsNode.width > szRankBiggestDimension.width)
                        bIsCurrentNodeDimensionBigger = true;
                    break;
                case "height":
                    if (boundsNode.height > szRankBiggestDimension.height)
                        bIsCurrentNodeDimensionBigger = true;

                    break;
            }
            return bIsCurrentNodeDimensionBigger;
        },
        _update: function (szDimensionToUpdate, node, dimension) {
            switch (dimension) {
                case "width":
                    szDimensionToUpdate.width = node.width;
                    break;
                case "height":
                    szDimensionToUpdate.height = node.height;
                    break;
            }
        },
        _makeLayout: function (layout, graph) {
            this._doInitXLayout(layout, graph);
            this._placeParentsRelativeToChildren(layout, graph.typeOrdered);
        },
        _doInitXLayout: function (layout, graphToSort) {
            var lstToSort = graphToSort.typeOrdered;
            var counter = 0;
            var lstSort;
            for (var lstSortIndex = 0; lstSortIndex < lstToSort.length; lstSortIndex++) {
                lstSort = lstToSort[lstSortIndex];
                this._makeLayoutByRank(layout, lstSort, counter, graphToSort);
                counter++;
            }
        },
        _makeLayoutByRank: function (layout, lstRank, nRank, graph) {
            var i, graphNode;
            if (layout.orientation == "toptobottom" || layout.orientation == "bottomtotop") {
                layout.fX = 0;
                for (i = 0; i < lstRank.length; i++) {
                    graphNode = lstRank[i];
                    if (graphNode != null)
                        this._xCoordinateRoutine(layout, graphNode, layout.fX);
                }
                // ============== Y Coordinate Routine ================
                var fYRank = this._calcRankPositionVerticalLayout(layout, nRank, graph);
                this._yCoordinateRoutine(lstRank, fYRank);
            }
            else {
                layout.fY = 0;
                for (i = 0; i < lstRank.length; i++) {
                    graphNode = lstRank[i];
                    if (graphNode != null) {
                        graphNode.node.offsetY = layout.fY + graphNode.node.height / 2;
                        layout.fY = graphNode.node.offsetY + graphNode.node.height / 2 + layout.horizontalSpacing;
                    }
                }
                // ============== X Coordinate Routine ================
                var fXRank = this._calcRankPositionHorizontalLayout(layout, nRank, graph);
                this._xCoordinateRoutineforhLayouts(lstRank, fXRank);
            }
        },
        _xCoordinateRoutine: function (layout, graphNode) {
            graphNode.node.offsetX = layout.fX + graphNode.node.width / 2;
            layout.fX += graphNode.node.width / 2 + layout.horizontalSpacing;
        },
        _yCoordinateRoutine: function (lstRank, fYRank) {
            var graphNode;
            for (var i = 0; i < lstRank.length; i++) {
                graphNode = lstRank[i];
                graphNode.node.offsetY = fYRank + graphNode.node.height / 2;
            }
        },
        _xCoordinateRoutineforhLayouts: function (lstRank, fXRank) {
            var graphNode;
            for (var i = 0; i < lstRank.length; i++) {
                graphNode = lstRank[i];
                graphNode.node.offsetX = fXRank + graphNode.node.width / 2;
            }
        },
        _calcRankPositionHorizontalLayout: function (layout, nRank) {
            var fRankPositionToReturn;
            if (nRank == 0)
                fRankPositionToReturn = 0;
            else {
                var fGraphHeightTillCurrentRank = this._getSubGraphDimension(layout, 0, nRank, "width");
                fRankPositionToReturn = fGraphHeightTillCurrentRank;
            }
            return fRankPositionToReturn + layout.xBorder;
        },
        _getSubGraphDimension: function (layout, nFromRank, nToRank, dimension) {
            var fGraphDimensionToReturn = 0;
            var nCounter = nFromRank;
            var nIncrease = 1;
            if (nFromRank > nToRank)
                nIncrease = -nIncrease;
            var szRankBiggestDimensions;
            if (layout.orientation == "toptobottom" || layout.orientation == "bottomtotop") {
                while (nCounter != nToRank) {
                    szRankBiggestDimensions = layout.biggestDimensions[nCounter];
                    switch (dimension) {
                        case "height":
                            fGraphDimensionToReturn += szRankBiggestDimensions.height;
                            fGraphDimensionToReturn += layout.verticalSpacing;
                            break;
                        case "width":
                            fGraphDimensionToReturn += szRankBiggestDimensions.width;
                            fGraphDimensionToReturn += layout.horizontalSpacing;
                            break;
                    }
                    nCounter += nIncrease;
                }
            } else {
                while (nCounter != nToRank) {
                    szRankBiggestDimensions = layout.biggestDimensions[nCounter];
                    switch (dimension) {
                        case "height":
                            fGraphDimensionToReturn += szRankBiggestDimensions.height;
                            fGraphDimensionToReturn += layout.horizontalSpacing;
                            break;
                        case "width":
                            fGraphDimensionToReturn += szRankBiggestDimensions.width;
                            fGraphDimensionToReturn += layout.verticalSpacing;
                            break;
                    }
                    nCounter += nIncrease;
                }
            }
            return fGraphDimensionToReturn;
        },
        _calcRankPositionVerticalLayout: function (layout, nRank) {
            var fRankPositionToReturn;
            if (nRank == 0)
                fRankPositionToReturn = 0;
            else {
                var fGraphHeightTillCurrentRank = this._getSubGraphDimension(layout, 0, nRank, "height");
                fRankPositionToReturn = fGraphHeightTillCurrentRank;
            }
            return fRankPositionToReturn + layout.yBorder;
        },
        _placeParentsRelativeToChildren: function (layout, lstToSort) {
            var list, i, j, k;
            if (lstToSort.length > 1) {
                for (i = lstToSort.length - 2; i >= 0; i--) {
                    list = lstToSort[i + 1];
                    this._placeRelativeToChildren(layout, list);
                    this._normalizeNodes(layout, lstToSort[i]);
                    j = i + 1;
                    while (j <= lstToSort.length - 1) {
                        k = j;
                        while (k >= i) {
                            this._normalizeNodes(layout, lstToSort[k]);
                            this._placeRelativeToChildren(layout, lstToSort[k]);
                            k--;
                        }
                        j++;
                    }
                }
            }
        },
        _placeRelativeToChildren: function (layout, lstRelatives) {
            var fLeftChildPosition;
            var fRightChildPosition;
            var lstParents = [];
            var node, parent, lstChildren, nodeLeft, nodeRight;
            var parentIndex, nodeTop, nodeBottom;
            for (var nodeIndex = 0; nodeIndex < lstRelatives.length; nodeIndex++) {
                node = lstRelatives[nodeIndex];
                for (parentIndex = 0; parentIndex < node.parents.length; parentIndex++) {
                    parent = node.parents[parentIndex];
                    if (lstParents.indexOf(parent) == -1)
                        lstParents.push(parent);
                }
            }
            if (layout.orientation == "toptobottom" || layout.orientation == "bottomtotop") {
                for (parentIndex = 0; parentIndex < lstParents.length; parentIndex++) {
                    parent = lstParents[parentIndex];
                    lstChildren = parent.children;
                    if (lstChildren.length > 0) {
                        nodeLeft = lstChildren[0].node;
                        nodeRight = lstChildren[lstChildren.length - 1].node;
                        fLeftChildPosition = nodeLeft.offsetX - nodeLeft.width / 2;
                        fRightChildPosition = nodeRight.offsetX + nodeRight.width / 2;
                        parent.node.offsetX = fLeftChildPosition + ((fRightChildPosition - fLeftChildPosition) / 2);
                    }
                }
            }
            else {
                for (parentIndex = 0; parentIndex < lstParents.length; parentIndex++) {
                    parent = lstParents[parentIndex];
                    lstChildren = parent.children;
                    if (lstChildren.length > 0) {
                        nodeTop = lstChildren[0].node;
                        nodeBottom = lstChildren[lstChildren.length - 1].node;
                        fLeftChildPosition = nodeTop.offsetY - nodeTop.height / 2;
                        fRightChildPosition = nodeBottom.offsetY + nodeBottom.height / 2;
                        parent.node.offsetY = fLeftChildPosition + ((fRightChildPosition - fLeftChildPosition) / 2);
                    }
                }
            }
            //this._normalizeNodes(layout, layoutlstRelatives);
        },
        _normalizeNodes: function (layout, list) {
            var bSuccess = false, i;
            var nodeBound, node, nodeNext, fOffset;
            if (layout.orientation == "toptobottom" || layout.orientation == "bottomtotop") {
                for (i = 0; i < list.length - 1; i++) {
                    node = list[i].node;
                    nodeNext = list[i + 1].node;
                    nodeBound = node.offsetX + node.width / 2 + layout.horizontalSpacing;
                    if (nodeBound > (nodeNext.offsetX - nodeNext.width / 2)) {
                        fOffset = nodeBound + nodeNext.width / 2 - nodeNext.offsetX;
                        nodeNext.offsetX = nodeBound + nodeNext.width / 2;
                        bSuccess = true;
                        this._moveChildren(layout, list[i + 1], fOffset);
                    }
                }
            }
            else {
                for (i = 0; i < list.length - 1; i++) {
                    node = list[i].node;
                    nodeNext = list[i + 1].node;
                    nodeBound = node.offsetY + node.height / 2 + layout.horizontalSpacing;
                    if (nodeBound > (nodeNext.offsetY - nodeNext.height / 2)) {
                        fOffset = nodeBound + nodeNext.height / 2 - nodeNext.offsetY;
                        nodeNext.offsetY = nodeBound + nodeNext.height / 2;
                        bSuccess = true;
                        this._moveChildrenVertically(layout, list[i + 1], fOffset);
                    }
                }
            }
            return bSuccess;
        },
        _moveChildren: function (layout, nodeNext, fOffset) {
            // Move children
            var gnChild;
            if (!nodeNext.line) {
                for (var gnChildIndex = 0; gnChildIndex < nodeNext.children.length; gnChildIndex++) {
                    gnChild = nodeNext.children[gnChildIndex];
                    gnChild.node.offsetX += fOffset;
                    this._moveChildren(layout, gnChild, fOffset);
                }
            }
        },
        _moveChildrenVertically: function (layout, nodeNext, fOffset) {
            // Move children
            var gnChild;
            if (!nodeNext.line) {
                for (var gnChildIndex = 0; gnChildIndex < nodeNext.children.length; gnChildIndex++) {
                    gnChild = nodeNext.children[gnChildIndex];
                    gnChild.node.offsetY += fOffset;
                    this._moveChildrenVertically(layout, gnChild, fOffset);
                }
            }
        },
        _updateOrientation: function (layout) {
            if (layout.orientation != "toptobottom" || layout.orientation != "lefttoright") {
                var nodes = layout.diagram.model.nodes, node;
                //var tempX, tempY;
                //var minXNode = this._getMinXNode(nodes);
                var maxXNode = this._getMaxXNode(nodes);
                //var minYNode = this._getMinYNode(nodes);
                var maxYNode = this._getMaxYNode(nodes);
                //var minX = minXNode.offsetX;
                var maxX = maxXNode.offsetX;
                //var minY = minYNode.offsetY;
                var maxY = maxYNode.offsetY;
                var i;
                if (layout.orientation == "bottomtotop") {
                    for (i = 0; i < nodes.length; i++) {
                        node = nodes[i];
                        if (!node.excludeFromLayout) {
                            node.offsetX = maxX - node.offsetX;
                            node.offsetY = maxY - node.offsetY;
                        }
                    }
                }
                else if (layout.orientation == "righttoleft") {
                    for (i = 0; i < nodes.length; i++) {
                        node = nodes[i];
                        if (!node.excludeFromLayout) {
                            node.offsetX = maxX - node.offsetX;
                            node.offsetY = maxY - node.offsetY;
                        }
                    }
                }
                //}
            }
        },
        _getMaxXNode: function (nodes) {
            var maxX = nodes[0].offsetX, node, index = 0;
            for (var i = 0; i < nodes.length; i++) {
                node = nodes[i];
                if (!node.excludeFromLayout) {
                    if (node.offsetX > maxX) {
                        maxX = node.offsetX;
                        index = i;
                    }
                }
            }
            return nodes[index];
        },
        _getMaxYNode: function (nodes) {
            var maxY = nodes[0].offsetY, node, index = 0;
            for (var i = 0; i < nodes.length; i++) {
                node = nodes[i];
                if (!node.excludeFromLayout) {
                    if (node.offsetY > maxY) {
                        maxY = node.offsetY;
                        index = i;
                    }
                }
            }
            return nodes[index];
        },
        _arrangeNodesToLeftMost: function (layout, fixedPosition) {
            var nodes = layout.diagram.model.nodes, node, i;
            if (nodes.length > 0) {
                if (fixedPosition) {
                    var difx = fixedPosition.x - layout.fixedNode.offsetX;
                    var dify = fixedPosition.y - layout.fixedNode.offsetY;
                    for (i = 0; i < nodes.length; i++) {
                        node = nodes[i];
                        if (!node.excludeFromLayout) {
                            node.offsetX = node.offsetX + difx;
                            node.offsetY = node.offsetY + dify;
                        }
                        ej.datavisualization.Diagram.SpatialUtil._updateQuad(layout.diagram, layout.diagram._spatialSearch, node, true);
                    }
                }
                else {
                    for (i = 0; i < nodes.length; i++) {
                        node = nodes[i];
                        this._adjustMargin(layout, node);
                        ej.datavisualization.Diagram.SpatialUtil._updateQuad(layout.diagram, layout.diagram._spatialSearch, node, true);
                    }
                }
            }
        },
        _adjustMargin: function (layout, node) {
            node.offsetX = layout.marginX + node.offsetX;
            node.offsetY = layout.marginY + node.offsetY;
        },
    };
    //#endregion
})(jQuery, Syncfusion);;

(function ($, ej) {
    "use strict";

    //#region ZoomAndPan
    ej.datavisualization.Diagram.ZoomUtil = {
        zoomPan: function (diagram, currentZoom, deltaX, deltaY, focusPoint, isZoom) {
            var matrix = ej.Matrix.identity();
            ej.Matrix.scale(matrix, diagram.model.zoomFactor, diagram.model.zoomFactor);
            ej.Matrix.translate(matrix, -diagram._hScrollOffset, -diagram._vScrollOffset);
            var newScale = diagram.model.zoomFactor * currentZoom;
            if (newScale > 30) {
                currentZoom = 30 / diagram.model.zoomFactor;
            }
            else if (newScale < 0.25) {
                currentZoom = 0.25 / diagram.model.zoomFactor;
            }
            var dMatrix = ej.Matrix.identity();
            var pivot;
            if (focusPoint) {
                pivot = ej.Matrix.transform(matrix, focusPoint);
            }
            else {
                pivot = ej.datavisualization.Diagram.Point($(diagram.element).width() / 2, $(diagram.element).height() / 2);
            }
            ej.Matrix.scale(dMatrix, currentZoom, currentZoom, pivot.x, pivot.y);
            newScale = diagram.model.zoomFactor * currentZoom;
            ej.Matrix.translate(dMatrix, deltaX, deltaY);
            ej.Matrix.multiply(matrix, dMatrix);
            var point = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(0, 0));
            if (!isZoom) {
                if (point.x > 0)
                    point.x = 0;
                if (point.y > 0)
                    point.y = 0;
            }
            this._applyTransform(diagram, newScale, point, isZoom);
        },
        _applyTransform: function (diagram, currentZoom, point, isZoom) {
            diagram.model.zoomFactor = currentZoom;
            var bounds = diagram._getDigramBounds();
            var zoomX = 0;
            var zoomY = 0;
            if (point.x * -1 > 0) {
                if (!((bounds.width * currentZoom) < $(diagram.element).width())) {
                    zoomX = point.x * -1;
                }
            }
            if (point.y * -1 > 0) {
                if (!((bounds.height * currentZoom) < $(diagram.element).height())) {
                    zoomY = point.y * -1;
                }
            }
            if (!isZoom) {
                var scrollModel = $("#" + diagram._canvas.id + "_scroller").ejScroller("instance").model;
                if (point.x * -1 > 0) {
                    if (point.x * -1 + (scrollModel.width - scrollModel.buttonSize) > bounds.width * currentZoom) {
                        zoomX = (bounds.width * currentZoom) - (scrollModel.width - scrollModel.buttonSize);
                    }
                }
                if (point.y * -1 > 0) {
                    if (point.y * -1 + (scrollModel.height - scrollModel.buttonSize) > bounds.height * currentZoom) {
                        zoomY = (bounds.height * currentZoom) - (scrollModel.height - scrollModel.buttonSize);
                    }
                }
            }
            diagram._updateScrollOffset(zoomX, zoomY, true);
        }
    };
    //#endregion 

    //#region PageSettings
    ej.datavisualization.Diagram.PageUtil = {
        _createPageBreaks: function (diagram) {
            this._removePageBreaks(diagram);
            var attr = { id: diagram._canvas.id + "pagebreaks", "pointer-events": "none" };
            var g = ej.datavisualization.Diagram.SvgContext._initializePageBreaks(diagram._svg, attr, diagram._pageBackgroundLayer);
            this._updatePageBreaks(g, diagram);
        },
        _removePageBreaks: function (diagram) {
            var g = diagram._svg.getElementById(diagram._canvas.id + "pagebreaks");
            if (g) { ej.datavisualization.Diagram.SvgContext._removePageBreaks(diagram._svg, g, diagram._pageBackgroundLayer); }
        },
        _updatePageBreaks: function (g, diagram) {
            var bounds = diagram._getDigramBounds();
            var pageSettings = diagram.model.pageSettings;
            var left = bounds.x;
            var right = bounds.width;
            var top = bounds.y;
            var bottom = bounds.height;
            var zoom = diagram.model.zoomFactor;
            var pHeight = pageSettings.pageHeight;
            var pWidth = pageSettings.pageWidth;
            var pMargin = pageSettings.pageMargin;
            var columncount = parseInt(Math.ceil((right - left) / pWidth));
            var rowcount = parseInt(Math.ceil((bottom - top) / pHeight));
            left = -diagram._canvas.clientLeft + (pMargin + left) * zoom;
            top = -diagram._canvas.clientTop + (pMargin + top) * zoom;
            var width = (pWidth * columncount - pMargin * 2) * zoom;
            var height = (pHeight * rowcount - pMargin * 2) * zoom;
            ej.datavisualization.Diagram.SvgContext._renderVPageBreakLine(ej.datavisualization.Diagram.Point(left, top), ej.datavisualization.Diagram.Point(left + width, top), diagram._svg, g);
            ej.datavisualization.Diagram.SvgContext._renderHPageBreakLine(ej.datavisualization.Diagram.Point(left, top), ej.datavisualization.Diagram.Point(left, top + height), diagram._svg, g);
            for (var column = 1; column < columncount; column++) {
                ej.datavisualization.Diagram.SvgContext._renderVPageBreakLine(ej.datavisualization.Diagram.Point(left + (pWidth * column - pMargin) * zoom, top),
                    ej.datavisualization.Diagram.Point(left + (pWidth * column - pMargin) * zoom, top + height), diagram._svg, g);
            }
            for (var row = 1; row < rowcount; row++) {
                ej.datavisualization.Diagram.SvgContext._renderHPageBreakLine(ej.datavisualization.Diagram.Point(left, top + (pHeight * row - pMargin) * zoom),
                    ej.datavisualization.Diagram.Point(left + width, top + (pHeight * row - pMargin) * zoom), diagram._svg, g);
            }
            ej.datavisualization.Diagram.SvgContext._renderVPageBreakLine(ej.datavisualization.Diagram.Point(left + width, top), ej.datavisualization.Diagram.Point(left + width, top + height), diagram._svg, g);
            ej.datavisualization.Diagram.SvgContext._renderHPageBreakLine(ej.datavisualization.Diagram.Point(left, top + height), ej.datavisualization.Diagram.Point(left + width, top + height), diagram._svg, g);
        },
        _updatePageSize: function (diagram) {
            var bounds = diagram._getDigramBounds();
            var zoom = diagram.model.zoomFactor;
            var left = bounds.x * zoom;
            var top = bounds.y * zoom;
            var width = (bounds.width - bounds.x) * zoom;
            var height = (bounds.height - bounds.y) * zoom;
            var pageSettings = diagram.model.pageSettings;
            if (diagram._pageBackgroundLayer && diagram._pageBackgroundLayer.firstChild) {
                ej.datavisualization.Diagram.SvgContext._updatePageBakground(ej.datavisualization.Diagram.Point(left, top), ej.datavisualization.Diagram.Point(width, height));
            }
            else {
                ej.datavisualization.Diagram.SvgContext._renderPageSettingsRect(ej.datavisualization.Diagram.Point(left, top), ej.datavisualization.Diagram.Point(width, height), diagram._svg, diagram._pageBackgroundLayer, pageSettings.pageBorderColor, pageSettings.pageBackgroundColor, pageSettings.pageBorderWidth);
            }
            var swap = false;
            if (pageSettings.pageOrientation == ej.datavisualization.Diagram.PageOrientations.Landscape) {
                if (pageSettings.pageHeight > pageSettings.pageWidth) {
                    swap = true;
                }
            }
            else {
                if (pageSettings.pageWidth > pageSettings.pageHeight) {
                    swap = true;
                }
            }
            if (swap) {
                var temp = pageSettings.pageWidth;
                pageSettings.pageWidth = pageSettings.pageHeight;
                pageSettings.pageHeight = temp;
            }
            width = bounds.width * zoom;
            height = bounds.height * zoom;
            diagram._svg.document.style.left = 0;
            diagram._svg.document.style.top = 0;
            var check = false;
            if (!diagram.model.pageSettings.pageWidth) {
                if (!diagram.model.pageSettings.pageHeight) {
                    check = true;
                }
            }
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(diagram);
            var vWidth = viewPort.width + diagram._hScrollOffset;
            var vHeight = viewPort.height + diagram._vScrollOffset;
            if (width < vWidth)
                width = vWidth;
            if (height < vHeight)
                height = vHeight;
            if (pageSettings.pageWidth && pageSettings.pageHeight) {
                if (pageSettings.showPageBreak) {
                    this._createPageBreaks(diagram);
                }
            }
            ej.datavisualization.Diagram.ScrollUtil._setScrollContentSize(diagram, width, height);
        }
    };
    //#endregion

    //#region Scroller
    ej.datavisualization.Diagram.ScrollUtil = {
        _transform: function (diagram, hOffset, vOffset, canScale) {
            var div = document.getElementById(diagram._canvas.id + "_scroller");
            $(div).ejScroller("scrollX", hOffset, true);
            $(div).ejScroller("scrollY", vOffset, true);
            ej.datavisualization.Diagram.SvgContext.transformView(diagram, -hOffset, -vOffset);
            if (canScale) {
                ej.datavisualization.Diagram.SvgContext.scaleContent(diagram, diagram.model.zoomFactor);
            }
            ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
            ej.datavisualization.Diagram.SvgContext._updateGrid(0, 0, diagram.model.zoomFactor,diagram);
        },
        _viewPort: function (diagram) {
            var element = diagram.element[0];
            var eWidth = $(element).width();
            var eHeight = $(element).height();
            var bRect = diagram.element[0].getBoundingClientRect();
            var screenX = (window.screenX < 0) ? window.screenX * -1 : window.screenX;
            if (eWidth === 0) {
                eWidth = Math.floor(((window.innerWidth - screenX) - Math.floor(bRect.left)));
            }
            var screenY = (window.screenY < 0) ? window.screenY * -1 : window.screenY;
            if (eHeight === 0) {
                eHeight = Math.floor(((window.innerHeight - screenY) - Math.floor(bRect.top)));
            }
            return ej.datavisualization.Diagram.Size(eWidth, eHeight);
        },
        _updateScroller: function (diagram) {
            var viewPort = this._viewPort(diagram);
            $("#" + diagram._canvas.id + "_scroller").ejScroller({ width: viewPort.width, height: viewPort.height });
        },
        _setScrollContentSize: function (diagram, width, height) {
            var id = diagram._canvas.id;
            $("#" + id + "_contentHolder_content").css({ width: width + "px", height: height + "px" });
            ej.datavisualization.Diagram.SvgContext.setSize(diagram._svg, width, height);
            $("#" + id + "_scroller").ejScroller("refresh");
        },
        _initScroller: function (diagram) {
            var canvas = diagram._canvas;
            var scrollDiv = document.getElementById(canvas.id + "_scroller");
            var viewPort = this._viewPort(diagram);
            $(scrollDiv).ejScroller({ height: viewPort.height, width: viewPort.width });
            $(scrollDiv).ejScroller({
                scroll: function (e) {
                    if (e.source != null) {
                        if (e.source == "thumb" || e.source == "button" || e.source == "key") {
                            if (e.scrollData != null) {
                                var content = $("#" + diagram._canvas.id + "_contentHolder_content");
                                if (e.scrollData.clientXy == "pageX") {
                                    if ((e.model.scrollLeft + e.model.width) <= content.width())
                                        diagram._updateScrollOffset(e.model.scrollLeft, e.model.scrollTop);
                                }
                                else if (e.scrollData.clientXy == "pageY") {

                                    if ((e.model.scrollTop + e.model.height) <= content.height())
                                        diagram._updateScrollOffset(e.model.scrollLeft, e.model.scrollTop);
                                }
                            }
                        }
                    }
                }
            });
            $("#" + diagram._canvas.id + "_contentHolder_content").css({
                width: $(diagram._svg.document).width() + "px", height: $(diagram._svg.document).height() + "px"
            });
            $(scrollDiv).ejScroller("refresh");
        }
    };
    //#endregion

    //#region Snapping
    ej.datavisualization.Diagram.SnapUtil = {
        _canConsider: function (nameTable, selectedObject, target) {
            var consider = false;
            if (selectedObject.isGroup) {
                consider = !this._contains(nameTable, selectedObject, target);
            }
            else if (!selectedObject.line) {
                consider = !(selectedObject == target);
            }
            return consider;
        },
        _contains: function (nameTable, group, child) {
            var name = child.name;
            var node = null;
            if (group.children.indexOf(name) >= 0)
                node = nameTable[name];
            if (node && !node.line) {
                if (node.isGroup)
                    return this._contains(nameTable, node, child);
                else if (node == child)
                    return true;
            }
            return false;
        },
        _round: function (value, snapintervals, scale) {
            var cutoff = 0, i;
            for (i = 0; i < snapintervals.length; i++) {
                cutoff += snapintervals[i];
            }
            cutoff /= scale;
            var quotient = Math.floor(Math.abs(value) / cutoff);
            var bal = value % cutoff;
            var prev = quotient * cutoff;
            if (value >= 0) {
                for (i = 0; i < snapintervals.length ; i++) {
                    if (bal <= snapintervals[i] / scale) {
                        return prev + (bal < (snapintervals[i] / (2 * scale)) ? 0 : snapintervals[i] / scale);
                    }
                    else {
                        prev += snapintervals[i] / scale;
                        bal -= snapintervals[i] / scale;
                    }
                }
            }
            else {
                prev = prev * -1;
                for (i = snapintervals.length - 1; i >= 0; i--) {
                    if (Math.abs(bal) <= snapintervals[i] / scale) {
                        return prev - (Math.abs(bal) < (snapintervals[i] / (2 * scale)) ? 0 : snapintervals[i] / scale);
                    }
                    else {
                        prev -= snapintervals[i] / scale;
                        bal += snapintervals[i] / scale;
                    }
                }
            }
            return value;
        },
        _findNodes: function (spatialSearch, node, child, viewPort, nodesInView) {
            var nodes = [], quad, nd, bounds;
            var quads = ej.datavisualization.Diagram.SpatialUtil.findQuads(spatialSearch, viewPort);
            var childBounds = ej.datavisualization.Diagram.Util.bounds(child);
            for (var i = 0; i < quads.length; i++) {
                quad = quads[i];
                if (quad.objects.length > 0) {
                    for (var j = 0; j < quad.objects.length; j++) {
                        nd = quad.objects[j];
                        if (!nd.line) {
                            bounds = ej.datavisualization.Diagram.Util.bounds(nd);
                            if (nodes.indexOf(nd) == -1 && ej.datavisualization.Diagram.Geometry.intersectsRect(childBounds, bounds))
                                nodes.push(nd);
                            if (nodesInView && nodesInView.indexOf(nd) && ej.datavisualization.Diagram.Geometry.intersectsRect(viewPort, bounds)) {
                                nodesInView.push(nd);
                            }
                        }
                    }
                }
            }
            return nodes;
        },
        _snapAngle: function (diagram, angle) {
            var snapAngle = diagram.model.snapSettings.snapAngle;
            var width = angle % snapAngle;
            if (width >= (snapAngle / 2)) {
                return angle + snapAngle - width;
            }
            else {
                return angle - width;
            }
        },
        _snapPoint: function (diagram, selectedObject, towardsLeft, towardsTop, del, endPoint, startPoint) {
            var snapSettings = diagram.model.snapSettings;
            var zoomFactor = diagram.model.zoomFactor;
            var offset = ej.datavisualization.Diagram.Point();
            var bounds = ej.datavisualization.Diagram.Util.bounds(selectedObject);
            var horizontallysnapped = { snapped: false, offset: 0 };
            var verticallysnapped = { snapped: false, offset: 0 };
            if (snapSettings.enableSnapToObject)
                this._snapObject(diagram, selectedObject, horizontallysnapped,
                    verticallysnapped, del, startPoint == endPoint);
            //original position
            var left = bounds.x + del.x;
            var top = bounds.y + del.y;
            var right = bounds.x + bounds.width + del.x;
            var bottom = bounds.y + bounds.height + del.y;
            //snapped positions
            var roundedRight = this._round(right, snapSettings.verticalGridLines.snapInterval, zoomFactor);
            var roundedLeft = this._round(left, snapSettings.verticalGridLines.snapInterval, zoomFactor);
            var roundedTop = this._round(top, snapSettings.horizontalGridLines.snapInterval, zoomFactor);
            var roundedBottom = this._round(bottom, snapSettings.horizontalGridLines.snapInterval, zoomFactor);
            //currentposition
            var currentright = bounds.x + bounds.width;
            var currentbottom = bounds.y + bounds.height;
            if (!horizontallysnapped.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToVerticalLines) {
                    if (Math.abs(del.x) >= 1) {
                        if (towardsLeft) {
                            if (Math.abs(roundedRight - currentright) > Math.abs(roundedLeft - bounds.x)) {
                                offset.x += roundedLeft - bounds.x;
                            } else
                                offset.x += roundedRight - currentright;
                        } else {
                            if (Math.abs(roundedRight - currentright) < Math.abs(roundedLeft - bounds.x)) {
                                offset.x += roundedRight - currentright;
                            } else
                                offset.x += roundedLeft - bounds.x;
                        }
                    }
                } else {
                    offset.x = endPoint.x - startPoint.x;
                }
            } else {
                if (snapSettings.enableSnapToObject)
                    offset.x = horizontallysnapped.offset;
                else
                    offset.x = endPoint.x - startPoint.x;
            }
            if (!verticallysnapped.snapped) {
                if (snapSettings.snapConstraints & ej.datavisualization.Diagram.SnapConstraints.SnapToHorizontalLines) {
                    if (Math.abs(del.y) >= 1) {
                        if (towardsTop) {
                            if (Math.abs(roundedBottom - currentbottom) > Math.abs(roundedTop - bounds.y)) {
                                offset.y += roundedTop - bounds.y;
                            }
                            else
                                offset.y += roundedBottom - currentbottom;
                        }
                        else {
                            if (Math.abs(roundedBottom - currentbottom) < Math.abs(roundedTop - bounds.y)) {
                                offset.y += roundedBottom - currentbottom;
                            }
                            else
                                offset.y += roundedTop - bounds.y;
                        }
                    }
                }
                else
                    offset.y = endPoint.y - startPoint.y;
            }
            else
                offset.y = verticallysnapped.offset;

            return offset;
        },
        _snapObject: function (diagram, selectedObject, hSnap, vSnap, del, ended) {
            var lengthX = null, lengthY = null;
            var hTarget, vTarget;
            var objectsAtLeft = [], objectsAtRight = [], objectsAtTop = [], objectsAtBottom = [];
            var bounds = ej.datavisualization.Diagram.Util.bounds(selectedObject);
            var scale = diagram.model.zoomFactor;
            var hoffset = diagram._hScrollOffset;
            var voffset = diagram._vScrollOffset;
            var snapObjDistance = diagram.model.snapSettings.snapObjectDistance;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(diagram);
            var hIntersectRect = ej.datavisualization.Diagram.Rectangle(hoffset / scale, (bounds.y - 5), viewPort.width / scale,
                (bounds.height + 10));
            var vIntersectRect = ej.datavisualization.Diagram.Rectangle((bounds.x - 5), voffset / scale,
                (bounds.width + 10), viewPort.height / scale);
            viewPort = ej.datavisualization.Diagram.Rectangle(hoffset / scale, voffset / scale, viewPort.width / scale,
                viewPort.height / scale);
            var nodes = this._findNodes(diagram._spatialSearch, selectedObject, vIntersectRect, viewPort);
            var i, target, targetBounds;
            var nameTable = diagram.nameTable;
            for (i = 0; i < nodes.length; i++) {
                target = nodes[i];
                if (!target.line && this._canConsider(nameTable, selectedObject, target)) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    if (targetBounds.y + targetBounds.height < bounds.y + del.y) {
                        objectsAtTop.push({ object: target, distance: Math.abs(bounds.y + del.y - targetBounds.y - targetBounds.height) });
                    }
                    else if (targetBounds.y > bounds.y + del.y + bounds.height) {
                        objectsAtBottom.push({ object: target, distance: Math.abs(bounds.y + del.y + bounds.height - targetBounds.y) });
                    }
                    if (lengthX == null || lengthX > Math.abs(targetBounds.y - bounds.y - del.y)) {
                        if (Math.abs(targetBounds.x + targetBounds.width / 2 - (bounds.x + bounds.width / 2 + del.x)) <= snapObjDistance) {
                            hTarget = this._createSnapObject(targetBounds, bounds, "centerX");
                            lengthX = Math.abs(targetBounds.y - bounds.y);
                        } else if (Math.abs(targetBounds.x - (bounds.x + del.x)) <= snapObjDistance) {
                            hTarget = this._createSnapObject(targetBounds, bounds, "left");
                            lengthX = Math.abs(targetBounds.y - bounds.y);
                        } else if (Math.abs(targetBounds.x + targetBounds.width - (bounds.x + bounds.width + del.x)) <= snapObjDistance) {
                            hTarget = this._createSnapObject(targetBounds, bounds, "right");
                            lengthX = Math.abs(targetBounds.y - bounds.y);
                        } else if (Math.abs(targetBounds.x + targetBounds.width - (bounds.x + del.x)) <= snapObjDistance) {
                            hTarget = this._createSnapObject(targetBounds, bounds, "leftRight");
                            lengthX = Math.abs(targetBounds.y - bounds.y);
                        } else if (Math.abs(targetBounds.x - (bounds.x + bounds.width + del.x)) <= snapObjDistance) {
                            hTarget = this._createSnapObject(targetBounds, bounds, "rightLeft");
                            lengthX = Math.abs(targetBounds.y - bounds.y);
                        }
                    }
                }
            }
            nodes = this._findNodes(diagram._spatialSearch, selectedObject, hIntersectRect, viewPort);
            for (i = 0; i < nodes.length; i++) {
                target = nodes[i];
                if (!target.line && this._canConsider(nameTable, selectedObject, target)) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    if (targetBounds.x + targetBounds.width < bounds.x + del.x) {
                        objectsAtLeft[objectsAtLeft.length] = { object: target, distance: Math.abs((bounds.x + del.x) - targetBounds.x - targetBounds.width) };
                    }
                    if (targetBounds.x > bounds.x + del.x + bounds.width) {
                        objectsAtRight[objectsAtRight.length] = { object: target, distance: Math.abs(bounds.x + del.x + bounds.width - targetBounds.x) };
                    }
                    if (lengthY == null || lengthY > Math.abs(targetBounds.x - bounds.x - del.x)) {
                        if (Math.abs(targetBounds.y + targetBounds.height / 2 - (bounds.y + bounds.height / 2 + del.y)) <= snapObjDistance) {
                            vTarget = this._createSnapObject(targetBounds, bounds, "centerY");
                            lengthY = Math.abs(targetBounds.x - bounds.x);
                        } else if (Math.abs(targetBounds.y - bounds.y - del.y) <= snapObjDistance) {
                            vTarget = this._createSnapObject(targetBounds, bounds, "top");
                            lengthY = Math.abs(targetBounds.x - bounds.x);
                        } else if (Math.abs(targetBounds.y + targetBounds.height - (bounds.y + bounds.height + del.y)) <= snapObjDistance) {
                            vTarget = this._createSnapObject(targetBounds, bounds, "bottom");
                            lengthY = Math.abs(targetBounds.x - bounds.x);
                        } else if (Math.abs(targetBounds.y + targetBounds.height - bounds.y - del.y) <= snapObjDistance) {
                            vTarget = this._createSnapObject(targetBounds, bounds, "topBottom");
                            lengthY = Math.abs(targetBounds.x - bounds.x);
                        } else if (Math.abs(targetBounds.y - (bounds.y + bounds.height + del.y)) <= snapObjDistance) {
                            vTarget = this._createSnapObject(targetBounds, bounds, "bottomTop");
                            lengthY = Math.abs(targetBounds.x - bounds.x);
                        }
                    }
                }
            }
            var g = this._createGuidelines(diagram, hTarget, vTarget, hSnap, vSnap, ended);
            if (!hSnap.snapped) {
                this._createHSpacingLines(diagram, selectedObject, objectsAtLeft, objectsAtRight, hSnap, vSnap, ended, g, del, snapObjDistance);
            }
            if (!vSnap.snapped) {
                this._createVSpacingLines(diagram, selectedObject, objectsAtTop, objectsAtBottom, hSnap, vSnap, ended, g, del, snapObjDistance);
            }
        },
        _snapSize: function (diagram, hSnap, vSnap, delx, dely, selectedObject, ended) {
            var lengthX = null, lengthY = null;
            var hTarget;
            var vTarget;
            var bounds = ej.datavisualization.Diagram.Util.bounds(selectedObject);
            var nameTable = diagram.nameTable;
            var sameWidth = [];
            var sameHeight = [];
            var scale = diagram.model.zoomFactor;
            var hoffset = diagram._hScrollOffset;
            var voffset = diagram._vScrollOffset;
            var snapObjDistance = diagram.model.snapSettings.snapObjectDistance;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(diagram);
            var hintersectedrect = ej.datavisualization.Diagram.Rectangle(hoffset / scale, (bounds.y - 5) / scale,
                viewPort.width / scale, (bounds.height + 10) / scale);
            var vintersectedrect = ej.datavisualization.Diagram.Rectangle((bounds.x - 5) / scale, voffset / scale,
                (bounds.width + 10) / scale, viewPort.height / scale);
            viewPort = ej.datavisualization.Diagram.Rectangle(hoffset / scale, voffset / scale, viewPort.width / scale,
               viewPort.height / scale);
            var nodesInView = [];
            var nodes = this._findNodes(diagram._spatialSearch, selectedObject, vintersectedrect, viewPort, nodesInView);
            var i, target, targetBounds;
            for (i = 0; i < nodes.length; i++) {
                target = nodes[i];
                if (this._canConsider(nameTable, selectedObject, target) && !target.line) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    if (lengthX == null || lengthX > Math.abs(targetBounds.y - bounds.y)) {
                        if (hSnap.left) {
                            if (Math.abs(bounds.x + delx - targetBounds.x) <= snapObjDistance) {
                                hTarget = this._createSnapObject(targetBounds, bounds, "left");
                                lengthX = Math.abs(targetBounds.y - bounds.y);
                            }
                            else if (Math.abs(bounds.x + delx - targetBounds.x - targetBounds.width) <= snapObjDistance) {
                                hTarget = this._createSnapObject(targetBounds, bounds, "leftRight");
                                lengthX = Math.abs(targetBounds.y - bounds.y);
                            }
                        }
                        else if (hSnap.right) {
                            if (Math.abs(bounds.x + delx + bounds.width - targetBounds.x - targetBounds.width) <= snapObjDistance) {
                                hTarget = this._createSnapObject(targetBounds, bounds, "right");
                                lengthX = Math.abs(targetBounds.y - bounds.y);
                            }
                            else if (Math.abs(bounds.x + delx + bounds.width - targetBounds.x) <= snapObjDistance) {
                                hTarget = this._createSnapObject(targetBounds, bounds, "rightLeft");
                                lengthX = Math.abs(targetBounds.y - bounds.y);
                            }
                        }
                    }
                }
            }
            nodes = this._findNodes(diagram._spatialSearch, selectedObject, hintersectedrect, viewPort);
            for (i = 0; i < nodes.length; i++) {
                target = nodes[i];
                if (this._canConsider(nameTable, selectedObject, target) && !target.line) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    if (lengthY == null || lengthY > Math.abs(targetBounds.x - bounds.x)) {
                        if (vSnap.top) {
                            if (Math.abs(bounds.y + dely - targetBounds.y) <= snapObjDistance) {
                                vTarget = this._createSnapObject(targetBounds, bounds, "top");
                                lengthY = Math.abs(targetBounds.x - bounds.x);
                            }
                            else if (Math.abs(bounds.y + dely - targetBounds.y - targetBounds.height) <= snapObjDistance) {
                                vTarget = this._createSnapObject(targetBounds, bounds, "topBottom");
                                lengthY = Math.abs(targetBounds.x - bounds.x);
                            }
                        }
                        else if (vSnap.bottom) {
                            if (Math.abs(bounds.y + bounds.height + dely - targetBounds.y - targetBounds.height) <= snapObjDistance) {
                                vTarget = this._createSnapObject(targetBounds, bounds, "bottom");
                                lengthY = Math.abs(targetBounds.x - bounds.x);
                            }
                            else if (Math.abs(bounds.y + bounds.height + dely - targetBounds.y) <= snapObjDistance) {
                                vTarget = this._createSnapObject(targetBounds, bounds, "bottomTop");
                                lengthY = Math.abs(targetBounds.x - bounds.x);
                            }
                        }
                    }
                }
            }
            for (i = 0; i < nodesInView.length; i++) {
                target = nodesInView[i];
                if (this._canConsider(nameTable, selectedObject, target)) {
                    var targetbounds = ej.datavisualization.Diagram.Util.bounds(target);
                    var del = hSnap.left ? -delx : delx;
                    var diff = Math.abs(bounds.width + del - targetbounds.width);
                    var actualDiff;
                    if (diff <= snapObjDistance) {
                        actualDiff = hSnap.left ? -targetbounds.width + bounds.width : targetbounds.width - bounds.width;
                        sameWidth[sameWidth.length] = { source: target, diff: diff, offset: actualDiff };
                    }
                    del = vSnap.top ? -dely : dely;
                    var dify = Math.abs(bounds.height + del - targetbounds.height);
                    if (dify <= snapObjDistance) {
                        actualDiff = vSnap.top ? -targetbounds.height + bounds.height : targetbounds.height - bounds.height;
                        sameHeight[sameHeight.length] = { source: target, diff: dify, offset: actualDiff };
                    }
                }
            }
            var g = this._createGuidelines(diagram, hTarget, vTarget, hSnap, vSnap, ended);
            if (!hSnap.snapped && sameWidth.length > 0 && (hSnap.left || hSnap.right)) {
                this._addSameWidthLines(diagram, sameWidth, hSnap, ended, g, selectedObject);
            }
            if (!vSnap.snapped && sameHeight.length > 0 && (vSnap.top || vSnap.bottom)) {
                this._addSameHeightLines(diagram, sameHeight, vSnap, ended, g, selectedObject);
            }
        },
        _createSnapObject: function (targetbounds, bounds, snap) {
            var snapObject;
            switch (snap) {
                case "left":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(targetbounds.x, Math.min(targetbounds.y, bounds.y)),
                        end: ej.datavisualization.Diagram.Point(targetbounds.x, Math.max(targetbounds.y + targetbounds.height, bounds.y + bounds.height)),
                        offsetX: targetbounds.x - bounds.x, offsetY: 0, type: "sideAlign"
                    };
                    break;
                case "right":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width, Math.min(targetbounds.y, bounds.y)),
                        end: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width, Math.max(targetbounds.y + targetbounds.height, bounds.y + bounds.height)),
                        offsetX: targetbounds.x + targetbounds.width - bounds.x - bounds.width, offsetY: 0, type: "sideAlign"
                    };
                    break;
                case "top":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(Math.min(targetbounds.x, bounds.x), targetbounds.y),
                        end: ej.datavisualization.Diagram.Point(Math.max(targetbounds.x + targetbounds.width, bounds.x + bounds.width), targetbounds.y),
                        offsetY: targetbounds.y - bounds.y, offsetX: 0, type: "sideAlign"
                    };
                    break;
                case "bottom":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(Math.min(targetbounds.x, bounds.x), targetbounds.y + targetbounds.height),
                        end: ej.datavisualization.Diagram.Point(Math.max(targetbounds.x + targetbounds.width, bounds.x + bounds.width), targetbounds.y + targetbounds.height),
                        offsetY: targetbounds.y + targetbounds.height - bounds.y - bounds.height, offsetX: 0, type: "sideAlign"
                    };
                    break;
                case "topBottom":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(Math.min(targetbounds.x, bounds.x), targetbounds.y + targetbounds.height),
                        end: ej.datavisualization.Diagram.Point(Math.max(targetbounds.x + targetbounds.width, bounds.x + bounds.width), targetbounds.y + targetbounds.height),
                        offsetY: targetbounds.y + targetbounds.height - bounds.y, offsetX: 0, type: "sideAlign"
                    };
                    break;
                case "bottomTop":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(Math.min(targetbounds.x, bounds.x), targetbounds.y),
                        end: ej.datavisualization.Diagram.Point(Math.max(targetbounds.x + targetbounds.width, bounds.x + bounds.width), targetbounds.y),
                        offsetY: targetbounds.y - bounds.y - bounds.height, offsetX: 0, type: "sideAlign"
                    };
                    break;
                case "leftRight":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width, Math.min(targetbounds.y, bounds.y)),
                        end: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width, Math.max(targetbounds.y + targetbounds.height, bounds.y + bounds.height)),
                        offsetX: targetbounds.x + targetbounds.width - bounds.x, offsetY: 0, type: "sideAlign"
                    };
                    break;
                case "rightLeft":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(targetbounds.x, Math.min(targetbounds.y, bounds.y)),
                        end: ej.datavisualization.Diagram.Point(targetbounds.x, Math.max(targetbounds.y + targetbounds.height, bounds.y + bounds.height)),
                        offsetX: targetbounds.x - bounds.x - bounds.width, offsetY: 0, type: "sideAlign"
                    };
                    break;
                case "centerX":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width / 2, Math.min(targetbounds.y, bounds.y)),
                        end: ej.datavisualization.Diagram.Point(targetbounds.x + targetbounds.width / 2, Math.max(targetbounds.y + targetbounds.height, bounds.y + bounds.height)),
                        offsetX: targetbounds.x + targetbounds.width / 2 - (bounds.x + bounds.width / 2), offsetY: 0, type: "centerAlign"
                    };
                    break;
                case "centerY":
                    snapObject = {
                        start: ej.datavisualization.Diagram.Point(Math.min(targetbounds.x, bounds.x), targetbounds.y + targetbounds.height / 2),
                        end: ej.datavisualization.Diagram.Point(Math.max(targetbounds.x + targetbounds.width, bounds.x + bounds.width), targetbounds.y + targetbounds.height / 2),
                        offsetY: targetbounds.y + targetbounds.height / 2 - (bounds.y + bounds.height / 2), offsetX: 0, type: "centerAlign"
                    };
                    break;
            }
            return snapObject;
        },
        _createGuidelines: function (diagram, hTarget, vTarget, hsnap, vsnap, ended) {
            var attr = { id: diagram._canvas.id + "guideline", "pointer-events": "none" };
            var g = ej.datavisualization.Diagram.SvgContext._initializeGuidelines(diagram._svg, attr, diagram._adornerLayer);
            var scale = diagram.model.zoomFactor;
            var hOffset = diagram._hScrollOffset;
            var vOffset = diagram._vScrollOffset;
            if (hTarget) {
                hsnap.offset = hTarget.offsetX;
                hsnap.snapped = true;
                if (!ended) {
                    if (hTarget.type == "sideAlign") {
                        ej.datavisualization.Diagram.SvgContext._renderSideAlignmentLines(hTarget.start, hTarget.end, g, diagram._svg, scale, hOffset, vOffset);
                    }
                    else if (hTarget.type == "centerAlign") {
                        ej.datavisualization.Diagram.SvgContext._renderCenterAlignmentLines(hTarget.start, hTarget.end, g, diagram._svg, scale, hOffset, vOffset);
                    }
                }
            }
            if (vTarget) {
                vsnap.offset = vTarget.offsetY;
                vsnap.snapped = true;
                if (!ended) {
                    if (vTarget.type == "sideAlign") {
                        ej.datavisualization.Diagram.SvgContext._renderSideAlignmentLines(vTarget.start, vTarget.end, g, diagram._svg, scale, hOffset, vOffset);
                    }
                    else if (vTarget.type == "centerAlign") {
                        ej.datavisualization.Diagram.SvgContext._renderCenterAlignmentLines(vTarget.start, vTarget.end, g, diagram._svg, scale, hOffset, vOffset);
                    }
                }
            }
            return g;
        },
        _removeGuidelines: function (diagram) {
            var g = diagram._svg.getElementById(diagram._canvas.id + "guideline");
            if (g != null) { ej.datavisualization.Diagram.SvgContext._removeGuidelines(diagram._adornerLayer, g); }
        },
        _createHSpacingLines: function (diagram, shape, objectsAtLeft, objectsAtRight, hSnap, vSnap, ended, g, del, snapObjDistance) {
            var top = null;
            objectsAtLeft.sort(function (a, b) { return a.distance - b.distance; });
            objectsAtRight.sort(function (a, b) { return a.distance - b.distance; });
            var equallySpaced = [];
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var nearestleft, nearestright;
            var targetBounds;
            if (objectsAtLeft.length > 0) {
                equallySpaced[equallySpaced.length] = objectsAtLeft[0];
                nearestleft = ej.datavisualization.Diagram.Util.bounds(objectsAtLeft[0].object);
                top = nearestleft.y;
                if (objectsAtLeft.length > 1) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtLeft[1].object);
                    var equaldistance = nearestleft.x - targetBounds.x - targetBounds.width;
                    if (Math.abs(equaldistance - objectsAtLeft[0].distance) <= snapObjDistance) {
                        top = this._findEquallySpacedNodesAtLeft(objectsAtLeft, equaldistance, top, equallySpaced);

                    } else equaldistance = objectsAtLeft[0].distance;
                } else equaldistance = objectsAtLeft[0].distance;
            }
            equallySpaced.sort(function (a, b) { return b.distance - a.distance; });
            equallySpaced[equallySpaced.length] = { object: shape, distance: 0 };
            top = bounds.y < top || !top ? bounds.y : top;
            if (objectsAtRight.length > 0) {
                var dist;
                nearestright = ej.datavisualization.Diagram.Util.bounds(objectsAtRight[0].object);
                top = nearestright.y < top ? nearestright.y : top;
                if (objectsAtRight.length > 1) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtRight[1].object);
                    dist = targetBounds.x - nearestright.x - nearestright.width;
                }
                if (objectsAtLeft.length > 0) {
                    if (Math.abs(objectsAtRight[0].distance - objectsAtLeft[0].distance) <= snapObjDistance) {
                        var adjustablevalue = Math.abs(objectsAtRight[0].distance - objectsAtLeft[0].distance) / 2;
                        (objectsAtRight[0].distance < objectsAtLeft[0].distance) ?
                        equaldistance -= adjustablevalue : equaldistance += adjustablevalue;
                        equallySpaced[equallySpaced.length] = objectsAtRight[0];
                    }
                    else if (objectsAtLeft.length == 1) {
                        nearestleft = undefined;
                        equallySpaced.splice(0, 1);
                        equallySpaced[equallySpaced.length] = objectsAtRight[0];
                        equaldistance = dist;
                    }
                }
                else {
                    equaldistance = dist;
                    equallySpaced[equallySpaced.length] = objectsAtRight[0];
                }
                if (objectsAtRight.length > 1 && nearestright.x + nearestright.width < targetBounds.x) {
                    top = this._findEquallySpacedNodesAtRight(objectsAtRight, dist, top, equallySpaced, snapObjDistance);
                }
            }
            if (equallySpaced.length > 2) {
                this._addHSpacingLines(diagram, equallySpaced, ended, g, top);
                var delta = 0;
                if (ended)
                    delta = del.x;
                if (nearestleft)
                    hSnap.offset = equaldistance - Math.abs(bounds.x + delta - nearestleft.x - nearestleft.width) + delta;
                else if (nearestright)
                    hSnap.offset = Math.abs(bounds.x + bounds.width + delta - nearestright.x) - equaldistance + delta;
                hSnap.snapped = true;
            }
        },
        _createVSpacingLines: function (diagram, shape, objectsAtTop, objectsAtBottom, hSnap, vSnap, ended, g, del, snapObjDistance) {
            var right = null;
            objectsAtTop.sort(function (a, b) { return a.distance - b.distance; });
            objectsAtBottom.sort(function (a, b) { return a.distance - b.distance; });
            var equallySpaced = [];
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var nearesttop, nearestbottom;
            var targetBounds;
            if (objectsAtTop.length > 0) {
                equallySpaced[equallySpaced.length] = objectsAtTop[0];
                nearesttop = ej.datavisualization.Diagram.Util.bounds(objectsAtTop[0].object);
                right = nearesttop.x + nearesttop.width;
                if (objectsAtTop.length > 1) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtTop[1].object);
                    var equaldistance = nearesttop.y - targetBounds.y - targetBounds.height;
                    if (Math.abs(equaldistance - objectsAtTop[0].distance) <= snapObjDistance) {
                        right = this._findEquallySpacedNodesAtTop(objectsAtTop, equaldistance, right, equallySpaced);
                    } else equaldistance = objectsAtTop[0].distance;
                } else equaldistance = objectsAtTop[0].distance;
            }

            equallySpaced.sort(function (a, b) { return b.distance - a.distance; });
            equallySpaced[equallySpaced.length] = { object: shape, distance: 0 };
            right = bounds.x + bounds.width > right || !right ? bounds.x + bounds.width : right;
            var dist;
            if (objectsAtBottom.length > 0) {
                nearestbottom = ej.datavisualization.Diagram.Util.bounds(objectsAtBottom[0].object);
                right = nearestbottom.x + nearestbottom.width > right ? nearestbottom.x + nearestbottom.width : right;
                if (objectsAtBottom.length > 1) {
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtBottom[1].object);
                    dist = targetBounds.y - nearestbottom.y - nearestbottom.height;
                }

                if (objectsAtTop.length > 0) {
                    if (Math.abs(objectsAtBottom[0].distance - objectsAtTop[0].distance) <= snapObjDistance) {
                        var adjustablevalue = Math.abs(objectsAtBottom[0].distance - objectsAtTop[0].distance) / 2;
                        (objectsAtBottom[0].distance < objectsAtTop[0].distance) ?
                        equaldistance -= adjustablevalue : equaldistance += adjustablevalue;
                        equallySpaced[equallySpaced.length] = objectsAtBottom[0];
                    }
                    else if (objectsAtTop.length == 1) {
                        nearesttop = undefined;
                        equallySpaced.splice(0, 1);
                        equallySpaced[equallySpaced.length] = objectsAtBottom[0];
                        equaldistance = dist;
                    }
                }
                else {
                    equaldistance = dist;
                    equallySpaced[equallySpaced.length] = objectsAtBottom[0];
                }
                if (objectsAtBottom.length > 1 && targetBounds.y > nearestbottom.y + nearestbottom.height) {
                    right = this._findEquallySpacedNodesAtBottom(objectsAtBottom, dist, right, equallySpaced, snapObjDistance);
                }

            }
            if (equallySpaced.length > 2) {
                this._addVSpacingLine(diagram, equallySpaced, ended, g, right);
                var delta = 0;
                if (ended)
                    delta = del.y;
                if (nearesttop)
                    vSnap.offset = equaldistance - Math.abs(bounds.y + delta - nearesttop.y - nearesttop.height) + delta;
                else if (nearestbottom)
                    vSnap.offset = Math.abs(bounds.y + bounds.height + delta - nearestbottom.y) - equaldistance + delta;
                vSnap.snapped = true;
            }
        },
        _addHSpacingLines: function (diagram, equallySpaced, ended, g, top) {
            var scale = diagram.model.zoomFactor;
            var hoffset = diagram._hScrollOffset;
            var voffset = diagram._vScrollOffset;
            if (equallySpaced.length > 2) {
                if (!ended) {
                    for (var i = 0; i < equallySpaced.length - 1; i++) {
                        var crnt = ej.datavisualization.Diagram.Util.bounds(equallySpaced[i].object);
                        var next = ej.datavisualization.Diagram.Util.bounds(equallySpaced[i + 1].object);
                        ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(crnt.x + crnt.width, top - 15),
                       ej.datavisualization.Diagram.Point(next.x, top - 15), g, diagram._svg, scale, hoffset, voffset);
                    }
                }

            }
        },
        _addVSpacingLine: function (diagram, equallySpaced, ended, g, right) {
            var scale = diagram.model.zoomFactor;
            var hoffset = diagram._hScrollOffset;
            var voffset = diagram._vScrollOffset;
            if (equallySpaced.length > 2) {
                if (!ended) {
                    var crnt, next;
                    for (var i = 0; i < equallySpaced.length - 1; i++) {
                        crnt = ej.datavisualization.Diagram.Util.bounds(equallySpaced[i].object);
                        next = ej.datavisualization.Diagram.Util.bounds(equallySpaced[i + 1].object);
                        ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(right + 15, crnt.y + crnt.height),
                      ej.datavisualization.Diagram.Point(right + 15, next.y), g, diagram._svg, scale, hoffset, voffset);
                    }
                }

            }
        },
        _addSameWidthLines: function (diagram, sameWidths, hSnap, ended, g, shape) {
            var scale = diagram.model.zoomFactor;
            var hOffset = diagram._hScrollOffset;
            var vOffset = diagram._vScrollOffset;
            sameWidths.sort(function (a, b) { return a.offset - b.offset; });
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var target = sameWidths[0];
            var targetBounds = ej.datavisualization.Diagram.Util.bounds(target.source);
            var sameSizes = [];
            sameSizes.push(sameWidths[0]);
            var i, crntbounds;
            for (i = 1; i < sameWidths.length; i++) {
                crntbounds = ej.datavisualization.Diagram.Util.bounds(sameWidths[i].source);
                if (crntbounds.width == targetBounds.width)
                    sameSizes.push(sameWidths[i]);
            }
            if (sameSizes.length > 0) {
                if (!ended) {
                    ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(bounds.x + target.offset, bounds.y - 15),
                        ej.datavisualization.Diagram.Point(bounds.x + bounds.width + target.offset, bounds.y - 15), g, diagram._svg, scale, hOffset, vOffset);
                    for (i = 0; i < sameSizes.length; i++) {
                        bounds = ej.datavisualization.Diagram.Util.bounds(sameSizes[i].source);
                        ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(bounds.x, bounds.y - 15),
                        ej.datavisualization.Diagram.Point(bounds.x + bounds.width, bounds.y - 15), g, diagram._svg, scale, hOffset, vOffset);
                    }
                }
            }
            hSnap.offset = target.offset;
            hSnap.snapped = true;
        },
        _addSameHeightLines: function (diagram, sameHeights, vSnap, ended, g, shape) {
            var scale = diagram.model.zoomFactor;
            var hOffset = diagram._hScrollOffset;
            var vOffset = diagram._vScrollOffset;
            sameHeights.sort(function (a, b) { return a.offset - b.offset; });
            var bounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var target = sameHeights[0];
            var targetBounds = ej.datavisualization.Diagram.Util.bounds(target.source);
            var sameSizes = [];
            sameSizes.push(sameHeights[0]);
            var i, crntBounds;
            for (i = 0; i < sameHeights.length; i++) {
                crntBounds = ej.datavisualization.Diagram.Util.bounds(sameHeights[i].source);
                if (crntBounds.height == targetBounds.height)
                    sameSizes.push(sameHeights[i]);
            }
            if (sameSizes.length > 0) {
                if (!ended) {
                    ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(bounds.x + bounds.width + 15, bounds.y + target.offset),
                        ej.datavisualization.Diagram.Point(bounds.x + bounds.width + 15, bounds.y + bounds.height + target.offset), g, diagram._svg, scale, hOffset, vOffset);
                    for (i = 0; i < sameSizes.length; i++) {
                        bounds = ej.datavisualization.Diagram.Util.bounds(sameSizes[i].source);
                        ej.datavisualization.Diagram.SvgContext._renderSpacingLines(ej.datavisualization.Diagram.Point(bounds.x + bounds.width + 15, bounds.y),
                        ej.datavisualization.Diagram.Point(bounds.x + bounds.width + 15, bounds.y + bounds.height), g, diagram._svg, scale, hOffset, vOffset);

                    }
                }
                vSnap.offset = target.offset;
                vSnap.snapped = true;
            }
        },
        _findEquallySpacedNodesAtLeft: function (objectsAtLeft, equalDistance, top, equallySpaced) {
            var prevBounds, targetBounds, dist;
            for (var i = 1; i < objectsAtLeft.length; i++) {
                prevBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtLeft[i - 1].object);
                targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtLeft[i].object);
                dist = prevBounds.x - targetBounds.x - targetBounds.width;
                if (Math.abs(dist - equalDistance) <= 1) {
                    equallySpaced[equallySpaced.length] = objectsAtLeft[i];
                    if (targetBounds.y < top)
                        top = targetBounds.y;
                }
                else
                    break;
            }
            return top;
        },
        _findEquallySpacedNodesAtRight: function (objectsAtRight, equalDistance, top, equallySpaced, snapObjDistance) {
            var actualDistance = objectsAtRight[0].distance;
            var target, targetBounds, prevBounds, dist;
            if (Math.abs(equalDistance - actualDistance) <= snapObjDistance) {
                for (var i = 0; i < objectsAtRight.length - 1; i++) {
                    target = objectsAtRight[i].object;
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtRight[i + 1].object);
                    prevBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    dist = targetBounds.x - prevBounds.x - prevBounds.width;
                    if (Math.abs(dist - equalDistance) <= 1) {
                        equallySpaced[equallySpaced.length] = objectsAtRight[i + 1];
                        if (prevBounds.y < top) {
                            top = prevBounds.y;
                        }
                    }
                    else
                        break;
                }
            }
            return top;
        },
        _findEquallySpacedNodesAtTop: function (objectsAtTop, equalDistance, right, equallySpaced) {
            var prevBounds, targetBounds, dist;
            for (var i = 1; i < objectsAtTop.length; i++) {
                prevBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtTop[i - 1].object);
                targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtTop[i].object);
                dist = prevBounds.y - targetBounds.y - targetBounds.height;
                if (Math.abs(dist - equalDistance) <= 1) {
                    equallySpaced[equallySpaced.length] = objectsAtTop[i];
                    if (targetBounds.x + targetBounds.width > right)
                        right = targetBounds.x + targetBounds.width;
                }
                else
                    break;
            }
            return right;
        },
        _findEquallySpacedNodesAtBottom: function (objectsAtBottom, equalDistance, right, equallySpaced, snapObjDistance) {
            var actualDistance = objectsAtBottom[0].distance;
            var target, targetBounds, prevBounds, dist;
            if (Math.abs(equalDistance - actualDistance) <= snapObjDistance) {
                for (var i = 0; i < objectsAtBottom.length - 1; i++) {
                    target = objectsAtBottom[i].object;
                    targetBounds = ej.datavisualization.Diagram.Util.bounds(objectsAtBottom[i + 1].object);
                    prevBounds = ej.datavisualization.Diagram.Util.bounds(target);
                    dist = targetBounds.y - prevBounds.y - prevBounds.height;
                    if (Math.abs(dist - equalDistance) <= 1) {
                        equallySpaced[equallySpaced.length] = objectsAtBottom[i + 1];
                        if (prevBounds.x + prevBounds.width > right)
                            right = prevBounds.x + prevBounds.width;
                    }
                    else
                        break;
                }
            }
            return right;
        },

    };
    //#endregion

    //#region SpatialSearch
    ej.datavisualization.Diagram.SpatialUtil = {
        findQuads: function (spatialSearch, viewPort) {
            spatialSearch.quads = [];
            var quad = spatialSearch.parentQuad;
            this._findQuads(spatialSearch, quad, viewPort);
            return spatialSearch.quads;
        },
        _addIntoAQuad: function (spatialSearch) {
            var isAdded = false;
            while (!isAdded) {
                isAdded = this._add(spatialSearch, spatialSearch.parentQuad);
            }
        },
        _setCurrentNode: function (spatialSearch, node) {
            spatialSearch.childnode = node;
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            spatialSearch.childLeft = bounds.left;
            spatialSearch.childTop = bounds.top;
            spatialSearch.childRight = bounds.right;
            spatialSearch.childBottom = bounds.bottom;
        },
        _add: function (spatialSearch, quad) {
            if (this._isContained(spatialSearch, quad)) {
                this._selectQuad(spatialSearch, quad);
                return true;
            } else {
                var newParent;
                var isEmpty = !quad.objects.length && quad.first == null && quad.second == null && quad.third == null && quad.fourth == null;
                if (spatialSearch.childLeft < quad.left) {
                    if (spatialSearch.childTop < quad.top) {
                        newParent = ej.datavisualization.Diagram.Quad(quad.left - quad.width, quad.top - quad.height, quad.width * 2, quad.height * 2);
                        if (!isEmpty)
                            newParent.fourth = quad;
                    }
                    else {
                        newParent = ej.datavisualization.Diagram.Quad(quad.left - quad.width, quad.top, quad.width * 2, quad.height * 2);
                        if (!isEmpty)
                            newParent.second = quad;
                    }
                }
                else if (spatialSearch.childTop < quad.top) {
                    newParent = ej.datavisualization.Diagram.Quad(quad.left, quad.top - quad.height, quad.width * 2, quad.height * 2);
                    if (!isEmpty)
                        newParent.third = quad;
                }
                else {
                    newParent = ej.datavisualization.Diagram.Quad(quad.left, quad.top, quad.width * 2, quad.height * 2);
                    if (!isEmpty)
                        newParent.first = quad;
                }
                quad.parent = newParent;
                spatialSearch.parentQuad = newParent;
                return false;
            }
        },
        _isContained: function (spatialSearch, quad) {
            if (spatialSearch.childLeft >= quad.left && spatialSearch.childRight <= quad.left + quad.width &&
                spatialSearch.childTop >= quad.top && spatialSearch.childBottom <= quad.top + quad.height) {
                return true;
            }
            return false;
        },
        _selectQuad: function (spatialSearch, quad) {
            var current = quad;
            while (current !== null) {
                current = this._getQuad(spatialSearch, current);
            }
        },
        _getQuad: function (spatialSearch, quad) {
            var halfWidth = quad.width / 2;
            var halfHeight = quad.height / 2;
            if (halfWidth >= 100 && halfHeight >= 100) {
                var xCenter = quad.left + halfWidth;
                var yCenter = quad.top + halfHeight;
                if (spatialSearch.childRight <= xCenter) {
                    if (spatialSearch.childBottom <= yCenter) {
                        return quad.first ? quad.first :
                               quad.first = ej.datavisualization.Diagram.Quad(quad.left, quad.top, halfWidth, halfHeight, quad);
                    }
                    else if (spatialSearch.childTop >= yCenter) {
                        return quad.third ? quad.third :
                                quad.third = ej.datavisualization.Diagram.Quad(quad.left, yCenter, halfWidth, halfHeight, quad);
                    }
                }
                else if (spatialSearch.childLeft >= xCenter) {
                    if (spatialSearch.childBottom <= yCenter) {
                        return quad.second ? quad.second :
                               quad.second = ej.datavisualization.Diagram.Quad(xCenter, quad.top, halfWidth, halfHeight, quad);
                    }
                    else if (spatialSearch.childTop >= yCenter) {
                        return quad.fourth ? quad.fourth :
                                quad.fourth = ej.datavisualization.Diagram.Quad(xCenter, yCenter, halfWidth, halfHeight, quad);
                    }
                }
            }
            quad.objects.push(spatialSearch.childnode);
            spatialSearch.quadTable[spatialSearch.childnode.name] = quad;
            return null;
        },
        _findQuads: function (spatialSearch, quad, viewPort) {
            if (quad.first && this._isIntersect(quad.first, viewPort)) {
                this._findQuads(spatialSearch, quad.first, viewPort);
            }
            if (quad.second && this._isIntersect(quad.second, viewPort)) {
                this._findQuads(spatialSearch, quad.second, viewPort);
            }
            if (quad.third && this._isIntersect(quad.third, viewPort)) {
                this._findQuads(spatialSearch, quad.third, viewPort);
            }
            if (quad.fourth && this._isIntersect(quad.fourth, viewPort)) {
                this._findQuads(spatialSearch, quad.fourth, viewPort);
            }
            if (quad.objects.length > 0)
                spatialSearch.quads.push(quad);
        },
        _isIntersect: function (quad, viewPort) {
            if (quad.left + quad.width < viewPort.left || quad.top + quad.height < viewPort.top || quad.left > viewPort.right || quad.top > viewPort.bottom) {
                return false;
            }
            return true;
        },
        _update: function (quad) {
            if (quad.parent != null && quad.objects.length == 0 && quad.first == null &&
                quad.second == null && quad.third == null && quad.fourth == null) {
                var parent = quad.parent;
                if (parent.first == quad) {
                    parent.first = null;
                }
                else if (parent.second == quad) {
                    parent.second = null;
                }
                else if (parent.third == quad) {
                    parent.third = null;
                }
                else if (parent.fourth == quad) {
                    parent.fourth = null;
                }
                this._update(quad.parent);
            }
            else
                return;
        },
        _isWithinPageBounds: function (spatialSearch, bounds) {
            if (bounds.left >= spatialSearch.pageLeft && bounds.right <= spatialSearch.pageRight &&
                bounds.top >= spatialSearch.pageTop && bounds.bottom <= spatialSearch.pageBottom)
                return true;
            else
                return false;
        },
        _updateBounds: function (diagram, spatialSearch, node) {
            var modified = false;
            if (node.name == spatialSearch.topElement.name) {
                modified = true;
                spatialSearch.pageTop = null;
                this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "top");
            }
            if (node.name == spatialSearch.leftElement.name) {
                modified = true;
                spatialSearch.pageLeft = null;
                this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "left");
            }
            if (node.name == spatialSearch.rightElement.name) {
                modified = true;
                spatialSearch.pageRight = null;
                this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "right");
            }
            if (node.name == spatialSearch.bottomElement.name) {
                modified = true;
                spatialSearch.pageBottom = null;
                this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "bottom");
            }
            if (modified) {
                if (diagram._pageBackgroundLayer) {
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
            }
        },
        _findQuadElement: function (spatialSearch, quad, direction) {
            switch (direction) {
                case "bottom":
                    if (quad.third != null || quad.fourth != null) {
                        if (quad.third != null) {
                            this._findQuadElement(spatialSearch, quad.third, direction);
                        }
                        if (quad.fourth != null) {
                            this._findQuadElement(spatialSearch, quad.fourth, direction);
                        }
                    }
                    else {
                        if (quad.first != null) {
                            this._findQuadElement(spatialSearch, quad.first, direction);
                        }
                        if (quad.second != null) {
                            this._findQuadElement(spatialSearch, quad.second, direction);
                        }
                    }
                    break;
                case "top":
                    if (quad.first != null || quad.second != null) {
                        if (quad.first != null) {
                            this._findQuadElement(spatialSearch, quad.first, direction);
                        }
                        if (quad.second != null) {
                            this._findQuadElement(spatialSearch, quad.second, direction);
                        }
                    }
                    else {
                        if (quad.third != null) {
                            this._findQuadElement(spatialSearch, quad.third, direction);
                        }
                        if (quad.fourth != null) {
                            this._findQuadElement(spatialSearch, quad.fourth, direction);
                        }
                    }
                    break;
                case "left":
                    if (quad.first != null || quad.third != null) {
                        if (quad.first != null) {
                            this._findQuadElement(spatialSearch, quad.first, direction);
                        }
                        if (quad.third != null) {
                            this._findQuadElement(spatialSearch, quad.third, direction);
                        }
                    }
                    else {
                        if (quad.second != null) {
                            this._findQuadElement(spatialSearch, quad.second, direction);
                        }
                        if (quad.fourth != null) {
                            this._findQuadElement(spatialSearch, quad.fourth, direction);
                        }
                    }
                    break;
                case "right":
                    if (quad.second != null || quad.fourth != null) {
                        if (quad.second != null) {
                            this._findQuadElement(spatialSearch, quad.second, direction);
                        }
                        if (quad.fourth != null) {
                            this._findQuadElement(spatialSearch, quad.fourth, direction);
                        }
                    }
                    else {
                        if (quad.third != null) {
                            this._findQuadElement(spatialSearch, quad.third, direction);
                        }
                        if (quad.first != null) {
                            this._findQuadElement(spatialSearch, quad.first, direction);
                        }
                    }

                    break;
            }

            var bounds;
            for (var i = 0; i < quad.objects.length; i++) {
                bounds = ej.datavisualization.Diagram.Util.bounds(quad.objects[i]);
                if (direction === "bottom" && (spatialSearch.pageBottom <= bounds.bottom || spatialSearch.pageBottom == null)) {
                    spatialSearch.pageBottom = bounds.bottom;
                    spatialSearch.bottomElement = quad.objects[i];
                }
                else if (direction === "top" && (spatialSearch.pageTop >= bounds.top || spatialSearch.pageTop == null)) {
                    spatialSearch.pageTop = bounds.top;
                    spatialSearch.topElement = quad.objects[i];
                }
                else if (direction === "left" && (spatialSearch.pageLeft >= bounds.left || spatialSearch.pageLeft == null)) {
                    spatialSearch.pageLeft = bounds.left;
                    spatialSearch.leftElement = quad.objects[i];
                }
                else if (direction === "right" && (spatialSearch.pageRight <= bounds.right || spatialSearch.pageRight == null)) {
                    spatialSearch.pageRight = bounds.right;
                    spatialSearch.rightElement = quad.objects[i];
                }
            }
        },
        _initializeNodes: function (diagram, spatialSearch) {
            var nodes = diagram.model.nodes;
            for (var i = 0; i < nodes.length; i++) {
                var node = nodes[i];
                if (!node.isGroup) {
                    this._updateQuad(diagram, spatialSearch, node);
                }
            }
        },

        _initializeConnectors: function (diagram, spatialSearch) {
            var connectors = diagram.model.connectors;
            for (var i = 0; i < connectors.length; i++) {
                this._updateQuad(diagram, spatialSearch, connectors[i]);
            }
        },

        _updateQuad: function (diagram, spatialSearch, node, layoutinAction) {
            this._setCurrentNode(spatialSearch, node);
            var bounds = ej.datavisualization.Diagram.Util.bounds(node);
            var quad = spatialSearch.quadTable[node.name];
            if (quad) {
                if (node.line) {
                    this._removeFromaQuad(spatialSearch, quad, node);
                    this._addIntoAQuad(spatialSearch);
                }
                else if (!this._isContained(spatialSearch, quad)) {
                    this._removeFromaQuad(spatialSearch, quad, node);
                    this._addIntoAQuad(spatialSearch);
                }
            }
            else {
                if (!spatialSearch.parentQuad)
                    spatialSearch.parentQuad = ej.datavisualization.Diagram.Quad(0, 0, 200, 200);
                this._addIntoAQuad(spatialSearch);
            }
            if (!(this._isWithinPageBounds(spatialSearch, bounds) && spatialSearch.leftElement != node &&
                spatialSearch.topElement != node && spatialSearch.rightElement != node && spatialSearch.bottomElement != node)) {
                var modified = false;
                if (spatialSearch.pageLeft >= spatialSearch.childLeft || spatialSearch.pageLeft == null) {
                    spatialSearch.pageLeft = spatialSearch.childLeft;
                    spatialSearch.leftElement = node;
                    modified = true;
                }
                else if (node == spatialSearch.leftElement) {
                    spatialSearch.pageLeft = null;
                    this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "left");
                    modified = true;
                }

                if (spatialSearch.pageTop >= spatialSearch.childTop || spatialSearch.pageTop == null) {
                    spatialSearch.pageTop = spatialSearch.childTop;
                    spatialSearch.topElement = node;
                    modified = true;
                }
                else if (node == spatialSearch.topElement) {
                    spatialSearch.pageTop = null;
                    this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "top");
                    modified = true;
                }

                if (spatialSearch.pageBottom <= spatialSearch.childBottom || spatialSearch.pageBottom == null) {
                    modified = true;
                    spatialSearch.pageBottom = spatialSearch.childBottom;
                    spatialSearch.bottomElement = node;
                }
                else if (node == spatialSearch.bottomElement) {
                    spatialSearch.pageBottom = null;
                    this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "bottom");
                    modified = true;
                }

                if (spatialSearch.pageRight <= spatialSearch.childRight || spatialSearch.pageRight == null) {
                    spatialSearch.pageRight = spatialSearch.childRight;
                    spatialSearch.rightElement = node;
                    modified = true;
                }
                else if (node == spatialSearch.rightElement) {
                    spatialSearch.pageRight = null;
                    this._findQuadElement(spatialSearch, spatialSearch.parentQuad, "right");
                    modified = true;
                }
            }
            if (modified) {
                diagram._views.forEach(function (viewid) {
                    var view = diagram._views[viewid];
                    if (view.type == "overview") {
                        var ovw = $("#" + viewid).ejOverview("instance");
                        if (ovw)
                            ovw._updateOverview(view);
                    }
                });
                if (!layoutinAction && diagram._pageBackgroundLayer) {
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
            }
        },
        _removeFromaQuad: function (spatialSearch, quad, node) {
            if (quad) {
                var index = quad.objects.indexOf(node);
                quad.objects.splice(index, 1);
                this._update(quad);
                delete spatialSearch.quadTable[node.name];
            }
        }

    };

    ej.datavisualization.Diagram.Quad = function (left, top, width, height, parent) {
        return {
            left: left, top: top, width: width, height: height, parent: parent,
            first: null, second: null, third: null, fourth: null, objects: []
        };
    }
    ej.datavisualization.Diagram.SpatialSearch = function () {
        return {
            pageLeft: null, pageRight: null, pageTop: null, pageBottom: null,
            topElement: null, bottomElement: null, rightElement: null, leftElement: null,
            childLeft: null, childTop: null, childRight: null, childBottom: null, childNode: null,
            quads: null, parentQuad: ej.datavisualization.Diagram.Quad(0, 0, 200, 200), quadTable: {}
        };
    };
    //#endregion

})(jQuery, Syncfusion);;